# localization

# region common
l_on = {
    'ru': "вкл",
    'en': "incl",
    'es': "incluido",
    'fr': "inclus",
    'zh': "包括",
    'ar': "بما في ذلك",
}
l_off = {
    'ru': "выкл",
    'en': "off",
    'es': "apagado",
    'fr': "désactivé",
    'zh': "离开",
    'ar': "عن",
}
l_yes = {
    'ru': "да",
    'en': "yes",
    'es': "sí",
    'fr': "oui",
    'zh': "是的",
    'ar': "نعم",
}
l_no = {
    'ru': "нет",
    'en': "no",
    'es': "no",
    'fr': "non",
    'zh': "不",
    'ar': "لا",
}
l_yes_percent = {
    'ru': "👩🏽‍💻 Да, 100%",
    'en': "👩🏽‍💻 Yes, 100%",
    'es': "👩🏽‍💻 Sí, 100%",
    'fr': "👩🏽‍💻 Oui, 100%",
    'zh': "👩🏽‍💻 是的，100%",
    'ar': "👩🏽‍💻 نعم ، 100٪",
}
l_no_percent = {
    'ru': "👩🏽‍💻 Нет, 0%",
    'en': "👩🏽‍💻 No, 0%",
    'es': "👩🏽‍💻 No, 0%",
    'fr': "👩🏽‍💻 Non, 0%",
    'zh': "👩🏽‍💻 没有，0%",
    'ar': "👩🏽‍💻 لا ، 0٪",
}
l_creturn_text = {
    'ru': "✖️ <b>Сбросить</b> настройки по умолчанию (до рекомендуемых) для [<b>{0}</b>]?",
    'en': "✖️ Reset default settings (recommended) for channel [<b>{0}</b>]?",
    'es': "✖️ ¿Restablecer la configuración predeterminada (recomendado) para el canal [<b>{0}</b>]?",
    'fr': "✖️ Réinitialiser les paramètres par défaut (recommandé) pour la chaîne [<b>{0}</b>] ?",
    'zh': "✖️ 重置频道 [<b>{0}</b>] 的默认设置（推荐）？",
    'ar': "✖️ إعادة تعيين الإعدادات الافتراضية (مستحسن) للقناة [<b>{0}</b>]؟",
}
l_all_ans = {
    'ru': "все",
    'en': "all",
    'es': "todo",
    'fr': "tous",
    'zh': "全部",
    'ar': "الجميع",
}
l_menu = {
    'ru': "🔙 Меню",
    'en': "🔙 Menu",
    'es': "🔙 Menú",
    'fr': "🔙 Menu",
    'zh': "🔙 菜单",
    'ar': "🔙 القائمة",
}
l_back = {
    'ru': "🔙 Назад",
    'en': "🔙 Back",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
l_forever = {
    'ru': "навсегда",
    'en': "forever",
    'es': "para siempre",
    'fr': "pour toujours",
    'zh': "永远",
    'ar': "للأبد",
}
l_members = {
    'ru': "участ.",
    'en': "participation.",
    'es': "participación.",
    'fr': "participation.",
    'zh': "参与。",
    'ar': "مشاركة.",
}
l_add = {
    'ru': "✅ Добавить",
    'en': "✅ Add",
    'es': "✅ Añadir",
    'fr': "✅ Ajouter",
    'zh': "✅ 添加",
    'ar': "✅ أضف",
}
l_remove = {
    'ru': "🚫 Удалить",
    'en': "🚫 Remove",
    'es': "🚫 Eliminar",
    'fr': "🚫 Supprimer",
    'zh': "🚫 移除",
    'ar': "🚫 إزالة",
}

l_choose_direction = {
    'ru': "👇🏽 <b>Выбери</b> направление",
    'en': "👇🏽 <b>Choose</b> a direction",
    'es': "👇🏽 <b>Elige</b> una dirección",
    'fr': "👇🏽 <b>Choisissez</b> une direction",
    'zh': "👇🏽<b>选择</b>方向",
    'ar': "👇🏽 <b>اختر</b> الاتجاه",
}
l_about = {
    'ru': "<b>👩🏽‍💻 Ferey projects</b>:\n\n▪️projects: @FereyDemoBot\n▪️constructor: @FereyBotBot\n▪️private_posts: @FereyPostBot\n▪️public_media: @FereyMediaBot\n▪️administration: @FereyChannelBot\n▪️moderation: @FereyGroupBot\n▪️search: @FereyFindBot\n▪️target: @FereyTargetBot\n▪️tools: @FereyToolsBot\n▪️vpn: @FereyVPNBot\n▪️ai: @FereyAIBot\n▪️automation: @FereyUserBot\n▪️vacancies: @FereyWorkBot\n▪️advert: @FereyAdsBot",
    'en': "<b>🦋 SocialMedia auto funnels &amp; chatbots</b> for:\n\n▪️target: @ferey_send_bot\n▪️search: @ferey_find_bot\n▪️posts: @ferey_post_bot\n▪️auto-replies: @ferey_user_bot\n▪️channel: @ferey_chat_bot\n▪️ channel: @ferey_chn_bot\n▪️ads: @ferey_advert_bot\n\n❗️all bots are public & public",
    'es': "<b>🦋 Embudos automáticos de redes sociales y chatbots</b> para:\n\n▪️objetivo: @ferey_send_bot\n▪️búsqueda: @ferey_find_bot\n▪️publicaciones: @ferey_post_bot\n▪️respuestas automáticas: @ferey_user_bot\n▪️canal: @ferey_chat_bot\n▪️ canal: @ferey_chn_bot\n▪️anuncios: @ferey_advert_bot\n\n❗️todos los bots son públicos y públicos",
    'fr': "<b>🦋 Entonnoirs automatiques et chatbots des médias sociaux</b> pour :\n\n▪️cible : @ferey_send_bot\n▪️recherche : @ferey_find_bot\n▪️messages : @ferey_post_bot\n▪️réponses automatiques : @ferey_user_bot\n▪️canal : @ferey_chat_bot\n▪️ chaîne : @ferey_chn_bot\n▪️annonces : @ferey_advert_bot\n\n❗️tous les bots sont publics et publics",
    'zh': "<b>🦋 社交媒体自动漏斗和聊天机器人</b>：\n\n▪️目标： @ferey_send_bot\n▪️搜索： @ferey_find_bot\n▪️帖子： @ferey_post_bot\n▪️自动回复： @ferey_user_bot\n▪️频道： @ferey_chat_bot\n▪️频道： @ferey_chn_bot\n▪️广告： @ferey_advert_bot\n\n❗️所有机器人都是公开的和公开的",
    'ar': "<b>🦋 مسارات تحويل SocialMedia التلقائية وروبوتات الدردشة</b> من أجل:\n\n▪️ الهدف: @ferey_send_bot\n▪️search: @ferey_find_bot\n▪️ المشاركات: @ferey_post_bot\n▪️auto-response: @ferey_user_bot\n▪️ القناة: @ferey_chat_bot القناة: @ferey_chn_bot\n▪️ads: @ferey_advert_bot\n\n❗️ جميع البوتات عامة وعامة",
}
l_subscribe = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную <i>подписку</i>\n\n¹ на @{0}-бота [{1} ₽]\n▪️ отсутствие рекламы\n▪️ творческие задания\n² Подписка на <u>всех</u> ботов [{2} ₽]",
    'en': "👩🏽‍💻 <b>Sign up for</b> a monthly\n\n¹ <i>subscription</i> to @{0}-bot [{1} ₽]\n▪️ no ads\n▪️ creative tasks\n² Subscribe to <u>all</u> bots [{2} ₽]",
    'es': "👩🏽‍💻 <b>Regístrese para obtener</b> una\n\n¹ <i>suscripción</i> mensual a @{0}-bot [{1} ₽]\n▪️ sin anuncios\n▪️ tareas creativas\n² Suscríbase a <u>todos</u> los bots [{2} ₽]",
    'fr': "👩🏽‍💻 <b>Inscrivez-vous pour</b> un <i>abonnement</i>\n\n¹ mensuel à @{0}-bot [{1} ₽]\n▪️ pas de publicité\n▪️ tâches créatives\n² Abonnez-vous à <u>tous</u> les bots [{2} ₽]",
    'zh': "👩🏽‍💻<b>注册</b>每月\n\n¹<i>订阅</i>@{0}-bot [{1} ₽]\n▪️ 无广告\n▪️ 创意任务\n² 订阅<u>所有</u>机器人 [{2} ₽]",
    'ar': "👩🏽‍💻 <b>اشترك للحصول على</b> <i>اشتراك</i> شهري\n\n¹ في @ {0} -bot [{1} ₽]\n▪️ بلا إعلانات\n▪️ مهام إبداعية\n² اشترك في <u>جميع</u> برامج التتبُّع [{2} ₽]",
}
l_subscribe_btn = {
    'ru': "👩🏽‍💻 Я подписался",
    'en': "👩🏽‍💻 I subscribed",
    'es': "👩🏽‍💻 Me suscribí",
    'fr': "👩🏽‍💻 je me suis abonné",
    'zh': "👩🏽‍💻 我订阅了",
    'ar': "👩🏽‍💻 لقد اشتركت",
}
l_language_get = {
    'ru': "🌏 <b>Выбери</b> один из доступных языков",
    'en': "🌏 <b>Choose</b> one of the available languages",
    'es': "🌏 <b>Elige</b> uno de los idiomas disponibles",
    'fr': "🌏 <b>Choisissez</b> l'une des langues disponibles",
    'zh': "🌏<b>选择</b>一种可用的语言",
    'ar': "🌏 <b>اختر</b> إحدى اللغات المتاحة",
}
l_language_set = {
    'ru': "{0} Текущий язык: {1}",
    'en': "{0} Current language: {1}",
    'es': "{0} Idioma actual: {1}",
    'fr': "{0} Langue actuelle : {1}",
    'zh': "{0} 当前语言：{1}",
    'ar': "{0} اللغة الحالية: {1}",
}
l_ferey_like = {
    'ru': "💔 Like",
    'en': "💔 Like",
    'es': "💔 Me gusta",
    'fr': "💔 J'aime",
    'zh': "💔 喜欢",
    'ar': "💔 مثل",
}
# endregion


# region post
l_post_text = {
    'ru': "✏️ 1. <b>Введи текст</b> для нового поста (не забудь использовать <i>форматирование</i>)\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 1. <b>Text</b> me for a new post (don&#x27;t forget to use <i>formatting</i> )\n\n( <i>or press &quot;➡️️/Next&quot; to skip this step</i> )",
    'es': "✏️ 1. <b>Envíame un mensaje de texto</b> para una nueva publicación (no olvides usar <i>formato</i> )\n\n( <i>o presiona &quot;➡️️/Siguiente&quot; para omitir este paso</i> )",
    'fr': "✏️ 1. <b>Envoyez</b> -moi un SMS pour un nouveau message (n&#x27;oubliez pas d&#x27;utiliser <i>le formatage</i> )\n\n( <i>ou appuyez sur &quot;➡️️/Suivant&quot; pour ignorer cette étape</i> )",
    'zh': "✏️ 1.<b>发短信</b>给我（不要忘记使用<i>格式</i>）\n\n（<i>或按“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرسل</b> لي رسالة نصية لمنشور جديد (لا تنس استخدام <i>التنسيق</i> )\n\n( <i>أو اضغط على &quot;➡️️ / التالي&quot; لتخطي هذه الخطوة</i> )",
}
l_post_text_limit = {
    'ru': "❗️ <b>Количество символов</b> текста (<i>включая форматирование</i>): <u>{0}</u> больше допустимых 1024",
    'en': "❗️ Number of <b>characters</b> of text ( <i>including formatting</i> ): <u>{0}</u> more than allowed 1024",
    'es': "❗️ Número de <b>caracteres</b> de texto ( <i>incluido el formato</i> ): <u>{0}</u> más de los permitidos 1024",
    'fr': "❗️ Nombre de <b>caractères</b> de texte ( <i>y compris le formatage</i> ) : <u>{0}</u> plus que autorisé 1024",
    'zh': "❗️ 文本<b>字符</b>数（<i>包括格式</i>）： <u>{0}</u>超过允许的 1024",
    'ar': "❗️ عدد <b>أحرف</b> النص ( <i>بما في ذلك التنسيق</i> ): <u>{0}</u> أكثر من العدد المسموح به وهو 1024",
}
l_post_text_empty = {
    'ru': "❗️ Пост пустой, попробуй сначала\n\n{0}",
    'en': "❗️ post is empty, try again\n\n{0}",
    'es': "❗️ la publicación está vacía, inténtalo de nuevo\n\n{0}",
    'fr': "❗️ la publication est vide, réessayez\n\n{0}",
    'zh': "❗️ 帖子为空，请重试\n\n{0}",
    'ar': "❗️ المنشور فارغ ، حاول مرة أخرى\n\n{0}",
}
l_post_edit = {
    'ru': "✏️ 1. <b>Введи измененный текст</b> для текущего поста\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 1. Submit the modified <b>text</b> for the current post\n\n( <i>or press &quot;➡️️/Next&quot; to skip this step</i> )",
    'es': "✏️ 1. Envíe el <b>texto</b> modificado para la publicación actual\n\n( <i>o presione &quot;➡️️/Siguiente&quot; para omitir este paso</i> )",
    'fr': "✏️ 1. Soumettez le <b>texte</b> modifié pour le message actuel\n\n( <i>ou appuyez sur &quot;➡️️/Suivant&quot; pour ignorer cette étape</i> )",
    'zh': "✏️ 1.提交当前帖子的修改<b>文本</b>\n\n（<i>或按“➡️️/Next”跳过此步骤</i>）",
    'ar': "✏️ 1. قم بإرسال <b>النص</b> المعدل للنشر الحالي\n\n( <i>أو اضغط على &quot;➡️️ / التالي&quot; لتخطي هذه الخطوة</i> )",
}
l_post_media = {
    'ru': "✏️ 2. <b>Прикрепи медиа</b> контент: фото/гиф/видео/аудио/документ/стикер или запиши голосовое/видео-заметку в кружке\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 2. Attach <b>media</b> content: photo/gif/video/audio/document/sticker or write a voice/video note in a circle\n\n( <i>or press &quot;➡️️/Next&quot; to skip this step</i> )",
    'es': "✏️ 2. Adjunte contenido <b>multimedia</b> : foto/gif/video/audio/documento/pegatina o escriba una nota de voz/video en un círculo\n\n( <i>o presione &quot;➡️️/Siguiente&quot; para omitir este paso</i> )",
    'fr': "✏️ 2. Joignez du contenu <b>multimédia</b> : photo/gif/vidéo/audio/document/autocollant ou écrivez une note vocale/vidéo dans un cercle\n\n( <i>ou appuyez sur &quot;➡️️/Suivant&quot; pour ignorer cette étape</i> )",
    'zh': "✏️ 2.附上<b>媒体</b>内容：照片/gif/视频/音频/文档/贴纸或在圈内写语音/视频备注\n\n（<i>或按“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 2. أرفق محتوى <b>وسائط</b> : صورة / gif / فيديو / صوت / مستند / ملصق أو اكتب ملاحظة صوتية / فيديو في دائرة\n\n( <i>أو اضغط على &quot;➡️️ / التالي&quot; لتخطي هذه الخطوة</i> )",
}
l_post_media_wait = {
    'ru': "👩🏽‍💻 <b>Обработка</b> {0}..\n#длительность {1}мин",
    'en': "👩🏽‍💻 Wait for processing {0}..\n#duration {1}min",
    'es': "👩🏽‍💻 Espere a que se procese {0}..\n#duration {1}min",
    'fr': "👩🏽‍💻 Attendez le traitement {0}..\n#duration {1}min",
    'zh': "👩🏽‍💻 等待处理 {0}..\n#duration {1}min",
    'ar': "👩🏽‍💻 انتظر المعالجة {0} ..\n# مدة {1} دقيقة",
}
l_post_media_toobig = {
    'ru': "👩🏽‍💻 Файл больше 20 Мб, загрузи меньший обьем",
    'en': "👩🏽‍💻 The file is larger than 20 MB, please upload a smaller size",
    'es': "👩🏽‍💻 El archivo tiene más de 20 MB, cargue un tamaño más pequeño",
    'fr': "👩🏽‍💻 Le fichier fait plus de 20 Mo, veuillez télécharger une taille plus petite",
    'zh': "👩🏽‍💻文件大于20MB，请上传较小的文件",
    'ar': "👩🏽‍💻 الملف أكبر من 20 ميغا بايت ، يرجى تحميل حجم أصغر",
}
l_post_tgph = {
    'ru': "✏️ *2. Использовать загруженный <b>media</b>-контент в виде <u>предпросмотра</u> внизу поста (работает только с <i>jpg|png|gif|mp4</i>-файлами до 5Mb)?\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ *2. Use uploaded <b>media</b> content as <u>a preview</u> at the bottom of the post (only works with <i>jpg|png|gif|mp4</i> files up to 5Mb)?\n\n( <i>or press &quot;➡️️/Next&quot; to skip this step</i> )",
    'es': "✏️ *2. ¿Usar el contenido <b>multimedia</b> cargado como <u>una vista previa</u> en la parte inferior de la publicación (solo funciona con archivos <i>jpg|png|gif|mp4</i> de hasta 5 Mb)?\n\n( <i>o presione &quot;➡️️/Siguiente&quot; para omitir este paso</i> )",
    'fr': "✏️ *2. Utiliser le contenu <b>multimédia</b> téléchargé comme <u>aperçu</u> au bas de la publication (fonctionne uniquement avec les fichiers <i>jpg|png|gif|mp4</i> jusqu&#x27;à 5 Mo) ?\n\n( <i>ou appuyez sur &quot;➡️️/Suivant&quot; pour ignorer cette étape</i> )",
    'zh': "✏️ *2。使用上传的<b>媒体</b>内容作为帖子底部的<u>预览</u>（仅适用于最大 5Mb 的<i>jpg|png|gif|mp4</i>文件）？\n\n（<i>或按“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ * 2. استخدم محتوى <b>الوسائط</b> الذي تم تحميله <u>كمعاينة</u> أسفل المنشور (يعمل فقط مع ملفات <i>jpg | png | gif | mp4</i> حتى 5 ميغا بايت)؟\n\n( <i>أو اضغط على &quot;➡️️ / التالي&quot; لتخطي هذه الخطوة</i> )",
}
l_post_tgph_yes = {
    'ru': "✅ Да",
    'en': "✅ Yes",
    'es': "✅ Sí",
    'fr': "✅ Oui",
    'zh': "✅ 是的",
    'ar': "✅ نعم",
}
l_post_tgph_no = {
    'ru': "☑️ Нет",
    'en': "☑️ No",
    'es': "☑️No",
    'fr': "☑️ Non",
    'zh': "☑️没有",
    'ar': "☑️ لا",
}
l_post_button = {
    'ru': "✏️ 3. <b>Введи названия</b> для кнопок и <b>ссылки</b> в формате (одну или несколько; кликни на образец ниже, чтобы скопировать):\n\n<code>[🐳 Link | https://t.me/XXXXX]</code>\n\nили\n\n<code>[❤️ Интересно][💔 Не пиши]</code>\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 3. Submit button <b>names</b> and <b>links</b> in the format (one or more; click on the sample below to copy):\n\n<code>[🐳 Link | https://t.me/XXXXX]</code>\n\nor\n\n<code>[❤️ Nice][💔 Don't disturb]</code>\n\n( <i>or press &quot;➡️️/Next&quot; to skip this step</i> )",
    'es': "✏️ 3. Envíe <b>nombres</b> de botones y <b>enlaces</b> en el formato (uno o más; haga clic en la muestra a continuación para copiar):\n\n<code>[🐳 Link | https://t.me/XXXXX]</code>\n\nor\n\n<code>[❤️ Nice][💔 Don't disturb]</code>\n\n( <i>o presiona &quot;➡️️/Siguiente&quot; para omitir este paso</i> )",
    'fr': "✏️ 3. Soumettez <b>les noms</b> des boutons et <b>les liens</b> au format (un ou plusieurs ; cliquez sur l&#x27;exemple ci-dessous pour le copier) :\n\n<code>[🐳 Link | https://t.me/XXXXX]</code>\n\nor\n\n<code>[❤️ Nice][💔 Don't disturb]</code>\n\n( <i>ou appuyez sur &quot;➡️️/Suivant&quot; pour ignorer cette étape</i> )",
    'zh': "✏️ 3. 提交按钮<b>名称</b>和<b>链接</b>格式（一个或多个；点击下方示例复制）：\n\n<code>[🐳 Link | https://t.me/XXXXX]</code>\n\nor\n\n<code>[❤️ Nice][💔 Don't disturb]</code>\n\n（<i>或按“➡️️/Next”跳过此步骤</i>）",
    'ar': "✏️ 3. إرسال <b>أسماء</b> الأزرار <b>والروابط</b> بالتنسيق (واحد أو أكثر ؛ انقر فوق النموذج أدناه لنسخه):\n\n<code>[🐳 Link | https://t.me/XXXXX]</code>\n\ ولا\n\n<code>[❤️ Nice][💔 Don't disturb]</code>\n\n( <i>أو اضغط على &quot;➡️️ / التالي&quot; لتخطي هذه الخطوة</i> )",
}
l_post_button_urlinvalid = {
    'ru': "🔗 Ссылка {0} не действительна",
    'en': "🔗 Link {0} is invalid",
    'es': "🔗 El enlace {0} no es válido",
    'fr': "🔗 Le lien {0} est invalide",
    'zh': "🔗 链接 {0} 无效",
    'ar': "🔗 الرابط {0} غير صالح",
}
l_post_pin = {
    'ru': "✏️ 3. Закреплять (<b>pin</b>) сообщение сверху экрана: <code>да</code> | <code>нет</code>?\n\n(<i>или нажми «➡️️/Next», чтобы <u>не закреплять</u> сообщение</i>)",
    'en': "✏️ 3. Pin ( <b>pin</b> ) the message in the channel at the top of the screen: <code>да</code> | <code>нет</code> ?\n\n( <i>or press &quot;➡️️/Next&quot; to <u>not pin</u> the message</i> )",
    'es': "✏️ 3. Pin ( <b>pin</b> ) el mensaje en el canal en la parte superior de la pantalla: <code>да</code> | <code>нет</code> ?\n\n( <i>o presione &quot;➡️️/Siguiente&quot; para <u>no fijar</u> el mensaje</i> )",
    'fr': "✏️ 3. Epingler ( <b>épingler</b> ) le message dans la chaîne en haut de l&#x27;écran : <code>да</code> | <code>нет</code> ?\n\n( <i>ou appuyez sur &quot;➡️️/Suivant&quot; pour <u>ne pas épingler</u> le message</i> )",
    'zh': "✏️ 3. 置顶（ <b>pin</b> ）屏幕上方频道中的消息： <code>да</code> | <code>нет</code> ？\n\n（<i>或按“➡️️/下一步”<u>不固定</u>消息</i>）",
    'ar': "✏️ 3. ثبّت ( <b>تثبيت</b> ) الرسالة في القناة أعلى الشاشة: <code>да</code> | <code>нет</code> ؟\n\n( <i>أو اضغط على &quot;➡️️ / التالي&quot; لعدم <u>تثبيت</u> الرسالة</i> )",
}
l_post_date = {
    'ru': "✏️ 4. <b>Выбери дату</b> на календаре\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 4. Select a date on the calendar\n\n( <i>or press &quot;➡️️/Next&quot; to skip this step</i> )",
    'es': "✏️ 4. Selecciona una fecha en el calendario\n\n( <i>o presiona &quot;➡️️/Siguiente&quot; para omitir este paso</i> )",
    'fr': "✏️ 4. Sélectionnez une date sur le calendrier\n\n( <i>ou appuyez sur &quot;➡️️/Suivant&quot; pour ignorer cette étape</i> )",
    'zh': "✏️ 4. 在日历上选择一个日期\n\n（<i>或按“➡️️/Next”跳过此步骤</i>）",
    'ar': "✏️ 4. حدد تاريخًا في التقويم\n\n( <i>أو اضغط على &quot;➡️️ / التالي&quot; لتخطي هذه الخطوة</i> )",
}
l_post_finish = {
    'ru': "✅ <b>Пост готов</b>\n\n<i>Нажми «➡️️/Next», чтобы подтвердить, а затем на кнопку 🔗 Опубликовать</i>",
    'en': "✅ <b>Post is ready</b>\n\n<i>Press &quot;➡️️/Next&quot; to confirm, and then press the button 🔗 Publish</i>",
    'es': "✅ <b>La publicación está lista</b>\n\n<i>Presiona &quot;➡️️/Siguiente&quot; para confirmar y luego presiona el botón 🔗 Publicar</i>",
    'fr': "✅ <b>La publication est prête</b>\n\n<i>Appuyez sur &quot;➡️️/Suivant&quot; pour confirmer, puis appuyez sur le bouton 🔗 Publier</i>",
    'zh': "✅<b>发布准备就绪</b>\n\n<i>按“➡️️/Next”确认，然后按按钮🔗发布</i>",
    'ar': "✅ <b>النشر جاهز</b>\n\n<i>اضغط على &quot;➡️️ / التالي&quot; للتأكيد ، ثم اضغط على الزر 🔗 نشر</i>",
}
l_switch_pm_text = {
    'ru': "🔗 Создать пост с кнопкой",
    'en': "🔗 Create post with button",
    'es': "🔗 Crear publicación con botón",
    'fr': "🔗 Créer un message avec le bouton",
    'zh': "🔗 使用按钮创建帖子",
    'ar': "🔗 إنشاء وظيفة مع زر",
}
l_post_new = {
    'ru': "⛰ Создать",
    'en': "⛰ Create",
    'es': "⛰ Crear",
    'fr': "⛰ Créer",
    'zh': "⛰ 创建",
    'ar': "⛰ خلق",
}
l_post_delete = {
    'ru': "🚫 Удалить",
    'en': "🚫 Delete",
    'es': "🚫 Eliminar",
    'fr': "🚫 Supprimer",
    'zh': "🚫 删除",
    'ar': "🚫 حذف",
}
l_post_change = {
    'ru': "♻️ Изменить",
    'en': "♻️ Change",
    'es': "♻️ Cambiar",
    'fr': "♻️ Changer",
    'zh': "♻️改变",
    'ar': "♻️ التغيير",
}
l_post_creation = {
    'ru': "<b>Дата создания</b>",
    'en': "<b>date of creation</b>",
    'es': "<b>fecha de creación</b>",
    'fr': "<b>date de création</b>",
    'zh': "<b>创建日期</b>",
    'ar': "<b>تاريخ الخلق</b>",
}

l_post_publish = {
    'ru': "🔗 Опубликовать",
    'en': "🔗 Post",
    'es': "🔗 Publicar",
    'fr': "🔗 Publier",
    'zh': "🔗 发布",
    'ar': "🔗 مشاركة",
}
l_post_pub = {
    'ru': "👩🏽‍💻 Пост опубликован",
    'en': "👩🏽‍💻 Post published in the channel",
    'es': "👩🏽‍💻 Post publicado en el canal",
    'fr': "👩🏽‍💻 Message publié sur la chaîne",
    'zh': "👩🏽‍💻 在频道中发布的帖子",
    'ar': "👩🏽‍💻 منشور منشور في القناة",
}
l_post_btn_answer = {
    'ru': "✅ Пользователь <b>{0}</b> (username={1}, id=<code>{2}</code>) <i>нажал</i> на [<b>{3}</b>] в посте #<u>{4}</u>",
    'en': "✅ User <b>{0}</b> (username={1}, id= <code>{2}</code> ) <i>clicked</i> on [<b>{3}</b>] in post # <u>{4}</u>",
    'es': "✅ El usuario <b>{0}</b> (username={1}, id= <code>{2}</code> ) <i>hizo clic</i> en [<b>{3}</b>] en la publicación n.º <u>{4}</u>",
    'fr': "✅ L'utilisateur <b>{0}</b> (username={1}, id= <code>{2}</code> ) <i>a cliqué</i> sur [<b>{3}</b>] dans le post # <u>{4}</u>",
    'zh': "✅ 用户<b>{0}</b> （用户名 = {1}，id = <code>{2}</code> ）在帖子 # <u>{4}</u>中<i>点击了</i>[<b>{3}</b>]",
    'ar': "✅ المستخدم <b>{0}</b> (اسم المستخدم = {1} ، المعرف = <code>{2}</code> ) <i>نقر</i> على [<b>{3}</b>] في المشاركة رقم <u>{4}</u>",
}
l_post_datetime = {
    'ru': "<b>Дата публикации</b>",
    'en': "<b>Publication date</b>",
    'es': "<b>Fecha de publicación</b>",
    'fr': "<b>Date de publication</b>",
    'zh': "<b>发布日期</b>",
    'ar': "<b>تاريخ النشر</b>",
}
l_post_preview = {
    'ru': "<b>Превью</b>",
    'en': "<b>Preview</b>",
    'es': "<b>Avance</b>",
    'fr': "<b>Aperçu</b>",
    'zh': "<b>预览</b>",
    'ar': "<b>معاينة</b>",
}
l_post_buttons = {
    'ru': "<b>Кнопки</b>",
    'en': "<b>Buttons</b>",
    'es': "<b>Botones</b>",
    'fr': "<b>Boutons</b>",
    'zh': "<b>纽扣</b>",
    'ar': "<b>أزرار</b>",
}
l_post_pins = {
    'ru': "<b>Закреп</b>",
    'en': "<b>Fix</b>",
    'es': "<b>Arreglar</b>",
    'fr': "<b>Réparer</b>",
    'zh': "<b>使固定</b>",
    'ar': "<b>يصلح</b>",
}

l_btn = {
    'ru': "кнопки",
    'en': "buttons",
    'es': "botones",
    'fr': "boutons",
    'zh': "纽扣",
    'ar': "أزرار",
}
l_pin = {
    'ru': "закреп",
    'en': "fixed",
    'es': "fijado",
    'fr': "fixé",
    'zh': "固定的",
    'ar': "مُثَبَّت",
}
l_silence = {
    'ru': "тихо",
    'en': "quiet",
    'es': "tranquilo",
    'fr': "calme",
    'zh': "安静的",
    'ar': "هادئ",
}
l_gallery = {
    'ru': "галерея",
    'en': "gallery",
    'es': "galería",
    'fr': "galerie",
    'zh': "画廊",
    'ar': "صالة عرض",
}
l_preview = {
    'ru': "превью",
    'en': "preview",
    'es': "avance",
    'fr': "aperçu",
    'zh': "预览",
    'ar': "معاينة",
}
l_spoiler = {
    'ru': "спойлер",
    'en': "spoiler",
    'es': "revelación",
    'fr': "divulgacher",
    'zh': "剧透",
    'ar': "المفسد",
}
l_buttons_text = {
    'ru': "👩🏽‍💻 Режим [кнопки] доступен, если создана хотя бы 1 кнопка при создании поста",
    'en': "👩🏽‍💻 [Buttons] mode is available if at least 1 button is created when creating a post",
    'es': "👩🏽‍💻 El modo [Botones] está disponible si se crea al menos 1 botón al crear una publicación",
    'fr': "👩🏽‍💻 Le mode [Boutons] est disponible si au moins 1 bouton est créé lors de la création d'une publication",
    'zh': "👩🏽‍💻 如果在创建帖子时至少创建了 1 个按钮，则可以使用 [按钮] 模式",
    'ar': "يكون وضع [الأزرار] متاحًا إذا تم إنشاء زر واحد على الأقل عند إنشاء منشور",
}
l_preview_text = {
    'ru': "👩🏽‍💻 Режим [превью] используется с одиночными jpg|png|gif|mp4-файлами до 5Mb",
    'en': "👩🏽‍💻 The [preview] mode is used with single jpg|png|gif|mp4 files up to 5Mb",
    'es': "👩🏽‍💻 El modo [vista previa] se usa con archivos individuales jpg|png|gif|mp4 de hasta 5Mb",
    'fr': "👩🏽‍💻 Le mode [aperçu] est utilisé avec des fichiers jpg|png|gif|mp4 uniques jusqu'à 5 Mo",
    'zh': "👩🏽‍💻 [预览] 模式用于最大 5Mb 的单个 jpg|png|gif|mp4 文件",
    'ar': "👩🏽‍💻 يتم استخدام وضع [المعاينة] مع ملفات jpg واحدة | png | gif | mp4 حتى 5 ميغا بايت",
}
l_gallery_text = {
    'ru': "👩🏽‍💻 Режим [галерея] доступен для 2 и более медиа файлов",
    'en': "👩🏽‍💻 [Gallery] mode is available for 2 or more media files",
    'es': "👩🏽‍💻 El modo [Galería] está disponible para 2 o más archivos multimedia",
    'fr': "👩🏽‍💻 Le mode [Galerie] est disponible pour 2 fichiers multimédias ou plus",
    'zh': "👩🏽‍💻 [图库] 模式可用于 2 个或更多媒体文件",
    'ar': "وضع [المعرض] متاح لملفات وسائط أو أكثر",
}
l_spoiler_text = {
    'ru': "👩🏽‍💻 Режим [спойлер] доступен для photo/gif/video",
    'en': "👩🏽‍💻 [spoiler] mode available for photo/gif/video",
    'es': "👩🏽‍💻 Modo [spoiler] disponible para foto/gif/video",
    'fr': "👩🏽‍💻 Mode [spoiler] disponible pour photo/gif/vidéo",
    'zh': "👩🏽‍💻 [剧透] 模式可用于照片/gif/视频",
    'ar': "👩🏽‍💻 وضع [المفسد] متاح للصور / gif / الفيديو",
}
l_post_has_restricted = {
    'ru': "👩🏽‍💻 У вас premium-аккаунт! В настройках <b>[Конфиденциальность]</b> добавь @{0} в <i>исключения</i> для <b>[Голосовые сообщения]</b>, чтобы отобразить <code>видео-заметку</code>/<code>голосовое</code>",
    'en': "👩🏽‍💻 In the <b>[Privacy]</b> settings, add @{0} to <i>the exclusions</i> for <b>[Voice Messages]</b> to display <code>видео-заметку</code> / <code>голосовое</code>",
    'es': "👩🏽‍💻 En la configuración <b>de [Privacidad]</b> , agregue @{0} a <i>las exclusiones</i> de <b>[Mensajes de voz]</b> para mostrar <code>видео-заметку</code> / <code>голосовое</code>",
    'fr': "👩🏽‍💻 Dans les paramètres <b>[Confidentialité]</b> , ajoutez @{0} aux <i>exclusions</i> pour <b>[Messages vocaux]</b> pour afficher <code>видео-заметку</code> / <code>голосовое</code>",
    'zh': "👩🏽‍💻在<b>【隐私】</b>设置中，添加@{0}到<b>【语音消息】</b>的<i>排除项</i>中，以显示<code>видео-заметку</code> / <code>голосовое</code>",
    'ar': "👩🏽‍💻 في إعدادات <b>[الخصوصية]</b> ، أضف @ {0} إلى <i>استثناءات</i> <b>[الرسائل الصوتية]</b> لعرض <code>видео-заметку</code> / <code>голосовое</code>",
}
l_post_tz = {
    'ru': "📍 <b>Часовой пояс</b> геопозиции установлен\n\n🕐 <b>Текуще</b>е время: <u>{0}</u> ({1}{2} по Гринвичу)",
    'en': "📍 Location <b>time zone</b> set\n\n🕐 Current time: <u>{0}</u> ({1}{2} GMT)",
    'es': "📍 Configuración <b>de la zona horaria</b> de la ubicación\n\n🕐 Hora actual: <u>{0}</u> ({1}{2} GMT)",
    'fr': "📍 <b>Fuseau horaire</b> de l&#x27;emplacement défini\n\n🕐 Heure actuelle : <u>{0}</u> ({1}{2} GMT)",
    'zh': "📍 位置<b>时区</b>设置\n\n🕐 当前时间： <u>{0}</u> （{1}{2} GMT）",
    'ar': "📍 تعيين <b>المنطقة الزمنية</b> للموقع\n\n🕐 الوقت الحالي: <u>{0}</u> ({1} {2} GMT)",
}
l_post_time_future = {
    'ru': "🕒 Укажи время в будущем",
    'en': "🕒 Set time in the future",
    'es': "🕒 Establecer tiempo en el futuro",
    'fr': "🕒 Réglez l'heure dans le futur",
    'zh': "🕒 设定未来的时间",
    'ar': "🕒 حدد الوقت في المستقبل",
}
l_me = {
    'ru': "👤 Себе",
    'en': "👤 Yourself",
    'es': "👤 tú mismo",
    'fr': "👤 Vous-même",
    'zh': "👤 你自己",
    'ar': "👤 نفسك",
}
l_all = {
    'ru': "👥 Всем",
    'en': "👥 Everyone",
    'es': "👥 Todos",
    'fr': "👥 Tout le monde",
    'zh': "👥 大家",
    'ar': "👥 الجميع",
}
l_channel = {
    'ru': "⛰️ Канал",
    'en': "👥 Everyone",
    'es': "👥 Todos",
    'fr': "👥 Tout le monde",
    'zh': "👥 大家",
    'ar': "👥 الجميع",
}
l_group = {
    'ru': "⛰️ Group",
    'en': "👥 Everyone",
    'es': "👥 Todos",
    'fr': "👥 Tout le monde",
    'zh': "👥 大家",
    'ar': "👥 الجميع",
}
l_bot = {
    'ru': "⛰️ Бот",
    'en': "👥 Everyone",
    'es': "👥 Todos",
    'fr': "👥 Tout le monde",
    'zh': "👥 大家",
    'ar': "👥 الجميع",
}
l_ids = {
    'ru': "🙌🏽 По id",
    'en': "🙌🏽 By id",
    'es': "🙌🏽 Por identificación",
    'fr': "🙌🏽 Par identifiant",
    'zh': "🙌🏽 通过 id",
    'ar': "🙌🏽 بالمعرف",
}
l_recipient = {
    'ru': "👩🏽‍💻 <b>Выбери</b> получателя",
    'en': "👩🏽‍💻 <b>Choose</b> recipient",
    'es': "👩🏽‍💻 <b>Elegir</b> destinatario",
    'fr': "👩🏽‍💻 <b>Choisissez</b> le destinataire",
    'zh': "👩🏽‍💻<b>选择</b>收件人",
    'ar': "👩🏽‍💻 <b>اختر</b> المستلم",
}
l_enter = {
    'ru': "👩🏽‍💻 <b>Введи</b> Ids получателей через пробельные или разделительные символы",
    'en': "👩🏽‍💻 <b>Enter</b> recipient Ids separated by spaces or separator characters",
    'es': "👩🏽‍💻 <b>Ingrese</b> las identificaciones de los destinatarios separadas por espacios o caracteres separadores",
    'fr': "👩🏽‍💻 <b>Entrez</b> les identifiants des destinataires séparés par des espaces ou des caractères de séparation",
    'zh': "👩🏽‍💻<b>输入</b>以空格或分隔符分隔的收件人 ID",
    'ar': "<b>أدخل</b> معرفات المستلمين مفصولة بمسافات أو أحرف فاصلة",
}
l_post_time_zone = {
    'ru': "📍 <b>Часовой пояс</b> геопозиции установлен\n\n🕐 <b>Текущее</b> время: <u>{0}</u> ({1}{2} по Гринвичу)",
    'en': "📍 Location <b>time zone</b> set\n\n🕐 Current time: <u>{0}</u> ({1}{2} GMT)",
    'es': "📍 Configuración <b>de la zona horaria</b> de la ubicación\n\n🕐 Hora actual: <u>{0}</u> ({1}{2} GMT)",
    'fr': "📍 <b>Fuseau horaire</b> de l&#x27;emplacement défini\n\n🕐 Heure actuelle : <u>{0}</u> ({1}{2} GMT)",
    'zh': "📍 位置<b>时区</b>设置\n\n🕐 当前时间： <u>{0}</u> （{1}{2} GMT）",
    'ar': "📍 تعيين <b>المنطقة الزمنية</b> للموقع\n\n🕐 الوقت الحالي: <u>{0}</u> ({1} {2} GMT)",
}
l_broadcast_plan = {
    'ru': "📧 <b>Готово!</b> Рассылка запланирована",
    'en': "🗝️ <b>Done!</b> Newsletter scheduled",
    'es': "🗝️ <b>Listo!</b> Boletín programado",
    'fr': "🗝️ <b>C&#x27;est fait !</b> Newsletter prévue",
    'zh': "🗝️<b>完成！</b>已安排时事通讯",
    'ar': "🗝️ <b>انتهى!</b> النشرة الإخبارية المجدولة",
}
l_broadcast_start = {
    'ru': "📧 <b>Старт</b> рассылки..\n#длительность {0}min",
    'en': "🗝️ <b>Start</b> mailing..\n#duration {0}min",
    'es': "🗝️ <b>Empezar a</b> enviar correos..\n#duración {0}min",
    'fr': "🗝️ <b>Lancer</b> l'envoi..\n#durée {0}min",
    'zh': "🗝️<b>开始</b>邮寄..\n#duration {0}min",
    'ar': "🗝️ <b>ابدأ</b> المراسلة ..\n# مدة {0} دقيقة",
}
l_broadcast_process = {
    'ru': "📧 <b>Рассылка</b>..{0}%",
    'en': "🗝️ <b>Newsletter</b> ..{0}%",
    'es': "🗝️ <b>Boletín</b> ..{0}%",
    'fr': "🗝️ <b>Newsletter</b> ..{0}%",
    'zh': "🗝️<b>时事通讯</b>..{0}%",
    'ar': "🗝️ <b>النشرة الإخبارية</b> .. {0}٪",
}
l_broadcast_finish = {
    'ru': "🏁 <b>Рассылка</b> завершена\n\n📧 Число пользователей, получивших сообщение: <u>{0}</u>",
    'en': "🏁 <b>Newsletter</b> ended\n\n🗝️ Number of users who received the message: <u>{0}</u>",
    'es': "🏁 <b>Boletín</b> finalizado\n\n🗝️ Número de usuarios que recibieron el mensaje: <u>{0}</u>",
    'fr': "🏁 <b>Newsletter</b> terminée\n\n🗝️ Nombre d&#x27;utilisateurs ayant reçu le message : <u>{0}</u>",
    'zh': "🏁<b>通讯</b>结束\n\n🗝️ 收到消息的用户数： <u>{0}</u>",
    'ar': "🏁 انتهت <b>الرسالة الإخبارية</b>\n\n🗝️ عدد المستخدمين الذين تلقوا الرسالة: <u>{0}</u>",
}

l_generate_calendar_time = {
    'ru': "🕒 <b>Отправь время</b> поста на {0} в формате <code>{1}</code>. Текущее время: <u>{2}</u> ({3} по Гринвичу)\n\n🔗 Пришли <b>геопозицию</b>, чтобы <i>автоматически</i> определить часовой пояс",
    'en': "🕒 Send <b>the time</b> of the post to {0} in the format <code>{1}</code> . Current time: <u>{2}</u> ({3} GMT)\n\n🔗 Send <b>geolocation</b> to <i>automatically</i> determine the time zone",
    'es': "🕒 Envía <b>la hora</b> de la publicación a {0} en el formato <code>{1}</code> . Hora actual: <u>{2}</u> ({3} GMT)\n\n🔗 Enviar <b>geolocalización</b> para determinar <i>automáticamente</i> la zona horaria",
    'fr': "🕒 Envoyez <b>l&#x27;heure</b> de la publication à {0} au format <code>{1}</code> . Heure actuelle : <u>{2}</u> ({3} GMT)\n\n🔗 Envoyez <b>la géolocalisation</b> pour déterminer <i>automatiquement</i> le fuseau horaire",
    'zh': "🕒 以<code>{1}</code>格式将帖子<b>时间</b>发送到 {0}。当前时间： <u>{2}</u> ({3} GMT)\n\n🔗 发送<b>地理定位</b>以<i>自动</i>确定时区",
    'ar': "🕒 أرسل <b>وقت</b> النشر إلى {0} بالتنسيق <code>{1}</code> . الوقت الحالي: <u>{2}</u> ({3} GMT)\n\n🔗 أرسل <b>الموقع الجغرافي</b> لتحديد المنطقة الزمنية <i>تلقائيًا</i>",
}
l_month_1 = {
    'ru': "Янв",
    'en': "Jan",
    'es': "Ene",
    'fr': "Jan",
    'zh': "简",
    'ar': "يناير",
}
l_month_2 = {
    'ru': "Фев",
    'en': "Feb",
    'es': "Feb",
    'fr': "Fév",
    'zh': "二月",
    'ar': "فبراير",
}
l_month_3 = {
    'ru': "Мар",
    'en': "Mar",
    'es': "Mar",
    'fr': "Mar",
    'zh': "三月",
    'ar': "مارس",
}
l_month_4 = {
    'ru': "Апр",
    'en': "Apr",
    'es': "Abr",
    'fr': "Avr",
    'zh': "4月",
    'ar': "أبريل",
}
l_month_5 = {
    'ru': "Май",
    'en': "Maybe",
    'es': "Tal vez",
    'fr': "Peut être",
    'zh': "或许",
    'ar': "ربما",
}
l_month_6 = {
    'ru': "Июн",
    'en': "June",
    'es': "Junio",
    'fr': "Juin",
    'zh': "六月",
    'ar': "يونيو",
}
l_month_7 = {
    'ru': "Июл",
    'en': "July",
    'es': "Julio",
    'fr': "Juillet",
    'zh': "七月",
    'ar': "يوليو",
}
l_month_8 = {
    'ru': "Авг",
    'en': "Aug",
    'es': "Ago",
    'fr': "Août",
    'zh': "八月",
    'ar': "أغسطس",
}
l_month_9 = {
    'ru': "Сен",
    'en': "You",
    'es': "Tú",
    'fr': "Toi",
    'zh': "你",
    'ar': "أنت",
}
l_month_10 = {
    'ru': "Окт",
    'en': "Oct",
    'es': "Oct",
    'fr': "Oct",
    'zh': "十月",
    'ar': "أكتوبر",
}
l_month_11 = {
    'ru': "Ноя",
    'en': "But I",
    'es': "Pero yo",
    'fr': "Mais je",
    'zh': "但是我",
    'ar': "لكن أنا",
}
l_month_12 = {
    'ru': "Дек",
    'en': "Dec",
    'es': "Dic",
    'fr': "Déc",
    'zh': "十二月",
    'ar': "ديسمبر",
}

l_weekday_1 = {
    'ru': "пн",
    'en': "mon",
    'es': "lun",
    'fr': "lun",
    'zh': "周一",
    'ar': "mon",
}
l_weekday_2 = {
    'ru': "вт",
    'en': "tue",
    'es': "mar",
    'fr': "mar",
    'zh': "星期二",
    'ar': "الثلاثاء",
}
l_weekday_3 = {
    'ru': "ср",
    'en': "sr",
    'es': "señor",
    'fr': "sr",
    'zh': "高级",
    'ar': "ريال سعودى",
}
l_weekday_4 = {
    'ru': "чт",
    'en': "ch",
    'es': "ch",
    'fr': "ch",
    'zh': "通道",
    'ar': "الفصل",
}
l_weekday_5 = {
    'ru': "пт",
    'en': "pt",
    'es': "punto",
    'fr': "pt",
    'zh': "点",
    'ar': "نقطة",
}
l_weekday_6 = {
    'ru': "сб",
    'en': "coll",
    'es': "col",
    'fr': "coll",
    'zh': "科尔",
    'ar': "كول",
}
l_weekday_7 = {
    'ru': "вс",
    'en': "vs",
    'es': "contra",
    'fr': "contre",
    'zh': "对比",
    'ar': "ضد",
}

l_inline_demo = {
    'ru': "обо всех проектах",
    'en': "about all projects",
    'es': "sobre todos los proyectos",
    'fr': "sur tous les projets",
    'zh': "关于所有项目",
    'ar': "عن جميع المشاريع",
}
l_inline_bot = {
    'ru': "конструктор ботов",
    'en': "bot constructor",
    'es': "constructor de bots",
    'fr': "constructeur de bot",
    'zh': "机器人构造器",
    'ar': "منشئ الروبوت",
}
l_inline_post = {
    'ru': "конструктор офферов",
    'en': "offer constructor",
    'es': "constructor de ofertas",
    'fr': "offre constructeur",
    'zh': "提供构造函数",
    'ar': "عرض منشئ",
}
l_inline_media = {
    'ru': "конструктор медиа-заметок",
    'en': "media note builder",
    'es': "generador de notas de medios",
    'fr': "constructeur de note média",
    'zh': "媒体笔记生成器",
    'ar': "منشئ الملاحظات الإعلامية",
}
l_inline_channel = {
    'ru': "администратор каналов",
    'en': "channel administrator",
    'es': "administrador del canal",
    'fr': "administrateur de la chaîne",
    'zh': "频道管理员",
    'ar': "مدير القناة",
}
l_inline_group = {
    'ru': "администратор групп",
    'en': "group administrator",
    'es': "administrador de grupo",
    'fr': "administrateur de groupe",
    'zh': "群管理员",
    'ar': "مسؤول المجموعة",
}
l_inline_find = {
    'ru': "бот для поиска",
    'en': "search bot",
    'es': "robot de búsqueda",
    'fr': "robot de recherche",
    'zh': "搜索机器人",
    'ar': "بحث بوت",
}
l_inline_ai = {
    'ru': "бот с нейросетью",
    'en': "bot with neural network",
    'es': "bot con red neuronal",
    'fr': "bot avec réseau de neurones",
    'zh': "具有神经网络的机器人",
    'ar': "بوت مع الشبكة العصبية",
}
l_inline_ads = {
    'ru': "рекламный бот",
    'en': "advertising bot",
    'es': "robot publicitario",
    'fr': "robot publicitaire",
    'zh': "广告机器人",
    'ar': "روبوت إعلاني",
}
l_inline_vpn = {
    'ru': "vpn-бот",
    'en': "vpn-bot",
    'es': "vpn-bot",
    'fr': "vpn-bot",
    'zh': "vpn机器人",
    'ar': "vpn- بوت",
}
l_inline_target = {
    'ru': "таргет-бот",
    'en': "target bot",
    'es': "robot objetivo",
    'fr': "robot cible",
    'zh': "目标机器人",
    'ar': "الهدف الروبوت",
}
l_inline_user = {
    'ru': "администратор пользователя",
    'en': "user administrator",
    'es': "administrador de usuarios",
    'fr': "administrateur d'utilisateurs",
    'zh': "用户管理员",
    'ar': "مسؤول المستخدم",
}
l_inline_tools = {
    'ru': "Telegram-инструменты",
    'en': "Telegram tools",
    'es': "Herramientas de telegramas",
    'fr': "Outils de télégramme",
    'zh': "电报工具",
    'ar': "أدوات Telegram",
}
l_inline_work = {
    'ru': "вакансии/конкурсы",
    'en': "vacancies/competitions",
    'es': "vacantes/concursos",
    'fr': "postes vacants/concours",
    'zh': "职位空缺/竞争",
    'ar': "الشواغر / المسابقات",
}
# endregion


# region FereyDemoBot
l_demo_btn1 = {
    'ru': "⛰️ Проекты",
    'en': "⛰️ Projects",
    'es': "⛰️ Proyectos",
    'fr': "⛰️ Projets",
    'zh': "⛰️ 项目",
    'ar': "⛰️ المشاريع",
}
l_demo_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_demo_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>проекта</code> <b>Ferey</b>:\n\n▪️<b>информация</b> обо всех проектах\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>the landing bot</i> of the <b>Ferey</b> <code>проекта</code> :\n\n▪️ <b>information</b> about all projects\n\n❗️ you can also order the development of a chat bot in our Ferey studio",
    'es': "🌱 {0}, bienvenido al <i>bot de aterrizaje</i> del <code>проекта</code> <b>Ferey</b> :\n\n▪️ <b>información</b> sobre todos los proyectos\n\n❗️ también puedes solicitar el desarrollo de un bot de chat en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue sur <i>le landing bot</i> du <code>проекта</code> <b>Ferey</b> :\n\n▪️ <b>informations</b> sur tous les projets\n\n❗️ vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎来到<b>Ferey</b> <code>проекта</code>的<i>落地机器人</i>：\n\n▪️ 所有项目的<b>信息</b>\n\n❗️ 您也可以在我们的Ferey工作室订购聊天机器人的开发",
    'ar': "🌱 {0} ، مرحبًا بك في <i>روبوت الهبوط</i> الخاص <code>проекта</code> <b>Ferey</b> :\n\n▪️ <b>معلومات</b> حول جميع المشاريع\n\n❗️ يمكنك أيضًا طلب تطوير روبوت محادثة في استوديو Ferey الخاص بنا",
}

l_kind_1 = {
    'ru': "<b>👩🏽‍💻@FereyDemoBot</b>\n\nДемонстрационный бот всех проектов",
    'en': "<b>👩🏽‍💻</b> <b>@FereyDemoBot</b>\n\nDemo bot of all projects",
    'es': "<b>👩🏽‍💻</b> <b>@FereyDemoBot</b>\n\nBot de demostración de todos los proyectos",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyDemoBot</b>\n\nDemo bot de tous les projets",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyDemoBot</b>\n\n所有项目的演示机器人",
    'ar': "<b>👩🏽‍💻FereyDemoBot</b>\n\nروبوت تجريبي <b>@FereyDemoBot</b> المشاريع",
}
l_kind_2 = {
    'ru': "<b>👩🏽‍💻@FereyBotBot</b>\n\nКонструктор ботов:\n▪️авто-генерация бота\n▪️авто-генерация контента (open-ai)\n▪️авто-бан/авто-перевод",
    'en': "<b>👩🏽‍💻</b> <b>@FereyBotBot</b>\n\nBot Builder:\n▪️auto-generate bot\n▪️auto-generate content (open-ai)\n▪️auto-ban/auto-translate",
    'es': "<b>👩🏽‍💻</b> <b>@FereyBotBot</b>\n\nGenerador de bots:\n▪️generación automática de bot\n▪️generación automática de contenido (open-ai)\n▪️prohibición automática/traducción automática",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyBotBot</b>\n\nBot Builder :\n▪️auto-génère le bot\n▪️auto-génère le contenu (open-ai)\n▪️auto-ban/auto-translate",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyBotBot</b>\n\nBot Builder：\n▪️自动生成机器人\n▪️自动生成内容（open-ai）\n▪️自动禁止/自动翻译",
    'ar': "<b>👩🏽‍💻FereyBotBot</b>\n\nBot Builder:\n▪️ إنشاء روبوت تلقائيًا <b>@FereyBotBot</b> n▪️ إنشاء محتوى تلقائيًا (فتح ai)\n▪️ حظر تلقائي / ترجمة آلية",
}
l_kind_3 = {
    'ru': "<b>👩🏽‍💻@FereyChannelBot</b>\n\nАдминистратор каналов:\n▪️авто-постинг\n▪️авто-декор",
    'en': "<b>👩🏽‍💻</b> <b>@FereyChannelBot</b>\n\nChannel admin:\n▪️auto-posting\n▪️auto-decor",
    'es': "<b>👩🏽‍💻</b> <b>@FereyChannelBot</b>\n\nAdministrador del canal:\n▪️publicación automática\n▪️decoración automática",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyChannelBot</b>\n\nAdministrateur de la chaîne :\n▪️publication automatique\n▪️décoration automatique",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyChannelBot</b>\n\n频道管理员：\n▪️自动发布\n▪️自动装饰",
    'ar': "<b>👩🏽‍💻FereyChannelBot</b>\n\nمسؤول القناة:\nنشر تلقائي <b>@FereyChannelBot</b> n ديكور تلقائي",
}
l_kind_4 = {
    'ru': "<b>👩🏽‍💻@FereyGroupBot</b>\n\nАдминистратор групп:\n▪️авто-постинг\n▪️модерация",
    'en': "<b>👩🏽‍💻</b> <b>@FereyGroupBot</b>\n\nGroup admin:\n▪️auto-posting\n▪️moderation",
    'es': "<b>👩🏽‍💻</b> <b>@FereyGroupBot</b>\n\nAdministrador del grupo:\n▪️publicación automática\n▪️moderación",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyGroupBot</b>\n\nAdministrateur du groupe :\n▪️publication automatique\n▪️modération",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyGroupBot</b>\n\n群组管理员：\n▪️自动发布\n▪️审核",
    'ar': "<b>👩🏽‍💻FereyGroupBot</b>\n\n<b>@FereyGroupBot</b> المجموعة:\nنشر تلقائي\n▪️ تعديل",
}
l_kind_5 = {
    'ru': "<b>👩🏽‍💻@FereyUserBot</b>\n\nАдминистратор пользователей:\n▪️авто-постинг\n▪️авто-декор",
    'en': "<b>👩🏽‍💻</b> <b>@FereyUserBot</b>\n\nUser Admin:\n▪️auto-posting\n▪️auto-decor",
    'es': "<b>👩🏽‍💻</b> <b>@FereyUserBot</b>\n\nAdministrador de usuarios:\n▪️publicación automática\n▪️decoración automática",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyUserBot</b>\n\nAdministrateur utilisateur :\n▪️publication automatique\n▪️décoration automatique",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyUserBot</b>\n\n用户管理员：\n▪️自动发布\n▪️自动装饰",
    'ar': "<b>👩🏽‍💻FereyUserBot</b>\n\nمسؤول المستخدم:\nنشر تلقائي\n<b>@FereyUserBot</b> تلقائي",
}
l_kind_6 = {
    'ru': "<b>👩🏽‍💻@FereyPostBot</b>\n\nБыстрое создание и публикация постов:\n▪️превью\n▪️галерея",
    'en': "<b>👩🏽‍💻</b> <b>@FereyPostBot</b>\n\nQuick post creation and publishing:\n▪️preview\n▪️gallery",
    'es': "<b>👩🏽‍💻</b> <b>@FereyPostBot</b>\n\nCreación y publicación rápidas de publicaciones:\n▪️vista previa\n▪️galería",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyPostBot</b>\n\nCréation et publication rapides d'articles :\n▪️aperçu\n▪️galerie",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyPostBot</b>\n\n快速创建和发布帖子：\n▪️预览\n▪️图库",
    'ar': "<b>👩🏽‍💻FereyPostBot</b>\n\nإنشاء منشور سريع <b>@FereyPostBot</b> :\nمعاينة\n▪️ معرض",
}
l_kind_7 = {
    'ru': "<b>👩🏽‍💻@FereyFindBot</b>\n\nПоиск по каналам/группам/пользователям/ботам:\n▪️отслеживание постов\n▪️гео-поиск",
    'en': "<b>👩🏽‍💻</b> <b>@FereyFindBot</b>\n\nSearch by channels/groups/users/bots:\n▪️post tracking\n▪️geo-search",
    'es': "<b>👩🏽‍💻</b> <b>@FereyFindBot</b>\n\nBuscar por canales/grupos/usuarios/bots:\n▪️seguimiento de publicaciones\n▪️búsqueda geográfica",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyFindBot</b>\n\nRecherche par canaux/groupes/utilisateurs/bots :\n▪️suivi des publications\n▪️géo-recherche",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyFindBot</b>\n\n按频道/群组/用户/机器人搜索：\n▪️post tracking\n▪️geo-search",
    'ar': "<b>👩🏽‍💻FereyFindBot</b>\n\nالبحث عن طريق القنوات / المجموعات <b>@FereyFindBot</b> المستخدمين / الروبوتات:\n▪️ تتبع المنشور\n▪️ البحث الجيو",
}
l_kind_8 = {
    'ru': "<b>👩🏽‍💻@FereyMediaBot</b>\n\nБот с популярными креативами:\n▪️аудио-заметки\n▪️видео-заметки",
    'en': "<b>👩🏽‍💻</b> <b>@FereyMediaBot</b>\n\nBot with popular creatives:\n▪️audio notes\n▪️video notes",
    'es': "<b>👩🏽‍💻</b> <b>@FereyMediaBot</b>\n\nBot con creatividades populares:\n▪️notas de audio\n▪️notas de video",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyMediaBot</b>\n\nBot avec des créations populaires :\n▪️notes audio\n▪️notes vidéo",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyMediaBot</b>\n\n具有流行创意的机器人：\n▪️音频笔记\n▪️视频笔记",
    'ar': "<b>👩🏽‍💻FereyMediaBot</b>\n\nاستخدام التصميمات المشهورة:\n▪️ ملاحظات الصوت \ <b>@FereyMediaBot</b> ملاحظات الفيديو",
}
l_kind_9 = {
    'ru': "<b>👩🏽‍💻@FereyVpnBot</b>\n\nВсе о VPN",
    'en': "<b>👩🏽‍💻</b> <b>@FereyVpnBot</b>\n\nAll about VPN",
    'es': "<b>👩🏽‍💻</b> <b>@FereyVpnBot</b>\n\nTodo sobre VPN",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyVpnBot</b>\n\nTout sur le VPN",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyVpnBot</b>\n\n关于 VPN",
    'ar': "<b>👩🏽‍💻FereyVpnBot</b> <b>@FereyVpnBot</b> n\nكل شيء عن VPN",
}
l_kind_10 = {
    'ru': "<b>👩🏽‍💻@FereyTargetBot</b>\n\nТаргетированная рассылка",
    'en': "<b>👩🏽‍💻</b> <b>@FereyTargetBot</b>\n\nTargeted email",
    'es': "<b>👩🏽‍💻</b> <b>@FereyTargetBot</b>\n\nCorreo electrónico dirigido",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyTargetBot</b>\n\nE-mail ciblé",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyTargetBot</b>\n\n目标电子邮件",
    'ar': "<b>👩🏽‍💻FereyTargetBot</b> \ <b>@FereyTargetBot</b>\nالبريد الإلكتروني المستهدف",
}
l_kind_11 = {
    'ru': "<b>👩🏽‍💻@FereyToolsBot</b>\n\nБот инструментов:\n▪️конвертация\n▪️загрузка",
    'en': "<b>👩🏽‍💻</b> <b>@FereyToolsBot</b>\n\nTool bot:\n▪️convert\n▪️download",
    'es': "<b>👩🏽‍💻</b> <b>@FereyToolsBot</b>\n\nHerramienta bot:\n▪️convertir\n▪️descargar",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyToolsBot</b>\n\nBot outil :\n▪️convertir\n▪️télécharger",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyToolsBot</b>\n\n工具机器人：\n▪️转换\n▪️下载",
    'ar': "<b>👩🏽‍💻FereyToolsBot</b>\n\ <b>@FereyToolsBot</b> بوت الأداة:\n▪️ تحويل\n▪️ تحميل",
}
l_kind_12 = {
    'ru': "<b>👩🏽‍💻@FereyAIBot</b>\n\nБот генерации контента (open-ai):\n▪️chat-gpt\n▪️dalli·e",
    'en': "<b>👩🏽‍💻</b> <b>@FereyAIBot</b>\n\nContent generation bot (open-ai):\n▪️chat-gpt\n▪️dalli e",
    'es': "<b>👩🏽‍💻</b> <b>@FereyAIBot</b>\n\nBot de generación de contenido (open-ai):\n▪️chat-gpt\n▪️dalli e",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyAIBot</b>\n\nBot de génération de contenu (open-ai) :\n▪️chat-gpt\n▪️dalli e",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyAIBot</b>\n\n内容生成机器人（open-ai）：\n▪️chat-gpt\n▪️dalli e",
    'ar': "<b>👩🏽‍💻FereyAIBot</b>\n\nروبوت إنشاء المحتوى (open <b>@FereyAIBot</b> ai):\n▪️chat-gpt\n▪️dalli e",
}
l_kind_13 = {
    'ru': "<b>👩🏽‍💻@FereyAdsBot</b>\n\nБот рекламы в:\n▪️ботах\n▪️каналах",
    'en': "<b>👩🏽‍💻</b> <b>@FereyAdsBot</b>\n\nBot ads in:\n▪️bots\n▪️channels",
    'es': "<b>👩🏽‍💻</b> <b>@FereyAdsBot</b>\n\nAnuncios de bot en:\n▪️bots\n▪️canales",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyAdsBot</b>\n\nAnnonces de robots dans :\n▪️bots\n▪️chaînes",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyAdsBot</b>\n\n机器人广告在：\n▪️bots\n▪️channels",
    'ar': "<b>👩🏽‍💻FereyAdsBot</b>\n\n<b>@FereyAdsBot</b> الإعلانات في:\n▪️ الروبوتات\n▪️ القنوات",
}
l_kind_14 = {
    'ru': "<b>👩🏽‍💻@FereyWorkBot</b>\n\nБот информации о:\n▪️вакансиях\n▪️соревнованиях",
    'en': "<b>👩🏽‍💻</b> <b>@FereyWorkBot</b>\n\nBot of information about:\n▪️vacancies\n▪️competitions",
    'es': "<b>👩🏽‍💻</b> <b>@FereyWorkBot</b>\n\nBot de información sobre:\n▪️vacantes\n▪️concursos",
    'fr': "<b>👩🏽‍💻</b> <b>@FereyWorkBot</b>\n\nBot d'informations sur :\n▪️offres d'emploi\n▪️concours",
    'zh': "<b>👩🏽‍💻</b> <b>@FereyWorkBot</b>\n\n有关以下信息的机器人：\n▪️职位空缺\n▪️比赛",
    'ar': "<b>👩🏽‍💻FereyWorkBot</b>\n\nبعض <b>@FereyWorkBot</b> حول:\n▪️ وظائف شاغرة\n▪️ مسابقات",
}
# endregion


# region FereyWorkBot
l_work_btn1 = {
    'ru': "⛰️ Вакансии",
    'en': "⛰️ Jobs",
    'es': "⛰️ Empleos",
    'fr': "⛰️ Emplois",
    'zh': "⛰️ 工作",
    'ar': "⛰️ وظائف",
}
l_work_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_work_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>проекта</code> <b>Ferey</b>:\n\n▪️<b>вакансии</b> нашего стартапа\n▪️конкурсы и <b>мероприятия</b>\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>the landing bot</i> of the <b>Ferey</b> <code>проекта</code> :\n\n▪️ <b>vacancies</b> of our startup\n▪️ contests and <b>events</b>\n\n❗️ you can also order the development of a chat bot in our Ferey studio",
    'es': "🌱 {0}, bienvenido al <i>bot de aterrizaje</i> del <code>проекта</code> <b>Ferey</b> :\n\n▪️ <b>vacantes</b> de nuestra startup\n▪️ concursos y <b>eventos</b>\n\n❗️ también puedes encargar el desarrollo de un chat bot en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue sur <i>le landing bot</i> du <code>проекта</code> <b>Ferey</b> :\n\n▪️ <b>offres d&#x27;emploi</b> de notre startup\n▪️ concours et <b>événements</b>\n\n❗️ vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎来到<b>Ferey</b> <code>проекта</code>的<i>登陆机器人</i>：\n\n▪️ 我们初创公司的<b>职位空缺</b>\n▪️ 竞赛和<b>活动</b>\n\n❗️ 您也可以在我们的Ferey工作室订购聊天机器人的开发",
    'ar': "🌱 {0} ، مرحبًا بك في <i>روبوت الهبوط</i> الخاص <code>проекта</code> <b>Ferey</b> :\n\n▪️ <b>الشواغر</b> في بدء التشغيل\n▪️ المسابقات <b>والأحداث</b>\n\n❗️ يمكنك أيضًا طلب تطوير روبوت محادثة في استوديو Ferey",
}
l_vacancy_1 = {
    'ru': "👩🏽‍💻 <b>Text to video ai-designer</b>\n\nTasks: create ferey-masks (realistic video) for any human\nGender: girl\nAge: less than 30\nPay: share of the company",
    'en': "👩🏽‍💻 <b>Text to video ai-designer</b>\n\nTasks: create ferey-masks (realistic video) for any human\nGender: girl\nAge: less than 30\nPay: share of the company",
    'es': "👩🏽‍💻 <b>Text to video ai-designer</b>\n\nTareas: crear máscaras ferey (video realista) para cualquier humano\nGénero: niña\nEdad: menos de 30\nPago: parte de la empresa",
    'fr': "👩🏽‍💻 <b>Text to video ai-designer</b>\n\nTâches : créer des masques de ferey (vidéo réaliste) pour tout humain\nSexe : fille\nÂge : moins de 30 ans\nPaiement : part de l'entreprise",
    'zh': "👩🏽‍💻<b>文本到视频 ai-designer</b>\n\n任务：为任何人创建 ferey-mask（逼真的视频）\n性别：女孩\n年龄：30 岁以下\n薪酬：公司股份",
    'ar': "👩🏽‍💻 <b>نص إلى فيديو مصمم ai</b>\n\nالمهام: إنشاء أقنعة ضيقة (فيديو واقعي) لأي إنسان\nالجنس: فتاة\nالعمر: أقل من 30\nالدفع: حصة الشركة",
}
l_vacancy_2 = {
    'ru': "👩🏽‍💻 <b>Content/video maker</b>\n\nTasks: generate creatives for all socials\nGender: girl\nAge: less than 30\nPay: 1 TON per 1 post for all socials",
    'en': "👩🏽‍💻 <b>Content/video maker</b>\n\nTasks: generate creatives for all socials\nGender: girl\nAge: less than 30\nPay: 1 TON per 1 post for all socials",
    'es': "👩🏽‍💻 <b>Creador de contenido/video</b>\n\nTareas: generar creatividades para todas las redes sociales\nGénero: niña\nEdad: menos de 30\nPago: 1 TON por 1 publicación para todas las redes sociales",
    'fr': "👩🏽‍💻 <b>Créateur de contenu/vidéo</b>\n\nTâches : générer des créations pour tous les réseaux sociaux\nSexe : fille\nÂge : moins de 30 ans\nPaiement : 1 TON pour 1 post pour tous les réseaux sociaux",
    'zh': "👩🏽‍💻<b>内容/视频制作者</b>\n\n任务：为所有社交生成创意\n性别：女孩\n年龄：小于 30\n报酬：所有社交每 1 个帖子 1 吨",
    'ar': "👩🏽‍💻 <b>صانع المحتوى / الفيديو</b>\n\nالمهام: إنشاء تصميمات لجميع وسائل التواصل الاجتماعي\nالجنس: فتاة\nالعمر: أقل من 30\nالدفع: 1 طن لكل مشاركة واحدة لجميع الشبكات الاجتماعية",
}
l_vacancy_3 = {
    'ru': "👩🏽‍💻 <b>Aio/pyro-gram developer</b>\n\nTasks: dev and support all projects\nGender: girl\nAge: less than 30\nPay: share of the company",
    'en': "👩🏽‍💻 <b>Aio/pyro-gram developer</b>\n\nTasks: dev and support all projects\nGender: girl\nAge: less than 30\nPay: share of the company",
    'es': "👩🏽‍💻 <b>Desarrollador Aio/pyro-gram</b>\n\nTareas: desarrollar y respaldar todos los proyectos\nGénero: niña\nEdad: menos de 30\nPago: parte de la empresa",
    'fr': "👩🏽‍💻 <b>Développeur Aio/pyro-gram</b>\n\nTâches : développement et support de tous les projets\nSexe : fille\nÂge : moins de 30 ans\nRémunération : part de l'entreprise",
    'zh': "👩🏽‍💻 <b>Aio/pyro-gram 开发者</b>\n\n任务：开发和支持所有项目\n性别：女孩\n年龄：30岁以下\n薪酬：公司股份",
    'ar': "👩🏽‍💻 <b>مطور Aio / pyro-gram</b>\n\nالمهام: تطوير ودعم جميع المشاريع\nالجنس: فتاة\nالعمر: أقل من 30\nالدفع: حصة الشركة",
}
# endregion


# region FereyAIBot
l_ai_btn1 = {
    'ru': "⛰️ Нейросети",
    'en': "⛰️ Neural networks",
    'es': "⛰️ Redes neuronales",
    'fr': "⛰️ Réseaux de neurones",
    'zh': "⛰️ 神经网络",
    'ar': "⛰️ الشبكات العصبية",
}
l_ai_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_ai_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>генерации</code> контента:\n\n▪️<b>текст</b>\n▪️<b>изображение</b>\n▪️<b>анализ Telegram-канала</b>\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to the content <code>генерации</code> <i>landing bot</i> :\n\n▪️ <b>text</b>\n▪️ <b>image</b>\n▪️ <b>analysis of the Telegram channel</b>\n\n❗️ you can also order the development of a chat bot in our studio Ferey",
    'es': "🌱 {0}, bienvenido al <i>bot de aterrizaje</i> <code>генерации</code> de contenido:\n\n▪️ <b>texto</b>\n▪️ <b>imagen</b>\n▪️ <b>análisis del canal de Telegram</b>\n\n❗️ también puedes encargar el desarrollo de un chat bot en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue dans le <i>landing bot</i> <code>генерации</code> de contenu :\n\n▪️ <b>texte</b>\n▪️ <b>image</b>\n▪️ <b>analyse de la chaîne Telegram</b>\n\n❗️ vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎使用内容<code>генерации</code><i>登陆机器人</i>：\n\n▪️<b>文字</b>\n▪️<b>图片</b>\n▪️ <b>Telegram 频道分析</b>\n\n❗️ 您也可以在我们的工作室Ferey订购聊天机器人的开发",
    'ar': "🌱 {0} ، مرحبًا بك في <i>روبوت إنشاء</i> <code>генерации</code> :\n\n▪️ <b>نص</b>\n▪️ <b>صورة</b>\n▪️ <b>تحليل قناة Telegram</b>\n\n❗️ يمكنك أيضًا طلب تطوير روبوت محادثة في استوديو Ferey الخاص بنا",
}
l_gen_txt = {
    'ru': "📘 Текст{0}",
    'en': "📘 Text{0}",
    'es': "📘 Texto{0}",
    'fr': "📘 Texte{0}",
    'zh': "📘 文字{0}",
    'ar': "📘 نص {0}",
}
l_gen_img = {
    'ru': "🌌 Образ",
    'en': "🌌 Image",
    'es': "🌌 Imagen",
    'fr': "🌌 Image",
    'zh': "🌌 图片",
    'ar': "🌌 صورة",
}
l_gen_tlg = {
    'ru': "👩🏽‍💻 Анализ Telegram-канала",
    'en': "👩🏽‍💻 Telegram channel analysis",
    'es': "👩🏽‍💻 Análisis de canales de Telegram",
    'fr': "👩🏽‍💻 Analyse des chaînes de télégrammes",
    'zh': "👩🏽‍💻电报频道分析",
    'ar': "👩🏽‍💻 تحليل قناة Telegram",
}
l_generate_main = {
    'ru': "👩🏽‍💻 <b>Выбери режим</b>",
    'en': "👩🏽‍💻 <b>Choose a mode</b>",
    'es': "👩🏽‍💻 <b>Elige un modo</b>",
    'fr': "👩🏽‍💻 <b>Choisissez un mode</b>",
    'zh': "👩🏽‍💻<b>选择模式</b>",
    'ar': "👩🏽‍💻 <b>اختر الوضع</b>",
}
l_generate_prompt = {
    'ru': "👩🏽‍💻 <b>Введи</b> запрос для <b>{0}</b> 👇🏼..",
    'en': "👩🏽‍💻 <b>Enter</b> a query for <b>{0}</b> 👇🏼..",
    'es': "👩🏽‍💻 <b>Ingrese</b> una consulta para <b>{0}</b> 👇🏼..",
    'fr': "👩🏽‍💻 <b>Entrez</b> une requête pour <b>{0}</b> 👇🏼..",
    'zh': "👩🏽‍💻<b>输入</b>查询<b>{0}</b> 👇🏼..",
    'ar': "👩🏽‍💻 <b>أدخل</b> استعلامًا عن <b>{0}</b> 👇🏼 ..",
}
l_generate_chn = {
    'ru': "👩🏽‍💻 <b>Вставь</b> ссылку на Telegram канал для анализа финансовых показателей",
    'en': "👩🏽‍💻 <b>Insert</b> a link to the Telegram channel to analyze financial performance",
    'es': "👩🏽‍💻 <b>Inserta</b> un enlace al canal de Telegram para analizar el desempeño financiero",
    'fr': "👩🏽‍💻 <b>Insérez</b> un lien vers la chaîne Telegram pour analyser les performances financières",
    'zh': "👩🏽‍💻<b>插入</b>到 Telegram 频道的链接以分析财务绩效",
    'ar': "👩🏽‍💻 <b>أدخل</b> رابطًا إلى قناة Telegram لتحليل الأداء المالي",
}
l_generate_wait = {
    'ru': "👩🏽‍💻 <b>Выбери режим</b> или <b>дождись</b> окончания генерации..",
    'en': "👩🏽‍💻 <b>Wait for</b> the generation to finish..",
    'es': "👩🏽‍💻 <b>Espera a</b> que termine la generación..",
    'fr': "👩🏽‍💻 <b>Attendez que</b> la génération se termine..",
    'zh': "👩🏽‍💻<b>等待</b>生成结束..",
    'ar': "👩🏽‍💻 <b>انتظر حتى</b> ينتهي الجيل ..",
}
l_generate_subcribe = {
    'ru': "👩🏽‍💻 Подожди {0}сек или оформи подписку",
    'en': "👩🏽‍💻 Please wait {0}sec or subscribe",
    'es': "👩🏽‍💻 Espera {0}segundos o suscríbete",
    'fr': "👩🏽‍💻 Veuillez patienter {0}sec ou vous abonner",
    'zh': "👩🏽‍💻 请等待 {0} 秒或订阅",
    'ar': "👩🏽‍💻 يرجى الانتظار {0} ثانية أو الاشتراك",
}
l_generate_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> генерации",
    'en': "👩🏽‍💻 Generation <b>Error</b>",
    'es': "👩🏽‍💻 <b>Error</b> de generación",
    'fr': "👩🏽‍💻 <b>Erreur</b> de génération",
    'zh': "👩🏽‍💻 生成<b>错误</b>",
    'ar': "👩🏽‍💻 <b>خطأ</b> في التوليد",
}
l_generate_errchn = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> доступа к каналу (попробуй позже или сделай канал публичным)",
    'en': "👩🏽‍💻 Channel access <b>error</b> (try again later or make the channel public)",
    'es': "👩🏽‍💻 <b>Error</b> de acceso al canal (inténtalo de nuevo más tarde o haz público el canal)",
    'fr': "👩🏽‍💻 <b>Erreur</b> d'accès à la chaîne (réessayez plus tard ou rendez la chaîne publique)",
    'zh': "👩🏽‍💻频道访问<b>错误</b>（稍后重试或公开频道）",
    'ar': "👩🏽‍💻 <b>خطأ</b> في الوصول إلى القناة (حاول مرة أخرى لاحقًا أو اجعل القناة عامة)",
}
# endregion


# region FereyAdsBot
l_ads_btn1 = {
    'ru': "⛰️ Посты",
    'en': "⛰️ Posts",
    'es': "⛰️ Publicaciones",
    'fr': "⛰️ Messages",
    'zh': "⛰️ 帖子",
    'ar': "⛰️ المشاركات",
}
l_ads_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_ads_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> для создания креативных <code>постов</code> <b>Ferey</b>\n\n▪️️реклама во всех Ferey-ботах\n▪️️заказ рекламы на канале\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>the landing bot</i> for creating creative <code>постов</code> <b>Ferey</b>\n\n▪️️advertising in all Ferey bots\n▪️️ ordering advertising on the channel\n\n❗️you can also order the development of a chat bot in our Ferey studio",
    'es': "🌱 {0}, bienvenido <i>al bot de aterrizaje</i> para crear <code>постов</code> creativas <b>Ferey</b>\n\n▪️️publicidad en todos los bots de Ferey\n▪️️solicitando publicidad en el canal\n\n❗️también puedes ordenar el desarrollo de un chatbot en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue sur <i>le bot de débarquement</i> pour la création <code>постов</code> créatifs <b>Ferey</b>\n\n▪️️publicité dans tous les bots Ferey\n▪️️ commande de publicité sur la chaîne\n\n❗️vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎来到<b>Ferey</b>创建创意<code>постов</code>的<i>登陆机器人</i>\n\n▪️️在所有 Ferey 机器人中投放广告\n▪️️ 在频道订购广告\n\n❗️您也可以在以下订购聊天机器人的开发我们的Ferey工作室",
    'ar': "🌱 {0} ، مرحبًا بك في <i>روبوت الهبوط</i> لإنشاء <code>постов</code> إبداعية <b>Ferey</b>\n\n▪️️ الإعلان في جميع برامج Ferey\n▪️️ طلب الإعلانات على القناة\n\n❗️ يمكنك أيضًا طلب تطوير روبوت محادثة في استوديو Ferey الخاص بنا",
}
l_post_media_ads = {
    'ru': "✏️ 2. Прикрепи <b>медиа</b> контент: фото/гиф/видео до 5Mb\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 2. Attach <b>media</b> content: photo/gif/video up to 5Mb\n\n( <i>or press &quot;➡️️/Next&quot; to skip this step</i> )",
    'es': "✏️ 2. Adjunte contenido <b>multimedia</b> : foto/gif/video de hasta 5 Mb\n\n( <i>o presione &quot;➡️️/Siguiente&quot; para omitir este paso</i> )",
    'fr': "✏️ 2. Joignez du contenu <b>multimédia</b> : photo/gif/vidéo jusqu&#x27;à 5 Mb\n\n( <i>ou appuyez sur &quot;➡️️/Suivant&quot; pour ignorer cette étape</i> )",
    'zh': "✏️ 2.附加<b>媒体</b>内容：照片/gif/视频最大5Mb\n\n（<i>或按“➡️️/Next”跳过此步骤</i>）",
    'ar': "✏️ 2. إرفاق محتوى <b>وسائط</b> : صورة / صورة / فيديو بحجم يصل إلى 5 ميغا بايت\n\n( <i>أو اضغط على &quot;➡️️ / التالي&quot; لتخطي هذه الخطوة</i> )",
}
# endregion


# region FereyPostBot
l_post_btn1 = {
    'ru': "⛰️ Посты",
    'en': "⛰️ Posts",
    'es': "⛰️ Publicaciones",
    'fr': "⛰️ Messages",
    'zh': "⛰️ 帖子",
    'ar': "⛰️ المشاركات",
}
l_post_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_post_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> для создания креативных <code>постов</code> <b>Ferey</b>\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>the landing bot</i> for creating creative <code>постов</code> <b>Ferey</b>\n\n❗️ you can also order the development of a chat bot in our Ferey studio",
    'es': "🌱 {0}, bienvenido al <i>bot de aterrizaje</i> para crear <code>постов</code> creativas <b>Ferey</b>\n\n❗️ también puedes solicitar el desarrollo de un bot de chat en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue sur <i>le landing bot</i> pour créer <code>постов</code> créatifs <b>Ferey</b>\n\n❗️ vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎使用<b>Ferey</b>创建创意<code>постов</code>的<i>登陆机器人</i>\n\n❗️您也可以在我们的Ferey工作室订购聊天机器人的开发",
    'ar': "🌱 {0} ، مرحبًا بك في <i>روبوت الهبوط</i> لإنشاء <code>постов</code> إبداعية <b>Ferey</b>\n\n❗️ يمكنك أيضًا طلب تطوير روبوت محادثة في استوديو Ferey الخاص بنا",
}

# endregion


# region FereyVPNBot
l_vpn_btn1 = {
    'ru': "⛰️ VPN",
    'en': "⛰️ VPN",
    'es': "⛰️VPN",
    'fr': "⛰️VPN",
    'zh': "⛰️ VPN",
    'ar': "⛰️ VPN",
}
l_vpn_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_vpn_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> проекта Ferey:\n\n▪️<b>openvpn</b>\n▪️<b>wireguard</b>\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>the landing bot</i> of the Ferey project:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ you can also order the development of a chat bot in our Ferey studio",
    'es': "🌱 {0}, bienvenido al <i>bot de aterrizaje</i> del proyecto Ferey:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ también puedes encargar el desarrollo de un chat bot en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue sur <i>le landing bot</i> du projet Ferey :\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎来到 Ferey 项目的<i>落地机器人</i>：\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️您也可以在我们的Ferey工作室订购聊天机器人的开发",
    'ar': "🌱 {0} ، مرحبًا بك في <i>روبوت الهبوط</i> الخاص بمشروع Ferey:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ يمكنك أيضًا طلب تطوير روبوت محادثة في استوديو Ferey",
}
l_vpn_1 = {
    'ru': "👩🏽‍💻 <b>Open VPN</b>\n\n{0}",
    'en': "👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link",
    'es': "👩🏽‍💻 <b>Abrir VPN</b>\n\n*config por enlace utm especial",
    'fr': "👩🏽‍💻 <b>Ouvrez VPN</b>\n\n*config par lien utm spécial",
    'zh': "👩🏽‍💻 通过特殊的 utm 链接<b>打开 VPN</b>\n\n*config",
    'ar': "👩🏽‍💻 <b>افتح VPN</b>\n\n* التكوين عن طريق ارتباط utm خاص",
}
l_vpn_2 = {
    'ru': "👩🏽‍💻 <b>Wire Guard</b>\n\n{0}",
    'en': "👩🏽‍💻 <b>Wire Guard</b>",
    'es': "👩🏽‍💻 <b>Protector de alambre</b>",
    'fr': "👩🏽‍💻 <b>Grille de protection</b>",
    'zh': "👩🏽‍💻<b>护线</b>",
    'ar': "👩🏽‍💻 <b>واقي سلكي</b>",
}
# endregion


# region FereyToolsBot
l_tools_btn1 = {
    'ru': "⛰️ Инструменты",
    'en': "⛰️ Tools",
    'es': "⛰️ Herramientas",
    'fr': "⛰️ Outils",
    'zh': "⛰️ 工具",
    'ar': "⛰️ أدوات",
}
l_tools_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_tools_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> Telegram-<code>инструментов</code>:\n\n▪️<b>преобразование</b> контента\n▪️<b>получение</b> информации о сообщении\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>the landing bot</i> of Telegram <code>инструментов</code> :\n\n▪️ content <b>conversion</b>\n▪️ <b>getting</b> information about the message\n\n❗️you can also order the development of a chat bot in our studio Ferey",
    'es': "🌱 {0}, bienvenido al <i>bot de aterrizaje</i> de <code>инструментов</code> de Telegram:\n\n▪️ <b>conversión</b> de contenido\n▪️ <b>obtener</b> información sobre el mensaje\n\n❗️también puedes solicitar el desarrollo de un bot de chat en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue dans <i>le landing bot</i> des <code>инструментов</code> Telegram :\n\n▪️ <b>conversion</b> de contenu\n▪️ <b>obtenir</b> des informations sur le message\n\n❗️vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎使用 Telegram <code>инструментов</code>的<i>登陆机器人</i>：\n\n▪️ 内容<b>转换</b>\n▪️<b>获取</b>有关消息的信息\n\n❗️您也可以在我们的工作室Ferey订购聊天机器人的开发",
    'ar': "🌱 {0} ، مرحبًا بك في <i>روبوت الهبوط</i> الخاص <code>инструментов</code> Telegram:\n\n▪️ <b>تحويل</b> المحتوى\n▪️ <b>الحصول على</b> معلومات حول الرسالة\n\n❗️ يمكنك أيضًا طلب تطوير روبوت محادثة في استوديو Ferey الخاص بنا",
}
l_image_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>изображения</i> в",
    'en': "👩🏽‍💻 <b>Choose</b> tools to convert <i>your image</i> to",
    'es': "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>su imagen</i> a",
    'fr': "👩🏽‍💻 <b>Choisissez</b> des outils pour convertir <i>votre image</i> en",
    'zh': "👩🏽‍💻<b>选择</b>工具将<i>您的图像</i>转换为",
    'ar': "👩🏽‍💻 <b>اختر</b> أدوات لتحويل <i>صورتك</i> إلى",
}
l_image_sticker = {
    'ru': "🌌 стикер",
    'en': "🌌 sticker",
    'es': "🌌 pegatina",
    'fr': "🌌 autocollant",
    'zh': "🌌 贴纸",
    'ar': "🌌 ملصق",
}
l_image_jpg = {
    'ru': "🏞️ jpg",
    'en': "🏞️ jpg",
    'es': "🏞️ jpg",
    'fr': "🏞️jpg",
    'zh': "🏞️ jpg",
    'ar': "🏞️ jpg",
}
l_image_png = {
    'ru': "🌁 png",
    'en': "🌁 png",
    'es': "🌁 png",
    'fr': "🌁 png",
    'zh': "🌁 png",
    'ar': "🌁 png",
}
l_image_rbg = {
    'ru': "🙌🏽 удалить фон",
    'en': "🙌🏽 png",
    'es': "🙌🏽 png",
    'fr': "🙌🏽 png",
    'zh': "🙌🏽 png",
    'ar': "🙌🏽 png",
}
l_image_mp4 = {
    'ru': "🎥 mp4",
    'en': "🎥 mp4",
    'es': "🎥 mp4",
    'fr': "🎥 mp4",
    'zh': "🎥 mp4",
    'ar': "🎥 mp4",
}
l_image_album = {
    'ru': "9️⃣ album⁹",
    'en': "9️⃣ album⁹",
    'es': "9️⃣ álbum⁹",
    'fr': "9️⃣album⁹",
    'zh': "9️⃣专辑⁹",
    'ar': "9️⃣ البوم⁹",
}
l_image_thumb = {
    'ru': "🖼️ thumb",
    'en': "🖼️ thumb-nail",
    'es': "🖼️ miniatura",
    'fr': "🖼️ ongle du pouce",
    'zh': "🖼️ 缩略图",
    'ar': "🖼️ الإبهام",
}
l_image_descpic = {
    'ru': "⿴ Bot Desc Pic",
    'en': "⿴ Bot Desc Pic",
    'es': "⿴ Foto de descripción del bot",
    'fr': "⿴ Image de description du robot",
    'zh': "⿴ 机器人描述图片",
    'ar': "⿴ بوت ديسك بيك",
}
l_image_sticker_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в стикер",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert into a sticker",
    'es': "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla en una pegatina",
    'fr': "👩🏽‍💻 <b>Joignez</b> une photo à convertir en autocollant",
    'zh': "👩🏽‍💻<b>附上</b>照片以转换为贴纸",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى ملصق",
}
l_image_jpg_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в jpg",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert to jpg",
    'es': "👩🏽‍💻 <b>Adjunta</b> una foto para convertir a jpg",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo à convertir en jpg",
    'zh': "👩🏽‍💻<b>附上</b>照片以转换为jpg",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى jpg",
}
l_image_png_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в png",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert to jpg",
    'es': "👩🏽‍💻 <b>Adjunta</b> una foto para convertir a jpg",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo à convertir en jpg",
    'zh': "👩🏽‍💻<b>附上</b>照片以转换为jpg",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى jpg",
}
l_image_rbg_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для удаления фона",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert to jpg",
    'es': "👩🏽‍💻 <b>Adjunta</b> una foto para convertir a jpg",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo à convertir en jpg",
    'zh': "👩🏽‍💻<b>附上</b>照片以转换为jpg",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى jpg",
}
l_image_mp4_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в mp4 (Telegram-аватарку)",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert to mp4 (Telegram avatar)",
    'es': "👩🏽‍💻 <b>Adjunta</b> una foto para convertir a mp4 (Avatar de Telegram)",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo à convertir en mp4 (avatar Telegram)",
    'zh': "👩🏽‍💻<b>附上</b>要转换为mp4的照片（电报头像）",
    'ar': "👩🏽‍💻 <b>إرفاق</b> صورة لتحويلها إلى mp4 (Telegram avatar)",
}
l_image_album_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в альбом из 9 частей",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to transform into a 9-part album",
    'es': "👩🏽‍💻 <b>Adjunta</b> una foto para transformarla en un álbum de 9 partes",
    'fr': "👩🏽‍💻 <b>Joignez</b> une photo pour la transformer en un album en 9 parties",
    'zh': "👩🏽‍💻<b>附上</b>一张照片，变身为9个部分的相册",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى ألبوم مكون من 9 أجزاء",
}
l_image_thumb_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в thumb-nail-иконку (160x160)",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert to a thumb-nail icon (160x160)",
    'es': "👩🏽‍💻 <b>Adjunte</b> una foto para convertirla en un icono de miniatura (160x160)",
    'fr': "👩🏽‍💻 <b>Joignez</b> une photo à convertir en icône de vignette (160x160)",
    'zh': "👩🏽‍💻<b>附加</b>照片以转换为缩略图图标 (160x160)",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى رمز مسمار الإبهام (160 × 160)",
}
l_image_descpic_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в формат, необходимый для установки Description Picture для бота в @BotFather (640x360)",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert to the format required to set the Description Picture for the bot in @BotFather (640x360)",
    'es': "👩🏽‍💻 <b>Adjunte</b> una foto para convertir al formato requerido para configurar la imagen de descripción para el bot en @BotFather (640x360)",
    'fr': "👩🏽‍💻 <b>Joignez</b> une photo à convertir au format requis pour définir l'image de description du bot dans @BotFather (640x360)",
    'zh': "👩🏽‍💻<b>附上</b>照片以转换为在@BotFather中为机器人设置描述图片所需的格式（640x360）",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى التنسيق المطلوب لتعيين وصف الصورة للروبوت في @BotFather (640x360)",
}

l_gif_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>гиф</i> в",
    'en': "👩🏽‍💻 <b>Choose</b> tools to convert <i>GIF</i> to",
    'es': "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>GIF</i> a",
    'fr': "👩🏽‍💻 <b>Choisissez</b> des outils pour convertir <i>GIF</i> en",
    'zh': "👩🏽‍💻<b>选择将</b><i>GIF</i>转换为的工具",
    'ar': "👩🏽‍💻 <b>اختر</b> أدوات لتحويل <i>GIF</i> إلى",
}
l_gif_mp4 = {
    'ru': "🎥 mp4",
    'en': "🎥 mp4",
    'es': "🎥 mp4",
    'fr': "🎥 mp4",
    'zh': "🎥 mp4",
    'ar': "🎥 mp4",
}
l_gif_thumb = {
    'ru': "🖼️ thumb-nail",
    'en': "🖼️ thumb-nail",
    'es': "🖼️ miniatura",
    'fr': "🖼️ ongle du pouce",
    'zh': "🖼️ 缩略图",
    'ar': "🖼️ الإبهام",
}
l_gif_descgif = {
    'ru': "⿴ Bot Desc Gif",
    'en': "⿴ Bottom Desc Gif",
    'es': "⿴ Gif de descripción inferior",
    'fr': "⿴ Bas Desc Gif",
    'zh': "⿴ 底部描述 Gif",
    'ar': "⿴ أسفل Desc Gif",
}
l_gif_mp4_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в mp4",
    'en': "👩🏽‍💻 <b>Attach</b> GIF to convert to mp4",
    'es': "👩🏽‍💻 <b>Adjuntar</b> GIF para convertir a mp4",
    'fr': "👩🏽‍💻 <b>Joindre</b> GIF pour convertir en mp4",
    'zh': "👩🏽‍💻<b>附加</b>GIF 以转换为 mp4",
    'ar': "👩🏽‍💻 <b>إرفاق</b> GIF للتحويل إلى mp4",
}
l_gif_thumb_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в thumb-nail-иконку (160x160)",
    'en': "👩🏽‍💻 <b>Attach</b> GIF to convert to thumb-nail icon (160x160)",
    'es': "👩🏽‍💻 <b>Adjuntar</b> GIF para convertir en icono de miniatura (160x160)",
    'fr': "👩🏽‍💻 <b>Attachez</b> GIF pour convertir en icône de vignette (160x160)",
    'zh': "👩🏽‍💻<b>附加</b>GIF 以转换为缩略图图标 (160x160)",
    'ar': "👩🏽‍💻 <b>أرفق</b> ملف GIF للتحويل إلى أيقونة مسمار الإبهام (160 × 160)",
}
l_gif_descgif_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в формат, необходимый для установки Description Gif для бота в @BotFather (640x360). После формирования GIF нажимаем на нее через <u>мобильное</u> приложение (ожидая загрузки), далее Поделиться - приложение Telegram - @BotFather",
    'en': "👩🏽‍💻 <b>Attach</b> a gif to convert to the format needed to set the Description Gif for the bot to @BotFather (640x360). After generating a GIF, click on it through <u>the mobile</u> application (waiting for download), then Share - Telegram application - @BotFather",
    'es': "👩🏽‍💻 <b>Adjunte</b> un gif para convertir al formato necesario para configurar el GIF de descripción para el bot en @BotFather (640x360). Después de generar un GIF, haga clic en él a través de <u>la aplicación móvil</u> (en espera de descarga), luego Compartir - Aplicación Telegram - @BotFather",
    'fr': "👩🏽‍💻 <b>Joignez</b> un gif à convertir au format nécessaire pour définir le gif de description du bot sur @BotFather (640x360). Après avoir généré un GIF, cliquez dessus via <u>l&#x27;application mobile</u> (en attente de téléchargement), puis Partager - Application Telegram - @BotFather",
    'zh': "👩🏽‍💻<b>附加</b>一个 gif 以转换为将机器人的描述 Gif 设置为@BotFather (640x360) 所需的格式。生成GIF后，通过<u>手机</u>应用点击（等待下载），然后Share - Telegram application - @BotFather",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة gif للتحويل إلى التنسيق المطلوب لتعيين Description Gif للبوت إلى @BotFather (640x360). بعد إنشاء ملف GIF ، اضغط عليه من خلال تطبيق <u>الهاتف المحمول</u> (في انتظار التنزيل) ، ثم شارك - تطبيق Telegram @BotFather",
}

l_video_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>видео</i> в",
    'en': "👩🏽‍💻 <b>Choose</b> tools to convert <i>video</i> to",
    'es': "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>videos</i> a",
    'fr': "👩🏽‍💻 <b>Choisissez</b> des outils pour convertir <i>la vidéo</i> en",
    'zh': "👩🏽‍💻<b>选择将</b><i>视频</i>转换为的工具",
    'ar': "👩🏽‍💻 <b>اختر</b> أدوات لتحويل <i>الفيديو</i> إلى",
}
l_video_videonote = {
    'ru': "⚫️ телескоп",
    'en': "⚫️ telescope",
    'es': "⚫️ telescopio",
    'fr': "⚫️ télescope",
    'zh': "⚫️望远镜",
    'ar': "⚫️ تلسكوب",
}
l_video_mp3 = {
    'ru': "▶️ mp3",
    'en': "▶️ mp3",
    'es': "▶️ mp3",
    'fr': "▶️ mp3",
    'zh': "▶️ mp3",
    'ar': "▶️ mp3",
}
l_video_mp4 = {
    'ru': "🎥 mp4",
    'en': "🎥 mp4",
    'es': "🎥 mp4",
    'fr': "🎥 mp4",
    'zh': "🎥 mp4",
    'ar': "🎥 mp4",
}
l_video_album = {
    'ru': "9️⃣ album⁹",
    'en': "9️⃣ album⁹",
    'es': "9️⃣ álbum⁹",
    'fr': "9️⃣album⁹",
    'zh': "9️⃣专辑⁹",
    'ar': "9️⃣ البوم⁹",
}
l_video_thumb = {
    'ru': "🖼️ thumb-nail",
    'en': "🖼️ thumb-nail",
    'es': "🖼️ miniatura",
    'fr': "🖼️ ongle du pouce",
    'zh': "🖼️ 缩略图",
    'ar': "🖼️ الإبهام",
}
l_video_gif = {
    'ru': "📽️ gif",
    'en': "📽️ gif",
    'es': "📽️ gif",
    'fr': "📽️ gif",
    'zh': "📽️动图",
    'ar': "📽️ gif",
}
l_video_transcribe = {
    'ru': "🗣️ транскрибация",
    'en': "🗣️ transcription",
    'es': "🗣️ transcripción",
    'fr': "🗣️ retranscription",
    'zh': "🗣️ 转录",
    'ar': "🗣️ النسخ",
}
l_video_videonote_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в телескоп (круглую видео-заметку)",
    'en': "👩🏽‍💻 <b>Attach</b> a video to transform into a telescope (round video note)",
    'es': "👩🏽‍💻 <b>Adjunta</b> un video para transformarte en telescopio (nota de video redonda)",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo pour se transformer en télescope (note vidéo ronde)",
    'zh': "👩🏽‍💻<b>附上</b>变身望远镜的视频（圆形视频笔记）",
    'ar': "<b>أرفق</b> مقطع فيديو لتحويله إلى تلسكوب (ملاحظة فيديو مستديرة)",
}
l_video_mp3_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в mp3-аудио",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert to mp3 audio",
    'es': "👩🏽‍💻 <b>Adjuntar</b> video para convertir a audio mp3",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo pour la convertir en audio mp3",
    'zh': "👩🏽‍💻<b>附加</b>视频以转换为 mp3 音频",
    'ar': "👩🏽‍💻 <b>إرفاق</b> الفيديو لتحويله إلى صوت mp3",
}
l_video_mp4_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в mp4",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert to mp4",
    'es': "👩🏽‍💻 <b>Adjuntar</b> video para convertir a mp4",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo à convertir en mp4",
    'zh': "👩🏽‍💻<b>附上</b>视频以转换为mp4",
    'ar': "👩🏽‍💻 <b>إرفاق</b> الفيديو لتحويله إلى mp4",
}
l_video_album_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в альбом из 9 частей",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert into 9 part album",
    'es': "👩🏽‍💻 <b>Adjuntar</b> video para convertir en álbum de 9 partes",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo à convertir en album en 9 parties",
    'zh': "👩🏽‍💻<b>附上</b>视频转换成9部分专辑",
    'ar': "👩🏽‍💻 <b>أرفق مقطع</b> فيديو لتحويله إلى ألبوم مكون من 9 أجزاء",
}
l_video_thumb_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в thumb-nail-иконку (160x160)",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert to thumbnail (160x160)",
    'es': "👩🏽‍💻 <b>Adjuntar</b> video para convertir a miniatura (160x160)",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo à convertir en vignette (160x160)",
    'zh': "👩🏽‍💻<b>附加</b>视频以转换为缩略图 (160x160)",
    'ar': "👩🏽‍💻 <b>إرفاق</b> فيديو للتحويل إلى صورة مصغرة (160 × 160)",
}
l_video_gif_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в гиф",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert to GIF",
    'es': "👩🏽‍💻 <b>Adjuntar</b> video para convertir a GIF",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo à convertir en GIF",
    'zh': "👩🏽‍💻<b>附加</b>视频以转换为 GIF",
    'ar': "👩🏽‍💻 <b>إرفاق</b> الفيديو لتحويله إلى GIF",
}
l_video_transcribe_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> круглую видео для преобразования в текст",
    'en': "👩🏽‍💻 <b>Attach</b> a round video note (telescope) to convert to text (converted format is not supported)",
    'es': "👩🏽‍💻 <b>Adjunte</b> una nota de video redonda (telescopio) para convertir a texto (no se admite el formato convertido)",
    'fr': "👩🏽‍💻 <b>Joignez</b> une note vidéo ronde (télescope) à convertir en texte (le format converti n'est pas pris en charge)",
    'zh': "👩🏽‍💻<b>附上</b>圆形视频笔记（望远镜）转文字（不支持转换格式）",
    'ar': "<b>إرفاق</b> مذكرة فيديو مستديرة (تلسكوب) لتحويلها إلى نص (التنسيق المحول غير مدعوم)",
}

l_audio_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>audio</i> в",
    'en': "👩🏽‍💻 <b>Choose</b> tools to convert <i>audio</i> to",
    'es': "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>audio</i> a",
    'fr': "👩🏽‍💻 <b>Choisissez</b> des outils pour convertir <i>l&#x27;audio</i> en",
    'zh': "👩🏽‍💻<b>选择</b>将<i>音频</i>转换为的工具",
    'ar': "👩🏽‍💻 <b>اختر</b> أدوات لتحويل <i>الصوت</i> إلى",
}
l_audio_mp3 = {
    'ru': "▶️ mp3-аудио",
    'en': "▶️ mp3-audio",
    'es': "▶️ audio mp3",
    'fr': "▶️ audio mp3",
    'zh': "▶️ mp3音频",
    'ar': "▶ ️ mp3 الصوت",
}
l_audio_ogg = {
    'ru': "🎤 ogg-голосовое",
    'en': "🎤 ogg-voice",
    'es': "🎤 voz ogg",
    'fr': "🎤 ogg-voix",
    'zh': "🎤 ogg 声音",
    'ar': "🎤 ogg-voice",
}
l_audio_transcribe = {
    'ru': "🗣️ транскрибация",
    'en': "🗣️ transcription",
    'es': "🗣️ transcripción",
    'fr': "🗣️ retranscription",
    'zh': "🗣️ 转录",
    'ar': "🗣️ النسخ",
}
l_audio_mp3_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> голосовое для преобразования в mp3",
    'en': "👩🏽‍💻 <b>Attach</b> voice to convert to mp3",
    'es': "👩🏽‍💻 <b>Adjuntar</b> voz para convertir a mp3",
    'fr': "👩🏽‍💻 <b>Joindre</b> une voix pour convertir en mp3",
    'zh': "👩🏽‍💻<b>附上</b>语音转换成mp3",
    'ar': "👩🏽‍💻 <b>إرفاق</b> الصوت للتحويل إلى mp3",
}
l_audio_ogg_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> audio для преобразования в голосовое",
    'en': "👩🏽‍💻 <b>Attach</b> audio to convert to voice",
    'es': "👩🏽‍💻 <b>Adjuntar</b> audio para convertir a voz",
    'fr': "👩🏽‍💻 <b>Attachez</b> l'audio pour convertir en voix",
    'zh': "👩🏽‍💻<b>附加</b>音频以转换为语音",
    'ar': "👩🏽‍💻 <b>إرفاق</b> الصوت لتحويله إلى صوت",
}
l_audio_transcribe_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> голосовое для преобразования в текст",
    'en': "👩🏽‍💻 <b>Attach</b> voice to convert to text (converted format not supported)",
    'es': "👩🏽‍💻 <b>Adjuntar</b> voz para convertir a texto (formato convertido no compatible)",
    'fr': "👩🏽‍💻 <b>Attachez</b> la voix pour convertir en texte (format converti non pris en charge)",
    'zh': "👩🏽‍💻<b>附加</b>语音转换为文本（不支持转换格式）",
    'ar': "<b>إرفاق</b> صوت لتحويله إلى نص (التنسيق المحول غير مدعوم)",
}
l_audio_recognize = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> распознавания речи",
    'en': "👩🏽‍💻 Speech Recognition <b>Error</b>",
    'es': "👩🏽‍💻 <b>Error</b> de reconocimiento de voz",
    'fr': "👩🏽‍💻 <b>Erreur</b> de reconnaissance vocale",
    'zh': "👩🏽‍💻语音识别<b>错误</b>",
    'ar': "👩🏽‍💻 <b>خطأ</b> في التعرف على الكلام",
}

l_text_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>текста</i> в",
    'en': "👩🏽‍💻 <b>Choose</b> tools to convert <i>text</i> to",
    'es': "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>texto</i> a",
    'fr': "👩🏽‍💻 <b>Choisissez</b> des outils pour convertir du <i>texte</i> en",
    'zh': "👩🏽‍💻<b>选择</b>将<i>文本</i>转换为的工具",
    'ar': "👩🏽‍💻 <b>اختر</b> أدوات لتحويل <i>النص</i> إلى",
}
l_text_bin = {
    'ru': "🔢 bin",
    'en': "▶️ mp3-audio",
    'es': "▶️ audio mp3",
    'fr': "▶️ audio mp3",
    'zh': "▶️ mp3音频",
    'ar': "▶ ️ mp3 الصوت",
}
l_text_hex = {
    'ru': "🔠 hex",
    'en': "▶️ mp3-audio",
    'es': "▶️ audio mp3",
    'fr': "▶️ audio mp3",
    'zh': "▶️ mp3音频",
    'ar': "▶ ️ mp3 الصوت",
}
l_text_null = {
    'ru': "0️⃣ null",
    'en': "▶️ mp3-audio",
    'es': "▶️ audio mp3",
    'fr': "▶️ audio mp3",
    'zh': "▶️ mp3音频",
    'ar': "▶ ️ mp3 الصوت",
}
l_text_mp3 = {
    'ru': "▶️ mp3-аудио",
    'en': "▶️ mp3-audio",
    'es': "▶️ audio mp3",
    'fr': "▶️ audio mp3",
    'zh': "▶️ mp3音频",
    'ar': "▶ ️ mp3 الصوت",
}
l_text_url = {
    'ru': "️🧾 url-encode",
    'en': "️🧾 url-encode",
    'es': "️🧾 codificación de URL",
    'fr': "️🧾 url-encoder",
    'zh': "️🧾 网址编码",
    'ar': "️🧾 عنوان url ترميز",
}
l_text_bin_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в бинарный вид",
    'en': "👩🏽‍💻 <b>Attach</b> text to convert to voice",
    'es': "👩🏽‍💻 <b>Adjuntar</b> texto para convertir a voz",
    'fr': "👩🏽‍💻 <b>Joindre</b> du texte à convertir en voix",
    'zh': "👩🏽‍💻<b>附加</b>文本以转换为语音",
    'ar': "👩🏽‍💻 <b>إرفاق</b> نص لتحويله إلى صوت",
}
l_text_hex_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в hex-символы",
    'en': "👩🏽‍💻 <b>Attach</b> text to convert to voice",
    'es': "👩🏽‍💻 <b>Adjuntar</b> texto para convertir a voz",
    'fr': "👩🏽‍💻 <b>Joindre</b> du texte à convertir en voix",
    'zh': "👩🏽‍💻<b>附加</b>文本以转换为语音",
    'ar': "👩🏽‍💻 <b>إرفاق</b> نص لتحويله إلى صوت",
}
l_text_mp3_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в голосовое",
    'en': "👩🏽‍💻 <b>Attach</b> text to convert to voice",
    'es': "👩🏽‍💻 <b>Adjuntar</b> texto para convertir a voz",
    'fr': "👩🏽‍💻 <b>Joindre</b> du texte à convertir en voix",
    'zh': "👩🏽‍💻<b>附加</b>文本以转换为语音",
    'ar': "👩🏽‍💻 <b>إرفاق</b> نص لتحويله إلى صوت",
}
l_text_url_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> текст для url-encode-преобразования",
    'en': "👩🏽‍💻 <b>Attach</b> text for url-encode conversion",
    'es': "👩🏽‍💻 <b>Adjunte</b> texto para la conversión de codificación URL",
    'fr': "👩🏽‍💻 <b>Joindre</b> du texte pour la conversion en url-encode",
    'zh': "👩🏽‍💻<b>附加</b>文本进行 url-encode 转换",
    'ar': "👩🏽‍💻 <b>إرفاق</b> نص لتحويل ترميز url",
}
l_text_text1024 = {
    'ru': "💭 Текст 1024 символа",
    'en': "💭 Text 1024 characters",
    'es': "💭 Texto 1024 caracteres",
    'fr': "💭 Texte 1024 caractères",
    'zh': "💭 文本 1024 个字符",
    'ar': "💭 نص 1024 حرفًا",
}
l_text_text4096 = {
    'ru': "🗯️ Текст 4096 символа",
    'en': "🗯️ Text 4096 characters",
    'es': "🗯️ Texto 4096 caracteres",
    'fr': "🗯️ Texte 4096 caractères",
    'zh': "🗯️ 文本 4096 个字符",
    'ar': "🗯️ نص 4096 حرفًا",
}

l_convert_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> преобразования контента (попробуй позже и загрузи другой файл)",
    'en': "👩🏽‍💻 Content Conversion <b>Error</b> (Please try later and upload another file)",
    'es': "👩🏽‍💻 <b>Error</b> de conversión de contenido (intente más tarde y cargue otro archivo)",
    'fr': "👩🏽‍💻 <b>Erreur</b> de conversion de contenu (veuillez réessayer plus tard et télécharger un autre fichier)",
    'zh': "👩🏽‍💻内容转换<b>错误</b>（请稍后再试并上传另一个文件）",
    'ar': "👩🏽‍💻 <b>خطأ</b> في تحويل المحتوى (يرجى المحاولة لاحقًا وتحميل ملف آخر)",
}
l_telegraph_text = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> .jpg/.png/.gif/.mp4 - контент, чтобы создать ссылку",
    'en': "👩🏽‍💻 <b>Attach</b> .jpg/.png/.gif/.mp4 content to create a link",
    'es': "👩🏽‍💻 <b>Adjunte</b> contenido .jpg/.png/.gif/.mp4 para crear un enlace",
    'fr': "👩🏽‍💻 <b>Joignez</b> du contenu .jpg/.png/.gif/.mp4 pour créer un lien",
    'zh': "👩🏽‍💻<b>附加</b>.jpg/.png/.gif/.mp4 内容以创建链接",
    'ar': "👩🏽‍💻 <b>أرفق</b> محتوى .jpg / .png / .gif / .mp4 لإنشاء ارتباط",
}
l_telegraph_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> получения ссылки (попробуй позже ии загрузи другой файл)",
    'en': "👩🏽‍💻 <b>Failed</b> to get link (try later and upload another file)",
    'es': "👩🏽‍💻 <b>No se pudo</b> obtener el enlace (intente más tarde y cargue otro archivo)",
    'fr': "👩🏽‍💻 <b>Échec</b> de l'obtention du lien (essayez plus tard et téléchargez un autre fichier)",
    'zh': "👩🏽‍💻 获取链接<b>失败</b>（请稍后尝试并上传另一个文件）",
    'ar': "👩🏽‍💻 <b>فشل</b> الحصول على الرابط (حاول لاحقًا وقم بتحميل ملف آخر)",
}
l_json_text = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> любое сообщение или сделай пересылку",
    'en': "👩🏽‍💻 <b>Attach</b> any message or forward",
    'es': "👩🏽‍💻 <b>Adjunte</b> cualquier mensaje o reenvíe",
    'fr': "👩🏽‍💻 <b>Joindre</b> n'importe quel message ou transférer",
    'zh': "👩🏽‍💻<b>附上</b>任何讯息或转发",
    'ar': "👩🏽‍💻 <b>إرفاق</b> أي رسالة أو إعادة توجيهها",
}
# endregion


# region FereyMediaBot
l_media_btn1 = {
    'ru': "⛰️ Медиа",
    'en': "⛰️ Media",
    'es': "⛰️ Medios",
    'fr': "⛰️ Médias",
    'zh': "⛰️ 媒体",
    'ar': "⛰️ ميديا",
}
l_media_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_media_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>медиа</code>-заметок:\n\n▪️<b>стикеры</b> из текста и фото\n▪️<b>аудио-звуки</b>\n▪️<b>видео-заметки</b>\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>the landing bot of</i> <code>медиа</code> notes:\n\n▪️ <b>stickers</b> from text and photos\n▪️ <b>audio sounds</b>\n▪️ <b>video notes</b>\n\n❗️ you can also order the development of a chat bot in our Ferey studio",
    'es': "🌱 {0}, bienvenido <i>al bot de aterrizaje de</i> notas <code>медиа</code> :\n\n▪️ <b>pegatinas</b> de texto y fotos\n▪️ <b>sonidos de audio</b>\n▪️ <b>notas de video</b>\n\n❗️ también puedes solicitar el desarrollo de un bot de chat en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue dans <i>le bot de débarquement des</i> notes <code>медиа</code> :\n\n▪️ <b>autocollants</b> à partir de textes et de photos\n▪️ <b>sons audio</b>\n▪️ <b>notes vidéo</b>\n\n❗️ vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎来到<code>медиа</code>笔记<i>的登陆机器人</i>：\n\n▪️文字和照片的<b>贴纸</b>\n▪️<b>音频声音</b>\n▪️<b>视频笔记</b>\n\n❗️您也可以在我们的Ferey工作室",
    'ar': "🌱 {0} ، مرحبًا بك في <i>الروبوت الأساسي</i> لملاحظات <code>медиа</code> :\n\n▪️ <b>ملصقات</b> من النصوص والصور\n▪️ <b>الأصوات الصوتية</b>\n▪️ <b>ملاحظات الفيديو</b>\n\n❗️ يمكنك أيضًا طلب تطوير روبوت الدردشة في استوديو Ferey الخاص بنا",
}

l_media_text = {
    'ru': "👩🏽‍💻 <b>Здесь</b> можно выбрать тип выпадающих media-заметок (/add | /del)",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puede seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici,</b> vous pouvez sélectionner le type de notes multimédia déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>可以选择下拉媒体备注的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/ add | / del)",
}
l_media_del = {
    'ru': "👩🏽‍💻 <b>Выбери</b> media-заметку для удаления",
    'en': "👩🏽‍💻 <b>Select</b> media note to delete",
    'es': "👩🏽‍💻 <b>Seleccione</b> nota multimedia para eliminar",
    'fr': "👩🏽‍💻 <b>Sélectionnez</b> la note multimédia à supprimer",
    'zh': "👩🏽‍💻<b>选择</b>要删除的媒体备注",
    'ar': "<b>حدد</b> ملاحظة وسائط لحذفها",
}
l_media_show = {
    'ru': "👩🏽‍💻 <b>Введи</b> текст для поиска по media-заметкам",
    'en': "👩🏽‍💻 <b>Select</b> media note to delete",
    'es': "👩🏽‍💻 <b>Seleccione</b> nota multimedia para eliminar",
    'fr': "👩🏽‍💻 <b>Sélectionnez</b> la note multimédia à supprimer",
    'zh': "👩🏽‍💻<b>选择</b>要删除的媒体备注",
    'ar': "<b>حدد</b> ملاحظة وسائط لحذفها",
}
l_media_random = {
    'ru': "🎲 <b>Случайный</b> выбор",
    'en': "👩🏽‍💻 <b>Select</b> media note to delete",
    'es': "👩🏽‍💻 <b>Seleccione</b> nota multimedia para eliminar",
    'fr': "👩🏽‍💻 <b>Sélectionnez</b> la note multimédia à supprimer",
    'zh': "👩🏽‍💻<b>选择</b>要删除的媒体备注",
    'ar': "<b>حدد</b> ملاحظة وسائط لحذفها",
}
l_media_none = {
    'ru': "👩🏽‍💻 <b>Media</b>-заметок не найдено",
    'en': "👩🏽‍💻 <b>Select</b> media note to delete",
    'es': "👩🏽‍💻 <b>Seleccione</b> nota multimedia para eliminar",
    'fr': "👩🏽‍💻 <b>Sélectionnez</b> la note multimédia à supprimer",
    'zh': "👩🏽‍💻<b>选择</b>要删除的媒体备注",
    'ar': "<b>حدد</b> ملاحظة وسائط لحذفها",
}
l_media_file = {
    'ru': "👩🏽‍💻 1/2. <b>Прикрепи</b> audio/video, text/photo контент для создания media-заметки",
    'en': "👩🏽‍💻 1/2. <b>Attach</b> audio/video, text/photo content to create a media note",
    'es': "👩🏽‍💻 1/2. <b>Adjunte</b> contenido de audio/video, texto/foto para crear una nota multimedia",
    'fr': "👩🏽‍💻 1/2. <b>Joignez</b> du contenu audio/vidéo, texte/photo pour créer une note multimédia",
    'zh': "👩🏽‍💻 1/2。<b>附加</b>音频/视频、文本/照片内容以创建媒体说明",
    'ar': "👩🏽‍💻 1/2. <b>قم بإرفاق</b> محتوى صوت / فيديو ونص / صورة لإنشاء ملاحظة وسائط",
}
l_media_title1 = {
    'ru': "👩🏽‍💻 2/2. <b>Введи</b> <code>ключевые_слова</code> для твоей media-заметки\n[изменить <code>ключевые_слова</code> нельзя]",
    'en': "👩🏽‍💻 2/2. <b>Enter</b> <code>ключевые_слова</code> for your media note\n[<code>ключевые_слова</code> cannot be changed]",
    'es': "👩🏽‍💻 2/2. <b>Ingrese</b> <code>ключевые_слова</code> para su nota de prensa\n[<code>ключевые_слова</code> no se pueden cambiar]",
    'fr': "👩🏽‍💻 2/2. <b>Saisissez</b> <code>ключевые_слова</code> pour votre note média\n[<code>ключевые_слова</code> ne peuvent pas être modifiés]",
    'zh': "👩🏽‍💻 2/2。为您的媒体说明<b>输入</b><code>ключевые_слова</code>\n[无法更改<code>ключевые_слова</code>]",
    'ar': "👩🏽‍💻 2/2. <b>أدخل</b> <code>ключевые_слова</code> لملاحظتك الإعلامية\n[لا يمكن تغيير <code>ключевые_слова</code>]",
}
l_media_title2 = {
    'ru': "👩🏽‍💻 2/2. <b>Текущие</b> <code>ключевые_слова</code> для твоей media-заметки\n\n{0}\n\n[пришли новые или нажми {1}]",
    'en': "👩🏽‍💻 2/2. <b>Current</b> <code>ключевые_слова</code> for your media note\n\n{0}\n\n[new ones come in or press {1}]",
    'es': "👩🏽‍💻 2/2. <code>ключевые_слова</code> <b>actuales</b> para su nota de prensa\n\n{0}\n\n[nuevas ingrese o presione {1}]",
    'fr': "👩🏽‍💻 2/2. <code>ключевые_слова</code> <b>actuels</b> pour votre note multimédia\n\n{0}\n\n[les nouveaux arrivent ou appuyez sur {1}]",
    'zh': "👩🏽‍💻 2/2。您的媒体说明的<b>当前</b><code>ключевые_слова</code>\n\n{0}\n\n[请输入新关键字或按 {1}]",
    'ar': "👩🏽‍💻 2/2. <code>ключевые_слова</code> <b>الحالية</b> لملاحظة الوسائط الخاصة بك\n\n{0}\n\n[يتم إدخال كلمات رئيسية جديدة أو الضغط على {1}]",
}
l_media_confirm = {
    'ru': "🏁 Завершить",
    'en': "🏁 Complete",
    'es': "🏁 Completa",
    'fr': "🏁 Complet",
    'zh': "🏁 完成",
    'ar': "🏁 مكتمل",
}
l_media_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> (попробуй позже или загрузи другое media)",
    'en': "👩🏽‍💻 <b>Error</b> (try later or upload another media)",
    'es': "👩🏽‍💻 <b>Error</b> (intenta más tarde o sube otro medio)",
    'fr': "👩🏽‍💻 <b>Erreur</b> (essayez plus tard ou téléchargez un autre média)",
    'zh': "👩🏽‍💻<b>错误</b>（稍后再试或上传其他媒体）",
    'ar': "👩🏽‍💻 <b>خطأ</b> (حاول لاحقًا أو قم بتحميل وسائط أخرى)",
}
l_media_finish = {
    'ru': "👩🏽‍💻 <b>Media</b>-заметка успешно создана",
    'en': "👩🏽‍💻 <b>Media</b> - note created successfully",
    'es': "👩🏽‍💻 <b>Medios</b> : nota creada con éxito",
    'fr': "👩🏽‍💻 <b>Média</b> - note créée avec succès",
    'zh': "👩🏽‍💻<b>媒体</b>- 笔记创建成功",
    'ar': "👩🏽‍💻 <b>الوسائط</b> - تم إنشاء الملاحظة بنجاح",
}
l_media_publish = {
    'ru': "🔗 Список",
    'en': "🔗 List",
    'es': "🔗 Lista",
    'fr': "🔗 Liste",
    'zh': "🔗 清单",
    'ar': "🔗 قائمة",
}
l_media_check = {
    'ru': "🔗 Проверка",
    'en': "🔗 Check",
    'es': "🔗 Comprobar",
    'fr': "🔗 Vérifier",
    'zh': "🔗 检查",
    'ar': "🔗 تحقق",
}
l_media_hasdeleted = {
    'ru': "👩🏽‍💻 <b>Media</b>-заметка удалена",
    'en': "👩🏽‍💻 <b>Media</b> - note deleted",
    'es': "👩🏽‍💻 <b>Medios</b> - nota eliminada",
    'fr': "👩🏽‍💻 <b>Médias</b> - note supprimée",
    'zh': "👩🏽‍💻<b>媒体</b>- 注释已删除",
    'ar': "👩🏽‍💻 <b>الوسائط</b> - تم حذف الملاحظة",
}
l_media_delprepare = {
    'ru': "🔗 Выбрать",
    'en': "🔗 Choose",
    'es': "🔗 Elige",
    'fr': "🔗 Choisissez",
    'zh': "🔗选择",
    'ar': "🔗 اختر",
}
# endregion


# region FereyFindBot
l_find_btn1 = {
    'ru': "⛰️ Поиск",
    'en': "⛰️ Search",
    'es': "⛰️ Buscar",
    'fr': "⛰️ Rechercher",
    'zh': "⛰️ 搜索",
    'ar': "⛰️ بحث",
}
l_find_btn2 = {
    'ru': "📍 Geo поиск",
    'en': "📍 Geo search",
    'es': "📍 Búsqueda geográfica",
    'fr': "📍 Recherche géographique",
    'zh': "📍地理搜索",
    'ar': "📍 البحث الجغرافي",
}
l_find_btn3 = {
    'ru': "🔔 Уведомления",
    'en': "🔔 Notifications",
    'es': "🔔 Notificaciones",
    'fr': "🔔 Notifications",
    'zh': "🔔 通知",
    'ar': "🔔 الإخطارات",
}
l_find_btn4 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_find_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>поиска</code> в <b>Telegram</b>:\n\n▪️<b>top</b> каналы/группы\n▪️<b>vip</b> пользователи/боты\n▪️<b>гео</b> парсинг\n▪️<b>пассивный</b> маркетинг\n\n❗️также можно заказать разработку Telegram-продвижения в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <b>Telegram</b> <code>поиска</code> <i>landing bot</i> :\n\n▪️ <b>top</b> channels/groups\n▪️ <b>vip</b> users/bots\n▪️ <b>geo</b> parsing\n▪️ <b>passive</b> marketing\n\n❗️ you can also order development Telegram promotions in our Ferey studio",
    'es': "🌱 {0}, bienvenido al <i>bot de aterrizaje</i> <code>поиска</code> <b>de Telegram</b> :\n\n▪️ canales/grupos <b>principales</b>\n▪️ usuarios <b>vip</b> /bots\n▪️ análisis <b>geográfico</b>\n▪️ marketing <b>pasivo</b>\n\n❗️ también puedes solicitar promociones de desarrollo de Telegram en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue sur <b>Telegram</b> <code>поиска</code> <i>landing bot</i> :\n\n▪️ <b>meilleurs</b> canaux/groupes\n▪️ utilisateurs/bots <b>vip</b>\n▪️ analyse <b>géographique</b>\n▪️ marketing <b>passif</b>\n\n❗️ vous pouvez également commander des promotions de développement Telegram dans notre atelier de Ferey",
    'zh': "🌱 {0}，欢迎使用<b>Telegram</b> <code>поиска</code><i>登陆机器人</i>：\n\n▪️<b>热门</b>频道/群组\n▪️ <b>vip</b>用户/机器人\n▪️<b>地理</b>解析\n▪️<b>被动</b>营销\n\n❗️ 您也可以订购开发 Telegram 促销在我们的Ferey工作室",
    'ar': "🌱 {0} ، مرحبًا بك في <i>الروبوت الهبوطي</i> <code>поиска</code> <b>Telegram</b> :\n\n▪️ <b>أفضل</b> القنوات / المجموعات\n▪️ مستخدمين / برامج تتبع <b>لكبار</b> الشخصيات\n▪️ تحليل <b>جغرافي</b>\n▪️ تسويق <b>سلبي</b>\n\n❗️ يمكنك أيضًا طلب ترويجات Telegram للتطوير في استوديو Ferey الخاص بنا",
}
l_geo_minus = {
    'ru': "-",
    'en': "-",
    'es': "-",
    'fr': "-",
    'zh': "-",
    'ar': "-",
}
l_geo_current = {
    'ru': "📍R: {0}m",
    'en': "📍R: {0}m",
    'es': "📍R: {0}m",
    'fr': "📍R : {0}mois",
    'zh': "📍R：{0}米",
    'ar': "📍R: {0} م",
}
l_geo_plus = {
    'ru': "+",
    'en': "+",
    'es': "+",
    'fr': "+",
    'zh': "+",
    'ar': "+",
}
l_geo_text1 = {
    'ru': "📍 <b>Geo-поиск</b> пользователей по координатам\n\n👩🏽‍💻 <b>Жми</b> на -/+, чтобы настроить 📍Radius",
    'en': "📍 <b>Geo-search</b> users by coordinates\n\n👩🏽‍💻 Click on -/+ to adjust 📍Radius",
    'es': "📍 Usuarios <b>de búsqueda geográfica</b> por coordenadas\n\n👩🏽‍💻 Haz clic en -/+ para ajustar el 📍Radio",
    'fr': "📍 <b>Géo-recherche</b> des utilisateurs par coordonnées\n\n👩🏽‍💻 Cliquez sur -/+ pour ajuster 📍Rayon",
    'zh': "📍 按坐标<b>地理搜索</b>用户\n\n👩🏽‍💻 点击 -/+ 调整📍半径",
    'ar': "📍 <b>البحث الجغرافي</b> للمستخدمين عن طريق الإحداثيات\n\n👩🏽‍💻 انقر فوق - / + لضبط 📍Radius",
}
l_geo_text2 = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> геопозицию через 📎-меню вложений или на<b>Жми</b> на кнопку ниже\n[📍Отправить Geo] 👇🏽",
    'en': "👩🏽‍💻 <b>Attach</b> a location via the attachments 📎 menu or click the button below\n[📍Send Geo] 👇🏽",
    'es': "👩🏽‍💻 <b>Adjunte</b> una ubicación a través del menú de archivos adjuntos 📎 o haga clic en el botón a continuación\n[📍Enviar geo] 👇🏽",
    'fr': "👩🏽‍💻 <b>Joignez</b> un emplacement via le menu des pièces jointes 📎 ou cliquez sur le bouton ci-dessous\n[📍Envoyer la géo] 👇🏽",
    'zh': "👩🏽‍💻通过附件📎菜单<b>附加</b>位置或单击下面的按钮\n[📍发送地理信息]👇🏽",
    'ar': "👩🏽‍💻 <b>أرفق</b> موقعًا عبر قائمة المرفقات أو انقر فوق الزر أدناه\n[Send Geo] 👇🏽",
}
l_geo_send = {
    'ru': "📍Отправить Geo",
    'en': "📍Send Geo",
    'es': "📍Enviar Geo",
    'fr': "📍Envoyer Géo",
    'zh': "📍发送地理位置",
    'ar': "📍إرسال جيو",
}
l_geo_start = {
    'ru': "🔎 Начинаем поиск..",
    'en': "🔎 Let's start the search..",
    'es': "🔎 Comencemos la búsqueda..",
    'fr': "🔎 Commençons la recherche..",
    'zh': "🔎 让我们开始搜索..",
    'ar': "🔎 لنبدأ البحث ..",
}
l_geo_no = {
    'ru': "📍 Пользователей (@username) в данной геопозиции не найдено",
    'en': "📍 No users ( @username ) found in this location",
    'es': "📍 No se encontraron usuarios ( @username ) en esta ubicación",
    'fr': "📍 Aucun utilisateur ( @username ) trouvé à cet emplacement",
    'zh': "📍 在此位置找不到用户 ( @username )",
    'ar': "📍 لم يتم العثور على مستخدمين ( @username ) في هذا الموقع",
}
l_geo_finish = {
    'ru': "🔥 <b>Готово!</b> Найдено пользователей: <u>{0}</u>",
    'en': "🔥 Done! Found users: <u>{0}</u>",
    'es': "🔥 Listo! Usuarios encontrados: <u>{0}</u>",
    'fr': "🔥 C'est fait ! Utilisateurs trouvés : <u>{0}</u>",
    'zh': "🔥 完成！找到的用户： <u>{0}</u>",
    'ar': "🔥 انتهى! المستخدمون الموجودون: <u>{0}</u>",
}

l_find_add_cmd = {
    'ru': "👩🏽‍💻 <b>Пришли</b> ссылку на канал/группу/пользователя/бота",
    'en': "👩🏽‍💻 <b>Send</b> a link to a channel/group/user/bot",
    'es': "👩🏽‍💻 <b>Enviar</b> un enlace a un canal/grupo/usuario/bot",
    'fr': "👩🏽‍💻 <b>Envoyer</b> un lien vers un canal/groupe/utilisateur/bot",
    'zh': "👩🏽‍💻<b>发送</b>指向频道/组/用户/机器人的链接",
    'ar': "👩🏽‍💻 <b>أرسل</b> رابطًا لقناة / مجموعة / مستخدم / روبوت",
}
l_find_err_cmd = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> (вставь корректную ссылку или повтори позже)",
    'en': "👩🏽‍💻 <b>Error</b> adding (insert correct link or try again later)",
    'es': "👩🏽‍💻 <b>Error</b> al agregar (insertar enlace correcto o intentarlo más tarde)",
    'fr': "👩🏽‍💻 <b>Erreur</b> lors de l'ajout (insérez le lien correct ou réessayez plus tard)",
    'zh': "👩🏽‍💻 添加<b>错误</b>（插入正确的链接或稍后重试）",
    'ar': "👩🏽‍💻 <b>خطأ</b> في الإضافة (أدخل الرابط الصحيح أو حاول مرة أخرى لاحقًا)",
}
l_find_ok_cmd = {
    'ru': "👩🏽‍💻 <b>Ссылка</b> успешно добавлена!",
    'en': "👩🏽‍💻 <b>Link</b> added successfully!",
    'es': "👩🏽‍💻 ¡ <b>Enlace</b> agregado exitosamente!",
    'fr': "👩🏽‍💻 <b>Lien</b> ajouté avec succès !",
    'zh': "👩🏽‍💻<b>链接</b>添加成功！",
    'ar': "👩🏽‍💻 تمت إضافة <b>الرابط</b> بنجاح!",
}
l_find_check = {
    'ru': "🔗 Проверка",
    'en': "🔗 Check",
    'es': "🔗 Comprobar",
    'fr': "🔗 Vérifier",
    'zh': "🔗 检查",
    'ar': "🔗 تحقق",
}

l_find_menu = {
    'ru': "↩ Menu",
    'en': "↩ Menu",
    'es': "↩ Menú",
    'fr': "↩Menu",
    'zh': "↩ 菜单",
    'ar': "↩ القائمة",
}
l_find_text = {
    'ru': "<b>🔎 Сбор целевой аудитории (ЦА)</b>\n\n▪️выгрузка тематических каналов\n▪️выгрузка лидов/чатов с ЦА\n▪️выгрузка конкурентов по нише\n▪️каталог ботов\n\n<b>Итог:</b> <i>получение <u>горячей</u> ЦА, анализ ЦА конкурентов</i>",
    'en': "<b>🔎 Gathering the target audience (CA)</b>\n\n▪️uploading thematic channels\n▪️uploading leads/chats from the target audience\n▪️uploading competitors by niche\n▪️bot directory\n\n<b>Result:</b> <i>getting <u>a hot target</u> audience, analyzing the target audience of competitors</i>",
    'es': "<b>🔎 Reunir al público objetivo (CA)</b>\n\n▪️cargar canales temáticos\n▪️cargar clientes potenciales/chats del público objetivo\n▪️cargar competidores por nicho\n▪️directorio de bots\n\n<b>Resultado:</b> <i>obtener <u>un público objetivo atractivo</u> , analizando el público objetivo de los competidores</i>",
    'fr': "<b>🔎 Rassembler le public cible (CA)</b>\n\n▪️télécharger des chaînes thématiques\n▪️télécharger des prospects/chats du public cible\n▪️télécharger des concurrents par niche\n▪️annuaire de robots\n\n<b>Résultat :</b> <i>obtenir <u>un public cible chaud</u> , analysant le public cible des concurrents</i>",
    'zh': "<b>🔎 收集目标受众 (CA)</b>\n\n▪️上传主题频道\n▪️从目标受众上传线索/聊天\n▪️按利基上传竞争对手\n▪️bot 目录\n\n<b>结果：</b><i>获得<u>热门目标</u>受众, 分析竞争对手的目标受众</i>",
    'ar': "<b>🔎 تجميع الجمهور المستهدف (CA)</b>\n\n▪️ تحميل القنوات الموضوعية\n▪️ تحميل العملاء المتوقعين / الدردشات من الجمهور المستهدف\n▪️ تحميل المنافسين حسب المجال المناسب\n▪️ الدليل الآلي\n\n<b>النتيجة:</b> <i>الحصول على جمهور <u>مستهدف نشط</u> ، وتحليل الجمهور المستهدف من المنافسين</i>",
}
l_find_category_typing = {
    'ru': "✅ #ввести свои параметры",
    'en': "✅ #ввести your parameters",
    'es': "✅ #ввести tus parámetros",
    'fr': "✅ #ввести vos paramètres",
    'zh': "✅ # #ввести你的参数",
    'ar': "✅ # #ввести المعلمات الخاصة بك",
}
l_find_desc = {
    'ru': "<b>Описание:</b> {0}",
    'en': "<b>Description:</b> {0}",
    'es': "<b>Descripción:</b> {0}",
    'fr': "<b>Descriptif :</b> {0}",
    'zh': "<b>说明：</b> {0}",
    'ar': "<b>الوصف:</b> {0}",
}
l_find_reacts = {
    'ru': "<b>Реакции:</b> {0}",
    'en': "<b>Reactions:</b> {0}",
    'es': "<b>Reacciones:</b> {0}",
    'fr': "<b>Réactions :</b> {0}",
    'zh': "<b>反应：</b> {0}",
    'ar': "<b>التفاعلات:</b> {0}",
}
l_find_send = {
    'ru': "<b>Сообщ/медиа/инлайн/инвайт:</b> {0}/{1}/{2}/{3}",
    'en': "<b>Message/Media/Inline/Invite:</b> {0}/{1}/{2}/{3}",
    'es': "<b>Mensaje/Medios/En línea/Invitación:</b> {0}/{1}/{2}/{3}",
    'fr': "<b>Message/Média/Inline/Invitation :</b> {0}/{1}/{2}/{3}",
    'zh': "<b>消息/媒体/内联/邀请：</b> {0}/{1}/{2}/{3}",
    'ar': "<b>رسالة / وسائط / مضمنة / دعوة:</b> {0} / {1} / {2} / {3}",
}
l_find_bio = {
    'ru': "<b>Био:</b> {0}",
    'en': "<b>Bio:</b> {0}",
    'es': "<b>Biografía:</b> {0}",
    'fr': "<b>Biographie :</b> {0}",
    'zh': "<b>简历：</b> {0}",
    'ar': "<b>السيرة الذاتية:</b> {0}",
}
l_find_about = {
    'ru': "<b>Описание:</b> {0}",
    'en': "<b>Description:</b> {0}",
    'es': "<b>Descripción:</b> {0}",
    'fr': "<b>Descriptif :</b> {0}",
    'zh': "<b>说明：</b> {0}",
    'ar': "<b>الوصف:</b> {0}",
}
l_find_description = {
    'ru': "<b>Подробнее:</b> {0}",
    'en': "<b>Read more:</b> {0}",
    'es': "<b>Leer más:</b> {0}",
    'fr': "<b>En savoir plus :</b> {0}",
    'zh': "<b>阅读更多：</b> {0}",
    'ar': "<b>اقرأ المزيد:</b> {0}",
}
l_find_commands = {
    'ru': "<b>Команды:</b> {0}",
    'en': "<b>Commands:</b> {0}",
    'es': "<b>Comandos:</b> {0}",
    'fr': "<b>Commandes :</b> {0}",
    'zh': "<b>命令：</b> {0}",
    'ar': "<b>الأوامر:</b> {0}",
}

l_find_chn = {
    'ru': "📰 Каналы",
    'en': "📰 Channels",
    'es': "📰 Canales",
    'fr': "📰 Chaînes",
    'zh': "📰频道",
    'ar': "📰 القنوات",
}
l_find_grp = {
    'ru': "📁 Группы",
    'en': "📁 Groups",
    'es': "📁 Grupos",
    'fr': "📁 Groupes",
    'zh': "📁 团体",
    'ar': "📁 المجموعات",
}
l_find_usr = {
    'ru': "🕵️ Конкуренты",
    'en': "🕵️ Competitors",
    'es': "🕵️ Competidores",
    'fr': "🕵️ Concurrents",
    'zh': "🕵️ 参赛者",
    'ar': "🕵️ المنافسون",
}
l_find_bot = {
    'ru': "🫥 Tg-боты",
    'en': "🫥 Tg bots",
    'es': "🫥Tg bots",
    'fr': "🫥 Robots Tg",
    'zh': "🫥 Tg 机器人",
    'ar': "🫥 Tg bots",
}

l_find_chn_choose = {
    'ru': "📰 <b>Выбери категорию</b> для выгрузки каналов",
    'en': "📰 Choose <b>a category</b> for uploading channels",
    'es': "📰 Elige <b>una categoría</b> para subir canales",
    'fr': "📰 Choisissez <b>une catégorie</b> pour télécharger des chaînes",
    'zh': "📰 选择上传频道的<b>类别</b>",
    'ar': "📰 اختر <b>فئة</b> لتحميل القنوات",
}
l_find_grp_choose = {
    'ru': "📁 <b>Выбери категорию</b> для выгрузки групп",
    'en': "📁 Choose <b>a category</b> for uploading groups",
    'es': "📁 Elige <b>una categoría</b> para subir grupos",
    'fr': "📁 Choisissez <b>une catégorie</b> pour télécharger des groupes",
    'zh': "📁 选择上传群组的<b>类别</b>",
    'ar': "📁 اختر <b>فئة</b> لتحميل المجموعات",
}
l_find_usr_choose = {
    'ru': "🕵️ <b>Выбери категорию</b> для выгрузки пользователей",
    'en': "🕵️ Choose <b>a category</b> to upload users",
    'es': "🕵️ Elige <b>una categoría</b> para subir usuarios",
    'fr': "🕵️ Choisissez <b>une catégorie</b> pour télécharger des utilisateurs",
    'zh': "🕵️选择<b>一个类别</b>上传用户",
    'ar': "🕵️ اختر <b>فئة</b> لتحميل المستخدمين",
}
l_find_bot_choose = {
    'ru': "🥾 <b>Выбери категорию</b> для выгрузки ботов",
    'en': "🥾 Choose <b>a category</b> for uploading bots",
    'es': "🥾 Elija <b>una categoría</b> para cargar bots",
    'fr': "🥾 Choisissez <b>une catégorie</b> pour télécharger des bots",
    'zh': "🥾 选择上传机器人的<b>类别</b>",
    'ar': "🥾 اختر <b>فئة</b> لتحميل الروبوتات",
}

l_find_chn_find = {
    'ru': "🔎 Поиск по каналам",
    'en': "🔎 Channel search",
    'es': "🔎 búsqueda de canales",
    'fr': "🔎 Recherche de chaînes",
    'zh': "🔎 频道搜索",
    'ar': "🔎 قناة البحث",
}
l_find_grp_find = {
    'ru': "🔎 Поиск по группам",
    'en': "🔎 Group search",
    'es': "🔎 Búsqueda de grupos",
    'fr': "🔎 Recherche de groupe",
    'zh': "🔎 群组搜索",
    'ar': "🔎 بحث المجموعة",
}
l_find_usr_find = {
    'ru': "🔎 Поиск по конкурентам",
    'en': "🔎 Search by competitors",
    'es': "🔎 Búsqueda por competidores",
    'fr': "🔎 Recherche par concurrents",
    'zh': "🔎 按竞争对手搜索",
    'ar': "🔎 البحث عن طريق المنافسين",
}
l_find_bot_find = {
    'ru': "🔎 Поиск по ботам",
    'en': "🔎 Search by bots",
    'es': "🔎 Búsqueda por bots",
    'fr': "🔎 Recherche par bots",
    'zh': "🔎 机器人搜索",
    'ar': "🔎 البحث عن طريق الروبوتات",
}

l_find_chn_link = {
    'ru': "🔗 Перейти к каналу",
    'en': "🔗 Go to channel",
    'es': "🔗 Ir al canal",
    'fr': "🔗 Aller à la chaîne",
    'zh': "🔗 前往频道",
    'ar': "🔗 اذهب إلى القناة",
}
l_find_grp_link = {
    'ru': "🔗 Перейти к группе",
    'en': "🔗 Go to group",
    'es': "🔗 Ir al grupo",
    'fr': "🔗 Aller au groupe",
    'zh': "🔗 进群",
    'ar': "🔗 اذهب إلى المجموعة",
}
l_find_usr_link = {
    'ru': "🔗 Перейти к пользователю",
    'en': "🔗 Go to user",
    'es': "🔗 Ir a usuario",
    'fr': "🔗 Aller à l'utilisateur",
    'zh': "🔗 转到用户",
    'ar': "🔗 اذهب إلى المستخدم",
}
l_find_bot_link = {
    'ru': "🔗 Перейти к боту",
    'en': "🔗 Go to bot",
    'es': "🔗 Ir al bot",
    'fr': "🔗 Aller au robot",
    'zh': "🔗 转到机器人",
    'ar': "🔗 اذهب إلى bot",
}

l_find_category_blog = {
    'ru': "#блогер",
    'en': "#blogger",
    'es': "#bloguero",
    'fr': "#blogueur",
    'zh': "#博主",
    'ar': "#مدَّوِن",
}
l_find_category_digit = {
    'ru': "#оцифровка",
    'en': "#digitizer",
    'es': "#digitalizador",
    'fr': "#numériseur",
    'zh': "#数字转换器",
    'ar': "#جهاز التحويل الرقمي",
}
l_find_category_smm = {
    'ru': "#смм",
    'en': "#smm",
    'es': "#mmm",
    'fr': "#nm",
    'zh': "#嗯",
    'ar': "#سم",
}
l_find_category_recruit = {
    'ru': "#рекрут",
    'en': "#recruit",
    'es': "#recluta",
    'fr': "#recruter",
    'zh': "#招募",
    'ar': "#تجنيد",
}
l_find_category_design = {
    'ru': "#дизайн",
    'en': "#design",
    'es': "#diseño",
    'fr': "#conception",
    'zh': "#设计",
    'ar': "#تصميم",
}
l_find_category_coach = {
    'ru': "#коуч",
    'en': "#coach",
    'es': "#entrenador",
    'fr': "#entraîneur",
    'zh': "#教练",
    'ar': "#مدرب",
}
l_find_category_it = {
    'ru': "#ИТ",
    'en': "#DOG",
    'es': "#PERRO",
    'fr': "#CHIEN",
    'zh': "#狗",
    'ar': "#كلب",
}
l_find_category_course = {
    'ru': "#курсы",
    'en': "#courses",
    'es': "#cursos",
    'fr': "#cours",
    'zh': "#培训班",
    'ar': "#الدورات",
}
l_find_category_business = {
    'ru': "#бизнес",
    'en': "#business",
    'es': "#negocio",
    'fr': "#entreprise",
    'zh': "#商业",
    'ar': "#عمل",
}
l_find_category_goods = {
    'ru': "#товарка",
    'en': "#cargo",
    'es': "#carga",
    'fr': "#cargaison",
    'zh': "#货物",
    'ar': "#البضائع",
}
l_find_category_offline = {
    'ru': "#оффлайн",
    'en': "#offline",
    'es': "#desconectado",
    'fr': "#hors ligne",
    'zh': "#离线",
    'ar': "#غير متصل على الانترنت",
}
l_find_category_lawyer = {
    'ru': "#юрист",
    'en': "#lawyer",
    'es': "#abogado",
    'fr': "#avocat",
    'zh': "#律师",
    'ar': "#محامي",
}
l_find_category_verified = {
    'ru': "#верифиц",
    'en': "#verification",
    'es': "#verificación",
    'fr': "#vérification",
    'zh': "#确认",
    'ar': "#تَحَقّق",
}
l_find_category_premium = {
    'ru': "#премиум",
    'en': "#premium",
    'es': "#de primera calidad",
    'fr': "#prime",
    'zh': "#优质的",
    'ar': "#غالي",
}
l_find_category_health = {
    'ru': "#здоровье",
    'en': "#health",
    'es': "#salud",
    'fr': "#santé",
    'zh': "#健康",
    'ar': "#صحة",
}

l_find_category_getting = {
    'ru': "🔎 Выгружаем <b>категорию</b> {0}..\n\n#длительность 0мин",
    'en': "🔎 Upload <b>category</b> {0}..\n\n#duration 0min",
    'es': "🔎 Subir <b>categoría</b> {0}..\n\n#duración 0min",
    'fr': "🔎 <b>Catégorie</b> de téléchargement {0}..\n\n#durée 0min",
    'zh': "🔎 上传<b>类别</b>{0}..\n\n#duration 0min",
    'ar': "🔎 <b>فئة</b> التحميل {0} ..\n\n# المدة 0 دقيقة",
}
l_find_keyword_getting = {
    'ru': "🔎 Выгружаем базу по ключевым словам <i>{0}</i>..\n\n#длительность 1мин",
    'en': "🔎 Unload the database by keywords <i>{0}</i> ..\n\n#duration 1 min",
    'es': "🔎 Descarga la base de datos por palabras clave <i>{0}</i> ..\n\n#duración 1 min",
    'fr': "🔎 Décharger la base de données par mots clés <i>{0}</i> ..\n\n#durée 1 min",
    'zh': "🔎 通过关键字<i>{0}</i>卸载数据库 ..\n\n#duration 1 分钟",
    'ar': "🔎 تفريغ قاعدة البيانات بالكلمات الأساسية <i>{0}</i> ..\n\n# المدة 1 دقيقة",
}
l_find_category_keywords = {
    'ru': "📰 <b>Введи</b> ключевые слова для поиска через пробелы или разделители",
    'en': "📰 Enter keywords to search through spaces or delimiters",
    'es': "📰 Ingrese palabras clave para buscar a través de espacios o delimitadores",
    'fr': "📰 Entrez des mots-clés pour rechercher dans des espaces ou des délimiteurs",
    'zh': "📰 输入关键字以通过空格或分隔符进行搜索",
    'ar': "📰 أدخل كلمات أساسية للبحث من خلال المسافات أو المحددات",
}
l_find_reached = {
    'ru': "<b>Охват</b>: <u>{0}</u> польз.",
    'en': "<b>Reach</b> : <u>{0}</u> users",
    'es': "<b>Alcance</b> : <u>{0}</u> usuarios",
    'fr': "<b>Atteignez</b> : <u>{0}</u> utilisateurs",
    'zh': "<b>覆盖</b>： <u>{0}</u>个用户",
    'ar': "<b>الوصول</b> : <u>{0}</u> مستخدمين",
}
l_find_watch = {
    'ru': "🔎 Просмотр",
    'en': "🔎 View",
    'es': "🔎 Ver",
    'fr': "🔎 Voir",
    'zh': "🔎 查看",
    'ar': "🔎 عرض",
}
l_add_text = {
    'ru': "🔎 Добавь свой канал/группу/пользователя/бота в базу командой: <code>/add ССЫЛКА</code>\n\n👩🏽‍💻 Условия: наличие аватара и @username/ссылки (+ для канала/группы > 100 участников + последнее сообщение < 100 дней назад + для бота и пользователя наличие описания)",
    'en': "🔎 Add your channel/group/user/bot to the database with the command: <code>/add ССЫЛКА</code>\n\n👩🏽‍💻 Conditions: availability of an avatar and @username /link (+ for channel/group > 100 members + last message < 100 days ago + for the bot and the user, the presence of a description)",
    'es': "🔎 Agregue su canal/grupo/usuario/bot a la base de datos con el comando: <code>/add ССЫЛКА</code>\n\n👩🏽‍💻 Condiciones: disponibilidad de un avatar y @username /link (+ para canal/grupo > 100 miembros + último mensaje < hace 100 días + para el bot y el usuario, la presencia de una descripción)",
    'fr': "🔎 Ajoutez votre chaîne/groupe/utilisateur/bot à la base de données avec la commande : <code>/add ССЫЛКА</code>\n\n👩🏽‍💻 Conditions : disponibilité d'un avatar et @username /link (+ pour chaîne/groupe > 100 membres + dernier message il y a < 100 jours + pour le bot et l'utilisateur, la présence d'une description)",
    'zh': "🔎 使用以下命令将您的频道/组/用户/机器人添加到数据库： <code>/add ССЫЛКА</code>\n\n👩🏽‍💻 条件：头像和@username /link 的可用性（+ 对于频道/组 > 100 个成员 + 最后一个消息 < 100 天前 + 对于机器人和用户，存在描述）",
    'ar': "🔎 أضف قناتك / مجموعتك / مستخدم / بوت إلى قاعدة البيانات بالأمر: <code>/add ССЫЛКА</code>\n\n👩🏽‍💻 الشروط: توفر الصورة الرمزية و @username / الرابط (+ للقناة / المجموعة> 100 عضو + الأخير رسالة <100 يوم مضت + للروبوت والمستخدم ، وجود وصف)",
}
l_add_join_err = {
    'ru': "🚫 Добавить в базу {0} не удалось, необходимо открыть свободный доступ для присоединения",
    'en': "🚫 Failed to add {0} to the database, you need to open free access to join",
    'es': "🚫 No se pudo agregar {0} a la base de datos, debe abrir el acceso gratuito para unirse",
    'fr': "🚫 Échec de l'ajout de {0} à la base de données, vous devez ouvrir un accès gratuit pour rejoindre",
    'zh': "🚫 添加{0}到数据库失败，需要开通免费权限才能加入",
    'ar': "🚫 فشل إضافة {0} إلى قاعدة البيانات ، تحتاج إلى فتح وصول مجاني للانضمام",
}

l_add_chn_fail = {
    'ru': "🚫 Канал {0} - не добавлен в базу\n\n{1} аватар\n{2} >100 подписчиков\n{3} последний пост <100 дней назад",
    'en': "🚫 Channel {0} - not added to the database\n\n{1} avatar\n{2} >100 subscribers\n{3} last post <100 days ago",
    'es': "🚫 Canal {0} - no agregado a la base de datos\n\n{1} avatar\n{2} >100 suscriptores\n{3} última publicación <100 días atrás",
    'fr': "🚫 Chaîne {0} - non ajoutée à la base de données\n\n{1} avatar\n{2} >100 abonnés\n{3} dernier message il y a <100 jours",
    'zh': "🚫 频道 {0} - 未添加到数据库\n\n{1} 头像\n{2} >100 个订阅者\n{3} 上次发布 <100 天前",
    'ar': "🚫 القناة {0} - لم تتم إضافتها إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2}> 100 مشترك\n{3} آخر مشاركة منذ أقل من 100 يوم",
}
l_add_grp_fail = {
    'ru': "🚫 Группа {0} - не добавлена в базу\n\n{1} аватар\n{2} >100 участников\n{3} последний пост <100 дней назад",
    'en': "🚫 Group {0} - not added to the database\n\n{1} avatar\n{2} >100 members\n{3} last post <100 days ago",
    'es': "🚫 Grupo {0} - no agregado a la base de datos\n\n{1} avatar\n{2} >100 miembros\n{3} última publicación <100 días atrás",
    'fr': "🚫 Groupe {0} - non ajouté à la base de données\n\n{1} avatar\n{2} >100 membres\n{3} dernier message il y a <100 jours",
    'zh': "🚫 组 {0} - 未添加到数据库\n\n{1} 头像\n{2} >100 名成员\n{3} 上次发帖 <100 天前",
    'ar': "🚫 المجموعة {0} - لم تتم إضافتها إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2}> 100 عضو\n{3} آخر مشاركة منذ أقل من 100 يوم",
}
l_add_usr_fail = {
    'ru': "🚫 Пользователь {0} - не добавлен в базу\n\n{1} аватар\n{2} @username\n{3} био",
    'en': "🚫 User {0} - not added to database\n\n{1} avatar\n{2} @username\n{3} bio",
    'es': "🚫 Usuario {0}: no agregado a la base de datos\n\n{1} avatar\n{2} @username\n{3} biografía",
    'fr': "🚫 Utilisateur {0} - non ajouté à la base de données\n\n{1} avatar\n{2} @username\n{3} bio",
    'zh': "🚫 用户 {0} - 未添加到数据库\n\n{1} 头像\n{2} @username\n{3} bio",
    'ar': "🚫 المستخدم {0} - لم تتم إضافته إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2} @username\n{3} السيرة الذاتية",
}
l_add_bot_fail = {
    'ru': "🚫 Бот {0} - не добавлен в базу\n\n{1} аватар\n{2} описание",
    'en': "🚫 Bot {0} - not added to the database\n\n{1} avatar\n{2} description",
    'es': "🚫 Bot {0} - no agregado a la base de datos\n\n{1} avatar\n{2} descripción",
    'fr': "🚫 Bot {0} - non ajouté à la base de données\n\n{1} description de l'avatar\n{2}",
    'zh': "🚫 机器人 {0} - 未添加到数据库\n\n{1} 头像\n{2} 描述",
    'ar': "🚫 بوت {0} - لم تتم إضافته إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2} الوصف",
}

l_add_chn_done = {
    'ru': "✅ Канал {0} - добавлен в базу и обновлен",
    'en': "✅ Channel {0} - added to the database and updated",
    'es': "✅ Canal {0}: agregado a la base de datos y actualizado",
    'fr': "✅ Chaîne {0} - ajoutée à la base de données et mise à jour",
    'zh': "✅ 频道 {0} - 添加到数据库并更新",
    'ar': "✅ القناة {0} - تمت إضافتها إلى قاعدة البيانات وتحديثها",
}
l_add_grp_done = {
    'ru': "✅ Группа {0} - добавлена в базу и обновлена",
    'en': "✅ Group {0} - added to the database and updated",
    'es': "✅ Grupo {0}: agregado a la base de datos y actualizado",
    'fr': "✅ Groupe {0} - ajouté à la base de données et mis à jour",
    'zh': "✅ 组 {0} - 添加到数据库并更新",
    'ar': "✅ المجموعة {0} - تمت إضافتها إلى قاعدة البيانات وتحديثها",
}
l_add_usr_done = {
    'ru': "✅ Пользователь {0} - добавлен в базу и обновлен",
    'en': "✅ User {0} - added to the database and updated",
    'es': "✅ Usuario {0}: agregado a la base de datos y actualizado",
    'fr': "✅ Utilisateur {0} - ajouté à la base de données et mis à jour",
    'zh': "✅ 用户 {0} - 添加到数据库并更新",
    'ar': "✅ المستخدم {0} - تمت إضافته إلى قاعدة البيانات وتحديثها",
}
l_add_bot_done = {
    'ru': "✅ Бот {0} - добавлен в базу и обновлен",
    'en': "✅ Bot {0} - added to the database and updated",
    'es': "✅ Bot {0}: agregado a la base de datos y actualizado",
    'fr': "✅ Bot {0} - ajouté à la base de données et mis à jour",
    'zh': "✅ Bot {0} - 添加到数据库并更新",
    'ar': "✅ بوت {0} - تمت إضافته إلى قاعدة البيانات وتحديثها",
}

l_find_chn_done = {
    'ru': "🔥 <b>Готово!</b> По {0} собрано <u>{1}</u> каналов, сегментированных по <i>ключевым</i> словам\n\n<b>Охват</b>: <u>{2}</u> польз\n\nМожно связаться с администраторами каналов, чтобы заказать рекламу",
    'en': "🔥 Done! {0} collected <u>{1}</u> channels segmented by <i>keywords</i>\n\n<b>Reach</b> : <u>{2}</u> users\n\nYou can contact channel administrators to order advertising",
    'es': "🔥 Listo! {0} recopilaron <u>{1}</u> canales segmentados por <i>palabras clave</i>\n\n<b>Alcance</b> : <u>{2}</u> usuarios\n\nPuede ponerse en contacto con los administradores del canal para solicitar publicidad",
    'fr': "🔥 C'est fait ! {0} a collecté <u>{1}</u> chaînes segmentées par <i>mots-clés</i>\n\n<b>Atteinte</b> : <u>{2}</u> utilisateurs\n\nVous pouvez contacter les administrateurs de chaîne pour commander de la publicité",
    'zh': "🔥 完成！ {0} 收集了<u>{1} 个</u>按<i>关键字</i>细分的频道\n\n<b>覆盖</b>： <u>{2} 个</u>用户\n\n您可以联系频道管理员订购广告",
    'ar': "🔥 انتهى! القنوات {0} المجمعة <u>{1}</u> المقسمة حسب <i>الكلمات الرئيسية</i>\n\n<b>الوصول إلى</b> : <u>{2}</u> المستخدمين\n\nيمكنك الاتصال بمسؤولي القناة لطلب الإعلانات",
}
l_find_grp_done = {
    'ru': "🔥 <b>Готово!</b> По {0} собрано <u>{1}</u> чатов, сегментированных по <i>ключевым</i> словам\n\n<b>Охват</b>: <u>{2}</u> польз\n\nМожно сделать <b>рассылку</b> по группам",
    'en': "🔥 Done! {0} collected <u>{1}</u> chats, segmented by <i>keywords</i>\n\n<b>Reach</b> : <u>{2}</u> users\n\nCan be <b>sent</b> to groups",
    'es': "🔥 Listo! {0} <u>{1}</u> chats recopilados, segmentados por <i>palabras clave</i>\n\n<b>Alcance</b> : <u>{2}</u> usuarios\n\nSe puede <b>enviar</b> a grupos",
    'fr': "🔥 C'est fait ! {0} a collecté <u>{1}</u> chats, segmentés par <i>mots-clés</i>\n\n<b>Atteinte</b> : <u>{2}</u> utilisateurs\n\nPeut être <b>envoyé</b> à des groupes",
    'zh': "🔥 完成！ {0} 收集了<u>{1} 个</u>聊天，按<i>关键字细分</i>\n\n<b>覆盖</b>： <u>{2} 个</u>用户\n\n可以<b>发送</b>到组",
    'ar': "🔥 انتهى! {0} دردشات <u>{1}</u> مجمعة ، مقسمة حسب <i>الكلمات الرئيسية</i>\n\n<b>مدى الوصول</b> : <u>{2}</u> مستخدمين\n\nيمكن <b>إرسالها</b> إلى مجموعات",
}
l_find_usr_done = {
    'ru': "🔥 <b>Готово!</b> По {0} собрано <u>{1}</u> пользователей, сегментированных по <i>ключевым</i> словам\n\nМожно сразу сделать <b>рассылку</b> или подписку-<b>инвайт</b> в чат по <i>полученным</i> лидам",
    'en': "🔥 Done! {0} collected <u>{1}</u> users, segmented by <i>keywords</i>\n\nYou can immediately make <b>a mailing list</b> or subscribe <b>- invite</b> to the chat according to <i>the received</i> leads",
    'es': "🔥 Listo! {0} recopiló <u>{1}</u> usuarios, segmentados por <i>palabras clave</i>\n\nPuede crear <b>una lista de correo</b> o suscribirse de inmediato <b>: invite</b> al chat de acuerdo con <i>los clientes potenciales recibidos</i>",
    'fr': "🔥 C'est fait ! {0} utilisateurs collectés <u>{1}</u> , segmentés par <i>mots-clés</i>\n\nVous pouvez immédiatement créer <b>une liste de diffusion</b> ou vous abonner <b>- inviter</b> au chat en fonction <i>des prospects reçus</i>",
    'zh': "🔥 完成！ {0} 收集了<u>{1} 个</u>用户，按<i>关键字</i>细分\n\n您可以立即制作<b>邮件列表</b>或订阅<b>-</b>根据<i>收到的</i>线索邀请聊天",
    'ar': "🔥 انتهى! {0} تم تجميع <u>{1}</u> مستخدمين ، مقسمين حسب <i>الكلمات الرئيسية</i>\n\nيمكنك على الفور إنشاء <b>قائمة بريدية</b> أو الاشتراك <b>- قم بدعوة</b> إلى الدردشة وفقًا للعملاء <i>المحتملين المستلمين</i>",
}
l_find_bot_done = {
    'ru': "🔥 <b>Готово!</b> По {0} собрано <u>{1}</u> ботов, сегментированных по <i>ключевым</i> словам",
    'en': "🔥 Done! {0} collected <u>{1}</u> bots segmented by <i>keywords</i>",
    'es': "🔥 Listo! {0} recopilaron <u>{1}</u> bots segmentados por <i>palabras clave</i>",
    'fr': "🔥 C'est fait ! {0} collecté <u>{1}</u> bots segmentés par <i>mots-clés</i>",
    'zh': "🔥 完成！ {0} 收集了<u>{1} 个</u><i>按关键字</i>细分的机器人",
    'ar': "🔥 انتهى! {0} جمعت <u>{1}</u> برامج التتبع مقسمة حسب <i>الكلمات الرئيسية</i>",
}
l_hashtag_categories = {
    "BLOG": ["blog", "блог", "влог", "блогер", "контентмейкер", 'contentmaker', 'youtube', 'путешестви',
             "курс", 'getcourse', 'геткурс', "английск", 'школ', "school", "запуск", 'заняти', 'урок', 'воркшоп',
             "language", "онлайн-школ", "онлайн школ", 'лингвист', 'linguist', 'марафон', 'практикум', 'семинар',
             'вебинар', 'лаборатор', 'хакатон', 'интенсив', 'обучени', 'запуск', 'колледж', 'институт',
             'университет', 'лекци', 'мастермайнд', 'симпозиум', 'тренинг', 'тимбилдинг', 'мастерск', 'образовани'],
    "DIGIT": ['оцифров', "фин.", 'финан', 'бух', 'инвест', 'франш', 'трейд', 'бирж', 'кредит', "учет",
              "банк", "торг", "кассы", "денежн", "консалт", 'consult', 'finan', 'business', "доход"],
    "SMM": ['smm', 'смм', 'инста', 'inst', "facebook", 'tiktok', "тикток", 'tik-tok', "тик-ток", 'youtube', 'маркето',
            'маркети', 'market', 'таргет', "target", 'распаковка', 'продвижение', 'seo', 'сео', 'бренд', "агентство",
            "лиды", "vkontakte", "вконтакте", "лидов", "реклам", 'taplink', "прогрев", "блог", "визуал", "запуск",
            "трафик", "mvp", "редакция",
            'директ'],
    "RECRUIT": ["рекрут", "роп", "работа", "фриланc", "freela", "найм", "hr", "pr", "персонал", "менеджер",
                "продаж", "ассист", "риелтор", 'млм', 'mlm', "управлен", "наем", "сотрудн", "делегир", "карьер"],
    "DESIGN": ["дизайн", "design", "интерьер", "декор", "мебел", "3d", "архитект", "двери", "ремонт", "строител",
               "фасад", 'тексти', "рису", "креатив", "визуал", "ландшафт", "художн", "картин",
               "имидж", "камин", "монтаж", 'граф', 'искусств', 'рукодел'],
    "COACH": ["коуч", "coach", 'консульт', 'продюсер', "бизнес", "наставн", "оратор", "энерг", "эксперт", "психо",
              "трекер", 'гайд',
              "практик", "бренд", "тайм", "мотива", "логопед", "мышлен", "нумеролог", "таролог", "йог",
              "ментор", "тренер", "гештальт", "предприним", "метафори", "денеж", "диагност", "icf"],
    "IT": ["лендинг", "crm", 'kotlin', 'swift', 'flutter', 'c++', 'c#', 'unity', 'angular',
           'amocrm', "powerbi", 'программирова', 'tilda', 'frontend', 'backend', 'python', 'ux/ui',
           "битрикс", 'автоматизаци', 'автоворон', 'разработч', 'java',
           "developer", 'блокчейн', 'blockchain', 'startup', 'coding'],
    "BUSINESS": ["business", "бизнес", "инвест", "франш", "кредит", "торг", "консалт", "consult",
                 "доход", "представит", "предпринимат", "коммерц", "фирм", "предприят", "компани", "промышл",
                 "производст", "invest", "капитал", "capital", "корпорац", "агентств", "пассив",
                 "дистриб", "акцио", "холдин", "прибыл", "рубл", "стартап", 'startup'],
    "GOODS": ["wildbe", "вайлд", 'ozon', "озон", 'avito', "авито", "авторск", "одежд", "китай",
              "китая", "складчина", "подарк", 'модн', 'маркетплейс', 'вещи'],
    "OFFLINE": ["салон", "студи", "логист", "грузопер", 'свечи', "маникюр", "макияж", "букеты", "клиник",
                "косметол", "магазин", "производств", 'эпиляц', 'парикмах', "ресниц", 'beauty', "кондитер",
                'бьюти', "пищев", 'кулинар', 'оффлайн', 'offline', 'адрес', 'храм', 'церковь', 'транспорт',
                'ресторан', 'недвижимость'],
    "HEALTH": ["beautifull", "beauty", "бьюти", "красота", "здоров", 'нутрициолог', 'косметик', 'косметол', 'йога',
               'питани', 'доктор', 'диет', 'похуден', 'волос', 'маникюр', 'макияж', 'клиник', 'ресниц', 'эпиляц',
               'парикмах', 'nutrition', 'krasota', 'zdorov', 'dietol', 'медицин', 'medic', 'стоматол',
               'врач', 'vrach', 'yoga', 'фитнес', 'fitnes', 'медиц', 'медик', 'лекарств', 'спортив', 'sport',
               'семья',
               'дети', 'ребенок'],
}
l_hashtag_translate = {
    "BLOG": {
        'ru': "#блоггер",
        'en': "#blogger",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "DIGIT": {
        'ru': "#оцифровка",
        'en': "#digit",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "SMM": {
        'ru': "#смм",
        'en': "#smm",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "RECRUIT": {
        'ru': "#рекрут",
        'en': "#recruit",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "DESIGN": {
        'ru': "#дизайн",
        'en': "#design",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "COACH": {
        'ru': "#коуч",
        'en': "#coach",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "IT": {
        'ru': "#ИТ",
        'en': "#IT",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "BUSINESS": {
        'ru': "#бизнес",
        'en': "#business",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "GOODS": {
        'ru': "#товарка",
        'en': "#goods",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "OFFLINE": {
        'ru': "#оффлайн",
        'en': "#offline",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "HEALTH": {
        'ru': "#здоровье",
        'en': "#health",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "ISVERIFIED": {
        'ru': "#верифиц",
        'en': "#virified",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "ISPREMIUM": {
        'ru': "#премиум",
        'en': "#premium",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
}

l_find_alert = {
    'ru': "👩🏽‍💻 <b>Жми</b> на ✅/☑️, чтобы вкл/выкл <i>уведомления</i> о Telegram-заказчиках в freelance-группах/каналах\n\n🔔 Например, <i>#ищу ассистента для ведения Telegram-канала или #search разработчик telegram-ботов</i>",
    'en': "👩🏽‍💻 <b>Click</b> on ✅/☑️ to turn on/off <i>notifications</i> about Telegram customers in freelance groups/channels\n\n🔔 For example, <i>#ищу</i> <i>an assistant to maintain a Telegram channel or</i> <i>#search</i> <i>a telegram bot developer</i>",
    'es': "👩🏽‍💻 <b>Haz clic</b> en ✅/☑️ para activar/desactivar <i>las notificaciones</i> sobre los clientes de Telegram en grupos/canales independientes\n\n🔔 Por ejemplo, <i>#ищу</i> <i>un asistente para mantener un canal de Telegram o</i> <i>#search</i> <i>un desarrollador de bots de Telegram</i>",
    'fr': "👩🏽‍💻 <b>Cliquez</b> sur ✅/☑️ pour activer/désactiver <i>les notifications</i> concernant les clients Telegram dans les groupes/canaux indépendants\n\n🔔 Par exemple, <i>#ищу</i> <i>un assistant pour gérer un canal Telegram ou</i> <i>#search</i> <i>un développeur de bot Telegram</i>",
    'zh': "👩🏽‍💻<b>点击</b>✅/☑️ 开启/关闭自由群组/频道中有关 Telegram 客户的<i>通知</i>\n\n🔔 例如， <i>#ищу维护</i><i> Telegram 频道的助手或#search一个 telegram 机器人开发者</i>",
    'ar': "👩🏽‍💻 <b>انقر</b> فوق ✅ / ☑️ لتشغيل / إيقاف تشغيل <i>الإشعارات</i> حول عملاء Telegram في مجموعات / قنوات مستقلة\n\n🔔 على سبيل المثال ، <i>#ищу</i> <i>مساعد للحفاظ على قناة Telegram أو</i> <i>#search</i> <i>مطور برامج Telegram bot</i>",
}
l_find_need_subscribe = {
    'ru': "👩🏽‍💻 <b>Для</b> получения ссылки на сообщение и заказчика оформи подписку на @FereyFindBot-бота:\n\nhttps://t.me",
    'en': "👩🏽‍💻 <b>To</b> get a link to the message and the customer, subscribe to @FereyFindBot -bot:\n\nhttps://t.me",
    'es': "👩🏽‍💻 <b>Para</b> obtener un enlace al mensaje y al cliente, suscríbete a @FereyFindBot -bot:\n\nhttps://t.me",
    'fr': "👩🏽‍💻 <b>Pour</b> obtenir un lien vers le message et le client, abonnez-vous à @FereyFindBot -bot :\n\nhttps://t.me",
    'zh': "👩🏽‍💻<b>要</b>获取消息和客户的链接，请订阅@FereyFindBot -bot：\n\nhttps://t.me",
    'ar': "👩🏽‍💻 <b>للحصول</b> على ارتباط للرسالة والعميل ، اشترك في @FereyFindBot -bot:\n\nhttps: //t.me",
}
# endregion


# region FereyChannelBot
l_chn_btn1 = {
    'ru': '⛰️ Каналы',
    'en': "⛰️ VPN",
    'es': "⛰️VPN",
    'fr': "⛰️VPN",
    'zh': "⛰️ VPN",
    'ar': "⛰️ VPN",
}
l_chn_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_chn_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>администрирования</code> <b>Telegram</b>-каналов:\n\n▪️<b>защита</b> канала от вступления шпионов\n▪️вывод <b>статистики</b> и вовлеченности (%)\n▪️ограничение прав до <b>подписки</b> на канал\n▪️<b>организация</b> бана и антифлуда\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>the landing bot</i> of the Ferey project:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ you can also order the development of a chat bot in our Ferey studio",
    'es': "🌱 {0}, bienvenido al <i>bot de aterrizaje</i> del proyecto Ferey:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ también puedes encargar el desarrollo de un chat bot en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue sur <i>le landing bot</i> du projet Ferey :\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎来到 Ferey 项目的<i>落地机器人</i>：\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️您也可以在我们的Ferey工作室订购聊天机器人的开发",
    'ar': "🌱 {0} ، مرحبًا بك في <i>روبوت الهبوط</i> الخاص بمشروع Ferey:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ يمكنك أيضًا طلب تطوير روبوت محادثة في استوديو Ferey",
}
l_add_chn_text = {
    'ru': "👮🏽‍♀️ <b>Добавь</b> @{0}-бота как  <b>Administrator</b> через настройки своего канала: ‹👤Add Admin›\n\n👮🏽‍♀️ <b>Опция</b> [✅ Назначение администраторов] позволит сделать парсинг старых пользователей, даже если в канале более 200 пользователей",
    'en': "👇🏽 Push the ‹channel› to add into your channel (with default settings): @{0}\n\n👮🏽‍♀️ Or add bot as <b>Admin</b> via Settings of your channel: ‹👤Add Admin›\n\n👮🏽‍♀️ If you can't add channel, try to change <b>Custom Title</b> (look screenshot)",
    'es': "👇🏽 Presione ‹➕ Agregar grupo› para agregar a su grupo (con la configuración predeterminada): @{0}\n\n👮🏽‍♀️ O agregue bot como <b>Administrador</b> a través de la Configuración de su grupo: ‹👤Agregar administrador›\n\n👮🏽‍♀️ Si no puede agregar un grupo, intente cambiar <b>Título personalizado</b> (ver captura de pantalla)",
    'fr': "👇🏽 Appuyez sur ‹➕ Ajouter un channele› pour ajouter à votre channele (avec les paramètres par défaut): @{0}\n\n👮🏽‍♀️ Ou ajoutez le bot en tant qu'<b>administrateur</b> via les paramètres de votre channele : ‹👤Ajouter un administrateur›\n\n👮🏽‍♀️ Si vous ne pouvez pas ajouter de channele, essayez de modifier le <b>Titre personnalisé</b> (regardez la capture d'écran)",
    'zh': "👇🏽 按下‹➕添加群組›以添加到您的群組（使用默認設置）: @{0}\n\n👮🏽‍♀️ 或通過您組的設置將機器人添加為 <b>Admin</b>：‹👤添加管理員›\n\n👮🏽‍♀️ 如果無法添加組，請嘗試更改 <b>自定義標題</b>（看截圖）",
    'ar': "👇🏽 اضغط على ‹➕ إضافة مجموعة› لإضافتها إلى مجموعتك (بالإعدادات الافتراضية): @{0}\n\n👮🏽‍♀️ أو أضف البوت كـ <b> مسؤول </b> عبر إعدادات مجموعتك: ‹👤 إضافة مسؤول›\n\n👮🏽‍♀️ إذا لم تتمكن من إضافة مجموعة ، فحاول تغيير <b> عنوان مخصص </b> (انظر في لقطة الشاشة)",
}
l_add_chn_txt_call = {
    'ru': "👮🏽‍♀️ Добавь @{0}-бота как Administrator через настройки своего канала: ‹👤Add Admin›",
    'en': "👇🏽 Push the ‹channel› to add into your channel (with default settings): @{0}\n\n👮🏽‍♀️ Or add bot as <b>Admin</b> via Settings of your channel: ‹👤Add Admin›\n\n👮🏽‍♀️ If you can't add channel, try to change <b>Custom Title</b> (look screenshot)",
    'es': "👇🏽 Presione ‹➕ Agregar grupo› para agregar a su grupo (con la configuración predeterminada): @{0}\n\n👮🏽‍♀️ O agregue bot como <b>Administrador</b> a través de la Configuración de su grupo: ‹👤Agregar administrador›\n\n👮🏽‍♀️ Si no puede agregar un grupo, intente cambiar <b>Título personalizado</b> (ver captura de pantalla)",
    'fr': "👇🏽 Appuyez sur ‹➕ Ajouter un channele› pour ajouter à votre channele (avec les paramètres par défaut): @{0}\n\n👮🏽‍♀️ Ou ajoutez le bot en tant qu'<b>administrateur</b> via les paramètres de votre channele : ‹👤Ajouter un administrateur›\n\n👮🏽‍♀️ Si vous ne pouvez pas ajouter de channele, essayez de modifier le <b>Titre personnalisé</b> (regardez la capture d'écran)",
    'zh': "👇🏽 按下‹➕添加群組›以添加到您的群組（使用默認設置）: @{0}\n\n👮🏽‍♀️ 或通過您組的設置將機器人添加為 <b>Admin</b>：‹👤添加管理員›\n\n👮🏽‍♀️ 如果無法添加組，請嘗試更改 <b>自定義標題</b>（看截圖）",
    'ar': "👇🏽 اضغط على ‹➕ إضافة مجموعة› لإضافتها إلى مجموعتك (بالإعدادات الافتراضية): @{0}\n\n👮🏽‍♀️ أو أضف البوت كـ <b> مسؤول </b> عبر إعدادات مجموعتك: ‹👤 إضافة مسؤول›\n\n👮🏽‍♀️ إذا لم تتمكن من إضافة مجموعة ، فحاول تغيير <b> عنوان مخصص </b> (انظر في لقطة الشاشة)",
}
l_add_chn_button = {
    'ru': "➕ Добавить канал",
    'en': "➕ Add channel",
    'es': "➕ Agregar grupo",
    'fr': "➕ Ajouter un channele",
    'zh': "➕ 添加組",
    'ar': "➕ إضافة مجموعة",
}
l_bot_removed = {
    'ru': "🚫 @{0}-бот удален из <b>{1}</b> (<code>{2}</code>)",
    'en': "🚫 @{0}-бот удален из {1} (<code>{2}</code>)",
    'es': "➕ Agregar grupo",
    'fr': "➕ Ajouter un channele",
    'zh': "➕ 添加組",
    'ar': "➕ إضافة مجموعة",
}

l_chn_config = {
    ("cban", "🕵🏽", "☑"): {
        'ru': "Авто-бан",
        'en': "Auto-ban",
        'es': "Prohibición automática",
        'fr': "Interdiction automatique",
        'zh': "自動禁止",
        'ar': "حظر تلقائي",
    },
    ("cpost", "🔔", "☐"): {
        'ru': "Авто-постинг",
        'en': "Auto-posting",
        'es': "Publicación automática",
        'fr': "Publication automatique",
        'zh': "自動發布",
        'ar': "النشر التلقائي",
    },
    ("creact", "👍🏽", "☐"): {
        'ru': "Авто-реакции",
        'en': "System messages",
        'es': "Mensajes del sistema",
        'fr': "Messages système",
        'zh': "系統消息",
        'ar': "رسائل النظام",
    },
    ("cview", "👁️‍🗨️", "☐"): {
        'ru': "Авто-просмотры",
        'en': "System messages",
        'es': "Mensajes del sistema",
        'fr': "Messages système",
        'zh': "系統消息",
        'ar': "رسائل النظام",
    },
    ("cdecor", "🪄", "☐"): {
        'ru': "Авто-декор",
        'en': "System messages",
        'es': "Mensajes del sistema",
        'fr': "Messages système",
        'zh': "系統消息",
        'ar': "رسائل النظام",
    },
    ("cmember", "👥", "☐"): {
        'ru': "Сбор подписчиков",
        'en': "System messages",
        'es': "Mensajes del sistema",
        'fr': "Messages système",
        'zh': "系統消息",
        'ar': "رسائل النظام",
    },
    ("ccheck", "👮🏽", "☐"): {
        'ru': "Запрос на вступление",
        'en': "Join request",
        'es': "Entrar en control",
        'fr': "Prenez le contrôle",
        'zh': "進入控制",
        'ar': "أدخل السيطرة",
    },
}
l_to_default = {
    'ru': "✖️Сброс настроек",
    'en': "✖️Restore settings",
    'es': "✖️Restaurar configuración",
    'fr': "✖️Restaurer les paramètres",
    'zh': "✖️恢復設置",
    'ar': "✖️ استعادة الإعدادات",
}
l_remove_channel = {
    'ru': "🚫Убрать канал",
    'en': "🚫Put away channel",
    'es': "🚫Guardar grupo",
    'fr': "🚫channele de rangement",
    'zh': "🚫收起組",
    'ar': "🚫 أبعد المجموعة",
}
l_show_channels = {
    'ru': "👩🏽‍💻 <b>Добавленные каналы</b>\n\n[команды /cmd]",
    'en': "👩🏽‍💻 <b>Added channels</b>\n\n[commands /cmd]",
    'es': "👩🏽‍💻 <b>Grupos añadidos</b>\n\n[comandos /cmd]",
    'fr': "👩🏽‍💻 <b>channeles ajoutés</b>\n\n[commands /cmd]",
    'zh': "👩🏽‍💻 <b>添加組</b>\n\n[命令 /cmd]",
    'ar': "👩🏽‍💻 <b> المجموعات المضافة </b> \n\n [أوامر /cmd]",
}
l_show_settings = {
    'ru': "⚙️ <b>Выбери</b> опцию для /cmd <i>настройки</i> [<b>{0}</b>] {1}",
    'en': "⚙️ <b>Choose</b> option for <i>settings</i> /cmd <b>{0}</b> {1}",
    'es': "⚙️ <b>Elegir</b> opción para <i>configuración</i> /cmd <b>{0}</b> {1}",
    'fr': "⚙️ <b>Choisir</b> l'option pour les <i>paramètres</i> /cmd <b>{0}</b> {1}",
    'zh': "⚙️ <i>設置</i> /cmd <b>{0}</b>{1}的<b>選擇</b>選項",
    'ar': "⚙️ <b> اختر </b> خيار <i> الإعدادات </i> /cmd <b>{0}</b>{1}",
}
l_chat_join_request_handler = {
    'ru': "👮🏽 {0}, ты отправил(а) заявку на вступление в <b>{1}</b>\n\n👉🏼 <b>Выбери</b> <i>правильный вариант</i> в соответствии с <code>заданием</code> на картинке, чтобы твоя <i>заявка</i> на вступление была <b>одобрена</b>",
    'en': "👮🏽 {0}, you send join-request to channel <b>{1}</b>\n\n👉🏼 Choose <i>correct option</i> according to the <code>task</code> on picture to Approve your join-<i>request</i>",
    'es': "👮🏽 {0}, envías una solicitud de unión al grupo <b>{1}</b>\n\n👉🏼 Elige la <i>opción correcta</i> según la <code>tarea</code> en la imagen para aprobar su <i>solicitud de unión</i>",
    'fr': "👮🏽 {0}, vous envoyez une demande de participation au channele <b>{1}</b>\n\n👉🏼 Choisissez <i>l'option correcte</i> en fonction de la <code>tâche</code> sur l'image pour approuver votre inscription-<i>demande</i>",
    'zh': "👮🏽 {0}，你發送加入請求到組 <b>{1}</b>\n\n👉🏼 根據<code>task</code>選擇<i>正確的選項</i> 在圖片上批准您的加入-<i>請求</i>",
    'ar': "👮🏽 {0} ، ترسل طلب انضمام إلى المجموعة <b>{1}</b> \n\n👉🏼 اختر <i> الخيار الصحيح </i> وفقًا لـ <code> المهمة </code> على الصورة للموافقة على انضمامك- <i> طلب </i>",
}
l_content_types_sub_button = {
    'ru': "👮🏽 Я подписался",
    'en': "👮🏽 I subscribed",
    'es': "👮🏽 Me suscribí",
    'fr': "👮🏽 Je me suis abonné",
    'zh': "👮🏽 我訂閱了",
    'ar': "👮🏽 لقد اشتركت",
}
l_content_types_subscribe = {
    'ru': "👮🏽 {0}, подпишись на {1}, чтобы твоя заявка на вступление была одобрена",
    'en': "👮🏽 {0}, subscribe on the {1} to join the channel",
    'es': "👮🏽 {0}, suscríbete en {1} para unirte al grupo",
    'fr': "👮🏽 {0}, abonnez-vous sur le {1} pour rejoindre le channele",
    'zh': "👮🏽 {0}，在 {1} 上訂閱以加入群組",
    'ar': "👮🏽 {0} ، اشترك في {1} للانضمام إلى المجموعة",
}
l_wait_1_min = {
    'ru': "🕐 Подожди 1мин",
    'en': "✖️ channel settings of [<b>{0}</b>] successfully reset!",
    'es': "✖️ ¡La configuración de grupo de [<b>{0}</b>] se restableció correctamente!",
    'fr': "✖️ Les paramètres de channele de [<b>{0}</b>] ont été réinitialisés !",
    'zh': "✖️ [<b>{0}</b>] 的群組設置已成功重置！",
    'ar': "✖️ تمت إعادة تعيين إعدادات المجموعة لـ [<b>{0}</b>] بنجاح!",
}

l_creturn_answer = {
    'ru': "✖️ Настройки для [<b>{0}</b>] успешно сброшены!",
    'en': "✖️ channel settings of [<b>{0}</b>] successfully reset!",
    'es': "✖️ ¡La configuración de grupo de [<b>{0}</b>] se restableció correctamente!",
    'fr': "✖️ Les paramètres de channele de [<b>{0}</b>] ont été réinitialisés !",
    'zh': "✖️ [<b>{0}</b>] 的群組設置已成功重置！",
    'ar': "✖️ تمت إعادة تعيين إعدادات المجموعة لـ [<b>{0}</b>] بنجاح!",
}
l_cdelete_text = {
    'ru': "🚫 Убрать привязку бота к [<b>{0}</b>]?",
    'en': "🚫 Put away bot-connection with channel [<b>{0}</b>]?",
    'es': "🚫 ¿Eliminar la conexión de bot con el grupo [<b>{0}</b>]?",
    'fr': "🚫 Mettre de côté la connexion au bot avec le channele [<b>{0}</b>] ?",
    'zh': "🚫 放棄與組 [<b>{0}</b>] 的機器人連接？",
    'ar': "🚫 التخلص من اتصال الروبوت بالمجموعة [<b>{0}</b>]؟",
}
l_cdelete_answer = {
    'ru': "🚫 <b>Бот</b> успешно отвязан от [<b>{0}</b>] и не числится его в участниках!",
    'en': "🚫 Bot successfully disconnected from channel [<b>{0}</b>] and it is not a member at all!",
    'es': "🚫 ¡El bot se desconectó con éxito del grupo [<b>{0}</b>] y no es miembro en absoluto!",
    'fr': "🚫 Le bot s'est déconnecté avec succès du channele [<b>{0}</b>] et il n'est pas du tout membre !",
    'zh': "🚫 Bot 已成功與群組 [<b>{0}</b>] 斷開連接，並且它根本不是成員！",
    'ar': "🚫 تم قطع اتصال البوت بنجاح بالمجموعة [<b>{0}</b>] وهو ليس عضوًا على الإطلاق!",
}

l_ccheck_btn_name = {
    'ru': "✔ Я человек",
    'en': "✔ I am human",
    'es': "✔ Soy humana",
    'fr': "✔ Je suis humain",
    'zh': "✔ 我是人",
    'ar': "✔ أنا إنسان",
}
l_ccheck_hello_txt = {
    'ru': "🌱 {name}, добро пожаловать в нашу <b>канал</b> {title}!",
    'en': "🌱 {name}, welcome to our <b>channel</b> {title}!",
    'es': "🌱 {name}, Bienvenida a nuestro <b>grupo</b> {title}!",
    'fr': "🌱 {name}, bienvenue dans notre <b>channele</b> {title}!",
    'zh': "🌱 {name}, 歡迎加入我們的<b>群</b> {title}!",
    'ar': "🌱 {name} ، مرحبًا بك في <b> مجموعتنا </ b> {title}!"
}
l_ccheck_add_channel = {
    'ru': "👮🏽 Для <i>проверки подписки</i> необходимо добавить канал командой:\n\n/channel ССЫЛКА НА КАНАЛ",
    'en': "👮🏽 It is necessary add channel for <i>subscribe checking</i> by command:\n\n/channel LINK",
    'es': "👮🏽 Es necesario agregar un canal para <i>comprobar suscripciones</i> mediante el comando:\n\n/channel LINK",
    'fr': "👮🏽 Il est nécessaire d'ajouter un canal pour <i>vérifier l'abonnement</i> par la commande :\n\n/channel LINK",
    'zh': "👮🏽 <i>訂閱檢查</i>需要通過命令添加頻道：\n\n/channel LINK",
    'ar': "👮🏽 من الضروري إضافة قناة لـ <i> فحص الاشتراك </i> بواسطة الأمر: \n\n/channel LINK",
}

# region commands
l_update_text = {
    'ru': "👩🏽‍💻 <b>Данные</b> о канале успешно обновлены:\n\n<b>{0}</b> [<code>{1}</code>]\n{2}\n<i>{3}</i>\n\n⚙️ <b>Команды</b> /cmd",
    'en': "➕ Add channel",
    'es': "➕ Agregar grupo",
    'fr': "➕ Ajouter un channele",
    'zh': "➕ 添加組",
    'ar': "➕ إضافة مجموعة",
}
l_chn_commands_handler = {
    'ru': "⚙️ <b>Настройка</b> канала <b>{0}</b> {1}\n\n<b>⛏ Admin-команды @{2}</b>\n/update <i>обновление параметров</i>\n/transfer   <i>передача admin-прав</i>\n/info   <i>информация</i>\n/stat   <i>статистика</i>\n/parse  <i>выгрузка базы подписчиков</i>\n/videochat 1 1 <i>анонс видео-трансляции</i>\n/clean  <i>долгая очистка канала от deleted/scam/fake-аккаунтов, а также по 🕵🏽 Авто-бан правилам</i>\n/channel NAME   <i>добавить другой канал для проверки подписки</i>",
    'en': "⚙️ <b>channel</b> settings of <b>{0}</b> {1}\n\n<b>⛏ Admin-commands @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/log   <i>see logs</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-accounts</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from channel for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in channel for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-accounts</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for channel</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'es': "⚙️ Configuración de <b>Grupo</b> de <b>{0}</b> {1}\n\n<b>⛏ Comandos de administración @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/log   <i>see logs</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-accounts</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from channel for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in channel for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-accounts</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for channel</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'fr': "⚙️ Paramètres de <b>channele</b> de <b>{0}</b> {1}\n\n<b>⛏ Commandes d'administration @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/log   <i>see logs</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-accounts</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from channel for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in channel for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-accounts</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for channel</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'zh': "⚙️ <b>組</b>設置 <b>{0}</b> {1}\n\n<b>⛏ 管理員命令 @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/log   <i>see logs</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-accounts</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from channel for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in channel for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-accounts</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for channel</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'ar': "⚙️ إعدادات <b> المجموعة </b> الخاصة بـ <b>{0}</b> {1}\n\n<b>⛏ أوامر المسؤول @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/parse  <i>[all|old|premium|active|online]</i>\n/log   <i>see logs</i>\n<code>/parse old</code> - <i>parsing old id-accounts</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from channel for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in channel for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-accounts</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for channel</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
}
l_info_restrict = {
    'ru': "<code>запрещено</code>\n",
    'en': "<code>prohibited</code>\n",
    'es': "<code>prohibida</code>\n",
    'fr': "<code>interdite</code>\n",
    'zh': "<code>禁止</code>\n",
    'ar': "<code>محظور</code>\n",
}
l_info_allow = {
    'ru': "<code>разрешено</code>\n",
    'en': "<code>allowed</code>\n",
    'es': "<code>permitida</code>\n",
    'fr': "<code>permise</code>\n",
    'zh': "<code>允許</code>\n",
    'ar': "<code>مسموح</code>\n",
}
l_info_protect = {
    'ru': "<b>Сохранение контента</b>: ",
    'en': "<b>Saving Content</b>: ",
    'es': "<b>Guardar contenido</b>:",
    'fr': "<b>Enregistrement du contenu</b> :",
    'zh': "<b>保存內容</b>：",
    'ar': "<b> حفظ المحتوى </b>:",
}
l_info_request = {
    'ru': "<b>Вступление после одобрения</b>: ",
    'en': "<b>Approve New Members</b>: ",
    'es': "<b>Aprobar nuevos miembros</b>:",
    'fr': "<b>Approuver les nouveaux membres</b> :",
    'zh': "<b>批准新成員</b>：",
    'ar': "<b> قبول الأعضاء الجدد </b>:",
}
l_info_send = {
    'ru': "<b>Возможность писать после вступления</b>: ",
    'en': "<b>Join to send message</b>: ",
    'es': "<b>Únete para enviar un mensaje</b>:",
    'fr': "<b>Rejoindre pour envoyer un message</b> :",
    'zh': "<b>加入發送消息</b>：",
    'ar': "<b> انضم لإرسال رسالة </b>:",
}
l_info_subscribe = {
    'ru': "<b>Проверка подписки при вступлении в канал</b>: ",
    'en': "<b>Check subscription to join</b>: ",
    'es': "<b>Verifique la suscripción para unirse</b>:",
    'fr': "<b>Vérifier l'abonnement pour rejoindre</b> :",
    'zh': "<b>檢查訂閱以加入</b>：",
    'ar': "<b> تحقق من الاشتراك للانضمام </b>:",
}
l_info_cmd = {
    'ru': "⚙️ <b>Команды</b> /cmd",
    'en': "Participants opportunities",
    'es': "Oportunidades de los participantes",
    'fr': "Opportunités pour les participants",
    'zh': "參與者機會",
    'ar': "فرص المشاركين",
}

l_change_chn_info = {
    'ru': "Изменение профиля канала",
    'en': "Change channel Info",
    'es': "Cambiar información del grupo",
    'fr': "Modifier les informations du channele",
    'zh': "更改組信息",
    'ar': "تغيير معلومات المجموعة",
}
l_send_messages = {
    'ru': "Отправка сообщений",
    'en': "Send Messages",
    'es': "Enviar mensajes",
    'fr': "Envoyer des messages",
    'zh': "發送信息",
    'ar': "إرسل رسائل",
}
l_info_reactions = {
    'ru': "Допуск emoji-реакций",
    'en': "Allowed emoji-reactions",
    'es': "Emoji-reacciones permitidas",
    'fr': "Emoji-réactions autorisées",
    'zh': "允許的表情符號反應",
    'ar': "ردود فعل الرموز التعبيرية المسموح بها",
}
l_admins = {
    'ru': "Администраторы",
    'en': "Administrators",
    'es': "Administradoras",
    'fr': "Administratrices",
    'zh': "管理員",
    'ar': "المسؤولين",
}

l_info_invite_admins = {
    'ru': "Приглашение других админов для",
    'en': "Promote admins for",
    'es': "Promocionar administradores para",
    'fr': "Promouvoir les administrateurs pour",
    'zh': "提升管理員為",
    'ar': "قم بترقية المسؤولين لـ",
}
l_chn_info_start1 = {
    'ru': "ℹ️ <b>Общая информация о канале</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    'en': "ℹ️ <b>Common info about channel statistics</b>\n\n",
    'es': "ℹ️ <b>Información común sobre las estadísticas del grupo</b>\n\n",
    'fr': "ℹ️ <b>Informations communes sur les statistiques de channele</b>\n\n",
    'zh': "ℹ️ <b>關於組統計的常見信息</b>\n\n",
    'ar': "ℹ️ <b> معلومات عامة حول إحصائيات المجموعة </b> \n\n",
}
l_chn_stat_start1 = {
    'ru': "ℹ️ <b>Общая статистика канала</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    'en': "ℹ️ <b>Common info about channel statistics</b>\n\n",
    'es': "ℹ️ <b>Información común sobre las estadísticas del grupo</b>\n\n",
    'fr': "ℹ️ <b>Informations communes sur les statistiques de channele</b>\n\n",
    'zh': "ℹ️ <b>關於組統計的常見信息</b>\n\n",
    'ar': "ℹ️ <b> معلومات عامة حول إحصائيات المجموعة </b> \n\n",
}
l_chn_stat_start2 = {
    'ru': "\n<b>Ссылка</b>: {0}\n<b>Описание</b>: {1}\n<b>Привязанная группа</b>: <code>{2}</code>\n",
    'en': "ℹ️ <b>Common info about channel statistics</b>\n\n",
    'es': "ℹ️ <b>Información común sobre las estadísticas del grupo</b>\n\n",
    'fr': "ℹ️ <b>Informations communes sur les statistiques de channele</b>\n\n",
    'zh': "ℹ️ <b>關於組統計的常見信息</b>\n\n",
    'ar': "ℹ️ <b> معلومات عامة حول إحصائيات المجموعة </b> \n\n",
}
l_chn_stat_start3 = {
    'ru': "\n<b>ID последнего поста</b>: {0}\n<b>Посты</b>: {1}\n<b>Реакции</b>: {2}\n<b>Просмотры</b>: {3}\n<b>Комментарии</b>: {4}\n<b>$кэштеги</b>: {5}\n<b>#хэштеги</b>: {6}\n",
    'en': "ℹ️ <b>Common info about channel statistics</b>\n\n",
    'es': "ℹ️ <b>Información común sobre las estadísticas del grupo</b>\n\n",
    'fr': "ℹ️ <b>Informations communes sur les statistiques de channele</b>\n\n",
    'zh': "ℹ️ <b>關於組統計的常見信息</b>\n\n",
    'ar': "ℹ️ <b> معلومات عامة حول إحصائيات المجموعة </b> \n\n",
}
l_top_hashtags = {
    'ru': "\n<b>Топ #хэштеги</b>:\n{0}\n",
    'en': "ℹ️ <b>Common info about channel statistics</b>\n\n",
    'es': "ℹ️ <b>Información común sobre las estadísticas del grupo</b>\n\n",
    'fr': "ℹ️ <b>Informations communes sur les statistiques de channele</b>\n\n",
    'zh': "ℹ️ <b>關於組統計的常見信息</b>\n\n",
    'ar': "ℹ️ <b> معلومات عامة حول إحصائيات المجموعة </b> \n\n",
}

l_transfer_start = {
    'ru': "⚠️ Пользователь {0} должен /start-запустить @{1}",
    'en': "⚠️ User {0} have to /start @{1}",
    'es': "⚠️ El usuario {0} debe /iniciar @{1}",
    'fr': "⚠️ L'utilisateur {0} doit /start @{1}",
    'zh': "⚠️ 用戶 {0} 必須 /start @{1}",
    'ar': "⚠️ المستخدم {0} يجب أن يبدأ @{1}",
}
l_transfer_admin = {
    'ru': "⚠️ Пользователь {0} должен быть <b>администратором</b> в <b>{1}</b>",
    'en': "⚠️ User {0} have to be <b>admin</b> of channel <b>{1}</b>",
    'es': "⚠️ El usuario {0} debe ser <b>administrador</b> del grupo <b>{1}</b>",
    'fr': "⚠️ L'utilisateur {0} doit être <b>admin</b> du channele <b>{1}</b>",
    'zh': "⚠️ 用戶 {0} 必須是組 <b>{1}</b> 的 <b>admin</b>",
    'ar': "⚠️ يجب أن يكون المستخدم {0}<b> مسؤولًا </b> للمجموعة <b>{1}</b>",
}
l_transfer_transfer = {
    'ru': "⚠️ Передать <b>admin</b>-права на <b>{0}</b> пользователю {1} в @{2}-боте?",
    'en': "⚠️ Are you sure to transfer ownership of channel <b>{0}</b> to user {1} in @{2}?",
    'es': "⚠️ ¿Estás seguro de transferir la propiedad del grupo <b>{0}</b> al usuario {1} en @{2}?",
    'fr': "⚠️ Êtes-vous sûr de transférer la propriété du channele <b>{0}</b> à l'utilisateur {1} dans @{2} ?",
    'zh': "⚠️ 您確定將組 <b>{0}</b> 的所有權轉讓給 @{2} 中的用戶 {1}？",
    'ar': "⚠️ هل أنت متأكد من نقل ملكية المجموعة <b>{0}</b> إلى المستخدم {1} في @{2}؟",
}
l_transfer_text = {
    'ru': "⚠️ Для передачи admin-прав канала в @{0}-боте используй команду: <code>/transfer ID-ПОЛЬЗОВАТЕЛЯ</code> (/id), где пользователь: администратор канала и участник @{0}-бота\n\n⚙️ <b>Команды</b> /cmd",
    'en': "⚠️ Use /transfer-command in reply user-message to transfer him ownership",
    'es': "⚠️ Use /transfer-command en el mensaje de usuario de respuesta para transferirle la propiedad",
    'fr': "⚠️ Utilisez /transfer-command dans le message utilisateur de réponse pour lui transférer la propriété",
    'zh': "⚠️ 使用 /transfer-command 回复 user-message 轉移他的所有權",
    'ar': "استخدم الأمر transfer-command/ في الرد على رسالة المستخدم لنقل ملكيته",
}
l_transfer_done_to = {
    'ru': "⚠️ <b>Admin</b>-права на [<b>{0}</b>] успешно переданы {1}",
    'en': "⚠️ <b>Admin</b>-privileges for channel [<b>{0}</b>] are successfully transferred to {1}",
    'es': "⚠️ <b>Administrador</b>: los privilegios del grupo [<b>{0}</b>] se transfirieron correctamente a {1}",
    'fr': "⚠️ Les privilèges <b>Admin</b> pour le channele [<b>{0}</b>] ont été transférés avec succès vers {1}",
    'zh': "⚠️ <b>Admin</b>-組 [<b>{0}</b>] 的權限已成功轉移到 {1}",
    'ar': "⚠️ تم نقل امتيازات <b> المسؤول </b> للمجموعة [<b>{0}</b>] بنجاح إلى {1}",
}
l_transfer_done_from = {
    'ru': "⚠️ <b>Admin</b>-права на [<b>{0}</b>] успешно получены от {1}",
    'en': "⚠️ <b>Admin</b>-privileges for channel [<b>{0}</b>] are successfully received from {1}",
    'es': "⚠️ <b>Administrador</b>: los privilegios para el grupo [<b>{0}</b>] se recibieron correctamente de {1}",
    'fr': "⚠️ Les privilèges <b>Admin</b> pour le channele [<b>{0}</b>] ont bien été reçus de {1}",
    'zh': "⚠️ <b>Admin</b>-組 [<b>{0}</b>] 的權限已從 {1} 成功接收",
    'ar': "⚠️ تم استلام امتيازات <b> المسؤول </b> للمجموعة [<b>{0}</b>] بنجاح من {1}",
}
l_chn_check = {
    'ru': "⚙️ Добавь @{0}-бота в канал для проверки подписки на него. Пришли мне корректную ссылку на канал:",
    'en': "⚙️ Add @{0} to channel for subscribe checking. Send me correct link to channel:",
    'es': "⚙️ Agregue @{0} al canal para verificar la suscripción. Envíame el enlace correcto al canal:",
    'fr': "⚙️ Ajoutez @{0} à la chaîne pour vérifier l'abonnement. Envoyez-moi le lien correct vers la chaîne :",
    'zh': "⚙️ 將@{0} 添加到頻道以進行訂閱檢查。 向我發送正確的頻道鏈接：",
    'ar': "⚙️ إضافة @{0} للقناة للتحقق من الاشتراك. أرسل لي الرابط الصحيح للقناة:",
}
l_videochat_rights = {
    'ru': "🎥 В настройках [Администраторы] вкл опцию для @{0}-бота:\n[✅ Назначение администраторов]\n[✅ Управление трансляциями]\n\n🕚Подожди 1min",
    'en': "In the Settings [Administrators] for @{0} enable:\n[✅ Delete Msgs]\n[✅ Ban Users]\n[✅ Invite Users]\n🕚Wait for 1min",
    'es': "En la Configuración [Administradores] para @{0} active:\n[✅ Eliminar mensajes]\n[✅ Prohibir usuarios]\n[✅ Invitar usuarios]\n🕚Espere 1 minuto",
    'fr': "Dans les paramètres [Administrateurs] pour @{0}, activez :\n[✅ Supprimer les messages]\n[✅ Bannir les utilisateurs]\n[✅ Inviter des utilisateurs]\n🕚Attendez 1 minute",
    'zh': "在@{0}的設置[管理員]中打開：\n[✅刪除消息]\n[✅禁止用戶]\n[✅邀請用戶]\n🕚等待1分鐘",
    'ar': " في الإعدادات [Administrators] لـ @{0} شغّل:\n [✅ حذف الرسائل] \n على [✅ حظر المستخدمين] \n [✅ دعوة المستخدمين] \n وانتظر لمدة دقيقة واحدة",
}
l_videochat_handler = {
    'ru': "🎥 Автоматическое анонсирование <b>видео-трансляции</b> <code>[/videochat d h]</code> каждый <u>d</u>-день (1-31) на <u>h</u>-часов (1-168). Текущее значение: /videochat {0}\n\n👩🏽‍💻 Например,\n<code>/videochat 1 1</code> (ежедневный видео-анонс длительностью 1 час)\n<code>/videochat 0</code> (отключение опции)\n\n⚙️ <b>Команды</b> /cmd",
    'en': "🎥 Send this command as reply to message",
    'es': "🎥 Enviar este comando como respuesta al mensaje",
    'fr': "🎥 Envoyez cette commande en réponse au message",
    'zh': "🎥 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_videochat_on = {
    'ru': "🎥 Анонсирована <b>видео-трансляция</b>: каждый <u>{0}</u> день на <u>{1}</u> часов\n\n⚙️ <b>Команды</b> /cmd",
    'en': "🎥 Send this command as reply to message",
    'es': "🎥 Enviar este comando como respuesta al mensaje",
    'fr': "🎥 Envoyez cette commande en réponse au message",
    'zh': "🎥 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_videochat_off = {
    'ru': "🎥 Анонсирование <b>видео-трансляции</b> отключено\n\n⚙️ <b>Команды</b> /cmd",
    'en': "🎥 Send this command as reply to message",
    'es': "🎥 Enviar este comando como respuesta al mensaje",
    'fr': "🎥 Envoyez cette commande en réponse au message",
    'zh': "🎥 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_ban_users_start = {
    'ru': "👩🏽‍💻 <b>Очистка</b> запущена\nТекущее количество пользователей в базе: <u>{0}</u>",
    'en': "🎥 Send this command as reply to message",
    'es': "🎥 Enviar este comando como respuesta al mensaje",
    'fr': "🎥 Envoyez cette commande en réponse au message",
    'zh': "🎥 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_ban_users_stop = {
    'ru': "👩🏽‍💻 <b>Очистка</b> завершена\nТекущее количество пользователей в базе: <u>{0}</u> (-{1})",
    'en': "🎥 Send this command as reply to message",
    'es': "🎥 Enviar este comando como respuesta al mensaje",
    'fr': "🎥 Envoyez cette commande en réponse au message",
    'zh': "🎥 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_chn_ccheck_handler = {
    'ru': "👮🏽 <b>Жми</b> на ✅/🔘, чтобы <b>переключить</b> тип <i>проверки</i> пользователя при <u>вступлении</u> по сгенерированной ссылке: {0} (только для <code>ЧАСТНЫХ</code> каналов)\n\n👉🏼 Для <b>проверки подписки</b> на другой канал <i>добавь</i> @{1}-бота в канал и выполни команду: <code>/channel {2}</code>\n\n👉🏼 Для <i>защиты от атаки</i> на канал включи режим <b>антирейд</b> (блокировка <u>всех</u> вступающих)",
    'en': "👮🏽 Push the ✅/🔘 to <b>switch</b> <i>Enter control</i> of user <u>joining</u> into channel\n\n👉🏼 To set name of <b>pushing button</b> execute command: <code>/button {0}</code>\n\n👉🏼 To check <b>channel-subscription</b> <i>add</i> @{1} to channel and execute command: <code>/channel {2}</code>\n\n👉🏼 To <i>defend</i> from channel-attack switch <b>anti-raid</b>-mode (ban <u>everyone</u> who joining)",
    'es': "👮🏽 Presiona ✅/🔘 para <b>cambiar</b> <i>Enter control</i> del usuario <u>uniéndose</u> al grupo\n\n👉🏼 Para establecer el nombre de <b> presionando el botón</b> ejecute el comando: <code>/button {0}</code>\n\n👉🏼 Para verificar <b>channel-subscription</b> <i>add</i> @{1} para canalizar y ejecutar el comando: <code>/channel {2}</code>\n\n👉🏼 Para <i>defender</i> del ataque grupal, active el modo <b>anti-raid</b> (prohibir a <u>todos</u> que se unan)",
    'fr': "👮🏽 Appuyez sur ✅/🔘 pour <b>commuter</b> <i>Entrez le contrôle</i> de l'utilisateur <u>rejoignant</u> le channele\n\n👉🏼 Pour définir le nom de <b> en appuyant sur le bouton</b> exécutez la commande : <code>/button {0}</code>\n\n👉🏼 Pour vérifier <b>channel-subscription</b> <i>add</i> @{1} pour canaliser et exécuter la commande : <code>/channel {2}</code>\n\n👉🏼 Pour <i>se défendre</i> contre une attaque de channele, activez le mode <b>anti-raid</b> (bannir <u>tous ceux</u> qui se joignent)",
    'zh': "👮🏽 按下 ✅/🔘 來<b>切換</b> <i>進入控制</i> 用戶<u>加入</u> 入組\n\n👉🏼 設置<b>的名字 按下按鈕</b> 執行命令：<code>/button {0}</code>\n\n👉🏼 檢查<b>頻道訂閱</b> <i>add</i> @{1} 引導並執行命令：<code>/channel {2}</code>\n\n👉🏼 以 <i>defend</i> 免受群攻開啟 <b>anti-raid</b>-mode （禁止加入的<u>每個人</u>）",
    'ar': "👮🏽 ادفع ✅ / 🔘 إلى <b> التبديل </b> <i> أدخل التحكم </i> للمستخدم <u> المنضم </u> إلى مجموعة \n\n👉🏼 لتعيين اسم <b> ضغط الزر </b> نفذ الأمر: <code> / button {0}</code>\n\n👉🏼 للتحقق من <b> اشتراك القناة </b> <i> إضافة </i> @{1} لتوجيه وتنفيذ الأمر: <code> / channel {2}</code>\n\n👉🏼 <i> للدفاع </i> من هجوم المجموعة ، شغّل وضع <b> anti-raid </b> (حظر <u> كل شخص </u> من ينضم)",
}
l_ccheck_call = {
    'ru': "👮🏽 Для проверки подписки необходимо добавить дополнительный канал командой:\n\n/channel ССЫЛКА НА КАНАЛ",
    'en': "👮🏽 To check <i>subscription</i> you have to add channel by command:\n\n/channel LINK",
    'es': "👮🏽 Para verificar la <i>suscripción</i>, debe agregar el canal mediante el comando:\n\n/channel LINK",
    'fr': "👮🏽 Pour vérifier l'<i>abonnement</i>, vous devez ajouter une chaîne par commande :\n\n/channel LINK",
    'zh': "👮🏽 要檢查<i>訂閱</i>，您必須通過命令添加頻道：\n\n/channel LINK",
    'ar': "👮🏽 للتحقق من <i> اشتراك </i> ، عليك إضافة قناة بأمر: \n\n/ channel LINK",
}
l_ccheck_call2 = {
    'ru': "👮🏽 В настройках [Администраторы] вкл опцию для @{0}-бота:\n[✅ Удаление сообщ]\n[✅ Блокировка польз]\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the Settings [Administrators] for @{0} enable:\n[✅ Delete Msgs]\n[✅ Ban Users]\n[✅ Invite Users]\n🕚Wait for 1min",
    'es': "👮🏽 En la Configuración [Administradores] para @{0} active:\n[✅ Eliminar mensajes]\n[✅ Prohibir usuarios]\n[✅ Invitar usuarios]\n🕚Espere 1 minuto",
    'fr': "👮🏽 Dans les paramètres [Administrateurs] pour @{0}, activez :\n[✅ Supprimer les messages]\n[✅ Bannir les utilisateurs]\n[✅ Inviter des utilisateurs]\n🕚Attendez 1 minute",
    'zh': "👮🏽 在@{0}的設置[管理員]中打開：\n[✅刪除消息]\n[✅禁止用戶]\n[✅邀請用戶]\n🕚等待1分鐘",
    'ar': " في الإعدادات [Administrators] لـ @{0} شغّل:\n [✅ حذف الرسائل] \n على [✅ حظر المستخدمين] \n [✅ دعوة المستخدمين] \n وانتظر لمدة دقيقة واحدة",
}
l_ccheck_chn_finish = {
    'ru': "👮🏽 <b>{0}</b>, <b>добро пожаловать</b>:\n\n{1}",
    'en': "👮🏽 To check <i>subscription</i> you have to add channel by command:\n\n/channel LINK",
    'es': "👮🏽 Para verificar la <i>suscripción</i>, debe agregar el canal mediante el comando:\n\n/channel LINK",
    'fr': "👮🏽 Pour vérifier l'<i>abonnement</i>, vous devez ajouter une chaîne par commande :\n\n/channel LINK",
    'zh': "👮🏽 要檢查<i>訂閱</i>，您必須通過命令添加頻道：\n\n/channel LINK",
    'ar': "👮🏽 للتحقق من <i> اشتراك </i> ، عليك إضافة قناة بأمر: \n\n/ channel LINK",
}
l_ccheck_free_on = {
    'ru': "✅☑Вкл свободный вход",
    'en': "✅☑On free entrance",
    'es': "✅☑En entrada libre",
    'fr': "✅☑En entrée libre",
    'zh': "✅☑免費入場",
    'ar': "✅☑ الدخول مجاني",
}
l_ccheck_free_off = {
    'ru': "🔘️☐Выкл свободный вход",
    'en': "🔘️☐Off free entrance",
    'es': "🔘️☐De Entrada libre",
    'fr': "🔘️☐De entrée gratuite",
    'zh': "🔘️☐免費入場",
    'ar': "🔘️☐ من الدخول المجاني",
}
l_ccheck_button_on = {
    'ru': "✅☑Вкл нажатие на кнопку",
    'en': "✅☑On button push",
    'es': "✅☑En el pulsador",
    'fr': "✅☑En bouton poussoir",
    'zh': "✅☑按按鈕",
    'ar': "✅☑عند الضغط على زر",
}
l_ccheck_button_off = {
    'ru': "🔘️☐Выкл нажатие на кнопку",
    'en': "🔘️☐Off button push",
    'es': "🔘️☐De pulsar botón",
    'fr': "🔘️☐De bouton poussoir",
    'zh': "🔘️☐關閉按鈕按下",
    'ar': "🔘️☐زر الضغط",
}
l_ccheck_subscribe_on = {
    'ru': "✅☑Вкл подписку",
    'en': "✅☑On subscription",
    'es': "✅☑En suscripción",
    'fr': "✅☑En abonnement",
    'zh': "✅☑啟用訂閱",
    'ar': "✅☑ تمكين الاشتراك",
}
l_ccheck_subscribe_off = {
    'ru': "🔘☐Выкл подписку",
    'en': "🔘☐Off subscription",
    'es': "🔘️☐De suscripción",
    'fr': "🔘️☐De abonnement",
    'zh': "🔘☐禁用訂閱",
    'ar': "🔘☐ تعطيل الاشتراك",
}
l_ccheck_eq_on = {
    'ru': "✅☑Вкл решение уравнения",
    'en': "✅☑On captcha",
    'es': "✅☑En captcha",
    'fr': "✅☑En captcha",
    'zh': "✅☑啟用驗證碼",
    'ar': "✅☑ تمكين كلمة التحقق",
}
l_ccheck_eq_off = {
    'ru': "🔘️☐Выкл решение уравнения",
    'en': "🔘️☐Off captcha",
    'es': "🔘️☐De captcha",
    'fr': "🔘️☐De captcha",
    'zh': "🔘️☐禁用驗證碼",
    'ar': "🔘️☐ تعطيل كلمة التحقق",
}
l_ccheck_captcha_on = {
    'ru': "✅☑Вкл решение капчи",
    'en': "✅☑On captcha",
    'es': "✅☑En captcha",
    'fr': "✅☑En captcha",
    'zh': "✅☑啟用驗證碼",
    'ar': "✅☑ تمكين كلمة التحقق",
}
l_ccheck_captcha_off = {
    'ru': "🔘️☐Выкл решение капчи",
    'en': "🔘️☐Off captcha",
    'es': "🔘️☐De captcha",
    'fr': "🔘️☐De captcha",
    'zh': "🔘️☐禁用驗證碼",
    'ar': "🔘️☐ تعطيل كلمة التحقق",
}
l_ccheck_request_on = {
    'ru': "✅☑Вкл подачу заявки",
    'en': "✅☑On send request",
    'es': "✅☑En enviar petición",
    'fr': "✅☑En envoyer une demande",
    'zh': "✅☑啟用發送請求",
    'ar': "✅☑ تمكين إرسال الطلب",
}
l_ccheck_request_off = {
    'ru': "🔘️☐Выкл подачу заявки",
    'en': "🔘️☐Off send request",
    'es': "🔘️☐De enviar petición",
    'fr': "🔘️☐De envoyer une demande",
    'zh': "🔘️☐禁用發送請求",
    'ar': "🔘️☐ تعطيل إرسال الطلب",
}
l_ccheck_antiraid_on = {
    'ru': "✅☑Вкл анти-рейд",
    'en': "✅☑On anti-raid",
    'es': "✅☑En anti-raid",
    'fr': "✅☑En anti-raid",
    'zh': "✅☑啟用反襲擊",
    'ar': "✅☑ تمكين مكافحة الغارة",
}
l_ccheck_antiraid_off = {
    'ru': "🔘️☐Выкл антирейд",
    'en': "🔘️☐Off anti-raid",
    'es': "🔘️☐De anti-raid",
    'fr': "🔘️☐De anti-raid",
    'zh': "🔘️☐禁用反襲擊",
    'ar': "🔘️☐ تعطيل مكافحة الغارة",
}
# endregion


# region cban_
l_cban_add = {
    'ru': "🕵🏽 <b>Введи</b> <code>id</code> или <code>@username</code> пользователей  через пробельные символы или разделители, чтобы добавить их в /ban-список (*даже тех, кого нет <u>{0}</u>-файле)\n\n👩🏽‍💻 <b>Текущее</b> число пользователей /ban-списка: <u>{1}</u>",
    'en': "🗣 Push the ✅/☑️ to <b>On/Off</b> auto-transcribe (speach to text) for <i><b>income</b>/<b>outgoing</b> messages</i>",
    'es': "🗣 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "🗣 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "🗣 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
l_cban_remove = {
    'ru': "🕵🏽 <b>Введи</b> <code>id</code> или <code>@username</code> пользователей из <u>{0}</u>-файла через пробельные символы или разделители, чтобы удалить их из /ban-списка\n\n👩🏽‍💻 <b>Текущее</b> число пользователей /ban-списка: <u>{1}</u>",
    'en': "🗣 Push the ✅/☑️ to <b>On/Off</b> auto-transcribe (speach to text) for <i><b>income</b>/<b>outgoing</b> messages</i>",
    'es': "🗣 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "🗣 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "🗣 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
l_cban_added = {
    'ru': "🕵🏽 Пользователь {0} добавлен в /ban-список (причина: <i>{1}</i>)",
    'en': "🗣 Push the ✅/☑️ to <b>On/Off</b> auto-transcribe (speach to text) for <i><b>income</b>/<b>outgoing</b> messages</i>",
    'es': "🗣 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "🗣 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "🗣 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
l_cban_text = {
    'ru': "🕵🏽 <b>Жми</b> на ✅/☑️ чтобы <b>Вкл/Выкл</b> бан <u>пользователей</u> бота: <i>с недавно зарегистрированными new-id/аккаунтов без @username/аккаунтов из <a href='https://cas.chat'>Anti-Spam Системы</a>/аккаунтов с 文-глиф, ب-араб/ <a href='https://www.zalgo.org'>zalgo-символами</a></i>\n\n👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/ban - блок/разблок пользователя\n/parse - вывести всех пользователей",
    'en': "🕵🏽 Push the ✅/☑️ to <b>On/Off</b> <u>auto</u>-ban <i>bots with recently registered new-id/without @username/bots from <a href='https://cas.chat'>Anti-Spam System</a>/bots with 文-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👩🏽‍💻 For example, option <b>new-id</b> blocks bots with <i>fresh</i> <u>id</u> and with the same photo upload <u>date</u> <i>many avatars</i>",
    'es': "🕵🏽 Presiona ✅/☑️ para <b>Encender/Apagar</b> <u>Auto</u>-banear <i>cuentas con nueva identificación registrada recientemente/cuentas eliminadas/cuentas de <a href='https://cas.chat'>Anti-Spam System</a>/cuentas con 文-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👩🏽‍💻 Por ejemplo, la opción <b>deleted-ban</b> elimina dichas cuentas: <i>👻 Cuenta eliminada [estafa, falsa]</i>",
    'fr': "🕵🏽 Appuyez sur ✅/☑️ pour <b>On/Off</b> <u>auto</u>-bannir <i>les comptes avec un nouvel identifiant/des comptes supprimés/des comptes récemment enregistrés depuis <a href='https://cas.chat'>Anti-Spam System</a>/comptes avec 文-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👩🏽‍💻 Par exemple, l'option <b>deleted-ban</b> supprime ces comptes : <i>👻 Compte supprimé [arnaque, faux]</i>",
    'zh': "🕵🏽 按下 ✅/☑️，以 <b>On/Off</b> <u>auto</u>-禁止 <i>具有最近從 註冊的 new-id/deleted-bots/bots <a href='https://cas.chat'>Anti-Spam System</a>/bots with text-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👩🏽‍💻 例如，選項 <b>deleted-ban</b> 刪除此類帳戶：<i>👻 Deleted bot [scam,fake]</i>",
    'ar': "🕵🏽 اضغط على ✅ / ☑️ ، إلى <b> تشغيل / إيقاف </b> <u> تلقائي </u> -حظر <i> الحسابات ذات المعرف الجديد / الحسابات / الحسابات المحذوفة حديثًا من <a href='https://cas.chat'> نظام مكافحة البريد العشوائي </a> / حسابات مع 文 -glif، ب- arab، <a href='https://www.zalgo.org'> zalgo-icons </a> </i> \n\n👩🏽‍💻 على سبيل المثال ، الخيار <b> حذف-حظر </b> يحذف مثل هذه الحسابات: <i> 👻 الحساب المحذوف [احتيال ، وهمي] </i>",
}
l_cban_done = {
    'ru': "🕵🏽 <b>Готово!</b> /ban-список нежелательных пользователей @{0}-бота\n\n👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/ban - блок/разблок пользователя\n/parse - вывести всех пользователей\n\n👩🏽‍💻 <b>Текущее</b> число пользователей /ban-списка: <u>{1}</u>",
    'en': "👥 Ready! Gathered members: <u>{0}</u>. You can immediately make an <b>sending</b> or <b>inviting</b> to channel by received members{1}",
    'es': "👥 Listo! Miembros reunidos: <u>{0}</u>. Inmediatamente puede hacer un <b>envío</b> o <b>invitación</b> al grupo por miembros recibidos{1}",
    'fr': "👥 Prêt ! Membres réunis : <u>{0}</u>. Vous pouvez immédiatement faire un <b>envoi</b> ou <b>inviter</b> pour channeler par membres reçus{1}",
    'zh': "👥 準備好了！ 聚集成員：<u>{0}</u>。 您可以立即<b>發送</b>或<b>邀請</b>按收到的成員分組{1}",
    'ar': "🔥 جاهز! الأعضاء الذين تم تجميعهم: <u>{0}</u>. يمكنك على الفور إجراء <b> إرسال </b> أو <b> دعوة </b> للانضمام إلى المجموعة بواسطة الأعضاء المستلمين {1}",
}
l_cban_correct = {
    'ru': "🕵🏽 <b>Введи</b> корректный id или @username пользователя или выведи всех пользователей в бана: /ban",
    'en': "👥 Ready! Gathered members: <u>{0}</u>. You can immediately make an <b>sending</b> or <b>inviting</b> to channel by received members{1}",
    'es': "👥 Listo! Miembros reunidos: <u>{0}</u>. Inmediatamente puede hacer un <b>envío</b> o <b>invitación</b> al grupo por miembros recibidos{1}",
    'fr': "👥 Prêt ! Membres réunis : <u>{0}</u>. Vous pouvez immédiatement faire un <b>envoi</b> ou <b>inviter</b> pour channeler par membres reçus{1}",
    'zh': "👥 準備好了！ 聚集成員：<u>{0}</u>。 您可以立即<b>發送</b>或<b>邀請</b>按收到的成員分組{1}",
    'ar': "🔥 جاهز! الأعضاء الذين تم تجميعهم: <u>{0}</u>. يمكنك على الفور إجراء <b> إرسال </b> أو <b> دعوة </b> للانضمام إلى المجموعة بواسطة الأعضاء المستلمين {1}",
}

l_cban_handler = {
    'ru': "🕵🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <u>авто</u>-бан <i>аккаунтов с недавно зарегистрированными new-id/без @username/аккаунтов из <a href='https://cas.chat'>Anti-Spam Системы</a>/аккаунтов с 文-глиф, ب-араб/ <a href='https://www.zalgo.org'>zalgo-символами</a></i>\n\n👉🏼 Например, опция <b>new-id</b> блокирует аккаунты со <i>свежим</i> <u>id</u>",
    'en': "🕵🏽 Push the ✅/☑️, to <b>On/Off</b> <u>auto</u>-ban <i>accounts with recently registered new-id/deleted-accounts/accounts from <a href='https://cas.chat'>Anti-Spam System</a>/accounts with 文-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👉🏼 For example, the option <b>deleted-ban</b> delete such accounts: <i>👻 Deleted account [scam,fake]</i>",
    'es': "🕵🏽 Presiona ✅/☑️, para <b>Encender/Apagar</b> <u>Auto</u>-banear <i>cuentas con nueva identificación registrada recientemente/cuentas eliminadas/cuentas de <a href='https://cas.chat'>Anti-Spam System</a>/cuentas con 文-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👉🏼 Por ejemplo, la opción <b>deleted-ban</b> elimina dichas cuentas: <i>👻 Cuenta eliminada [estafa, falsa]</i>",
    'fr': "🕵🏽 Appuyez sur ✅/☑️, pour <b>On/Off</b> <u>auto</u>-bannir <i>les comptes avec un nouvel identifiant/des comptes supprimés/des comptes récemment enregistrés depuis <a href='https://cas.chat'>Anti-Spam System</a>/comptes avec 文-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👉🏼 Par exemple, l'option <b>deleted-ban</b> supprime ces comptes : <i>👻 Compte supprimé [arnaque, faux]</i>",
    'zh': "🕵🏽 按下 ✅/☑️，以 <b>On/Off</b> <u>auto</u>-禁止 <i>具有最近從 註冊的 new-id/deleted-accounts/accounts <a href='https://cas.chat'>Anti-Spam System</a>/accounts with text-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👉🏼 例如，選項 <b>deleted-ban</b> 刪除此類帳戶：<i>👻 Deleted account [scam,fake]</i>",
    'ar': "🕵🏽 اضغط على ✅ / ☑️ ، إلى <b> تشغيل / إيقاف </b> <u> تلقائي </u> -حظر <i> الحسابات ذات المعرف الجديد / الحسابات / الحسابات المحذوفة حديثًا من <a href='https://cas.chat'> نظام مكافحة البريد العشوائي </a> / حسابات مع 文 -glif، ب- arab، <a href='https://www.zalgo.org'> zalgo-icons </a> </i> \n\n👉🏼 على سبيل المثال ، الخيار <b> حذف-حظر </b> يحذف مثل هذه الحسابات: <i> 👻 الحساب المحذوف [احتيال ، وهمي] </i>",
}
l_cban_new_on = {
    'ru': "✅☑Вкл new-id-бан",
    'en': "✅☑On new-id-ban",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_cban_new_off = {
    'ru': "☑️☐Выкл new-id-бан",
    'en': "☑️☐Off new-id-ban",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}
l_cban_nousername_on = {
    'ru': "✅☑Вкл без @username-бан",
    'en': "✅☑On deleted-ban",
    'es': "✅☑En eliminadad-ban",
    'fr': "✅☑En supprimé-ban",
    'zh': "✅☑啟用已刪除的禁令",
    'ar': "✅☑ تمكين الحظر المحذوف",
}
l_cban_nousername_off = {
    'ru': "☑️☐Выкл без @username-бан",
    'en': "☑️☐Off deleted-ban",
    'es': "☑️☐De eliminadad-ban",
    'fr': "☑️☐De supprimé-ban",
    'zh': "☑️☐禁用已刪除的禁令",
    'ar': "☑️☐ تعطيل الحظر المحذوف",
}
l_cban_cas_on = {
    'ru': "✅☑Вкл CAS-бан",
    'en': "✅☑On CAS-ban",
    'es': "✅☑En CAS-ban",
    'fr': "✅☑En CAS-ban",
    'zh': "✅☑使能夠 CAS-ban",
    'ar': "✅☑ يُمكَِن CAS-ban",
}
l_cban_cas_off = {
    'ru': "☑️☐Выкл CAS-бан",
    'en': "☑️☐Off CAS-ban",
    'es': "☑️☐De CAS-ban",
    'fr': "☑️☐De CAS-ban",
    'zh': "☑️☐禁用 CAS-ban",
    'ar': "☑️☐ تعطيل CAS-ban",
}
l_cban_symbols_on = {
    'ru': "✅☑Вкл 文ب-бан",
    'en': "✅☑On 文ب-ban",
    'es': "✅☑En 文ب-ban",
    'fr': "✅☑En 文ب-ban",
    'zh': "✅☑使能夠 文ب-ban",
    'ar': "✅☑ يُمكَِن 文ب-ban",
}
l_cban_symbols_off = {
    'ru': "☑️☐Выкл 文ب-бан",
    'en': "☑️☐Off 文ب-ban",
    'es': "☑️☐De 文ب-ban",
    'fr': "☑️☐De 文ب-ban",
    'zh': "☑️☐禁用 文ب-ban",
    'ar': "☑️☐ تعطيل 文ب-ban",
}
l_cban_zalgo_on = {
    'ru': "✅☑Вкл zalgo-бан",
    'en': "✅☑On zalgo-ban",
    'es': "✅☑En zalgo-ban",
    'fr': "✅☑En zalgo-ban",
    'zh': "✅☑使能夠 zalgo-ban",
    'ar': "✅☑ يُمكَِن zalgo-ban",
}
l_cban_zalgo_off = {
    'ru': "☑️☐Выкл zalgo-бан",
    'en': "☑️☐Off zalgo-ban",
    'es': "☑️☐De zalgo-ban",
    'fr': "☑️☐De zalgo-ban",
    'zh': "☑️☐禁用 zalgo-ban",
    'ar': "☑️☐ تعطيل zalgo-ban",
}
# endregion

# region cpost_
l_cpost_call = {
    'ru': "🔔 Нужно ⚙️Настроить хотя бы один пост",
    'en': "🔔 You have to  ⚙️Configure at least one post",
    'es': "🔔 Tienes que ⚙️Configurar al menos una publicación",
    'fr': "🔔 Vous devez ⚙️Configurer au moins une publication",
    'zh': "🔔 你必須⚙️至少配置一篇帖子",
    'ar': "🔔 يجب عليك ⚙️ تكوين منشور واحد على الأقل",
}
l_cpost_text = {
    'ru': "🔔 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <b>авто</b>-постинг по дате\n\n👉🏼 <b>Текущее</b> количество постов <u>{0}</u>",
    'en': "🔔 Push the ✅/☑️, to <b>On/Off</b> <b>auto</b>-posting of messages to channel by datetime\n\n👉🏼 Current post number is <u>{0}</u>",
    'es': "🔔 Presiona ✅/☑️ para <b>activar/desactivar</b> <b>automático</b>: publicación de mensajes para agrupar por fecha y hora\n\n👉🏼 El número de publicación actual es <u>{0}</u>",
    'fr': "🔔 Appuyez sur ✅/☑️, sur <b>On/Off</b> <b>auto</b>-publication des messages pour channeler par datetime\n\n👉🏼 Le numéro de publication actuel est <u>{0}</u>",
    'zh': "🔔 將 ✅/☑️ 推到 <b>On/Off</b> <b>auto</b>- 將消息發佈到按日期時間分組\n\n👉🏼 當前帖子編號是 <u>{0}</u>",
    'ar': "🔔 اضغط على ✅ / ☑️ ، من أجل <b> تشغيل / إيقاف </b> <b> تلقائي </b> - النشر التلقائي للرسائل إلى التجميع حسب التاريخ والوقت \n\n👉🏼 رقم المنشور الحالي هو <u>{0}</u>"
}
l_fsm_post_call = {
    'ru': "🔔 В настройках [Администраторы] вкл опцию для @{0}-бота:\n[✅ Отправка сообщений]\n[✅ Редактирование постов]\n\n🕚Подожди 1min",
    'en': "🔔 In the Settings [Administrators] enable:\n[✅ Pin Messages] for @{0}",
    'es': "🔔 En la Configuración [Administradores] habilite:\n[✅ Pinear mensajes] para @{0}",
    'fr': "🔔 Dans les paramètres [Administrateurs], activez :\n[✅ Épingler les messages] pour @{0}",
    'zh': "🔔 在設置 [Administrators] 中啟用：\n[✅ Pin Messages] for @{0}",
    'ar': "🔔 في الإعدادات ، فعّل [المسؤولون]: \n [✅ تثبيت الرسائل] لـ @{0}",
}
l_fsm_post_pin_call = {
    'ru': "🔔 В настройках [Администраторы] вкл опцию для @{0}-бота:\n[✅ Закрепление сообщений]\n\n🕚Подожди 1min",
    'en': "🔔 In the Settings [Administrators] enable:\n[✅ Pin Messages] for @{0}",
    'es': "🔔 En la Configuración [Administradores] habilite:\n[✅ Pinear mensajes] para @{0}",
    'fr': "🔔 Dans les paramètres [Administrateurs], activez :\n[✅ Épingler les messages] pour @{0}",
    'zh': "🔔 在設置 [Administrators] 中啟用：\n[✅ Pin Messages] for @{0}",
    'ar': "🔔 في الإعدادات ، فعّل [المسؤولون]: \n [✅ تثبيت الرسائل] لـ @{0}",
}
# endregion


# region creact_
l_creact_text = {
    'ru': "👍🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> креативные авто-реакции на последний пост канала\n\n👩🏽‍💻 Используй команду /react {0}, чтобы задать количество авто-реакций на пост(<b>текущее</b> количество: <u>{0}</u>)",
    'en': "👍🏽 Push the ✅/☑️, to <b>On/Off</b> auto-inviting users to your channel\n\n👉🏼 Inviting <u>{0}</u> users per day from channel {1}",
    'es': "👍🏽 Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👉🏼 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "👍🏽 Appuyez sur ✅/☑️, pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre channele\n\n👉🏼 Inviter <u>{0}</u> utilisateurs par jour à partir du channele {1}",
    'zh': "👍🏽 按下 ✅/☑️, 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👉🏼 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶 ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👉🏼 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}
l_creact_call = {
    'ru': "👍🏽 В настройках [Администраторы] для @{0} вкл:\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "\n\nIn the Settings [Administrators] for @{0} enable:\n[✅ Delete Msgs]\n[✅ Ban Users]\n[✅ Invite Users]\n🕚Wait for 1min",
    'es': "\n\nEn la Configuración [Administradores] para @{0} active:\n[✅ Eliminar mensajes]\n[✅ Prohibir usuarios]\n[✅ Invitar usuarios]\n🕚Espere 1 minuto",
    'fr': "\n\nDans les paramètres [Administrateurs] pour @{0}, activez :\n[✅ Supprimer les messages]\n[✅ Bannir les utilisateurs]\n[✅ Inviter des utilisateurs]\n🕚Attendez 1 minute",
    'zh': "\n\n在@{0}的設置[管理員]中打開：\n[✅刪除消息]\n[✅禁止用戶]\n[✅邀請用戶]\n🕚等待1分鐘",
    'ar': "\n\n في الإعدادات [Administrators] لـ @{0} شغّل:\n [✅ حذف الرسائل] \n على [✅ حظر المستخدمين] \n [✅ دعوة المستخدمين] \n وانتظر لمدة دقيقة واحدة",
}
l_creact_correct = {
    'ru': "👍🏽 <b>Введи</b> корректное <b>число</b> креативных авто-реакций на последний пост канала\n\n👩🏽‍💻 Используй команду <code>/react {0}</code>, чтобы задать количество авто-реакций (<b>текущее</b> количество: <u>{0}</u>)",
    'en': "👍🏽 Ready! Current primary delay for <u>new</u> users (before writing their <u>1</u>st message) is <u>{0}</u> min",
    'es': "👍🏽 Listo! El retraso principal actual para los <u>nuevos</u> usuarios (antes de escribir su <u>1</u>er mensaje) es <u>{0}</u> min",
    'fr': "👍🏽 Prêt! Le délai principal actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) est de <u>{0}</u> min",
    'zh': "👍🏽 準備好了！<u>新</u>用戶的當前主要延遲（在寫他們的<u>1</u>st消息之前）是<u>{0}</u>分鐘",
    'ar': "👥 جاهز! التأخير الأساسي الحالي لمستخدمي <u> الجدد </u> (قبل كتابة رسالتهم <u> 1 </u> st) هو <u>{0}</u> min",
}
l_creact_on = {
    'ru': "👍🏽 <b>Готово!</b> Текущее количество <b>авто-реакций</b> на пост канала установлено в значение <u>{0}</u>",
    'en': "👍🏽 Ready! Current primary delay for <u>new</u> users (before writing their <u>1</u>st message) is <u>{0}</u> min",
    'es': "👍🏽 Listo! El retraso principal actual para los <u>nuevos</u> usuarios (antes de escribir su <u>1</u>er mensaje) es <u>{0}</u> min",
    'fr': "👍🏽 Prêt! Le délai principal actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) est de <u>{0}</u> min",
    'zh': "👍🏽 準備好了！<u>新</u>用戶的當前主要延遲（在寫他們的<u>1</u>st消息之前）是<u>{0}</u>分鐘",
    'ar': "👥 جاهز! التأخير الأساسي الحالي لمستخدمي <u> الجدد </u> (قبل كتابة رسالتهم <u> 1 </u> st) هو <u>{0}</u> min",
}
l_creact_off = {
    'ru': "👍🏽 Режим /react-авто-реакций отключен",
    'en': "👍🏽 Ready! Current primary delay for <u>new</u> users (before writing their <u>1</u>st message) is <u>{0}</u> min",
    'es': "👍🏽 Listo! El retraso principal actual para los <u>nuevos</u> usuarios (antes de escribir su <u>1</u>er mensaje) es <u>{0}</u> min",
    'fr': "👍🏽 Prêt! Le délai principal actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) est de <u>{0}</u> min",
    'zh': "👍🏽 準備好了！<u>新</u>用戶的當前主要延遲（在寫他們的<u>1</u>st消息之前）是<u>{0}</u>分鐘",
    'ar': "👥 جاهز! التأخير الأساسي الحالي لمستخدمي <u> الجدد </u> (قبل كتابة رسالتهم <u> 1 </u> st) هو <u>{0}</u> min",
}
# endregion


# region cview_
l_cview_text = {
    'ru': "👁️‍🗨️ <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-просмотры поста канала\n\n👩🏽‍💻 Используй команду /view {0}, чтобы задать количество авто-просмотров (<b>текущее</b> количество: <u>{0}</u>)",
    'en': "👁️‍🗨️ Push the ✅/☑️, to <b>On/Off</b> auto-inviting users to your channel\n\n👉🏼 Inviting <u>{0}</u> users per day from channel {1}",
    'es': "👁️‍🗨️ Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👉🏼 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "👁️‍🗨️ Appuyez sur ✅/☑️, pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre channele\n\n👉🏼 Inviter <u>{0}</u> utilisateurs par jour à partir du channele {1}",
    'zh': "👁️‍🗨️ 按下 ✅/☑️, 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👉🏼 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶 ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👉🏼 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}
l_cview_call = {
    'ru': "👁️‍🗨️ В настройках [Администраторы] для @{0} вкл:\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "\n\nIn the Settings [Administrators] for @{0} enable:\n[✅ Delete Msgs]\n[✅ Ban Users]\n[✅ Invite Users]\n🕚Wait for 1min",
    'es': "\n\nEn la Configuración [Administradores] para @{0} active:\n[✅ Eliminar mensajes]\n[✅ Prohibir usuarios]\n[✅ Invitar usuarios]\n🕚Espere 1 minuto",
    'fr': "\n\nDans les paramètres [Administrateurs] pour @{0}, activez :\n[✅ Supprimer les messages]\n[✅ Bannir les utilisateurs]\n[✅ Inviter des utilisateurs]\n🕚Attendez 1 minute",
    'zh': "\n\n在@{0}的設置[管理員]中打開：\n[✅刪除消息]\n[✅禁止用戶]\n[✅邀請用戶]\n🕚等待1分鐘",
    'ar': "\n\n في الإعدادات [Administrators] لـ @{0} شغّل:\n [✅ حذف الرسائل] \n على [✅ حظر المستخدمين] \n [✅ دعوة المستخدمين] \n وانتظر لمدة دقيقة واحدة",
}
l_cview_correct = {
    'ru': "👁️‍🗨️ <b>Введи</b> корректное <b>число</b> авто-просмотров последнего поста канала\n\n👩🏽‍💻 Используй команду <code>/view {0}</code>, чтобы задать количество авто-просмотров (<b>текущее</b> количество: <u>{0}</u>)",
    'en': "👁️‍🗨️ Ready! Current primary delay for <u>new</u> users (before writing their <u>1</u>st message) is <u>{0}</u> min",
    'es': "👁️‍🗨️ Listo! El retraso principal actual para los <u>nuevos</u> usuarios (antes de escribir su <u>1</u>er mensaje) es <u>{0}</u> min",
    'fr': "👁️‍🗨️ Prêt! Le délai principal actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) est de <u>{0}</u> min",
    'zh': "👁️‍🗨️ 準備好了！<u>新</u>用戶的當前主要延遲（在寫他們的<u>1</u>st消息之前）是<u>{0}</u>分鐘",
    'ar': "👥 جاهز! التأخير الأساسي الحالي لمستخدمي <u> الجدد </u> (قبل كتابة رسالتهم <u> 1 </u> st) هو <u>{0}</u> min",
}
l_cview_on = {
    'ru': "👁️‍🗨️ <b>Готово!</b> Текущее количество <b>авто-просмотров</b> на последний пост канала установлено в значение <u>{0}</u>",
    'en': "👁️‍🗨️ Ready! Current primary delay for <u>new</u> users (before writing their <u>1</u>st message) is <u>{0}</u> min",
    'es': "👁️‍🗨️ Listo! El retraso principal actual para los <u>nuevos</u> usuarios (antes de escribir su <u>1</u>er mensaje) es <u>{0}</u> min",
    'fr': "👁️‍🗨️ Prêt! Le délai principal actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) est de <u>{0}</u> min",
    'zh': "👁️‍🗨️ 準備好了！<u>新</u>用戶的當前主要延遲（在寫他們的<u>1</u>st消息之前）是<u>{0}</u>分鐘",
    'ar': "👥 جاهز! التأخير الأساسي الحالي لمستخدمي <u> الجدد </u> (قبل كتابة رسالتهم <u> 1 </u> st) هو <u>{0}</u> min",
}
l_cview_off = {
    'ru': "👁️‍🗨️ Режим /view-авто-просмотров отключен",
    'en': "👁️‍🗨️ Ready! Current primary delay for <u>new</u> users (before writing their <u>1</u>st message) is <u>{0}</u> min",
    'es': "👁️‍🗨️ Listo! El retraso principal actual para los <u>nuevos</u> usuarios (antes de escribir su <u>1</u>er mensaje) es <u>{0}</u> min",
    'fr': "👁️‍🗨️ Prêt! Le délai principal actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) est de <u>{0}</u> min",
    'zh': "👁️‍🗨️ 準備好了！<u>新</u>用戶的當前主要延遲（在寫他們的<u>1</u>st消息之前）是<u>{0}</u>分鐘",
    'ar': "👥 جاهز! التأخير الأساسي الحالي لمستخدمي <u> الجدد </u> (قبل كتابة رسالتهم <u> 1 </u> st) هو <u>{0}</u> min",
}
# endregion


# region cdecor_
l_cdecor_text = {
    'ru': "🪄 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-декор публикуемого поста: <i><b>пагинация</b> (порядковый номер поста)/креативный <b>формат текста</b> (<b>жирный</b>/<i>курсив</i>/<u>подчеркнутый</u>/<code>моно</code>/<tg-spoiler>спойлер</tg-spoiler>/#хэштег/<a href='{0}'>ссылка</a>)/<b>футер</b> (текстовое окончание поста)</i>\n\n👉🏼 Например, опция <b>[✅☑Вкл формат текста]</b> означает креативное изменение поста с использованием 7 стилей",
    'en': "🪄 Push the ✅/☑️, to <b>On/Off</b> <i>externak <b>links</b>/telegram-<b>links</b>/forward</i>-<b>links</b>\n\n👉🏼 For example, [✅☑On forward-links] means permission on <b>forward</b> messages from <u>other</u> Telegram-<i>channels/channels/accounts</i> into <u>our</u> channel",
    'es': "🪄 Presiona ✅/☑️ para <b>Activar/Desactivar</b> <i>externak <b>enlaces</b>/telegram-<b>enlaces</b>/reenviar</i>-<b>enlaces</b>\n\n👉🏼 Por ejemplo, [✅☑On forward-links] significa permiso en <b>reenviar</b> mensajes de <u>otros</u> Telegram-<i>canales /grupos/cuentas</i> en <u>nuestro</u> grupo",
    'fr': "🪄 Appuyez sur le ✅/☑️, sur <b>On/Off</b> <i>externak <b>links</b>/telegram-<b>links</b>/forward</i>-<b>liens</b>\n\n👉🏼 Par exemple, [✅☑On forward-links] signifie l'autorisation de <b>transférer</b> les messages provenant d'<u>autres</u> chaînes Telegram-<i> /channeles/comptes</i> dans <u>notre</u> channele",
    'zh': "🪄 將 ✅/☑️ 推到 <b>On/Off</b> <i>externak <b>links</b>/telegram-<b>links</b>/forward</i>-<b>links</b>\n\n👉🏼 例如，[✅☑On forward-links] 表示允許 <b>forward</b> 來自 <u>other</u> Telegram-<i> 頻道的消息 /channels/accounts</i> 進入 <u>我們的</u> 組",
    'ar': "🔗 ادفع ✅ / ☑️ إلى تشغيل / إيقاف روابط خارجية telegram- روابط/ إعادة توجيه الروابط \n\n👉🏼 على سبيل المثال ، [على روابط إعادة التوجيه] تعني إذنًا بشأن <b> إعادة توجيه </b> الرسائل من أخرى Telegram قنوات/channels/accounts في مجموعتنا",
}
l_cdecor_footer_call = {
    'ru': "🪄 Футер пустой, необходимо его ⚙️Настроить",
    'en': "🪄 There are no greetings you need to ⚙️Configure",
    'es': "🪄 No hay saludos que necesites ⚙️Configurar",
    'fr': "🪄 Vous n'avez pas besoin de salutations ⚙️Configurer",
    'zh': "🪄 無需問候⚙️配置",
    'ar': "🔔لا توجد تحيات تحتاج إلى تكوين",
}
l_cdecor_footer_call2 = {
    'ru': "🪄 В настройках [Администраторы] вкл опцию для @{0}-бота:\n[✅ Редактирование постов]\n\n🕚Подожди 1min",
    'en': "🪄 In the Settings [Administrators] enable:\n[✅ Pin Messages] for @{0}",
    'es': "🪄 En la Configuración [Administradores] habilite:\n[✅ Pinear mensajes] para @{0}",
    'fr': "🪄 Dans les paramètres [Administrateurs], activez :\n[✅ Épingler les messages] pour @{0}",
    'zh': "🪄 在設置 [Administrators] 中啟用：\n[✅ Pin Messages] for @{0}",
    'ar': "🔔 في الإعدادات ، فعّل [المسؤولون]: \n [✅ تثبيت الرسائل] لـ @{0}",
}
l_cdecor_footer_config = {
    'ru': "🪄 <b>Введи</b> краткий <b>текст</b>, который будет добавляться в окончание к постам канала (например, часто используемые #хэштеги)",
    'en': "🪄 There are no greetings you need to ⚙️Configure",
    'es': "🪄 No hay saludos que necesites ⚙️Configurar",
    'fr': "🪄 Vous n'avez pas besoin de salutations ⚙️Configurer",
    'zh': "🪄 無需問候⚙️配置",
    'ar': "🔔لا توجد تحيات تحتاج إلى تكوين",
}
l_cdecor_footer_done = {
    'ru': "🪄 <b>Готово!</b> <b>Футер</b> из <u>{0}</u>-символов будет использоваться как окончание поста в канале\n\nОпцию можно включить, нажав <b>[✅☑Вкл футер]</b>",
    'en': "🪄 There are no greetings you need to ⚙️Configure",
    'es': "🪄 No hay saludos que necesites ⚙️Configurar",
    'fr': "🪄 Vous n'avez pas besoin de salutations ⚙️Configurer",
    'zh': "🪄 無需問候⚙️配置",
    'ar': "🔔لا توجد تحيات تحتاج إلى تكوين",
}
l_cdecor_page_on = {
    'ru': "✅☑Вкл пагинация",
    'en': "✅☑On external links",
    'es': "✅☑En enlaces externos",
    'fr': "✅☑En Liens externes",
    'zh': "✅☑使能夠 外部鏈接",
    'ar': "✅☑ يُمكَِن روابط خارجية",
}
l_cdecor_page_off = {
    'ru': "☑️☐Выкл пагинация",
    'en': "☑️☐Off external links",
    'es': "☑️☐De enlaces externos",
    'fr': "☑️☐De Liens externes",
    'zh': "☑️☐禁用 外部鏈接",
    'ar': "☑️☐ تعطيل روابط خارجية",
}
l_cdecor_footer_on = {
    'ru': "✅☑Вкл футер",
    'en': "✅☑On @telegram links",
    'es': "✅☑En enlaces @telegram",
    'fr': "✅☑En Liens @telegram",
    'zh': "✅☑使能夠 @telegram-鏈接",
    'ar': "✅☑ يُمكَِن @telegram-الروابط",
}
l_cdecor_footer_off = {
    'ru': "☑️☐Выкл футер",
    'en': "☑️☐Off @telegram-links",
    'es': "☑️☐De @telegram-enlaces",
    'fr': "☑️☐De @telegram-Liens",
    'zh': "☑️☐禁用 @telegram-鏈接",
    'ar': "☑️☐ تعطيل @telegram-الروابط",
}
l_cdecor_format_on = {
    'ru': "✅☑Вкл формат текста",
    'en': "✅☑On forward-links",
    'es': "✅☑En forward-enlaces",
    'fr': "✅☑En forward-Liens",
    'zh': "✅☑使能夠 forward-鏈接",
    'ar': "✅☑ يُمكَِن forward-الروابط",
}
l_cdecor_format_off = {
    'ru': "☑️☐Выкл формат текста",
    'en': "☑️☐Off forward-links",
    'es': "☑️☐De forward-enlaces",
    'fr': "☑️☐De forward-Liens",
    'zh': "☑️☐禁用 forward-鏈接",
    'ar': "☑️☐ تعطيل forward-الروابط",
}
# endregion


# region cmember_
l_cmember_text = {
    'ru': "👥 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> сбор подписчиков канала (с момента подключения бота в канал)\n\n👩🏽‍💻 Для выгрузки подписчиков канала выполни команду /parse",
    'en': "👥 Push the ✅/☑️, to <b>On/Off</b> auto-inviting users to your channel\n\n👉🏼 Inviting <u>{0}</u> users per day from channel {1}",
    'es': "👥 Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👉🏼 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "👥 Appuyez sur ✅/☑️, pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre channele\n\n👉🏼 Inviter <u>{0}</u> utilisateurs par jour à partir du channele {1}",
    'zh': "👥 按下 ✅/☑️, 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👉🏼 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶 ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👉🏼 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}
l_cmember_on = {
    'ru': "👁️‍🗨️ <b>Готово!</b> Текущее количество <b>авто-просмотров</b> на последний пост канала установлено в значение <u>{0}</u>",
    'en': "👁️‍🗨️ Ready! Current primary delay for <u>new</u> users (before writing their <u>1</u>st message) is <u>{0}</u> min",
    'es': "👁️‍🗨️ Listo! El retraso principal actual para los <u>nuevos</u> usuarios (antes de escribir su <u>1</u>er mensaje) es <u>{0}</u> min",
    'fr': "👁️‍🗨️ Prêt! Le délai principal actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) est de <u>{0}</u> min",
    'zh': "👁️‍🗨️ 準備好了！<u>新</u>用戶的當前主要延遲（在寫他們的<u>1</u>st消息之前）是<u>{0}</u>分鐘",
    'ar': "👥 جاهز! التأخير الأساسي الحالي لمستخدمي <u> الجدد </u> (قبل كتابة رسالتهم <u> 1 </u> st) هو <u>{0}</u> min",
}
l_cmember_off = {
    'ru': "👁️‍🗨️ Режим /view-авто-просмотров отключен",
    'en': "👁️‍🗨️ Ready! Current primary delay for <u>new</u> users (before writing their <u>1</u>st message) is <u>{0}</u> min",
    'es': "👁️‍🗨️ Listo! El retraso principal actual para los <u>nuevos</u> usuarios (antes de escribir su <u>1</u>er mensaje) es <u>{0}</u> min",
    'fr': "👁️‍🗨️ Prêt! Le délai principal actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) est de <u>{0}</u> min",
    'zh': "👁️‍🗨️ 準備好了！<u>新</u>用戶的當前主要延遲（在寫他們的<u>1</u>st消息之前）是<u>{0}</u>分鐘",
    'ar': "👥 جاهز! التأخير الأساسي الحالي لمستخدمي <u> الجدد </u> (قبل كتابة رسالتهم <u> 1 </u> st) هو <u>{0}</u> min",
}
l_cmember_parse = {
    'ru': "👥 <b>Готово!</b> Собрано реальных участников: <u>{0}</u>\n\n👩🏽‍💻 Старые подписчики будут постепенно пополнять базу, пока у @{1}-бота есть права [✅ Назначение администраторов]\n\n{2}",
    'en': "👥 Ready! Gathered members: <u>{0}</u>. You can immediately make an <b>sending</b> or <b>inviting</b> to channel by received members{1}",
    'es': "👥 Listo! Miembros reunidos: <u>{0}</u>. Inmediatamente puede hacer un <b>envío</b> o <b>invitación</b> al grupo por miembros recibidos{1}",
    'fr': "👥 Prêt ! Membres réunis : <u>{0}</u>. Vous pouvez immédiatement faire un <b>envoi</b> ou <b>inviter</b> pour channeler par membres reçus{1}",
    'zh': "👥 準備好了！ 聚集成員：<u>{0}</u>。 您可以立即<b>發送</b>或<b>邀請</b>按收到的成員分組{1}",
    'ar': "🔥 جاهز! الأعضاء الذين تم تجميعهم: <u>{0}</u>. يمكنك على الفور إجراء <b> إرسال </b> أو <b> دعوة </b> للانضمام إلى المجموعة بواسطة الأعضاء المستلمين {1}",
}
l_parse_rights = {
    'ru': "👥 В настройках [Администраторы] вкл опцию для @{0}-бота:\n[✅ Назначение администраторов]\n🕚Подожди 1min\n👩🏽‍💻 Выполни команду /parse\n\n⚙️ <b>Команды</b> /cmd",
    'en': "In the Settings [Administrators] for @{0} enable:\n[✅ Delete Msgs]\n[✅ Ban Users]\n[✅ Invite Users]\n🕚Wait for 1min",
    'es': "En la Configuración [Administradores] para @{0} active:\n[✅ Eliminar mensajes]\n[✅ Prohibir usuarios]\n[✅ Invitar usuarios]\n🕚Espere 1 minuto",
    'fr': "Dans les paramètres [Administrateurs] pour @{0}, activez :\n[✅ Supprimer les messages]\n[✅ Bannir les utilisateurs]\n[✅ Inviter des utilisateurs]\n🕚Attendez 1 minute",
    'zh': "在@{0}的設置[管理員]中打開：\n[✅刪除消息]\n[✅禁止用戶]\n[✅邀請用戶]\n🕚等待1分鐘",
    'ar': " في الإعدادات [Administrators] لـ @{0} شغّل:\n [✅ حذف الرسائل] \n على [✅ حظر المستخدمين] \n [✅ دعوة المستخدمين] \n وانتظر لمدة دقيقة واحدة",
}
# endregion
# endregion


# region FereyGroupBot
l_group_btn1 = {
    'ru': '⛰️ Группы',
    'en': "⛰️ VPN",
    'es': "⛰️VPN",
    'fr': "⛰️VPN",
    'zh': "⛰️ VPN",
    'ar': "⛰️ VPN",
}
l_group_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_group_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>администрирования</code> <b>Telegram</b>-групп:\n\n▪️<b>защита</b> группы от вступления шпионов\n▪️вывод <b>статистики</b> и вовлеченности (%)\n▪️ограничение прав до <b>подписки</b> на канал\n▪️<b>организация</b> бана и антифлуда\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>the landing bot</i> of the Ferey project:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ you can also order the development of a chat bot in our Ferey studio",
    'es': "🌱 {0}, bienvenido al <i>bot de aterrizaje</i> del proyecto Ferey:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ también puedes encargar el desarrollo de un chat bot en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue sur <i>le landing bot</i> du projet Ferey :\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎来到 Ferey 项目的<i>落地机器人</i>：\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️您也可以在我们的Ferey工作室订购聊天机器人的开发",
    'ar': "🌱 {0} ، مرحبًا بك في <i>روبوت الهبوط</i> الخاص بمشروع Ferey:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ يمكنك أيضًا طلب تطوير روبوت محادثة في استوديو Ferey",
}
l_add_group_text = {
    'ru': "👇🏽 <b>Жми</b> на ‹➕ Добавить группу›, чтобы добавить в свою группу (с настройками по ум) бота: @{0}\n\n👮🏽‍♀️ Или добавь бота как <b>Administrator</b> через настройки своей группы: ‹👤Add Admin›\n\n👮🏽‍♀️ Если не добавляется группа, то измени <b>Должность</b> (см. скрин)",
    'en': "👇🏽 Push the ‹Group› to add into your group (with default settings): @{0}\n\n👮🏽‍♀️ Or add bot as <b>Admin</b> via Settings of your group: ‹👤Add Admin›\n\n👮🏽‍♀️ If you can't add group, try to change <b>Custom Title</b> (look screenshot)",
    'es': "👇🏽 Presione ‹➕ Agregar grupo› para agregar a su grupo (con la configuración predeterminada): @{0}\n\n👮🏽‍♀️ O agregue bot como <b>Administrador</b> a través de la Configuración de su grupo: ‹👤Agregar administrador›\n\n👮🏽‍♀️ Si no puede agregar un grupo, intente cambiar <b>Título personalizado</b> (ver captura de pantalla)",
    'fr': "👇🏽 Appuyez sur ‹➕ Ajouter un groupe› pour ajouter à votre groupe (avec les paramètres par défaut): @{0}\n\n👮🏽‍♀️ Ou ajoutez le bot en tant qu'<b>administrateur</b> via les paramètres de votre groupe : ‹👤Ajouter un administrateur›\n\n👮🏽‍♀️ Si vous ne pouvez pas ajouter de groupe, essayez de modifier le <b>Titre personnalisé</b> (regardez la capture d'écran)",
    'zh': "👇🏽 按下‹➕添加群組›以添加到您的群組（使用默認設置）: @{0}\n\n👮🏽‍♀️ 或通過您組的設置將機器人添加為 <b>Admin</b>：‹👤添加管理員›\n\n👮🏽‍♀️ 如果無法添加組，請嘗試更改 <b>自定義標題</b>（看截圖）",
    'ar': "👇🏽 اضغط على ‹➕ إضافة مجموعة› لإضافتها إلى مجموعتك (بالإعدادات الافتراضية): @{0}\n\n👮🏽‍♀️ أو أضف البوت كـ <b> مسؤول </b> عبر إعدادات مجموعتك: ‹👤 إضافة مسؤول›\n\n👮🏽‍♀️ إذا لم تتمكن من إضافة مجموعة ، فحاول تغيير <b> عنوان مخصص </b> (انظر في لقطة الشاشة)",
}
l_add_group_button = {
    'ru': "➕ Добавить группу",
    'en': "➕ Add group",
    'es': "➕ Agregar grupo",
    'fr': "➕ Ajouter un groupe",
    'zh': "➕ 添加組",
    'ar': "➕ إضافة مجموعة",
}

# region group
l_group_config = {
    ("ccheck", "👮🏽", "☑"): {
        'ru': "Входной контроль",
        'en': "Enter control",
        'es': "Entrar en control",
        'fr': "Prenez le contrôle",
        'zh': "進入控制",
        'ar': "أدخل السيطرة",
    },
    ("chello", "👋🏽", "☐"): {
        'ru': "Авто-приветствие",
        'en': "Auto-greeting",
        'es': "Saludo automático",
        'fr': "Message d'accueil automatique",
        'zh': "自動問候",
        'ar': "الترحيب التلقائي",
    },
    ("cban", "🕵🏽", "☑"): {
        'ru': "Авто-бан",
        'en': "Auto-ban",
        'es': "Prohibición automática",
        'fr': "Interdiction automatique",
        'zh': "自動禁止",
        'ar': "حظر تلقائي",
    },
    ("cpost", "🔔", "☐"): {
        'ru': "Авто-постинг",
        'en': "Auto-posting",
        'es': "Publicación automática",
        'fr': "Publication automatique",
        'zh': "自動發布",
        'ar': "النشر التلقائي",
    },
    ("cinvite", "🚶", "☐"): {
        'ru': "Авто-инвайтинг",
        'en': "Auto-inviting",
        'es': "Invitación automática",
        'fr': "Invitation automatiquel",
        'zh': "自動邀請",
        'ar': "دعوة تلقائية",
    },
    ("csystem", "👣", "☐"): {
        'ru': "Сообщ системные",
        'en': "System messages",
        'es': "Mensajes del sistema",
        'fr': "Messages système",
        'zh': "系統消息",
        'ar': "رسائل النظام",
    },
    ("cchannel", "🫥", "☐"): {
        'ru': "Cообщ от‍ имени канала",
        'en': "Msgs from channel name",
        'es': "Msjs del nombre del canal",
        'fr': "Msgs du nom de la chaîne",
        'zh': "來自頻道名稱的消息",
        'ar': "رسائل من اسم القناة",
    },
    ("clink", "🔗", "☑"): {
        'ru': "Cообщ с ссылками",
        'en': "Messages with links",
        'es': "Mensajes con enlaces",
        'fr': "Messages avec liens",
        'zh': "帶有鏈接的消息",
        'ar': "الرسائل ذات الروابط",
    },
    ("csymbol", "文", "☐"): {
        'ru': "Cообщ с 文/ب/ȳ̵͘̚",
        'en': "Messages with 文/ب/ȳ̵͘̚",
        'es': "Mensajes con 文/ب/y",
        'fr': "Messagerie avec 文/ب/y",
        'zh': "與消息 文/ب/y",
        'ar': "文/ب/y الرسائل ذات",
    },
    ("cmedia", "🗣", "☐"): {
        'ru': "Сообщ с медиа",
        'en': "Messages with media",
        'es': "Mensajes con medios",
        'fr': "Msgs avec les médias",
        'zh': "與媒體的消息",
        'ar': "الرسائل بوسائل الإعلام",
    },
    ("cstart", "🚀", "☐"): {
        'ru': "Старт-слова",
        'en': "Start-words",
        'es': "Palabras de inicio",
        'fr': "Mots de départ",
        'zh': "起始詞",
        'ar': "بداية الكلمات",
    },
    ("cstop", "🧾", "☐"): {
        'ru': "Стоп-слова",
        'en': "Stop-words",
        'es': "Para las palabras",
        'fr': "Mots vides",
        'zh': "停用詞",
        'ar': "كلمات التوقف",
    },
    ("cflood", "💬", "☐"): {
        'ru': "Стоп-флуд",
        'en': "Stop-flood",
        'es': "Stop-inundación",
        'fr': "Arrêt-inondation",
        'zh': "止水",
        'ar': "وقف الفيضان",
    },
    ("cuser", "👥", "☑"): {
        'ru': "Пользователи",
        'en': "Users",
        'es': "Usuarias",
        'fr': "Utilisatrices",
        'zh': "用戶",
        'ar': "المستخدمون",
    },
    ("cadmin", "👮🏽", "☑"): {
        'ru': "Администраторы",
        'en': "Admins",
        'es': "Administradoras",
        'fr': "Administratrices",
        'zh': "管理員",
        'ar': "المشرفون",
    },
}
l_remove_group = {
    'ru': "🚫Убрать группу",
    'en': "🚫Put away group",
    'es': "🚫Guardar grupo",
    'fr': "🚫Groupe de rangement",
    'zh': "🚫收起組",
    'ar': "🚫 أبعد المجموعة",
}
l_show_groups = {
    'ru': "👩🏽‍💻 <b>Добавленные группы</b>\n\n[команды /cmd]",
    'en': "👩🏽‍💻 <b>Добавленные группы</b>\n\n[команды /cmd]",
    'es': "👩🏽‍💻 <b>Добавленные группы</b>\n\n[команды /cmd]",
    'fr': "👩🏽‍💻 <b>Добавленные группы</b>\n\n[команды /cmd]",
    'zh': "👩🏽‍💻 <b>Добавленные группы</b>\n\n[команды /cmd]",
    'ar': "👩🏽‍💻 <b>Добавленные группы</b>\n\n[команды /cmd]",
}

l_GROUPP_CCHECKBTNNAME = {
    'ru': "✔ Я человек",
    'en': "✔ I am human",
    'es': "✔ Soy humana",
    'fr': "✔ Je suis humain",
    'zh': "✔ 我是人",
    'ar': "✔ أنا إنسان",
}
l_GROUPP_CHELLOTEXT = {
    'ru': "🌱 {name}, добро пожаловать в нашу <b>группу</b> {title}!",
    'en': "🌱 {name}, welcome to our <b>group</b> {title}!",
    'es': "🌱 {name}, Bienvenida a nuestro <b>grupo</b> {title}!",
    'fr': "🌱 {name}, bienvenue dans notre <b>groupe</b> {title}!",
    'zh': "🌱 {name}, 歡迎加入我們的<b>群</b> {title}!",
    'ar': "🌱 {name} ، مرحبًا بك في <b> مجموعتنا </ b> {title}!"
}
l_GROUPP_CCHECKCHANNEL = {
    'ru': "👮🏽 Для <i>проверки подписки</i> необходимо добавить канал командой:\n\n/channel ССЫЛКА НА КАНАЛ",
    'en': "👮🏽 It is necessary add channel for <i>subscribe checking</i> by command:\n\n/channel LINK",
    'es': "👮🏽 Es necesario agregar un canal para <i>comprobar suscripciones</i> mediante el comando:\n\n/channel LINK",
    'fr': "👮🏽 Il est nécessaire d'ajouter un canal pour <i>vérifier l'abonnement</i> par la commande :\n\n/channel LINK",
    'zh': "👮🏽 <i>訂閱檢查</i>需要通過命令添加頻道：\n\n/channel LINK",
    'ar': "👮🏽 من الضروري إضافة قناة لـ <i> فحص الاشتراك </i> بواسطة الأمر: \n\n/channel LINK",
}
# endregion


# region commands
l_group_commands_handler = {
    'ru': "⚙️ <b>Настройка</b> группы <b>{0}</b> {1}\n\n<b>⛏ Admin-команды @{2}</b>\n/update <i>обновление параметров</i>\n/transfer   <i>передача admin-прав</i>\n/info   <i>информация</i>\n/stat   <i>статистика</i>\n/log   <i>посмотреть логи</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>парсинг старых id-аккаунтов</i>\n\n<b>⛏ Команды администраторов</b>\n/ban 5m|1h|10d <i>удаление из группы на время</i>\n/unban\n/mute 5m|1h|10d <i>ограничение в группе на время</i>\n/unmute\n/warn+сообщ <i>предупреждение</i>\n/status\n/karma  [+|-]\n/tag+сообщ   <i>@tager random-аккаунтов</i>\n/stop  <i>добавить стоп-слово</i>\n/channel NAME   <i>добавить канал для проверки подписки</i>\n/button NAME    <i>добавить имя кнопки входного контроля</i>\n/delay MIN      <i>установить количество min для задержки 1го сообщ</i>\n/flood NUM      <i>установить количество сообщ для flood</i>\n\n<b>⛏ Команды пользователей</b>\n/help   <i>вывод команд</i>\n/rules  <i>правила группы</i>\n/report <i>сообщить о нарушении</i>\n/happy  <i>получить радость</i>\n/thanks <i>поблагодарить</i>",
    'en': "⚙️ <b>Group</b> settings of <b>{0}</b> {1}\n\n<b>⛏ Admin-commands @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/log   <i>see logs</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-accounts</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from group for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in group for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-accounts</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for group</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'es': "⚙️ Configuración de <b>Grupo</b> de <b>{0}</b> {1}\n\n<b>⛏ Comandos de administración @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/log   <i>see logs</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-accounts</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from group for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in group for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-accounts</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for group</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'fr': "⚙️ Paramètres de <b>groupe</b> de <b>{0}</b> {1}\n\n<b>⛏ Commandes d'administration @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/log   <i>see logs</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-accounts</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from group for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in group for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-accounts</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for group</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'zh': "⚙️ <b>組</b>設置 <b>{0}</b> {1}\n\n<b>⛏ 管理員命令 @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/log   <i>see logs</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-accounts</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from group for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in group for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-accounts</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for group</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'ar': "⚙️ إعدادات <b> المجموعة </b> الخاصة بـ <b>{0}</b> {1}\n\n<b>⛏ أوامر المسؤول @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/parse  <i>[all|old|premium|active|online]</i>\n/log   <i>see logs</i>\n<code>/parse old</code> - <i>parsing old id-accounts</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from group for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in group for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-accounts</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for group</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
}
l_update_handler00 = {
    'ru': "🛡 Для дальнейшего <b>администрирования</b> данной группы запустите @{0}-бота и добавьте его в группу как <b>Administrator</b>",
    'en': "🛡 For further <b>administration</b> of this group, please start @{0} and add this bot to group as <b>Administrator</b>",
    'es': "🛡 Para una mayor <b>administración</b> de este grupo, inicie @{0} y agregue este bot al grupo como <b>Administrador</b>",
    'fr': "🛡 Pour plus d'<b>administration</b> de ce groupe, veuillez démarrer @{0} et ajouter ce bot au groupe en tant qu'<b>administrateur</b>",
    'zh': "🛡 如需進一步<b>管理</b>此群組，請啟動@{0}並將此機器人添加到群組中作為<b>管理員</b>",
    'ar': "🛡 لمزيد من <b> الإدارة </b> لهذه المجموعة ، يرجى البدء @{0} وإضافة هذا الروبوت إلى المجموعة <b> كمسؤول </b>",
}
l_update_handler01 = {
    'ru': "🛡 Группа добавлена в @{0}-бота и готова к администрированию",
    'en': "🛡 Group added to @{0} and ready for administration",
    'es': "🛡 Grupo agregado a @{0} y listo para administración",
    'fr': "🛡 Groupe ajouté à @{0} et prêt pour l'administration",
    'zh': "🛡 組已添加到 @{0} 並準備好進行管理",
    'ar': "🛡 تمت إضافة المجموعة إلى @{0} وهي جاهزة للإدارة",
}
l_update_handler10 = {
    'ru': "🛡 Группа обновлена и администрируется в @{0}-боте",
    'en': "🛡 Group updated and administered by @{0}",
    'es': "🛡 Grupo actualizado y administrado por @{0}",
    'fr': "🛡 Groupe mis à jour et administré par @{0}",
    'zh': "🛡 群組由 @{0} 更新和管理",
    'ar': "🛡 تم تحديث المجموعة وإدارتها بواسطة @{0}",
}
l_update_handler100 = {
    'ru': "🛡 Группа обновлена, но не подключена @{0}-боту! Для дальнейшего <b>администрирования</b> данной группы зайдите в @{0}-бота и нажмите /start",
    'en': "🛡 Group updated, but not connected to @{0}! For further <b>administration</b> of this group, please /start @{0}",
    'es': "🛡 ¡Grupo actualizado, pero no conectado a @{0}! Para continuar con la <b>administración</b> de este grupo, /start @{0}",
    'fr': "🛡 Groupe mis à jour, mais pas connecté à @{0} ! Pour plus d'<b>administration</b> de ce groupe, veuillez /start @{0}",
    'zh': "🛡 群組已更新，但未連接到 @{0}！ 如需進一步<b>管理</b>此組，請 /start @{0}",
    'ar': "🛡 تم تحديث المجموعة ولكنها غير مرتبطة بـ @{0}! لمزيد من <b> الإدارة </b> لهذه المجموعة ، يرجى / start @{0}",
}
l_group_info_start1 = {
    'ru': "ℹ️ <b>Общая информация о группе</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    'en': "ℹ️ <b>Common info about channel statistics</b>\n\n",
    'es': "ℹ️ <b>Información común sobre las estadísticas del grupo</b>\n\n",
    'fr': "ℹ️ <b>Informations communes sur les statistiques de channele</b>\n\n",
    'zh': "ℹ️ <b>關於組統計的常見信息</b>\n\n",
    'ar': "ℹ️ <b> معلومات عامة حول إحصائيات المجموعة </b> \n\n",
}
l_group_stat_start = {
    'ru': "ℹ️ <b>Общая информация о статистике группы</b>\n\n",
    'en': "ℹ️ <b>Common info about group statistics</b>\n\n",
    'es': "ℹ️ <b>Información común sobre las estadísticas del grupo</b>\n\n",
    'fr': "ℹ️ <b>Informations communes sur les statistiques de groupe</b>\n\n",
    'zh': "ℹ️ <b>關於組統計的常見信息</b>\n\n",
    'ar': "ℹ️ <b> معلومات عامة حول إحصائيات المجموعة </b> \n\n",
}
l_group_stat_start1 = {
    'ru': "ℹ️ <b>Общая статистика группы</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    'en': "ℹ️ <b>Common info about channel statistics</b>\n\n",
    'es': "ℹ️ <b>Información común sobre las estadísticas del grupo</b>\n\n",
    'fr': "ℹ️ <b>Informations communes sur les statistiques de channele</b>\n\n",
    'zh': "ℹ️ <b>關於組統計的常見信息</b>\n\n",
    'ar': "ℹ️ <b> معلومات عامة حول إحصائيات المجموعة </b> \n\n",
}
l_group_stat_start2 = {
    'ru': "\n<b>Ссылка</b>: {0}\n<b>Описание</b>: {1}\n<b>Привязанный канал</b>: <code>{2}</code>\n",
    'en': "ℹ️ <b>Common info about channel statistics</b>\n\n",
    'es': "ℹ️ <b>Información común sobre las estadísticas del grupo</b>\n\n",
    'fr': "ℹ️ <b>Informations communes sur les statistiques de channele</b>\n\n",
    'zh': "ℹ️ <b>關於組統計的常見信息</b>\n\n",
    'ar': "ℹ️ <b> معلومات عامة حول إحصائيات المجموعة </b> \n\n",
}
l_group_stat_start3 = {
    'ru': "<b>Сообщения</b>: {0}\n<b>Дата 1го сообщ</b>: ~{1}\n<b>ID последнего сообщ</b>: {2}\n",
    'en': "ℹ️ <b>Common info about channel statistics</b>\n\n",
    'es': "ℹ️ <b>Información común sobre las estadísticas del grupo</b>\n\n",
    'fr': "ℹ️ <b>Informations communes sur les statistiques de channele</b>\n\n",
    'zh': "ℹ️ <b>關於組統計的常見信息</b>\n\n",
    'ar': "ℹ️ <b> معلومات عامة حول إحصائيات المجموعة </b> \n\n",
}
l_participants = {
    'ru': "участ.",
    'en': "users",
    'es': "usuarias",
    'fr': "utilisatrices",
    'zh': "用戶",
    'ar': "المستخدمين",
}
l_info_opportunity = {
    'ru': "<b>Возможность просмотра увидевших сообщ</b>: <code>Да (до 50участ.)</code>\n",
    'en': "<b>Opportunity to see Message-Seen</b>: <code>Yes (up to 50users)</code>\n",
    'es': "<b>Oportunidad de ver mensajes vistos</b>: <code>Sí (hasta 50 usuarios)</code>\n",
    'fr': "<b>Possibilité de voir Message-Seen</b> : <code>Oui (jusqu'à 50 utilisateurs)</code>\n",
    'zh': "<b>查看消息的機會</b>：<code>是（最多 50 個用戶）</code>\n",
    'ar': "<b> فرصة لرؤية الرسالة المرئية </b>: <code> نعم (حتى 50 مستخدمًا) </code> \n",
}
l_info_history = {
    'ru': "<b>История для новых участников</b>: ",
    'en': "<b>History for new participants</b>: ",
    'es': "<b>Historial de nuevos participantes</b>:",
    'fr': "<b>Historique pour les nouveaux participants</b> :",
    'zh': "<b>新參與者的歷史</b>：",
    'ar': "<b> سجل للمشاركين الجدد </b>:",
}
l_info_history_show = {
    'ru': "<code>видна</code>\n",
    'en': "<code>visible</code>\n",
    'es': "<code>visible</code>\n",
    'fr': "<code>visible</code>\n",
    'zh': "<code>可見的</code>\n",
    'ar': "<code>مرئي</code>\n",
}
l_info_history_hide = {
    'ru': "<code>скрыта</code>\n",
    'en': "<code>hidden</code>\n",
    'es': "<code>oculta</code>\n",
    'fr': "<code>cachée</code>\n",
    'zh': "<code>隱</code>\n",
    'ar': "<code>مختفي</code>\n",
}
l_info_autodel = {
    'ru': "<b>Автоудаление сообщений</b>: ",
    'en': "<b>Auto-delete time for msg</b>: ",
    'es': "<b>Tiempo de eliminación automática para msg</b>:",
    'fr': "<b>Heure de suppression automatique des msg</b> :",
    'zh': "<b>自動刪除消息的時間</b>：",
    'ar': "<b> وقت الحذف التلقائي للرسائل </b>:",
}
l_info_slowmode = {
    'ru': "<b>Как часто можно писать</b>: ",
    'en': "<b>Slow Mode</b>: ",
    'es': "<b>Modo lento</b>:",
    'fr': "<b>Mode lent</b> :",
    'zh': "<b>慢速模式</b>：",
    'ar': "<b> الوضع البطيء </b>:",
}
l_info_slowmode_limitless = {
    'ru': "<code>без ограничений</code>\n",
    'en': "<code>without limits</code>\n",
    'es': "<code>sin límites</code>\n",
    'fr': "<code>sans limites</code>\n",
    'zh': "<code>沒有限制</code>\n",
    'ar': "<code>من غير قيود</code>\n",
}
l_info_oppforpart = {
    'ru': "Возможности участников",
    'en': "Participants opportunities",
    'es': "Oportunidades de los participantes",
    'fr': "Opportunités pour les participants",
    'zh': "參與者機會",
    'ar': "فرص المشاركين",
}
l_change_group_info = {
    'ru': "Изменение профиля группы",
    'en': "Change Group Info",
    'es': "Cambiar información del grupo",
    'fr': "Modifier les informations du groupe",
    'zh': "更改組信息",
    'ar': "تغيير معلومات المجموعة",
}
l_pin_message = {
    'ru': "Закрепление сообщений",
    'en': "Pin Messages",
    'es': "Mensajes de pines",
    'fr': "Épingler les messages",
    'zh': "固定消息",
    'ar': "تثبيت الرسائل",
}
l_add_members = {
    'ru': "Добавление участников",
    'en': "Add Members",
    'es': "Añadir miembros",
    'fr': "Ajouter des membres",
    'zh': "添加成員",
    'ar': "إضافة أعضاء",
}
l_embed_links = {
    'ru': "Предпросмотр ссылок",
    'en': "Embed links",
    'es': "Insertar enlaces",
    'fr': "Intégrer des liens",
    'zh': "嵌入鏈接",
    'ar': "روابط التضمين",
}
l_send_media = {
    'ru': "Отправка фото и видео",
    'en': "Send Media",
    'es': "Enviar medios",
    'fr': "Envoyer le média",
    'zh': "發送媒體",
    'ar': "إرسال الوسائط",
}
l_send_polls = {
    'ru': "Отправка опросов",
    'en': "Send Polls",
    'es': "Enviar encuestas",
    'fr': "Envoyer des sondages",
    'zh': "發送投票",
    'ar': "إرسال استطلاعات الرأي",
}
l_send_stickers = {
    'ru': "Отправка sticker/giff/via_bot",
    'en': "Send sticker/giff/via_bot",
    'es': "apagada",
    'fr': "à l'arrêt",
    'zh': "離開",
    'ar': "إيقاف",
}
l_info_anonymous_for = {
    'ru': "Анонимность для",
    'en': "Anonymous for",
    'es': "Anónimo para",
    'fr': "Anonyme pour",
    'zh': "匿名",
    'ar': "مجهول لـ",
}

l_stat_msg_cnt = {
    'ru': "Количество сообщ",
    'en': "Message number",
    'es': "Recuento de mensajes",
    'fr': "Nombre de messages",
    'zh': "消息數",
    'ar': "عدد الرسائل",
}
l_stat_history_for_new = {
    'ru': "История для новых участников",
    'en': "History for new members",
    'es': "Historia para nuevas miembros",
    'fr': "Historique pour les nouveaux membres",
    'zh': "Historia para nuevas miembros",
    'ar': "التاريخ للأعضاء الجدد",
}
l_stat_history_turn_on = {
    'ru': "(для просмотра статистики <u>включите</u> [Историю группы])",
    'en': "(to show statistics <u>enable</u> [Group history])",
    'es': "(para mostrar estadísticas <u>activar</u> [Historial del grupo])",
    'fr': "(pour afficher les statistiques, <u>activez</u> [Historique du groupe])",
    'zh': "（顯示統計信息<u>開啟</u> [群組歷史]）",
    'ar': "(لإظهار الإحصائيات <u> قم بتشغيل </u> [سجل المجموعة])",
}
l_stat_first_msg_date = {
    'ru': "Дата 1-го сообщ",
    'en': "1st msg date",
    'es': "fecha del 1er mensaje",
    'fr': "Date du 1er message",
    'zh': "第一個消息日期",
    'ar': "تاريخ الرسالة الأولى",
}
l_stat_involved = {
    'ru': "Вовлеченность в чате",
    'en': "Сhat engagement",
    'es': "Compromiso de chat",
    'fr': "Сat engagement",
    'zh': "Сhat 訂婚",
    'ar': "المشاركة الدردشة",
}
l_stat_sent = {
    'ru': "{0}\n@{1} написал(а): {2}  сообщ",
    'en': "{0}\n@{1} write: {2} message",
    'es': "{0}\n@{1} escribir: {2} mensaje",
    'fr': "{0}\n@{1} écrire : {2} message",
    'zh': "{0}\n@{1} 寫：{2} 條消息",
    'ar': "{0} \n @{1} اكتب: {2} رسالة",
}
l_stat_meet = {
    'ru': "{0}\n{1}. <i>{2}</i>..: встретилось {3} раз",
    'en': "{0}\n{1}. <i>{2}</i>..: met {3} times",
    'es': "{0}\n{1}. <i>{2}</i>..: se reunió {3} veces",
    'fr': "{0}\n{1}. <i>{2}</i>.. : rencontré {3} fois",
    'zh': "{0}\n{1}。 <i>{2}</i>..：遇到 {3} 次",
    'ar': "{0} \n {1}. <i>{2}</i> ..: التقى {3} مرة",
}
l_stat_top5users = {
    'ru': "Топ 5 пользователей (на 1000 сообщ)",
    'en': "Top 5 users (for 1000 msgs)",
    'es': "Las 5 mejores usuarios (para 1000 msgs)",
    'fr': "Top 5 des utilisateurs (pour 1000 msgs)",
    'zh': "前 5 名用戶（1000 條消息）",
    'ar': "أعلى 5 مستخدمين (لكل 1000 رسالة)",
}
l_stat_top5msgs = {
    'ru': "Топ 5 сообщ (из 1000)",
    'en': "Top 5 msgs (from 1000)",
    'es': "Las 5 mejores mensajes (desde 1000)",
    'fr': "Top 5 des messages (sur 1000)",
    'zh': "前 5 條消息（來自 1000 條）",
    'ar': "أهم 5 رسائل (من 1000)",
}
l_status_for = {
    'ru': "⚠️ Статус <b>{0}</b> для {1}:\n\n",
    'en': "⚠️ Статус <b>{0}</b> для {1}:\n\n",
    'es': "Las 5 mejores mensajes (desde 1000)",
    'fr': "Top 5 des messages (sur 1000)",
    'zh': "前 5 條消息（來自 1000 條）",
    'ar': "أهم 5 رسائل (من 1000)",
}

l_transfer_reply = {
    'ru': "⚠️ Используй команду /transfer в <b>ответном</b> сообщении пользователя, которому вы хотите передать права",
    'en': "⚠️ Use /transfer-command in reply user-message to transfer him ownership",
    'es': "⚠️ Use /transfer-command en el mensaje de usuario de respuesta para transferirle la propiedad",
    'fr': "⚠️ Utilisez /transfer-command dans le message utilisateur de réponse pour lui transférer la propriété",
    'zh': "⚠️ 使用 /transfer-command 回复 user-message 轉移他的所有權",
    'ar': "استخدم الأمر transfer-command/ في الرد على رسالة المستخدم لنقل ملكيته",
}
l_button_handler = {
    'ru': "👮🏽 <b>Готово!</b> Текущее <b>имя кнопки</b> на <i>входном контроле</i> установлено: {0}",
    'en': "👮🏽 Ready! Current <b>button name</b> in <i>Enter control</i> is: {0}",
    'es': "👮🏽 Lista! El <b>nombre del botón</b> actual en <i>Control de entrada</i> es: {0}",
    'fr': "👮🏽 Prêt! Le <b>nom du bouton</b> actuel dans <i>Saisir le contrôle</i> est : {0}",
    'zh': "👮🏽 準備好! <i>輸入控件</i>中的當前<b>按鈕名稱</b>是：{0}",
    'ar': "👮🏽 جاهز! <b> اسم الزر </b> الحالي في <i> إدخال التحكم </i> هو: {0}",
}
l_button_correct = {
    'ru': "👮🏽 <b>Введи</b> корректное название <i>для имени кнопки</i> Входного контроля\n\n👉🏼 Например, <code>/button {0}</code>",
    'en': "👮🏽 Enter correct <i>button name</i> for Enter control\n\n👉🏼 For example, <code>/button {0}</code>",
    'es': "👮🏽 Ingrese el <i>nombre del botón</i> correcto para el control Intro\n\n👉🏼 Por ejemplo, <código>/botón {0}</código>",
    'fr': "👮🏽 Saisissez le <i>nom du bouton</i> correct pour Entrer le contrôle\n\n👉🏼 Par exemple, <code>/bouton {0}</code>",
    'zh': "👮🏽 為 Enter 控件輸入正確的 <i>按鈕名稱</i>\n\n👉🏼 例如，<code>/button {0}</code>",
    'ar': "👮🏽 أدخل <i> اسم الزر </i> الصحيح لإدخال عنصر التحكم \n\n👉🏼 على سبيل المثال ، <code> / button {0}</code>",
}
l_channel_check = {
    'ru': "⚙️ Добавь @{0}-бота в канал для проверки подписки на него. Пришли мне корректную ссылку на канал:",
    'en': "⚙️ Add @{0} to channel for subscribe checking. Send me correct link to channel:",
    'es': "⚙️ Agregue @{0} al canal para verificar la suscripción. Envíame el enlace correcto al canal:",
    'fr': "⚙️ Ajoutez @{0} à la chaîne pour vérifier l'abonnement. Envoyez-moi le lien correct vers la chaîne :",
    'zh': "⚙️ 將@{0} 添加到頻道以進行訂閱檢查。 向我發送正確的頻道鏈接：",
    'ar': "⚙️ إضافة @{0} للقناة للتحقق من الاشتراك. أرسل لي الرابط الصحيح للقناة:",
}
l_channel_done = {
    'ru': "👮🏽 <b>Готово!</b> Проверка подписки на {0} настроена\n\nОпцию можно включить в настройках, нажав [✅☑Вкл подписку]",
    'en': "👮🏽 Ready! Subscribe checking to {0}-channel is configured\n\nEnable this option in the Settings by pushing [✅☑Enable subscription]",
    'es': "👮🏽 Listo! La verificación de suscripción a {0}-canal está configurada\n\nActive esta opción en Configuración presionando [✅☑Habilitar suscripción]",
    'fr': "👮🏽 Prêt! La vérification de l'abonnement à la chaîne {0} est configurée\n\nActivez cette option dans les paramètres par push [✅☑Activer l'abonnement]",
    'zh': "👮🏽 準備好了！ 已配置對 {0} 頻道的訂閱檢查\n\n通過推送在“設置”中打開此選項 [✅☑啟用訂閱]",
    'ar': "👮🏽 جاهز! التحقق من الاشتراك في {0} - تم تكوين القناة \n\n قم بتشغيل هذا الخيار في الإعدادات عن طريق الدفع [✅☑ تمكين الاشتراك]",
}
l_channel_correct = {
    'ru': "👮🏽 Добавь @{0}-бота в канал и отправь корректную <i>ссылку</i> этого канала\n\n👉🏼 Например, <code>/channel @{1}</code>",
    'en': "👮🏽 Add @{0} to channel and send correct <i>link</i> of this channel\n\n👉🏼 For example, <code>/channel @{1}</code>",
    'es': "👮🏽 Agrega @{0} al canal y envía el <i>enlace</i> correcto de este canal\n\n👉🏼 Por ejemplo, <code>/channel @{1}</code>",
    'fr': "👮🏽 Ajoutez @{0} au canal et envoyez le <i>lien</i> correct de ce canal\n\n👉🏼 Par exemple, <code>/channel @{1}</code>",
    'zh': "👮🏽 將@{0} 添加到頻道並發送此頻道的正確<i>鏈接</i>\n\n👉🏼 例如，<code>/channel @{1}</code>",
    'ar': "👮🏽 إضافة @{0} إلى القناة وإرسال <i> الرابط </i> الصحيح لهذه القناة \n \n👉🏼 على سبيل المثال ، <code> / channel @{1}</code>",
}
l_delay_correct = {
    'ru': "👥 <b>Введи</b> корректное <i>число</i> минут для первичного ограничения новых пользователей\n\n👉🏼 Например, <code>/delay 1</code>\n\nИли используй <b>медленный режим</b> в настройках группы для <u>1</u> сообщения",
    'en': "👥 Enter correct <i>number</i> in minutes for primary mute-restriction for new users\n\n👉🏼 For example, <code>/delay 1</code>\n\nOr use <b>Slow Mode</b> in group Settings for <u>1</u>st message",
    'es': "👥 Ingrese el <i>número</i> correcto en minutos para la restricción de silencio principal para nuevos usuarios\n\n👉🏼 Por ejemplo, <code>/delay 1</code>\n\nO use <b>Slow Mode </b> en Configuración de grupo para <u>1</u>er mensaje",
    'fr': "👥 Entrez le <i>nombre</i> correct en minutes pour la restriction principale de mise en sourdine pour les nouveaux utilisateurs\n\n👉🏼 Par exemple, <code>/delay 1</code>\n\nOu utilisez le <b>mode lent </b> dans le groupe Paramètres pour le <u>1</u>er message",
    'zh': "👥 在分鐘內輸入正確的 <i>number</i> 用於新用戶的主要靜音限制\n\n👉🏼 例如，<code>/delay 1</code>\n\n或使用 <b>Slow Mode <u>1</u>st 消息的組設置中的</b>",
    'ar': "👥 أدخل <i> الرقم الصحيح </i> في دقائق لتقييد كتم الصوت الأساسي للمستخدمين الجدد \n \n👉🏼 على سبيل المثال ، <code> / تأخير 1 </code> \n \n أو استخدم <b> الوضع البطيء </b> في إعدادات المجموعة لرسالة <u> 1 </u> st",
}
l_parse_error = {
    'ru': "📇 Осуществить парсинг пользователей  не удалось",
    'en': "📇 Parsing (by @username) is failed",
    'es': "📇 El análisis (por @username) falló",
    'fr': "📇 L'analyse (par @username) a échoué",
    'zh': "📇 解析（@username）失敗",
    'ar': "📇 فشل التحليل (حسب اسم المستخدم)",
}
l_parse_done = {
    'ru': "🔥 <b>Готово!</b> Собрано реальных участников: <u>{0}</u>. Можно сразу сделать <b>рассылку</b> или подписку-<b>инвайт</b> в чат по <i>полученным</i> лидам{1}",
    'en': "🔥 Ready! Gathered members: <u>{0}</u>. You can immediately make an <b>sending</b> or <b>inviting</b> to group by received members{1}",
    'es': "🔥 Listo! Miembros reunidos: <u>{0}</u>. Inmediatamente puede hacer un <b>envío</b> o <b>invitación</b> al grupo por miembros recibidos{1}",
    'fr': "🔥 Prêt ! Membres réunis : <u>{0}</u>. Vous pouvez immédiatement faire un <b>envoi</b> ou <b>inviter</b> pour grouper par membres reçus{1}",
    'zh': "🔥 準備好了！ 聚集成員：<u>{0}</u>。 您可以立即<b>發送</b>或<b>邀請</b>按收到的成員分組{1}",
    'ar': "🔥 جاهز! الأعضاء الذين تم تجميعهم: <u>{0}</u>. يمكنك على الفور إجراء <b> إرسال </b> أو <b> دعوة </b> للانضمام إلى المجموعة بواسطة الأعضاء المستلمين {1}",
}
l_parse_btnsend = {
    'ru': "📨️ Рассылка",
    'en': "📨️ Sending",
    'es': "📨️ Enviando",
    'fr': "📨️ Envoi",
    'zh': "📨️ 發送",
    'ar': "📨️ الإرسال",
}
l_parse_btninvite = {
    'ru': "🚶🏽 Инвайт",
    'en': "🚶🏽 Inviting",
    'es': "🚶🏽 invitando",
    'fr': "🚶🏽 Invitant",
    'zh': "🚶🏽 邀請",
    'ar': "🚶🏽 دعوة",
}
l_parse_start = {
    'ru': "📇 Начинаем парсинг..",
    'en': "📇 Parsing is started..",
    'es': "📇 Se inicia el análisis..",
    'fr': "📇 L'analyse est lancée..",
    'zh': "📇 解析開始..",
    'ar': "📇 بدأ الإعراب ..",
}
l_ban_handler = {
    'ru': "🪦 Пользователь {0} в бане на {1}",
    'en': "🪦 User {0} is banned for {1}",
    'es': "🪦 El usuario {0} está baneado por{1}",
    'fr': "🪦 L'utilisateur {0} est banni pour{1}",
    'zh': "🪦 用戶 {0} 因 в {1} 而被禁止",
    'ar': "🪦 المستخدم {0} محظور منذ {1}",
}
l_ban_error = {
    'ru': "🪦 Формат бана: /ban (1m|1h|10d)",
    'en': "🪦 Ban format: /ban (1m|1h|10d)",
    'es': "🪦 Formato de prohibición: /ban (1m|1h|10d)",
    'fr': "🪦 Format d'interdiction : /ban (1m|1h|10j)",
    'zh': "🪦 禁令格式：/ban (1m|1h|10d)",
    'ar': "🪦 تنسيق الحظر: / ban (1m | 1h | 10d)",
}
l_ban_unban = {
    'ru': "🪦 Пользователь возвращен из бана",
    'en': "🪦 User is returned from ban",
    'es': "🪦 Usuario que regresa de la prohibición",
    'fr': "🪦 Retour de l'utilisateur de l'interdiction",
    'zh': "🪦 用戶從禁令中返回",
    'ar': "🪦 عودة المستخدم من الحظر",
}
l_mute_handler = {
    'ru': "💤 Пользователь {0} обеззвучен на {1}",
    'en': "💤 User {0} is muted for {1}",
    'es': "💤 La usuario {0} está silenciada por {1}",
    'fr': "💤 L'utilisateur {0} est mis en sourdine pendant {1}",
    'zh': "💤 用戶 {0} 為 {1} 靜音",
    'ar': "💤 المستخدم {0} مكتوم لـ {1}",
}
l_mute_error = {
    'ru': "💤 Формат обеззвучивания: /mute (1m|1h|10d)",
    'en': "💤 Mute format: /mute (1m|1h|10d)",
    'es': "💤 Formato de silencio: /mute (1m|1h|10d)",
    'fr': "💤 Format muet : /muet (1m|1h|10j)",
    'zh': "💤 靜音格式：/mute (1m|1h|10d)",
    'ar': "💤 تنسيق كتم الصوت: / كتم الصوت (1 م | 1 س | 10 د)",
}
l_mute_unmute = {
    'ru': "💤 Пользователь {0} больше не обеззвучен",
    'en': "💤 User is no longer in mute",
    'es': "💤 La usuario ya no está en silencio.",
    'fr': "💤 L'utilisateur n'est plus en mode muet",
    'zh': "💤 用戶不再靜音",
    'ar': "💤 لم يعد المستخدم في وضع الصامت",
}
l_warn_handler = {
    'ru': "⚠️ От имени группы <b>{0}</b> выносится предупреждение {1}{2}",
    'en': "⚠️ In the name of the group <b>{0}</b> a warning is issued to {1}{2}",
    'es': "⚠️ En el nombre del grupo <b>{0}</b> se emite una advertencia a {1}{2}",
    'fr': "⚠️ Au nom du groupe <b>{0}</b> un avertissement est émis à {1}{2}",
    'zh': "⚠️ 以組 <b>{0}</b> 的名義向 {1}{2} 發出警告",
    'ar': "⚠️ باسم المجموعة <b>{0}</b> تم إصدار تحذير لـ {1} {2}",
}
l_status_pin = {
    'ru': "Закреп сообщ",
    'en': "Pin message",
    'es': "Pin mensaje",
    'fr': "Épingler le message",
    'zh': "固定消息",
    'ar': "رسالة دبوس",
}
l_status_profile = {
    'ru': "Изменение профиля группы",
    'en': "Change Group Info",
    'es': "Cambiar información del grupo",
    'fr': "Modifier les informations du groupe",
    'zh': "更改組信息",
    'ar': "تغيير معلومات المجموعة",
}
l_sendmsg = {
    'ru': "Отправка сообщ",
    'en': "Sending messages",
    'es': "Enviando mensajes",
    'fr': "Envoi de messages",
    'zh': "發送消息",
    'ar': "إرسال الرسائل",
}
l_status_limit = {
    'ru': "Ограничения до",
    'en': "Limit for",
    'es': "Límite para",
    'fr': "Limite pour",
    'zh': "限制為",
    'ar': "حد لـ",
}
l_status_without = {
    'ru': "(отсутствует) для",
    'en': "(none) for",
    'es': "(ninguno) para",
    'fr': "(aucun) pour",
    'zh': "（無）為",
    'ar': "(لا شيء) لـ",
}

l_karma_current = {
    'ru': "Текущая карма пользователя",
    'en': "Current Karma of user",
    'es': "Karma actual de la usuaria",
    'fr': "Karma actuel de l'utilisateur",
    'zh': "用戶當前的業力",
    'ar': "الكارما الحالية للمستخدم",
}
l_karma_in_group = {
    'ru': "в группе",
    'en': "in group",
    'es': "en grupo",
    'fr': "en groupe",
    'zh': "在小組中",
    'ar': "في مجموعة",
}
l_karma_all = {
    'ru': "🪺 Карма пользователей группы <b>{0}</b>",
    'en': "🪺 Karma of group users <b>{0}</b>",
    'es': "🪺 Karma de las usuarias del grupo <b>{0}</b>",
    'fr': "🪺 Karma des utilisateurs du groupe <b>{0}</b>",
    'zh': "🪺 群組用戶的業力 <b>{0}</b>",
    'ar': "🪺 كارما مجموعة المستخدمين <b>{0}</b>",
}
l_karma_off = {
    'ru': "🪹 Карма пользователей группы <b>{0}</b> не установлена",
    'en': "🪹 Karma of group users <b>{0}</b> is none",
    'es': "🪹 El karma de las usuarias del grupo <b>{0}</b> no es ninguna",
    'fr': "🪹 Le karma des utilisateurs du groupe <b>{0}</b> est nul",
    'zh': "🪹 群組用戶 <b>{0}</b> 的業力是無",
    'ar': "🪹 كارما مجموعة المستخدمين <b>{0}</b> لا توجد",
}
l_tag_handler = {
    'ru': "@ Необходимо ввести сообщение",
    'en': "@ You have to write message",
    'es': "@ Tienes que escribir mensaje",
    'fr': "@ Vous devez écrire un message",
    'zh': "@你必須寫消息",
    'ar': "@ عليك كتابة رسالة",
}
l_help_handler = {
    'ru': "👉🏼 <b>Команды</b> пользователя:\n\n/rules - правила группы\n/report - сообщить о нарушении\n/happy - получить радость\n/thanks - поблагодарить",
    'en': "👉🏼 <b>Users commands</b>:\n\n/rules - of group\n/report - about violation of the rules\n/happy - get happiness\n/thanks - say thank you",
    'es': "👉🏼 <b>Comandos de las usuarias</b>:\n\n/rules - of group\n/report - about violation of the rules\n/happy - get happiness\n/thanks - say thank you",
    'fr': "👉🏼 <b>Commandes utilisateurs</b>:\n\n/rules - of group\n/report - about violation of the rules\n/happy - get happiness\n/thanks - say thank you",
    'zh': "👉🏼 <b>用戶命令</b>:\n\n/rules - of group\n/report - about violation of the rules\n/happy - get happiness\n/thanks - say thank you",
    'ar': "👉🏼 <b>أوامر المستخدمين</b>:\n\n/rules - of group\n/report - about violation of the rules\n/happy - get happiness\n/thanks - say thank you",
}
l_report_handler = {
    'ru': "❗️ Информация передана администратору. Пользователь {0} взят на карандаш",
    'en': "❗️ User {0} in group <b>{1}</b> ask to pay attention to message {2}{3}",
    'es': "❗️ El usuario {0} del grupo <b>{1}</b> pide prestar atención al mensaje {2}{3}",
    'fr': "❗️ L'utilisateur {0} du groupe <b>{1}</b> demande de prêter attention au message {2}{3}",
    'zh': "❗️ <b>{1}</b> 組中的用戶 {0} 要求關註消息 {2}{3}",
    'ar': "❗️ يطلب المستخدم {0} في مجموعة <b>{1}</b> الانتباه إلى الرسالة {2} {3}",
}
l_report_admin = {
    'ru': "❗️ Пользователь {0} в группе <b>{1}</b> просит обратить внимание на сообщение {2}{3}",
    'en': "❗️ User {0} in group <b>{1}</b> ask to pay attention to message {2}{3}",
    'es': "❗️ El usuario {0} del grupo <b>{1}</b> pide prestar atención al mensaje {2}{3}",
    'fr': "❗️ L'utilisateur {0} du groupe <b>{1}</b> demande de prêter attention au message {2}{3}",
    'zh': "❗️ <b>{1}</b> 組中的用戶 {0} 要求關註消息 {2}{3}",
    'ar': "❗️ يطلب المستخدم {0} في مجموعة <b>{1}</b> الانتباه إلى الرسالة {2} {3}",
}
l_report_reply = {
    'ru': "❗ Отправь эту команду в ответ на сообщение",
    'en': "❗ Send this command as reply to message",
    'es': "❗ Enviar este comando como respuesta al mensaje",
    'fr': "❗ Envoyez cette commande en réponse au message",
    'zh': "❗ 將此命令作為對消息的回復發送",
    'ar': "❗ أرسل هذا الأمر كرد على الرسالة",
}
l_thanks_handler = {
    'ru': "🎉 От имени группы <b>{0}</b> обьявляется благодарность {1}{2}",
    'en': "🎉 In the name of the group <b>{0}</b> gratitude is announced to {1}{2}",
    'es': "🎉 En nombre del grupo <b>{0}</b> se anuncia el agradecimiento a {1}{2}",
    'fr': "🎉 Au nom du groupe <b>{0}</b> la gratitude est annoncée à {1}{2}",
    'zh': "🎉 以 <b>{0}</b> 小組的名義向 {1}{2} 宣布感謝",
    'ar': "🎉 باسم المجموعة <b>{0}</b> تم الإعلان عن الامتنان لـ {1} {2}",
}
l_thanks_reply = {
    'ru': "🎉 Отправь эту команду в ответ на сообщение",
    'en': "🎉 Send this command as reply to message",
    'es': "🎉 Enviar este comando como respuesta al mensaje",
    'fr': "🎉 Envoyez cette commande en réponse au message",
    'zh': "🎉 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_birthday_handler = {
    'ru': "🥳 От имени группы <b>{0}</b> поздравляем с днем рождения {1}{2}",
    'en': "🥳 In the name of the group <b>{0}</b> gratitude is announced to {1}{2}",
    'es': "🎉 En nombre del grupo <b>{0}</b> se anuncia el agradecimiento a {1}{2}",
    'fr': "🎉 Au nom du groupe <b>{0}</b> la gratitude est annoncée à {1}{2}",
    'zh': "🎉 以 <b>{0}</b> 小組的名義向 {1}{2} 宣布感謝",
    'ar': "🎉 باسم المجموعة <b>{0}</b> تم الإعلان عن الامتنان لـ {1} {2}",
}
l_birthday_reply = {
    'ru': "🥳 Отправь эту команду в ответ на сообщение",
    'en': "🎉 Send this command as reply to message",
    'es': "🎉 Enviar este comando como respuesta al mensaje",
    'fr': "🎉 Envoyez cette commande en réponse au message",
    'zh': "🎉 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_videochat_text = {
    'ru': "🎥 Автоматическое анонсирование <b>видео-трансляции</b> <code>[/videochat d h]</code> каждый <u>d</u>-день (1-31) на <u>h</u>-часов (1-168). Текущее значение: /videochat {0}\n\n👩🏽‍💻 Например,\n<code>/videochat 1 1</code> (ежедневный видео-анонс длительностью 1 час)\n<code>/videochat 0</code> (отключение опции)",
    'en': "🎥 Send this command as reply to message",
    'es': "🎥 Enviar este comando como respuesta al mensaje",
    'fr': "🎥 Envoyez cette commande en réponse au message",
    'zh': "🎥 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_flood_text = {
    'ru': "💬 <b>Введи</b> корректное <i>число</i> сообщений от <u>3</u> до <u>10</u>\n\n👉🏼 <b>Текущее</b> значение <code>/flood {0}</code>\n\n👩🏽‍💻 Например, /flood 3 (идентификация 3х сообщений подряд как flood)\n/flood 0 (отключение опции)",
    'en': "🎥 Send this command as reply to message",
    'es': "🎥 Enviar este comando como respuesta al mensaje",
    'fr': "🎥 Envoyez cette commande en réponse au message",
    'zh': "🎥 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_flood_on = {
    'ru': "💬 Установлен flood-режим: {0} сообщения подряд",
    'en': "🎥 Send this command as reply to message",
    'es': "🎥 Enviar este comando como respuesta al mensaje",
    'fr': "🎥 Envoyez cette commande en réponse au message",
    'zh': "🎥 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_flood_off = {
    'ru': "💬 Режим flood отключен",
    'en': "🎥 Send this command as reply to message",
    'es': "🎥 Enviar este comando como respuesta al mensaje",
    'fr': "🎥 Envoyez cette commande en réponse au message",
    'zh': "🎥 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_delay_text = {
    'ru': "👥 <b>Введи</b> корректное <i>число</i> минут для первичного ограничения новых пользователей\n\n👉🏼 <b>Текущее</b> значение <code>/delay {0}</code>\n\n👩🏽‍💻 Например, /delay 3 (ограничение на 3 min)\n/delay 0 (отключение опции)",
    'en': "🎥 Send this command as reply to message",
    'es': "🎥 Enviar este comando como respuesta al mensaje",
    'fr': "🎥 Envoyez cette commande en réponse au message",
    'zh': "🎥 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_delay_on = {
    'ru': "👥 <b>Готово!</b> Текущая первичная задержка для <u>новых</u> пользователей (перед написанием их <u>1</u>го сообщ) установлена в значение <u>{0}</u> min",
    'en': "👥 Ready! Current primary delay for <u>new</u> users (before writing their <u>1</u>st message) is <u>{0}</u> min",
    'es': "👥 Listo! El retraso principal actual para los <u>nuevos</u> usuarios (antes de escribir su <u>1</u>er mensaje) es <u>{0}</u> min",
    'fr': "👥 Prêt! Le délai principal actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) est de <u>{0}</u> min",
    'zh': "👥 準備好了！<u>新</u>用戶的當前主要延遲（在寫他們的<u>1</u>st消息之前）是<u>{0}</u>分鐘",
    'ar': "👥 جاهز! التأخير الأساسي الحالي لمستخدمي <u> الجدد </u> (قبل كتابة رسالتهم <u> 1 </u> st) هو <u>{0}</u> min",
}
l_delay_off = {
    'ru': "👥 Режим delay отключен",
    'en': "👥 Ready! Current primary delay for <u>new</u> users (before writing their <u>1</u>st message) is <u>{0}</u> min",
    'es': "👥 Listo! El retraso principal actual para los <u>nuevos</u> usuarios (antes de escribir su <u>1</u>er mensaje) es <u>{0}</u> min",
    'fr': "👥 Prêt! Le délai principal actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) est de <u>{0}</u> min",
    'zh': "👥 準備好了！<u>新</u>用戶的當前主要延遲（在寫他們的<u>1</u>st消息之前）是<u>{0}</u>分鐘",
    'ar': "👥 جاهز! التأخير الأساسي الحالي لمستخدمي <u> الجدد </u> (قبل كتابة رسالتهم <u> 1 </u> st) هو <u>{0}</u> min",
}
l_rules_handler = {
    'ru': "👉🏼 <b>Правила</b> группы <b>{0}</b>:\n\n{1}",
    'en': "👉🏼 <b>Group rules</b> for <b>{0}</b>:\n\n{1}",
    'es': "👉🏼 <b>Reglas de grupo</b> para <b>{0}</b>:\n\n{1}",
    'fr': "👉🏼 <b>Règles de groupe</b> pour <b>{0}</b> :\n\n{1}",
    'zh': "👉🏼 <b>{0}</b> 的 <b>組規則</b>：\n\n{1}",
    'ar': "👉🏼 <b> قواعد المجموعة </b> لـ <b>{0}</b>:\n\n{1}",
}
l_rules_on = {
    'ru': "👉🏼 Установлены <u>новые</u> <b>правила</b> для группы <b>{0}</b>:\n\n{1}",
    'en': "👉🏼 New <u>rules</u> for group<b>{0}</b>:\n\n{1}",
    'es': "👉🏼 Nuevas <u>reglas</u> para el grupo<b>{0}</b>:\n\n{1}",
    'fr': "👉🏼 Nouvelles <u>règles</u> pour le groupe<b>{0}</b> :\n\n{1}",
    'zh': "👉🏼 組<b>{0}</b>的新<u>規則</u>：\n\n{1}",
    'ar': "👉🏼 قواعد <u> جديدة </u> للمجموعة <b>{0}</b>:\n\n{1}",
}
l_rules_off = {
    'ru': "👉🏼 <b>Правила</b> в группе <b>{0}</b> не установлены. Необходимо <u>ответить на пост</u> с правилами <b>командой</b> /rules",
    'en': "👉🏼 <b>Group rules</b> for <b>{0}</b> is not configured. You have to <u>reply to message</u> with rules by /rules-<b>command</b>",
    'es': "👉🏼 <b>Reglas de grupo</b> para <b>{0}</b> no están configuradas. Tienes que <u>responder al mensaje</u> con reglas por /rules-<b>comando</b>",
    'fr': "👉🏼 Les <b>règles de groupe</b> pour <b>{0}</b> ne sont pas configurées. Vous devez <u>répondre au message</u> avec des règles par /rules-<b>commande</b>",
    'zh': "👉🏼 <b>{0}</b> 的 <b>組規則</b> 未配置。 您必須通過 /rules-<b>command</b> 使用規則<u>回复消息</u>",
    'ar': "👉🏼 لم تتم تهيئة <b> قواعد المجموعة </b> لـ <b>{0}</b>. يجب عليك <u> الرد على الرسالة </u> بالقواعد من خلال / rules- <b> أمر </b>",
}
# endregion


# region ccheck
l_ccheck_handler = {
    'ru': "👮🏽 <b>Жми</b> на ✅/🔘, чтобы <b>переключить</b> тип <i>проверки</i> пользователя при <u>вступлении</u> в группу\n\n👉🏼 Для установки имени <b>нажимаемой кнопки</b>, выполни команду: <code>/button {0}</code>\n\n👉🏼 Для <b>проверки подписки</b> на канал <i>добавь</i> @{1}-бота в канал и выполни команду: <code>/channel {2}</code>\n\n👉🏼 Для <i>защиты от атаки</i> на группу включи режим <b>антирейд</b> (блокировка <u>всех</u> вступающих)",
    'en': "👮🏽 Push the ✅/🔘 to <b>switch</b> <i>Enter control</i> of user <u>joining</u> into group\n\n👉🏼 To set name of <b>pushing button</b> execute command: <code>/button {0}</code>\n\n👉🏼 To check <b>channel-subscription</b> <i>add</i> @{1} to channel and execute command: <code>/channel {2}</code>\n\n👉🏼 To <i>defend</i> from group-attack switch <b>anti-raid</b>-mode (ban <u>everyone</u> who joining)",
    'es': "👮🏽 Presiona ✅/🔘 para <b>cambiar</b> <i>Enter control</i> del usuario <u>uniéndose</u> al grupo\n\n👉🏼 Para establecer el nombre de <b> presionando el botón</b> ejecute el comando: <code>/button {0}</code>\n\n👉🏼 Para verificar <b>channel-subscription</b> <i>add</i> @{1} para canalizar y ejecutar el comando: <code>/channel {2}</code>\n\n👉🏼 Para <i>defender</i> del ataque grupal, active el modo <b>anti-raid</b> (prohibir a <u>todos</u> que se unan)",
    'fr': "👮🏽 Appuyez sur ✅/🔘 pour <b>commuter</b> <i>Entrez le contrôle</i> de l'utilisateur <u>rejoignant</u> le groupe\n\n👉🏼 Pour définir le nom de <b> en appuyant sur le bouton</b> exécutez la commande : <code>/button {0}</code>\n\n👉🏼 Pour vérifier <b>channel-subscription</b> <i>add</i> @{1} pour canaliser et exécuter la commande : <code>/channel {2}</code>\n\n👉🏼 Pour <i>se défendre</i> contre une attaque de groupe, activez le mode <b>anti-raid</b> (bannir <u>tous ceux</u> qui se joignent)",
    'zh': "👮🏽 按下 ✅/🔘 來<b>切換</b> <i>進入控制</i> 用戶<u>加入</u> 入組\n\n👉🏼 設置<b>的名字 按下按鈕</b> 執行命令：<code>/button {0}</code>\n\n👉🏼 檢查<b>頻道訂閱</b> <i>add</i> @{1} 引導並執行命令：<code>/channel {2}</code>\n\n👉🏼 以 <i>defend</i> 免受群攻開啟 <b>anti-raid</b>-mode （禁止加入的<u>每個人</u>）",
    'ar': "👮🏽 ادفع ✅ / 🔘 إلى <b> التبديل </b> <i> أدخل التحكم </i> للمستخدم <u> المنضم </u> إلى مجموعة \n\n👉🏼 لتعيين اسم <b> ضغط الزر </b> نفذ الأمر: <code> / button {0}</code>\n\n👉🏼 للتحقق من <b> اشتراك القناة </b> <i> إضافة </i> @{1} لتوجيه وتنفيذ الأمر: <code> / channel {2}</code>\n\n👉🏼 <i> للدفاع </i> من هجوم المجموعة ، شغّل وضع <b> anti-raid </b> (حظر <u> كل شخص </u> من ينضم)",
}
l_ccheck_add = {
    'ru': "\n\nВ настройках [Администраторы] вкл для {0}-бота:\n[✅ Удаление сообщ]\n[✅ Блокировка польз]\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "\n\nIn the Settings [Administrators] for @{0} enable:\n[✅ Delete Msgs]\n[✅ Ban Users]\n[✅ Invite Users]\n🕚Wait for 1min",
    'es': "\n\nEn la Configuración [Administradores] para @{0} active:\n[✅ Eliminar mensajes]\n[✅ Prohibir usuarios]\n[✅ Invitar usuarios]\n🕚Espere 1 minuto",
    'fr': "\n\nDans les paramètres [Administrateurs] pour @{0}, activez :\n[✅ Supprimer les messages]\n[✅ Bannir les utilisateurs]\n[✅ Inviter des utilisateurs]\n🕚Attendez 1 minute",
    'zh': "\n\n在@{0}的設置[管理員]中打開：\n[✅刪除消息]\n[✅禁止用戶]\n[✅邀請用戶]\n🕚等待1分鐘",
    'ar': "\n\n في الإعدادات [Administrators] لـ @{0} شغّل:\n [✅ حذف الرسائل] \n على [✅ حظر المستخدمين] \n [✅ دعوة المستخدمين] \n وانتظر لمدة دقيقة واحدة",
}
l_ccheck_call_request_on = {
    'ru': "👮🏽 В настройках [Тип группы] вкл:\n[✅ Заявки на вступление]{0}",
    'en': "👮🏽 In the Settings [Group Type] enable:\n[✅ Approve New Members]{0}",
    'es': "👮🏽 En la Configuración [Tipo de grupo] habilite:\n[✅ Aprobar nuevos miembros]{0}",
    'fr': "👮🏽 Dans les paramètres [Type de groupe], activez :\n[✅ Approuver les nouveaux membres]{0}",
    'zh': "👮🏽 在設置 [群組類型] 中啟用：\n[✅ 批准新成員]{0}",
    'ar': "👮🏽 في إعدادات [نوع المجموعة] تمكين: \n [✅ الموافقة على أعضاء جدد] {0}",
}
l_ccheck_call_request_off = {
    'ru': "👮🏽 В настройках [Тип группы] выкл:\n[☑️ Заявки на вступление]{0}",
    'en': "👮🏽 In the Settings [Group Type] disable:\n[☑️ Approve New Members]{0}",
    'es': "👮🏽 En la Configuración [Tipo de grupo], deshabilite:\n[☑️ Aprobar nuevos miembros]{0}",
    'fr': "👮🏽 在設置 [群組類型] 中禁用：\n[☑️ 批准新成員]{0}",
    'zh': "👮🏽 在設置 [群組類型] 中禁用：\n[☑️ 批准新成員]{0}",
    'ar': "👮🏽 في إعدادات [نوع المجموعة] تعطيل: \n [☑️ الموافقة على أعضاء جدد] {0}",
}
l_ccheck_other_person = {
    'ru': "👮🏽 Эта кнопка не для тебя",
    'en': "👮🏽 This button is not for you",
    'es': "👮🏽 Este botón no es para ti",
    'fr': "👮🏽 Ce bouton n'est pas pour vous",
    'zh': "👮🏽 這個按鈕不適合你",
    'ar': "👮🏽 هذا الزر ليس لك",
}
l_ccheckchannel_link = {
    'ru': "👮🏽 Ссылка на {0} не доступна",
    'en': "👮🏽 Link for {0} is invalid",
    'es': "👮🏽 El enlace para {0} no es válido",
    'fr': "👮🏽 Le lien pour {0} n'est pas valide",
    'zh': "👮🏽 {0} 的鏈接無效",
    'ar': "👮🏽 ارتباط {0} غير صالح",
}
l_ccheckchannel_chn = {
    'ru': "👮🏽 Ты не вступил в {0}\n\nПопробуй ещё раз позже",
    'en': "👮🏽 You are not join to {0}\n\nTry again later",
    'es': "👮🏽 No te has unido a {0}\n\nInténtalo de nuevo más tarde",
    'fr': "👮🏽 您沒有加入 {0}\n\n 請稍後再試",
    'zh': "👮🏽 您沒有加入 {0}\n\n 請稍後再試",
    'ar': "👮🏽 أنت لست مشتركًا في {0} \n\n حاول مرة أخرى لاحقًا",
}
l_ccheck_ban = {
    'ru': "👮🏽‍ Пользователь {0} не прошел входной контроль и был удален из группы",
    'en': "👮🏽 User {0} did not pass Enter Control and have been deleted from this group",
    'es': "👮🏽 El usuario {0} no pasa el control de entrada y ha sido eliminado de este grupo",
    'fr': "👮🏽 L'utilisateur {0} ne passe pas Enter Control et a été supprimé de ce groupe",
    'zh': "👮🏽 用戶 {0} 未通過 Enter Control 並已從該組中刪除",
    'ar': "👮🏽 المستخدم {0} لا يجتاز إدخال التحكم وقد تم حذفه من هذه المجموعة",
}
l_ccheckchannel_error = {
    'ru': "👮🏽 Ошибка проверки",
    'en': "👮🏽 Error of checking",
    'es': "👮🏽 Error de verificación",
    'fr': "👮🏽 Erreur de vérification",
    'zh': "👮🏽檢查錯誤",
    'ar': "👮🏽 خطأ في الفحص",
}
l_ccheck_wrong = {
    'ru': "👮🏽 К сожалению, ответ неверный\n\nПопробуй ещё раз позже",
    'en': "👮🏽 Unfortunately the answer is not correct\n\nTry again later",
    'es': "👮🏽 Lamentablemente la respuesta no es correcta\n\nVuelve a intentarlo más tarde",
    'fr': "👮🏽 Malheureusement, la réponse n'est pas correcte\n\nRéessayez plus tard",
    'zh': "👮🏽 很遺憾答案不正確\n\n稍後再試",
    'ar': "👮🏽 للأسف الإجابة غير صحيحة \n\n حاول مرة أخرى لاحقًا",
}
l_ccheck_time = {
    'ru': "👮🏽 Входной контроль пройден за {0} sec",
    'en': "👮🏽 Enter Control passed for {0} sec",
    'es': "👮🏽 Control de entrada superado durante {1} seg.",
    'fr': "👮🏽 Entrez le contrôle passé pendant {1} sec",
    'zh': "👮🏽 輸入控制已通過 {1} 秒",
    'ar': "👮🏽 أدخل التحكم الذي تم تمريره لمدة {1} ثانية",
}
# endregion


# region chello_
l_chello_call = {
    'ru': "🔔 Нет ни одного приветствия, необходимо ⚙️Настроить",
    'en': "🔔 There are no greetings you need to ⚙️Configure",
    'es': "🔔 No hay saludos que necesites ⚙️Configurar",
    'fr': "🔔 Vous n'avez pas besoin de salutations ⚙️Configurer",
    'zh': "🔔無需問候⚙️配置",
    'ar': "🔔لا توجد تحيات تحتاج إلى تكوين",
}
l_chello_your_hello = {
    'ru': "Ваше приветствие",
    'en': "Your greeting",
    'es': "Tu saludo",
    'fr': "Votre message d'accueil",
    'zh': "你的問候",
    'ar': "تحياتك",
}
l_chello_text = {
    'ru': "👋🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> приветствие, а также его ⚙️Настроить\n\n👉🏼 Например, <code>{0}</code>{1}",
    'en': "👋🏽 Push the ✅/☑️, to <b>On/Off</b> greeting, and to ⚙️Configure\n\n👉🏼 For example, <code>{0}</code>{1}",
    'es': "👋🏽 Presione ✅/☑️, para <b>Activar/Desactivar</b> el saludo y para ⚙️Configurar\n\n👉🏼 Por ejemplo, <code>{0}</code>{1}",
    'fr': "👋🏽 Appuyez sur ✅/☑️, sur <b>Activer/Désactiver</b> le message d'accueil et sur ⚙️Configurer\n\n👉🏼 Par exemple, <code>{0}</code>{1}",
    'zh': "👋🏽 按下 ✅/☑️、<b>On/Off</b> 問候語和 ⚙️Configure\n\n👉🏼 例如，<code>{0}</code>{1}",
    'ar': "👋🏽 اضغط على ✅ / ☑️ ، من أجل <b> تشغيل / إيقاف </b> الترحيب ، و تكوين \n\n👉🏼 على سبيل المثال ، <code>{0}</code>{1}",
}
l_btn_on = {
    'ru': "✅☑Вкл",
    'en': "✅☑On",
    'es': "✅☑En",
    'fr': "✅☑En",
    'zh': "✅☑使能夠",
    'ar': "✅☑ تمكين",
}
l_btn_off = {
    'ru': "☑️☐Выкл",
    'en': "☑️☐Off",
    'es': "☑️☐De",
    'fr': "☑️☐De",
    'zh': "☑️☐禁用",
    'ar': "☑️☐ تعطيل",
}
l_btn_settings = {
    'ru': "⚙️Настроить",
    'en': "⚙️Configure",
    'es': "⚙️Configurar",
    'fr': "⚙️Configurer",
    'zh': "⚙️配置",
    'ar': "⚙️ تكوين",
}
l_chellochange_handler = {
    'ru': "👋🏽 Отправь мне <b>текст</b>/<b>медиа</b> контент с текстом: фото/гиф/видео/аудио/документ или запиши голосовое/видео-заметку в кружке\n\n👉🏼 Например, <code>{0}</code>",
    'en': "👋🏽 Send me <b>text</b>/<b>media</b> content with text: photo/giff/video/audio/document or voice/video-note\n\n👉🏼 For example, <code>{0}</code>",
    'es': "👋🏽 Envíame contenido de <b>texto</b>/<b>medios</b> con texto: photo/giff/video/audio/document or voice/video-note\n\n👉🏼 Par exemple, <code>{0}</code>",
    'fr': "👋🏽 Envoyez-moi du contenu <b>texte</b>/<b>média</b> avec du texte: photo/giff/video/audio/document or voice/video-note\n\n👉🏼 Par exemple, <code>{0}</code>",
    'zh': "👋🏽 向我發送帶有文本的 <b>text</b>/<b>media</b> 內容: photo/giff/video/audio/document or voice/video-note\n\n👉🏼 例如, <code>{0}</code>",
    'ar': "👋🏽 أرسل لي محتوى <b> نصًا </b> / <b> وسائط </b> مع نص: photo/giff/video/audio/document or voice/video-note\n\n👉🏼 فمثلا, <code>{0}</code>",
}
l_fsm_hello_finish = {
    'ru': "👋🏽 Приветствие записано!\n\nОпцию можно включить в настройках [👋🏽Авто-приветствие], нажав [✅☑Вкл]",
    'en': "👋🏽 Greeting is recorded!\n\nYou can enable this option in the Settings [👋🏽Auto-greeting], by pushing [✅☑On]",
    'es': "👋🏽 ¡Se graba el saludo!\n\nPuede habilitar esta opción en la Configuración [👋🏽Auto-saludo], presionando [✅☑On]",
    'fr': "👋🏽 Le message d'accueil est enregistré !\n\nVous pouvez activer cette option dans les paramètres [👋🏽Auto-salutation], en appuyant sur [✅☑On]",
    'zh': "👋🏽問候語已錄製！\n\n您可以在設置[👋🏽自動問候語]中啟用此選項，方法是按[✅☑On]",
    'ar': "👋🏽 تم تسجيل الترحيب!\n\n يمكنك تمكين هذا الخيار في الإعدادات [الترحيب التلقائي] ، بالضغط على [تشغيل]",
}
# endregion


# region cinvite_
l_cinvite_call = {
    'ru': "👮🏽 В настройках [Разрешения] вкл опцию:\n\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the Settings [Permissions] enable:\n\n[✅ Add memebers]\n🕚Wait for 1min",
    'es': "👮🏽 En la Configuración [Permisos] habilite:\n\n[✅ Agregar miembros]\n🕚Espere 1 minuto",
    'fr': "👮🏽 Dans les paramètres [Autorisations], activez :\n\n[✅ Ajouter des membres]\n🕚Attendez 1 min",
    'zh': "👮🏽在設置[權限]中啟用：\n\n[✅添加成員]\n🕚等待1分鐘",
    'ar': "👮🏽 في الإعدادات [الأذونات] ، قم بتمكين: \n\n [✅ إضافة أعضاء]\n🕚 انتظر لمدة دقيقة واحدة",
}
l_cinvite_text_add = {
    'ru': "\n\n👉🏼 Приглашается <u>{0}</u> пользователей в сутки из группы {1}",
    'en': "🚶🏽 Push the ✅/☑️, to <b>On/Off</b> auto-inviting users to your group\n\n👉🏼 Inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👉🏼 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Appuyez sur ✅/☑️, pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre groupe\n\n👉🏼 Inviter <u>{0}</u> utilisateurs par jour à partir du groupe {1}",
    'zh': "🚶🏽 按下 ✅/☑️, 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👉🏼 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👉🏼 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_text = {
    'ru': "🚶🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-инвайт пользователей в <b>{0}</b>-группу\n\n👩🏽‍💻 <b>Текущие</b> настройки авто-рассылки: {1}",
    'en': "🚶🏽 Push the ✅/☑️, to <b>On/Off</b> auto-inviting users to your group\n\n👉🏼 Inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👉🏼 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Appuyez sur ✅/☑️, pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre groupe\n\n👉🏼 Inviter <u>{0}</u> utilisateurs par jour à partir du groupe {1}",
    'zh': "🚶🏽 按下 ✅/☑️, 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👉🏼 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👉🏼 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}

l_cinvite_current = {
    'ru': "🚶🏽 <b>Текущие</b> настройки авто-инвайта в группу:\n\n<u>{0}</u> пользователей/сутки\n<u>{1}</u> источник",
    'en': "🚶🏽 Send <b>link</b> to userbot as source for new members\n\n👉🏼 For example, <code>https://t.me/likeconcentrat</code> - push the link to copy",
    'es': "🚶🏽 Envía <b>enlace</b> al grupo como fuente para nuevos miembros\n\n👉🏼 Por ejemplo, <code>https://t.me/likeconcentrat</code> - presiona el enlace para copiar",
    'fr': "🚶🏽 Envoyez <b>lien</b> au userbote comme source pour les nouveaux membres\n\n👉🏼 Par exemple, <code>https://t.me/likeconcentrat</code> - appuyez sur le lien pour le copier",
    'zh': "🚶🏽 將 <b>link</b> 發送到群組作為新成員的來源\n\n👉🏼 例如，<code>https://t.me/likeconcentrat</code> - 推送鏈接以進行複制",
    'ar': "📨️ أرسل <b> ارتباط </b> للمجموعة كمصدر للأعضاء الجدد \n\n👉🏼 على سبيل المثال ، <code> https://t.me/likeconcentrat </code> - ادفع الرابط للنسخ",
}
l_cinvite_cnt = {
    'ru': "{0} польз/сутки",
    'en': "Send <b>link</b> to userbot as source for new members\n\n👉🏼 For example, <code>https://t.me/likeconcentrat</code> - push the link to copy",
    'es': "Envía <b>enlace</b> al grupo como fuente para nuevos miembros\n\n👉🏼 Por ejemplo, <code>https://t.me/likeconcentrat</code> - presiona el enlace para copiar",
    'fr': "Envoyez <b>lien</b> au userbote comme source pour les nouveaux membres\n\n👉🏼 Par exemple, <code>https://t.me/likeconcentrat</code> - appuyez sur le lien pour le copier",
    'zh': "將 <b>link</b> 發送到群組作為新成員的來源\n\n👉🏼 例如，<code>https://t.me/likeconcentrat</code> - 推送鏈接以進行複制",
    'ar': "📨️ أرسل <b> ارتباط </b> للمجموعة كمصدر للأعضاء الجدد \n\n👉🏼 على سبيل المثال ، <code> https://t.me/likeconcentrat </code> - ادفع الرابط للنسخ",
}
l_cinvite_src = {
    'ru': "{0} источник",
    'en': "Send <b>link</b> to userbot as source for new members\n\n👉🏼 For example, <code>https://t.me/likeconcentrat</code> - push the link to copy",
    'es': "Envía <b>enlace</b> al grupo como fuente para nuevos miembros\n\n👉🏼 Por ejemplo, <code>https://t.me/likeconcentrat</code> - presiona el enlace para copiar",
    'fr': "Envoyez <b>lien</b> au userbote comme source pour les nouveaux membres\n\n👉🏼 Par exemple, <code>https://t.me/likeconcentrat</code> - appuyez sur le lien pour le copier",
    'zh': "將 <b>link</b> 發送到群組作為新成員的來源\n\n👉🏼 例如，<code>https://t.me/likeconcentrat</code> - 推送鏈接以進行複制",
    'ar': "📨️ أرسل <b> ارتباط </b> للمجموعة كمصدر للأعضاء الجدد \n\n👉🏼 على سبيل المثال ، <code> https://t.me/likeconcentrat </code> - ادفع الرابط للنسخ",
}
l_cinvitechange_handler = {
    'ru': "🚶🏽 Пришли мне <b>ссылку</b> на группу, откуда будем брать подписчиков\n\n👉🏼 Например, <code>https://t.me/likeconcentrat</code> - <b>Жми</b> на ссылку, чтобы скопировать",
    'en': "🚶🏽 Send <b>link</b> to group as source for new members\n\n👉🏼 For example, <code>https://t.me/likeconcentrat</code> - push the link to copy",
    'es': "🚶🏽 Envía <b>enlace</b> al grupo como fuente para nuevos miembros\n\n👉🏼 Por ejemplo, <code>https://t.me/likeconcentrat</code> - presiona el enlace para copiar",
    'fr': "🚶🏽 Envoyez <b>lien</b> au groupe comme source pour les nouveaux membres\n\n👉🏼 Par exemple, <code>https://t.me/likeconcentrat</code> - appuyez sur le lien pour le copier",
    'zh': "🚶🏽 將 <b>link</b> 發送到群組作為新成員的來源\n\n👉🏼 例如，<code>https://t.me/likeconcentrat</code> - 推送鏈接以進行複制",
    'ar': "🚶🏽 أرسل <b> ارتباط </b> للمجموعة كمصدر للأعضاء الجدد \n\n👉🏼 على سبيل المثال ، <code> https://t.me/likeconcentrat </code> - ادفع الرابط للنسخ",
}
l_correct_link = {
    'ru': "👩🏽‍💻 <b>Вставь</b> корректные данные или повтори операцию",
    'en': "👩🏽‍💻 Send correct link or try again later",
    'es': "👩🏽‍💻 Envíe el enlace correcto o vuelva a intentarlo más tarde",
    'fr': "👩🏽‍💻 Envoyez le lien correct ou réessayez plus tard",
    'zh': "👩🏽‍💻 發送正確的鏈接或稍後再試",
    'ar': "👩🏽‍💻 أرسل الرابط الصحيح أو حاول مرة أخرى لاحقًا",
}
l_admin_require = {
    'ru': "👩🏽‍💻 Требуются права администратора",
    'en': "👩🏽‍💻 Send correct link or try again later",
    'es': "👩🏽‍💻 Envíe el enlace correcto o vuelva a intentarlo más tarde",
    'fr': "👩🏽‍💻 Envoyez le lien correct ou réessayez plus tard",
    'zh': "👩🏽‍💻 發送正確的鏈接或稍後再試",
    'ar': "👩🏽‍💻 أرسل الرابط الصحيح أو حاول مرة أخرى لاحقًا",
}
l_group_not_channel = {
    'ru': "🚶🏽 Вставь ссылку на группу, а не канал",
    'en': "🚶🏽 Send group-link, not channel-link",
    'es': "🚶🏽 Enviar enlace de grupo, no enlace de canal",
    'fr': "🚶🏽 Envoyer un lien de groupe, pas un lien de chaîne",
    'zh': "🚶🏽 發送群組鏈接，而不是頻道鏈接",
    'ar': "🚶🏽 أرسل رابط المجموعة ، وليس رابط القناة",
}
l_no_participants = {
    'ru': "🚶🏽 Нет доступных подписчиков",
    'en': "🚶🏽 No available subscribers",
    'es': "🚶🏽 No hay suscriptores disponibles",
    'fr': "🚶🏽 Aucun abonné disponible",
    'zh': "🚶🏽 沒有可用的訂閱者",
    'ar': "🚶🏽 لا يوجد مشتركون متاحون",
}
l_current_participants = {
    'ru': "🚶🏽 Для {0}<b>текущее количество</b> реальных подписчиков: <u>{1}</u>\n\n▪️ <b>Введи</b> <i>число</i> подписчиков, которое необходимо подписывать <b>ежедневно</b> от 1 до 3 (без подписки +{2}):",
    'en': "🚶🏽 For {0}<b>current number</b> of real members: <u>{1}</u>\n\n▪️ Enter <i>number</i> of members to subscribe <b>everyday</b> from 1 to 3 (without subscription +{2}):",
    'es': "🚶🏽 Para {0}<b>número actual</b> de miembros reales: <u>{1}</u>\n\n▪️ Ingrese <i>número</i> de miembros para suscribirse <b>todos los días </b> del 1 al 3 (sin suscripción +{2}):",
    'fr': "🚶🏽 Pour {0}<b>nombre actuel</b> de membres réels : <u>{1}</u>\n\n▪️ Saisissez le <i>nombre</i> de membres à souscrire <b>tous les jours </b> de 1 à 3 (sans abonnement +{2}) :",
    'zh': "🚶🏽 {0}<b>當前人數</b> 的真實會員：<u>{1}</u>\n\n▪️ 輸入 <i>會員人數</i> 以訂閱<b>每天 </b> 從 1 到 3（無訂閱 +{2}）：",
    'ar': "🚶🏽 بالنسبة إلى {0}<b> العدد الحالي </b> للأعضاء الحقيقيين: <u>{1}</u> \n\n▪️ أدخل <i> عدد </i> من الأعضاء للاشتراك <b> كل يوم </b> من 1 إلى 3 (بدون اشتراك + {2}):",
}
l_everyday_participants = {
    'ru': "🚶🏽 <b>Введи</b> количество пользователей для ежедневной подписки от 1 до 3 включительно",
    'en': "🚶🏽 Enter number of users for everyday inviting from 1 to 3",
    'es': "🚶🏽 Ingrese el número de usuarios para invitar todos los días de 1 a 3",
    'fr': "🚶🏽 Entrez le nombre d'utilisateurs pour l'invitation quotidienne de 1 à 3",
    'zh': "🚶🏽 輸入每天邀請的用戶數，從 1 到 3",
    'ar': "🚶🏽 أدخل عدد المستخدمين للدعوة اليومية من 1 إلى 3",
}
l_invite_need_subscribe = {
    'ru': "🚶🏽 Для инвайта > 1 пользователя в день необходимо приобрести подписку. Оформи подписку или введи 1:",
    'en': "🚶🏽 For inviting > 1 members per day you have to subscribe or type 1:",
    'es': "🚶🏽 Para invitar > 1 miembros por día tienes que suscribirte o escribir 1:",
    'fr': "🚶🏽 Pour inviter > 1 membres par jour il faut s'inscrire ou taper 1 :",
    'zh': "🚶🏽 每天邀請 > 1 個成員，您必須訂閱或輸入 1：",
    'ar': "🚶🏽 لدعوة> عضو واحد يوميًا ، يجب عليك الاشتراك أو اكتب 1:",
}
l_invite_correct_num = {
    'ru': "🚶🏽 <b>Введи</b> корректное число",
    'en': "🚶🏽 Enter correct number",
    'es': "🚶🏽 Ingrese el número correcto",
    'fr': "🚶🏽 Entrez le bon numéro",
    'zh': "🚶輸入正確的數字",
    'ar': "🚶🏽 Enter correct number",
}
l_fsm_invite_finish = {
    'ru': "🚶🏽 <b>Готово!</b> Настроен <b>авто</b>-инвайт <u>{0}</u> пользователей в сутки из группы {1}",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_nosrc = {
    'ru': "🚶🏽 Не задан источник для инвайта пользователей в группу",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_group = {
    'ru': "🚶🏽 Группа",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_file = {
    'ru': "🚶🏽 Файл",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_geo = {
    'ru': "🚶🏽 Гео",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_choose_src = {
    'ru': "🚶🏽 <b>Выбери источник</b>, откуда будем брать @username для авто-инвайта",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_choose_cnt = {
    'ru': "🚶🏽 <b>Введи</b> <b>количество</b> пользователей для авто-инвайта, которые будут приглашаться ежедневно (без подписки: 1 польз)",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_choose_group = {
    'ru': "🚶🏽 Отправь <b>ссылку</b> на группу, чтобы сделать авто-инвайт по ее @username",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_choose_file = {
    'ru': "🚶🏽 Отправь текстовый <b>файл</b> со списком @username, чтобы сделать по ним авто-инвайт",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_choose_geo = {
    'ru': "🚶🏽 Отправь <b>геопозицию</b>, чтобы получить гео-@username для авто-инвайта",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_csv_table = {
    'ru': "🚶🏽 В csv-файле @username или ссылка должны быть в 3м столбце",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_csv_file = {
    'ru': "🚶🏽 Пришли корректный текстовый <b>файл</b> со списком @username",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_src_empty = {
    'ru': "🚶🏽 No @usernames in {0} for {1}",
    'en': "🚶🏽 Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "🚶🏽 準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_choose = {
    'ru': "Выбрать",
    'en': "Ready! <b>Auto</b>-inviting <u>{0}</u> users per day from group {1}",
    'es': "Listo! Invitación <b>automática</b> a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "Prêt ! <b>Auto</b>-inviter <u>{0}</u> utilisateurs par jour du groupe {1}",
    'zh': "準備好了！ <b>自動</b>-每天從組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🚶🏽 جاهز! <b> دعوة تلقائية </b> <u>{0}</u> للمستخدمين يوميًا من المجموعة {1}",
}
# endregion


# region csystem_
l_csystem_text = {
    'ru': "👣 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>системные</i> сообщения\n\n👉🏼 Например, <i>Пользователь вступил(а) в группу</i>",
    'en': "👣 Push the ✅/☑️, to <b>On/Off</b> <i>system</i> messages\n\n👉🏼 For example, <i>User joined the group</i>",
    'es': "👣 Presiona ✅/☑️, para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👉🏼 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "👣 Appuyez sur ✅/☑️, pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👉🏼 Par exemple, <i>L'utilisateur a rejoint le groupe</i>",
    'zh': "👣 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👉🏼 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👉🏼 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
# endregion


# region cchannel_
l_cchannel_text = {
    'ru': "🫥 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>возможность</i> пользователю в группе писать <i>анонимно</i> (от имени <b>его</b> канала)",
    'en': "🫥 Push the ✅/☑️, to <b>On/Off</b> <i>opportunity</i> for users in group to write <i>anonymously</i> (from name of <b>his</b> channel)",
    'es': "🫥 Presiona ✅/☑️ para <b>Activar/Desactivar</b> <i>oportunidad</i> para que los usuarios del grupo escriban <i>anónimamente</i> (del nombre de <b>su</b> canal)",
    'fr': "🫥 Poussez le ✅/☑️, sur <b>On/Off</b> <i>opportunité</i> pour les utilisateurs du groupe d'écrire <i>anonymement</i> (du nom de <b>son</b> canal)",
    'zh': "🫥 將 ✅/☑️ 推到 <b>On/Off</b> <i>機會</i> 讓群組中的用戶<i>匿名</i> （來自<b>他的名字</b> 頻道）",
    'ar': "🫥 اضغط على ✅/☑️ ، من أجل <b> تشغيل / إيقاف </b> <i> فرصة </i> للمستخدمين في المجموعة لكتابة <i> مجهول </i> (من اسم <b> الخاص به </b> قناة)",
}

# endregion


# region clink_
l_clink_text = {
    'ru': "🔗 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>внешние <b>ссылки</b>/telegram-<b>ссылки</b>/forward</i>-<b>ссылки</b>\n\n👉🏼 Например, [✅☑Вкл forward-ссылки] означает разрешение на <b>forward-пересылку</b> сообщений из <u>других</u> Telegram-<i>каналов/групп/аккаунтов</i> в <u>нашу</u> группу",
    'en': "🔗 Push the ✅/☑️, to <b>On/Off</b> <i>externak <b>links</b>/telegram-<b>links</b>/forward</i>-<b>links</b>\n\n👉🏼 For example, [✅☑On forward-links] means permission on <b>forward</b> messages from <u>other</u> Telegram-<i>channels/groups/accounts</i> into <u>our</u> group",
    'es': "🔗 Presiona ✅/☑️ para <b>Activar/Desactivar</b> <i>externak <b>enlaces</b>/telegram-<b>enlaces</b>/reenviar</i>-<b>enlaces</b>\n\n👉🏼 Por ejemplo, [✅☑On forward-links] significa permiso en <b>reenviar</b> mensajes de <u>otros</u> Telegram-<i>canales /grupos/cuentas</i> en <u>nuestro</u> grupo",
    'fr': "🔗 Appuyez sur le ✅/☑️, sur <b>On/Off</b> <i>externak <b>links</b>/telegram-<b>links</b>/forward</i>-<b>liens</b>\n\n👉🏼 Par exemple, [✅☑On forward-links] signifie l'autorisation de <b>transférer</b> les messages provenant d'<u>autres</u> chaînes Telegram-<i> /groupes/comptes</i> dans <u>notre</u> groupe",
    'zh': "🔗 將 ✅/☑️ 推到 <b>On/Off</b> <i>externak <b>links</b>/telegram-<b>links</b>/forward</i>-<b>links</b>\n\n👉🏼 例如，[✅☑On forward-links] 表示允許 <b>forward</b> 來自 <u>other</u> Telegram-<i> 頻道的消息 /groups/accounts</i> 進入 <u>我們的</u> 組",
    'ar': "🔗 ادفع ✅ / ☑️ إلى تشغيل / إيقاف روابط خارجية telegram- روابط/ إعادة توجيه الروابط \n\n👉🏼 على سبيل المثال ، [على روابط إعادة التوجيه] تعني إذنًا بشأن <b> إعادة توجيه </b> الرسائل من أخرى Telegram قنوات/groups/accounts في مجموعتنا",
}
l_clink_http_on = {
    'ru': "✅☑Вкл внешние-ссылки",
    'en': "✅☑On external links",
    'es': "✅☑En enlaces externos",
    'fr': "✅☑En Liens externes",
    'zh': "✅☑使能夠 外部鏈接",
    'ar': "✅☑ يُمكَِن روابط خارجية",
}
l_clink_http_off = {
    'ru': "☑️☐Выкл внешние-ссылки",
    'en': "☑️☐Off external links",
    'es': "☑️☐De enlaces externos",
    'fr': "☑️☐De Liens externes",
    'zh': "☑️☐禁用 外部鏈接",
    'ar': "☑️☐ تعطيل روابط خارجية",
}
l_clink_telegram_on = {
    'ru': "✅☑Вкл @telegram-ссылки",
    'en': "✅☑On @telegram links",
    'es': "✅☑En enlaces @telegram",
    'fr': "✅☑En Liens @telegram",
    'zh': "✅☑使能夠 @telegram-鏈接",
    'ar': "✅☑ يُمكَِن @telegram-الروابط",
}
l_clink_telegram_off = {
    'ru': "☑️☐Выкл @telegram-ссылки",
    'en': "☑️☐Off @telegram-links",
    'es': "☑️☐De @telegram-enlaces",
    'fr': "☑️☐De @telegram-Liens",
    'zh': "☑️☐禁用 @telegram-鏈接",
    'ar': "☑️☐ تعطيل @telegram-الروابط",
}
l_clink_forward_on = {
    'ru': "✅☑Вкл forward-ссылки",
    'en': "✅☑On forward-links",
    'es': "✅☑En forward-enlaces",
    'fr': "✅☑En forward-Liens",
    'zh': "✅☑使能夠 forward-鏈接",
    'ar': "✅☑ يُمكَِن forward-الروابط",
}
l_clink_forward_off = {
    'ru': "☑️☐Выкл forward-ссылки",
    'en': "☑️☐Off forward-links",
    'es': "☑️☐De forward-enlaces",
    'fr': "☑️☐De forward-Liens",
    'zh': "☑️☐禁用 forward-鏈接",
    'ar': "☑️☐ تعطيل forward-الروابط",
}
# endregion


# region csymbol_
l_csymbol_text = {
    'ru': "文 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <u>авто</u>-бан <i>слов с 文-глиф, ب-араб/ <a href='https://www.zalgo.org'>zalgo-символами</a></i>\n\n👉🏼 Например, опция <b>zalgo-бан</b> удаляет сообщения такого вида <i>h̴̢̝̱̜͓̠̮̪̞͓͚̦͓͆͗̅̎̂͑̃̋͜e̷̡̧͙̹̥͓̣͍̰̮͙̻͍̐͒̒̍̈́̒̎̅̈́ḻ̸̨̢̘̥͛̈́̔̀̇̏̈́̂̎͠l̶̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏͆̕͜͝ô̶͍̼͎͈̬̩̩̰̱͙̒͗͐̊̐̐͛̾́͗̈́̚͝͝ͅ</i>",
    'en': "文 Push the ✅/☑️, to <b>On/Off</b> <u>auto</u>-ban <i>words with 文-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👉🏼 For example, the option <b>zalgo-ban</b> delete messages <i>h̴̢̝̱̜͓̠̮̪̞͓͚̦͓͆͗̅̎̂͑̃̋͜e̷̡̧͙̹̥͓̣͍̰̮͙̻͍̐͒̒̍̈́̒̎̅̈́ḻ̸̨̢̘̥͛̈́̔̀̇̏̈́̂̎͠l̶̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏͆̕͜͝ô̶͍̼͎͈̬̩̩̰̱͙̒͗͐̊̐̐͛̾́͗̈́̚͝͝ͅ</i>",
    'es': "文 Presione ✅/☑️, para <b>Encender/Apagar</b> <u>automático</u>-prohibir <i>palabras con 文-glif, ب-arab, <a href='https://www.zalgo.org'>Zalgo-Symbols</a></i>\n\n👉🏼 Por ejemplo, la opción <b>Zalgo-ban</b> Eliminar mensajes <i>h̴̢̝̱̜͓̠̮̪̞͓͚̦͓͆͗̅̎̂͑̃̋͜e̷̡̧͙̹̥͓̣͍̰̮͙̻͍̐͒̒̍̈́̒̎̅̈́ḻ̸̷̨̢̡̧̘̥͙̹̥͓̣͍̰̮͙̻͍͛̈́̔̀̐͒̒̍̈́̒̎̅̈́ḻ̸̨̢̘̥͛̈́̔̀l̶̶̡̡̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏͆̔̀̾̾͛͑́̏͆̕̕͜͜͝͝</i>",
    'fr': "文 Appuyez sur ✅/☑️, pour <b>On/Off</b> <u>auto</u>-bannir <i>les mots avec 文-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👉🏼 Par exemple, l'option <b>zalgo-ban</b> supprimer les messages <i>h̴̢̝̱̜͓̠̮̪̞͓͚̦͓͆͗̅̎̂͑̃̋͜e̷̡̧͙̹̥͓̣͍̰̮͙̻͍̐͒̒̍̈́̒̎̅̈́ḻ̸̷̨̢̡̧̘̥͙̹̥͓̣͍̰̮͙̻͍͛̈́̔̀̐͒̒̍̈́̒̎̅̈́ḻ̸̨̢̘̥͛̈́̔̀l̶̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏͆̕͜͝ô̶͍̼͎͈̬̩̩̰̱͙̒͗͐̊̐̐͛̾́͗̈́̚͝͝ͅ</i>",
    'zh': "文推 ✅/☑️, 到 <b>On/Off</b> <u>auto</u>-ban <i>words with 文-glif, ب-arab, <a href='https://www.zalgo.org'>zalgo-symbols</a></i>\n\n👉🏼 例如，選項<b>zalgo-ban</b>刪除消息",
    'ar': "文 اضغط على ✅ / ☑️ ، من أجل تشغيل / إيقاف تلقائي - حظر الكلمات التي تحتوي على -glif ، ب- arab ، <a href ='https://www.zalgo.org'>رموز zalgo</a>\n\n👉🏼 على سبيل المثال ، الخيار <b>zalgo-ban</b> يحذف الرسائل h̴̢̝̱̜͓̠̮̪̞͓͚̦͓͆͗̅̎̂͑̃̋͜e̷̡̧͙̹̥͓̣͍̰̮͙̻͍̐͒̒̍̈́̒̎̅̈́ḻ̸̨̢̘̥͛̈́̔̀̇̏̈́̂̎͠l̶̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏͆̕͜͝ô̶͍̼͎͈̬̩̩̰̱͙̒͗͐̊̐̐͛̾́͗̈́̚͝͝ͅ",
}
l_csymbol_symbols_on = {
    'ru': "✅☑Вкл 文ب-бан",
    'en': "✅☑On 文ب-ban",
    'es': "✅☑En 文ب-ban",
    'fr': "✅☑En 文ب-ban",
    'zh': "✅☑使能夠 文ب-ban",
    'ar': "✅☑ يُمكَِن 文ب-ban",
}
l_csymbol_symbols_off = {
    'ru': "☑️☐Выкл 文ب-бан",
    'en': "☑️☐Off 文ب-ban",
    'es': "☑️☐De 文ب-ban",
    'fr': "☑️☐De 文ب-ban",
    'zh': "☑️☐禁用 文ب-ban",
    'ar': "☑️☐ معاق 文ب-ban",
}
l_csymbol_zalgo_on = {
    'ru': "✅☑Вкл zalgo-бан",
    'en': "✅☑On zalgo-ban",
    'es': "✅☑En zalgo-ban",
    'fr': "✅☑En zalgo-ban",
    'zh': "✅☑使能夠 zalgo-ban",
    'ar': "✅☑ يُمكَِن zalgo-ban",
}
l_csymbol_zalgo_off = {
    'ru': "☑️☐Выкл zalgo-бан",
    'en': "☑️☐Off zalgo-ban",
    'es': "☑️☐De zalgo-ban",
    'fr': "☑️☐De zalgo-ban",
    'zh': "☑️☐禁用 zalgo-ban",
    'ar': "☑️☐ معاق zalgo-ban",
}
# endregion


# region cmedia_
l_cmedia_text = {
    'ru': "🗣 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> разрешение на <i>media</i>-сообщения\n\n👉🏼 Например, [☑️☐Выкл видео-заметки] означает запрет на <b>видео-заметки в кружочке</b> в нашей группе\n\n👉🏼 Чтобы разрешить/запретить конкретный стикерпак, жми [⚙️Настроить]",
    'en': "🗣 Push the ✅/☑️, to <b>On/Off</b> permission on <i>media</i>-messages\n\n👉🏼 For example, [☑️☐Off video-note] means sending-prohibition on <b>video-note</b> in our group\n\n👉🏼 To allow/prohibit specific sticker-pack, push the [⚙️Configure]",
    'es': "🗣 Presiona ✅/☑️, para <b>Activar/Desactivar</b> permiso en <i>medios</i>-mensajes\n\n👉🏼 Por ejemplo, [☑️☐Off video-note] significa enviar- Prohibición de <b>notas de video</b> en nuestro grupo\n\n👉🏼 Para permitir/prohibir un paquete de calcomanías específico, presiona [⚙️Configurar]",
    'fr': "🗣 Appuyez sur ✅/☑️, sur l'autorisation <b>On/Off</b> sur les messages <i>media</i>\n\n👉🏼 Par exemple, [☑️☐Off video-note] signifie envoyer- interdiction de <b>video-note</b> dans notre groupe\n\n👉🏼 Pour autoriser/interdire un pack d'autocollants spécifique, appuyez sur [⚙️Configurer]",
    'zh': "🗣 將 ✅/☑️ 推送到 <i>media</i> 消息上的 <b>On/Off</b> 權限\n\n👉🏼 例如，[☑️☐Off video-note] 表示發送- 禁止我們組中的 <b>video-note</b>\n\n👉🏼 要允許/禁止特定的貼紙包，請按下 [⚙️Configure]",
    'ar': "🗣 ادفع ✅ / ☑️ ، إلى إذن <b> تشغيل / إيقاف </b> على <i> الوسائط </i> - الرسائل \n\n👉🏼 على سبيل المثال ، [☑️☐ Off video-note] تعني إرسال- حظر <b> ملاحظة الفيديو </b> في مجموعتنا \n\n👉🏼 للسماح / حظر حزمة ملصقات معينة ، اضغط على [⚙️ تكوين]",
}
l_cmedia_photo_on = {
    'ru': "✅☑Вкл photo",
    'en': "✅☑On photo",
    'es': "✅☑En photo",
    'fr': "✅☑En photo",
    'zh': "✅☑使能夠 photo",
    'ar': "✅☑ يُمكَِن photo",
}
l_cmedia_photo_off = {
    'ru': "☑️☐Выкл photo",
    'en': "☑️☐Off photo",
    'es': "☑️☐De photo",
    'fr': "☑️☐De photo",
    'zh': "☑️☐禁用 photo",
    'ar': "☑️☐تعطيل photo",
}
l_cmedia_video_on = {
    'ru': "✅☑Вкл video",
    'en': "✅☑On video",
    'es': "✅☑En video",
    'fr': "✅☑En video",
    'zh': "✅☑使能夠 video",
    'ar': "✅☑ يُمكَِن video",
}
l_cmedia_video_off = {
    'ru': "☑️☐Выкл video",
    'en': "☑️☐Off video",
    'es': "☑️☐De video",
    'fr': "☑️☐De video",
    'zh': "☑️☐禁用 video",
    'ar': "☑️☐تعطيل video",
}
l_cmedia_giff_on = {
    'ru': "✅☑Вкл giff",
    'en': "✅☑On giff",
    'es': "✅☑En giff",
    'fr': "✅☑En giff",
    'zh': "✅☑使能夠 giff",
    'ar': "✅☑ يُمكَِن giff",
}
l_cmedia_giff_off = {
    'ru': "☑️☐Выкл giff",
    'en': "☑️☐Off giff",
    'es': "☑️☐De giff",
    'fr': "☑️☐De giff",
    'zh': "☑️☐禁用 giff",
    'ar': "☑️☐تعطيل giff",
}
l_cmedia_audio_on = {
    'ru': "✅☑Вкл audio",
    'en': "✅☑On audio",
    'es': "✅☑En audio",
    'fr': "✅☑En audio",
    'zh': "✅☑使能夠 audio",
    'ar': "✅☑ يُمكَِن audio",
}
l_cmedia_audio_off = {
    'ru': "☑️☐Выкл audio",
    'en': "☑️☐Off audio",
    'es': "☑️☐De audio",
    'fr': "☑️☐De audio",
    'zh': "☑️☐禁用 audio",
    'ar': "☑️☐تعطيل audio",
}
l_cmedia_emoji_on = {
    'ru': "✅☑Вкл emoji",
    'en': "✅☑On emoji",
    'es': "✅☑En emoji",
    'fr': "✅☑En emoji",
    'zh': "✅☑使能夠 emoji",
    'ar': "✅☑ يُمكَِن emoji",
}
l_cmedia_emoji_off = {
    'ru': "☑️☐Выкл emoji",
    'en': "☑️☐Off emoji",
    'es': "☑️☐De emoji",
    'fr': "☑️☐De emoji",
    'zh': "☑️☐禁用 emoji",
    'ar': "☑️☐تعطيل emoji",
}
l_cmedia_docum_on = {
    'ru': "✅☑Вкл docum",
    'en': "✅☑On docum",
    'es': "✅☑En docum",
    'fr': "✅☑En docum",
    'zh': "✅☑使能夠 docum",
    'ar': "✅☑ يُمكَِن docum",
}
l_cmedia_docum_off = {
    'ru': "☑️☐Выкл docum",
    'en': "☑️☐Off docum",
    'es': "☑️☐De docum",
    'fr': "☑️☐De docum",
    'zh': "☑️☐禁用 docum",
    'ar': "☑️☐تعطيل docum",
}
l_cmedia_viabot_on = {
    'ru': "✅☑Вкл via_bot",
    'en': "✅☑On via_bot",
    'es': "✅☑En via_bot",
    'fr': "✅☑En via_bot",
    'zh': "✅☑使能夠 via_bot",
    'ar': "✅☑ يُمكَِن via_bot",
}
l_cmedia_viabot_off = {
    'ru': "☑️☐Выкл via_bot",
    'en': "☑️☐Off via_bot",
    'es': "☑️☐De via_bot",
    'fr': "☑️☐De via_bot",
    'zh': "☑️☐禁用 via_bot",
    'ar': "☑️☐تعطيل via_bot",
}
l_cmedia_poll_on = {
    'ru': "✅☑Вкл опросы",
    'en': "✅☑On poll",
    'es': "✅☑En poll",
    'fr': "✅☑En poll",
    'zh': "✅☑使能夠 poll",
    'ar': "✅☑ يُمكَِن poll",
}
l_cmedia_poll_off = {
    'ru': "☑️☐Выкл опросы",
    'en': "☑️☐Off poll",
    'es': "☑️☐De poll",
    'fr': "☑️☐De poll",
    'zh': "☑️☐禁用 poll",
    'ar': "☑️☐تعطيل poll",
}
l_cmedia_sticker_on = {
    'ru': "✅☑Вкл sticker",
    'en': "✅☑On sticker",
    'es': "✅☑En sticker",
    'fr': "✅☑En sticker",
    'zh': "✅☑使能夠 sticker",
    'ar': "✅☑ يُمكَِن sticker",
}
l_cmedia_sticker_off = {
    'ru': "☑️☐Выкл sticker",
    'en': "☑️☐Off sticker",
    'es': "☑️☐De sticker",
    'fr': "☑️☐De sticker",
    'zh': "☑️☐禁用 sticker",
    'ar': "☑️☐تعطيل sticker",
}
l_cmedia_voice_on = {
    'ru': "✅☑Вкл голосовые",
    'en': "✅☑On voice",
    'es': "✅☑En voice",
    'fr': "✅☑En voice",
    'zh': "✅☑使能夠 voice",
    'ar': "✅☑ يُمكَِن voice",
}
l_cmedia_voice_off = {
    'ru': "☑️☐Выкл голосовые",
    'en': "☑️☐Off voice",
    'es': "☑️☐De voice",
    'fr': "☑️☐De voice",
    'zh': "☑️☐禁用 voice",
    'ar': "☑️☐تعطيل voice",
}
l_cmedia_videonote_on = {
    'ru': "✅☑Вкл видео-заметки",
    'en': "✅☑On video-note",
    'es': "✅☑En video-note",
    'fr': "✅☑En video-note",
    'zh': "✅☑使能夠 video-note",
    'ar': "✅☑ يُمكَِن video-note",
}
l_cmedia_videonote_off = {
    'ru': "☑️☐Выкл видео-заметки",
    'en': "☑️☐Off video-note",
    'es': "☑️☐De video-note",
    'fr': "☑️☐De video-note",
    'zh': "☑️☐禁用 video-note",
    'ar': "☑️☐تعطيل video-note",
}
l_cmedia_call_photo = {
    'ru': "👮🏽 В настройках [Разрешения] включи опцию:\n\n[✅ Отправка фото и видео]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the Settings [Permissions] enable:\n\n[✅ Send Media]\n🕚Wait for 1min",
    'es': "👮🏽 En la Configuración [Permisos] habilite:\n\n[✅ Enviar medios]\n🕚 Espere 1 minuto",
    'fr': "👮🏽 Dans les paramètres [Autorisations], activez :\n\n[✅ Envoyer un média]\nt🕚Attendez 1 min",
    'zh': "👮🏽在設置[權限]中啟用：\n\n[✅發送媒體]\n🕚等待1分鐘",
    'ar': "👮🏽 في الإعدادات [الأذونات] ، قم بتمكين: \n\n [✅ إرسال الوسائط]\n🕚 انتظر لمدة دقيقة واحدة",
}
l_cmedia_call_sticker_giff = {
    'ru': "👮🏽 В настройках [Разрешения] включи опцию:\n\n[✅ Отправка стикеров и GIF]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the Settings [Permissions] enable:\n\n[✅ Send Stickers]\n🕚Wait for 1min",
    'es': "👮🏽 En la Configuración [Permisos] habilite:\n\n[✅ Enviar Pegatinas]\n🕚Espere 1 minuto",
    'fr': "👮🏽 Dans les paramètres [Autorisations], activez :\n\n[✅ Envoyer des Autocollants]\n🕚Attendez 1 min",
    'zh': "👮🏽 在設置[權限]中啟用：\n\n[✅發送貼紙]\n🕚等待1分鐘",
    'ar': "👮🏽 في الإعدادات [الأذونات] ، قم بتمكين: \n\n [✅ إرسال ملصقات] \n🕚 انتظر لمدة دقيقة واحدة",
}
l_cmedia_call_poll = {
    'ru': "👮🏽 В настройках [Разрешения] включи опцию:\n\n[✅ Отправка опросов]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the Settings [Permissions] enable:\n\n[✅ Send Poll]\n🕚Wait for 1min",
    'es': "👮🏽 En la Configuración [Permisos] habilite:\n\n[✅ Enviar encuesta]\n🕚Espere 1 minuto",
    'fr': "👮🏽 Dans les paramètres [Autorisations], activez :\n\n[✅ Envoyer un sondage]\n🕚Attendez 1 min",
    'zh': "👮🏽 在設置[權限]中啟用：\n\n[✅發送投票]\n🕚等待1分鐘",
    'ar': "👮🏽 في الإعدادات [الأذونات] ، قم بتمكين: \n\n [✅ إرسال استطلاع] \n🕚 انتظر لمدة دقيقة واحدة",
}
l_cstickerconfig_text = {
    'ru': "🦊 <b>Исключения</b> для стикерпаков в <code>{0}</code>-файле:\n\n+ Разрешенные: <u>{1}</u>\n- Запрещенные: <u>{2}</u>\n\n[✅ Разрешить] пропускает указанные стикерпаки <i>в качестве исключения</i>, когда выбрана опция [☑️☐Выкл sticker]\n\n[🚫 Запретить] запрещает указанные стикерпаки <i>в качестве исключения</i>, когда выбрана опция [✅☑Вкл sticker]",
    'en': "🦊 <b>Exceptions</b> for sticker-packs in <code>{0}</code>-file:\n\n+ Allowed: <u>{1}</u>\n- Prohibited: <u>{2}</u>\n\n[✅ Allow] allow specified sticker-packs <i>as exception</i>, when [☑️☐Off sticker]\n[🚫 Prohibit] prohibits the specified sticker-packs <i>as exception</i>, when [✅☑On sticker]",
    'es': "🦊 <b>Excepciones</b> para paquetes de pegatinas en el archivo <code>{0}</code>:\n\n+ Permitido: <u>{1}</u>\n- Prohibido: <u>{2}</u>\n\n[✅ Permitir] permitir paquetes de adhesivos especificados <i>como excepción</i>, cuando [☑️☐Desactivar adhesivo]\n[🚫 Prohibir] prohíbe los paquetes de adhesivos especificados <i>como excepción</i>, cuando [✅☑En la etiqueta]",
    'fr': "🦊 <b>Exceptions</b> pour les packs d'autocollants dans le fichier <code>{0}</code> :\n\n+ Autorisé : <u>{1}</u>\n- Interdit : <u>{2}</u>\n\n[✅ Autoriser] autoriser les packs d'autocollants spécifiés <i>à titre exceptionnel</i>, lorsque [☑️☐Autocollant désactivé]\n[🚫 Interdire] interdit les packs d'autocollants spécifiés <i>par exception</i>, lorsque [✅☑Sur l'autocollant]",
    'zh': "🦊 <code>{0}</code>-文件中貼紙包的<b>例外</b>：\n\n+ 允許：<u>{1}</u>\n- 禁止：<u>{2}</u>\n\n[✅ Allow] 允許指定的貼紙包<i>作為例外</i>，當 [☑️☐Off 貼紙]\n[🚫 Prohibit] 禁止指定的貼紙包 <i>例外</i>，當 [✅☑On 貼紙]",
    'ar': "🦊 <b> استثناءات </b> لحزم الملصقات في <code>{0}</code> -ملف: \n\n + المسموح به: <u>{1}</u> \n- محظور: <u>{2}</u> \n\n [✅ السماح] السماح بحزم الملصقات المحددة <i> كاستثناء </i> ، عندما يحظر [☑️☐ إيقاف الملصق] \n [🚫 منع] حزم الملصقات المحددة <i> كاستثناء </i> ، عند [✅☑ على الملصق]",
}
l_cstickerpack_1 = {
    'ru': "✅ Разрешить",
    'en': "✅ Allow",
    'es': "✅ Permitir",
    'fr': "✅ Autoriser",
    'zh': "✅ 允許",
    'ar': "✅ سماح",
}
l_cstickerpack_0 = {
    'ru': "🚫 Запретить",
    'en': "🚫 Prohibit",
    'es': "🚫 Prohibir",
    'fr': "🚫 Interdire",
    'zh': "🚫 禁止",
    'ar': "🚫 تحظر",
}
l_coperation_1 = {
    'ru': "✅ Добавить",
    'en': "✅ Add",
    'es': "✅ Añadir",
    'fr': "✅ Ajouter",
    'zh': "✅ 添加",
    'ar': "✅ أضف",
}
l_coperation_0 = {
    'ru': "🚫 Удалить",
    'en': "🚫 Remove",
    'es': "🚫 Eliminar",
    'fr': "🚫 Supprimer",
    'zh': "🚫 移除",
    'ar': "🚫 إزالة",
}
l_GROUPP_CSTICKER1_NUM1 = {
    'ru': "🦊 Текущее количество <b>разрешенных</b> стикерпаков в <code>{0}</code>-файле: <u>{1}</u>\n\n<b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> разрешенные стикерпаки",
    'en': "🦊 Current number of <b>allowed</b> sticker-packs in the <code>{0}</code>-file: <u>{0}</u>\n\nPush the ✅/🚫, to <b>Add/Remove</b> allowed sticker-packs",
    'es': "🦊 Número actual de paquetes de pegatinas <b>permitidos</b> en el archivo <code>{0}</code>: <u>{0}</u>\n\nPresione ✅/🚫, para <b>Añadir/eliminar</b> paquetes de pegatinas permitidos",
    'fr': "🦊 Nombre actuel de packs d'autocollants <b>autorisés</b> dans le fichier <code>{0}</code> : <u>{0}</u>\n\nAppuyez sur ✅/🚫 pour <b>Ajouter/Supprimer</b> les packs d'autocollants autorisés",
    'zh': "🦊 <code>{0}</code>-文件中<b>允許</b>貼紙包的當前數量：<u>{0}</u>\n\n將 ✅/🚫 推到 <b>添加/刪除</b>允許的貼紙包",
    'ar': "🦊 العدد الحالي لحزم الملصقات <b> المسموح بها </b> في <code>{0}</code> -ملف: <u>{0}</u> \n\n اضغط على ✅/🚫 ، من أجل <b> إضافة / إزالة </b> حزم الملصقات المسموح بها",
}
l_GROUPP_CSTICKER1_NUM0 = {
    'ru': "🦊 Текущее количество <b>разрешенных</b> стикерпаков: <u>{0}</u>\n\n<b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> разрешенные стикерпаки",
    'en': "🦊 Current number of <b>allowed</b> sticker-packs: <u>{0}</u>\n\nPush the ✅/🚫, to <b>Add/Remove</b> allowed sticker-packs",
    'es': "🦊 Número actual de paquetes de adhesivos <b>permitidos</b>: <u>{0}</u>\n\nPresione ✅/🚫 para <b>Agregar/Quitar</b> paquetes de adhesivos permitidos",
    'fr': "🦊 Nombre actuel de packs d'autocollants <b>autorisés</b> : <u>{0}</u>\n\nAppuyez sur ✅/🚫 pour <b>ajouter/supprimer</b> les packs d'autocollants autorisés",
    'zh': "🦊 當前<b>允許</b>個貼紙包的數量：<u>{0}</u>\n\n按下 ✅/🚫，以<b>添加/刪除</b>個允許的貼紙包",
    'ar': "🦊 العدد الحالي لحزم الملصقات <b> المسموح بها </b>: <u>{0}</u> \n\n اضغط على ✅/🚫 ، من أجل <b> إضافة / إزالة </b> حزم الملصقات المسموح بها",
}
l_GROUPP_CSTICKER0_NUM1 = {
    'ru': "🦊 Текущее количество <b>запрещенных</b> стикерпаков в <code>{0}</code>-файле: <u>{1}</u>\n\n<b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> запрещенные стикерпаки",
    'en': "🦊 Current number of <b>prohibited</b> sticker-packs in the <code>{0}</code>-file: <u>{0}</u>\n\nPush the ✅/🚫, to <b>Add/Remove</b> prohibited sticker-packs",
    'es': "🦊 Número actual de paquetes de adhesivos <b>prohibidos</b> en el archivo <code>{0}</code>: <u>{0}</u>\n\nPresione el ✅/🚫 para <b>Añadir/eliminar</b> paquetes de pegatinas prohibidos",
    'fr': "🦊 Nombre actuel de packs d'autocollants <b>interdits</b> dans le fichier <code>{0}</code> : <u>{0}</u>\n\nAppuyez sur ✅/🚫 pour <b>Ajouter/Supprimer</b> des packs d'autocollants interdits",
    'zh': "🦊 <code>{0}</code>-文件中<b>禁止</b>貼紙包的當前數量：<u>{0}</u>\n\n將 ✅/🚫 推到 <b>添加/刪除</b>禁止的貼紙包",
    'ar': "🦊 العدد الحالي لحزم الملصقات <b> المحظورة </b> في <code>{0}</code> -ملف: <u>{0}</u> \n\n اضغط على ✅/🚫 ، من أجل <b> إضافة / إزالة </b> حزم الملصقات المحظورة",
}
l_GROUPP_CSTICKER0_NUM0 = {
    'ru': "🦊 Текущее количество <b>запрещенных</b> стикерпаков: <u>{0}</u>\n\n<b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> запрещенные стикерпаки",
    'en': "🦊 Current number of <b>prohibited</b> sticker-packs: <u>{0}</u>\n\nPush the ✅/🚫, to <b>Add/Remove</b> prohibited sticker-packs",
    'es': "🦊 Número actual de paquetes de adhesivos <b>prohibidos</b>: <u>{0}</u>\n\nPresione ✅/🚫 para <b>Agregar/Quitar</b> paquetes de adhesivos prohibidos",
    'fr': "🦊 Nombre actuel de packs d'autocollants <b>interdits</b> : <u>{0}</u>\n\nAppuyez sur ✅/🚫 pour <b>Ajouter/Supprimer</b> des packs d'autocollants interdits",
    'zh': "🦊 當前<b>禁止</b>貼紙包的數量：<u>{0}</u>\n\n按下 ✅/🚫，<b>添加/刪除</b>禁止貼紙包",
    'ar': "🦊 العدد الحالي لحزم الملصقات <b> المحظورة </b>: <u>{0}</u> \n\n اضغط على ✅/🚫 ، من أجل <b> إضافة / إزالة </b> حزم الملصقات المحظورة",
}
l_cstickeroperation_add = {
    'ru': "\n\n👉🏼 Например, https://t.me/addstickers/HotCherry или <code>HotCherry</code>",
    'en': "\n\n👉🏼 For example, https://t.me/addstickers/HotCherry or <code>HotCherry</code>",
    'es': "\n\n👉🏼 Por ejemplo, https://t.me/addstickers/HotCherry o <code>HotCherry</code>",
    'fr': "\n\n👉🏼 Par exemple, https://t.me/addstickers/HotCherry ou <code>HotCherry</code>",
    'zh': "\n\n👉🏼 例如, https://t.me/addstickers/HotCherry 或者 <code>HotCherry</code>",
    'ar': "\n\n👉🏼 فمثلا, https://t.me/addstickers/HotCherry أو <code>HotCherry</code>",
}
l_cstickeroperation_isadd = {
    'ru': "✅ Пришли ссылку или имя <b>стикерпака</b>, чтобы <b>добавить</b> его в список разрешенных{0}",
    'en': "✅ Send link or <b>sticker-pack</b>-name to <b>add</b> it to allowed list{0}",
    'es': "✅ Enviar enlace o nombre de <b>paquete de pegatinas</b> para <b>añadir</b> a la lista de permitidos{0}",
    'fr': "✅ Envoyez le lien ou le nom du <b>pack d'autocollants</b> pour <b>l'ajouter</b> à la liste autorisée{0}",
    'zh': "✅ 發送鏈接或 <b>sticker-pack</b>-name 以將其<b>添加</b>到允許列表{0}",
    'ar': "✅ أرسل رابطًا أو اسم <b> حزمة الملصقات </b> <b> لإضافته </b> إلى القائمة المسموح بها {0}",
}
l_cstickeroperation_isnotadd = {
    'ru': "🚫 Пришли ссылку или имя <b>стикерпака</b>, чтобы <b>удалить</b> из списка разрешенных{0}",
    'en': "🚫 Send link or <b>sticker-pack</b>-name to <b>remove</b> it from allowed list{0}",
    'es': "🚫 Enviar enlace o nombre de <b>paquete de pegatinas</b> para <b>eliminarlo</b> de la lista permitida{0}",
    'fr': "🚫 Envoyez le lien ou le nom du <b>pack d'autocollants</b> pour le <b>supprimer</b> de la liste autorisée{0}",
    'zh': "🚫 發送鏈接或 <b>sticker-pack</b>-name 以將其從允許列表中<b>刪除</b>{0}",
    'ar': "🚫 أرسل رابطًا أو اسم <b> حزمة الملصقات </b> <b> لإزالته </b> من القائمة المسموح بها {0}",
}
l_cstickeroperation_isadd2 = {
    'ru': "✅ Пришли ссылку или имя <b>стикерпака</b>, чтобы <b>добавить</b> его в список запрещенных{0}",
    'en': "✅ Send link or <b>sticker-pack</b>-name to <b>add</b> it to prohibited list{0}",
    'es': "✅ Enviar enlace o nombre de <b>paquete de pegatinas</b> para <b>añadir</b> a la lista prohibida{0}",
    'fr': "✅ Envoyez le lien ou le nom du <b>pack d'autocollants</b> pour <b>l'ajouter</b> à la liste interdite{0}",
    'zh': "✅ 發送鏈接或 <b>sticker-pack</b>-name 以將其<b>添加</b>到禁止列表{0}",
    'ar': "✅ أرسل رابطًا أو اسم <b> حزمة الملصقات </b> <b> لإضافته </b> إلى القائمة المحظورة {0}",
}
l_cstickeroperation_isnotadd2 = {
    'ru': "🚫 Пришли ссылку или имя <b>стикерпака</b>,  чтобы <b>удалить</b> его из списка запрещенных{0}",
    'en': "🚫 Send link or <b>sticker-pack</b>-name to <b>remove</b> it from prohibited list{0}",
    'es': "🚫 Enviar enlace o nombre de <b>paquete de pegatinas</b> para <b>eliminarlo</b> de la lista prohibida{0}",
    'fr': "🚫 Envoyez le lien ou le nom du <b>pack d'autocollants</b> pour le <b>supprimer</b> de la liste interdite{0}",
    'zh': "🚫 發送鏈接或 <b>sticker-pack</b>-name 以將其從禁止列表中<b>刪除</b>{0}",
    'ar': "🚫 أرسل رابطًا أو اسم <b> حزمة الملصقات </b> <b> لإزالته </b> من القائمة المحظورة {0}",
}
l_fsm_sticker_add = {
    'ru': "🦊 <b>Готово!</b> <b>Исключения</b> для стикерпаков:\n\n+ Разрешенные: <u>{0}</u>\n- Запрещенные: <u>{1}</u>\n\n[✅ Разрешить] пропускает указанные стикерпаки <i>в качестве исключения</i>, когда выбрана опция [☑️☐Выкл sticker]\n[🚫 Запретить] запрещает указанные стикерпаки <i>в качестве исключения</i>, когда выбрана опция [✅☑Вкл sticker]",
    'en': "🦊 Ready! <b>Exceptions</b> for sticker-packs:\n\n+ Allowed: <u>{0}</u>\n- Prohibited: <u>{1}</u>\n\n[✅ Allow] allow specified sticker-packs <i>as exception</i>, when [☑️☐Off sticker]\n[🚫 Prohibit] prohibits the specified sticker-packs <i>as exception</i>, when [✅☑On sticker]",
    'es': "🦊 Listo! <b>Excepciones</b> para paquetes de pegatinas:\n\n+ Permitido: <u>{0}</u>\n- Prohibido: <u>{1}</u>\n\n[✅ Permitir] permitir paquetes de adhesivos especificados <i>como excepción</i>, cuando [☑️☐De sticker]\n[🚫 Prohibir] prohíbe los paquetes de adhesivos especificados <i>como excepción</i>, cuando [✅☑En sticker]",
    'fr': "🦊 Prêt ! <b>Exceptions</b> pour les packs d'autocollants :\n\n+ Autorisé : <u>{0}</u>\n- Interdit : <u>{1}</u>\n\n[✅ Autoriser] autoriser les packs d'autocollants spécifiés <i>à titre exceptionnel</i>, lorsque [☑️☐En sticker]\n[🚫 Interdire] interdit les packs d'autocollants spécifiés <i>à titre exceptionnel</i>, lorsque [✅☑En sticker]",
    'zh': "🦊 準備好了！ 貼紙包的<b>例外情況</b>：\n\n+ 允許：<u>{0}</u>\n- 禁止：<u>{1}</u>\n\n[✅ Allow] 允許指定的貼紙包<i>作為例外</i>，當 [☑️☐Off 貼紙]\n[🚫 Prohibit] 禁止指定的貼紙包<i>作為例外</i>，當 [✅☑ 貼上]",
    'ar': "🦊 جاهز! <b> استثناءات </b> لحزم الملصقات: \n\n + المسموح بها: <u>{0}</u>\n- محظور: <u>{1}</u>\n\n [✅ السماح] السماح بحزم الملصقات المحددة <i> كاستثناء </i> ، عندما [☑️☐ ملصق إيقاف]\n[🚫 منع] يحظر حزم الملصقات المحددة <i> كاستثناء </i> ، عندما [✅☑ على الملصق]",
}
# endregion


# region cstart_
l_cstart_text = {
    'ru': "🚀 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-ответ на триггер-сообщения, содержащие конкретные старт-слова\n\n👉🏼 <b>Текущее</b> количество старт-слов <u>{0}</u>",
    'en': "🚀 Push the ✅/☑️, to <b>On/Off</b> auto-answer on trigger-messages, containing specific start-words\n\n👉🏼 Current number of start-words <u>{0}</u>",
    'es': "🚀 Presiona ✅/☑️, para <b>Activar/Desactivar</b> la respuesta automática en mensajes desencadenantes, que contienen palabras de inicio específicas\n\n👉🏼 Número actual de palabras de inicio <u>{0}</u>",
    'fr': "🚀 Appuyez sur ✅/☑️, pour <b>Activer/Désactiver</b> la réponse automatique aux messages déclencheurs, contenant des mots de départ spécifiques\n\n👉🏼 Nombre actuel de mots de départ <u>{0}</u>",
    'zh': "🚀 將 ✅/☑️ 推到 <b>On/Off</b> 觸發消息上的自動應答，包含特定的起始詞\n\n👉🏼 當前起始詞的數量<u>{0}</u>",
    'ar': "🚀 اضغط على ✅ / ☑️ ، لإجراء تشغيل / إيقاف الرد التلقائي على الرسائل المشغلة ، التي تحتوي على كلمات بداية محددة \n\n👉🏼 العدد الحالي لكلمات البداية {0} / ش",
}
l_cstart_call = {
    'ru': "🔔 Нужно ⚙️Настроить хотя бы одно старт-слово",
    'en': "🔔 You have to ⚙️Configure at least one start-word",
    'es': "🔔 Tienes que ⚙️ Configurar al menos una palabra de inicio",
    'fr': "🔔 Vous devez ⚙️ Configurer au moins un mot de départ",
    'zh': "🔔 你必須 ⚙️ 配置至少一個起始詞",
    'ar': "🔔 يجب عليك ⚙️ تكوين كلمة بداية واحدة على الأقل",
}
l_cstartconfig_call = {
    'ru': "🚀 Нужно ⚙️Настроить хотя бы один пост через опцию 🔔Авто-постинг",
    'en': "🚀 You have to ⚙️Configure at least one post via 🔔Auto-posting",
    'es': "🚀 Tienes que ⚙️Configurar al menos una publicación a través de 🔔Publicación automática",
    'fr': "🚀 Vous devez ⚙️Configurer au moins une publication via 🔔Auto-publication",
    'zh': "🚀您必須通過🔔自動發布⚙️配置至少一篇帖子",
    'ar': "🚀 عليك تكوين منشور واحد على الأقل عبر النشر التلقائي",
}
l_cstartconfig_text = {
    'ru': "🚀 <b>Выбери пост</b>, который будет присылаться в ответ на <b>старт</b>-слова и жми [🚀 <b>Использовать</b>] под выбранным постом\n\n👉🏼 Общее количество старт-слов: <u>{0}</u>",
    'en': "🚀 At first, choose the auto-reply (from posts), which will be sent in response to the start-words",
    'es': "🚀 Al principio, elija la respuesta automática (de las publicaciones), que se enviará en respuesta a las palabras de inicio",
    'fr': "🚀 Dans un premier temps, choisissez la réponse automatique (à partir des messages), qui sera envoyée en réponse aux mots de départ",
    'zh': "🚀 首先，選擇自動回复（來自帖子），它將響應起始詞發送",
    'ar': "🚀 في البداية ، اختر الرد التلقائي (من المشاركات) ، والذي سيتم إرساله ردًا على كلمات البداية",
}
l_cstartconfig_use = {
    'ru': "🚀 Использовать",
    'en': "🚀 Use",
    'es': "🚀 Uso",
    'fr': "🚀 Utiliser",
    'zh': "🚀 使用",
    'ar': "🚀 استخدم",
}
l_cstartoperation_caption = {
    'ru': "🚀 <b>Текущее</b> количество <i>старт-слов</i> для поста #{0} в <code>{1}</code>-файле: <u>{2}</u>\n\n<b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> старт-слова",
    'en': "🚀 Current number of start-words for post #{0} in <code>{1}</code>-file: <u>{2}</u>\n\nPuch the ✅/🚫, to <b>Add/Remove</b> start-words",
    'es': "🚀 Número actual de palabras iniciales para la publicación #{0} en el archivo <code>{1}</code>: <u>{2}</u>\n\nPulse el ✅/🚫, para <b> Agregar o quitar</b> palabras de inicio",
    'fr': "🚀  Nombre actuel de mots de départ pour le message #{0} dans le fichier <code>{1}</code> : <u>{2}</u>\n\nAppuyez sur le ✅/🚫 pour <b> Ajouter/supprimer</b> des mots de départ",
    'zh': "🚀 當前的起始詞數 在 <code>{1}</code>-文件中發布 #{0}：<u>{2}</u>\n\n點擊 ✅/🚫，開始<b>添加/刪除</b> -字",
    'ar': "🚀 العدد الحالي لكلمات البداية للنشر # {0} في <code>{1}</code> -الملف:{2} \n\n قم بإرسال ✅/🚫 إلى إضافة / إزالة كلمات البداية",
}
l_cstartoperation_text = {
    'ru': "🚀 <b>Текущее</b> количество <i>старт-слов</i> для поста #{0}: <u>{1}</u>\n\n<b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> старт-слова",
    'en': "🚀 Current number of start-words for post #{0}: <u>{2}</u>\n\nPuch the ✅/🚫, to <b>Add/Remove</b> start-words",
    'es': "🚀 Número actual de palabras de inicio para la publicación #{0}: <u>{2}</u>\n\nPresione ✅/🚫 para <b>Agregar/Quitar</b> palabras de inicio",
    'fr': "🚀  Nombre actuel de mots de départ pour le message #{0} : <u>{2}</u>\n\nAppuyez sur le ✅/🚫 pour <b>ajouter/supprimer</b> des mots de départ",
    'zh': "🚀 帖子 #{0} 的當前起始詞數：<u>{2}</u>\n\n點擊 ✅/🚫，以<b>添加/刪除</b>個起始詞",
    'ar': "🚀 العدد الحالي لكلمات البداية للنشر # {0}:{2}\n\n استخدم ✅/🚫 ، من أجل <b> إضافة / إزالة </b> كلمات البداية",
}
l_cstartoperation_handler = {
    'ru': "\n\n▪️регистр не важен\n▪️поставь звездочку после слова, чтобы учитывать вхождение\n▪️например, если ввести <b>психо*</b>, то авто-постинг сработает на <u>все</u> сообщения, которые <b>содержат</b> данное сочетание: <i>анти<u>психо</u>лог, <u>Психо</u>терапевт..</i>",
    'en': "\n\n▪️word case is not important\n▪️set * after word to account for occurrence\n▪️for example, if write <b>psy*</b>, then <u>all</u> messages, which are <b>contained</b> this combination of letters will be removed: <i>anti-<u>psy</u>chologist, <u>Psy</u>chotherapist..</i>",
    'es': "\n\n▪️las mayúsculas y minúsculas no son importantes\n▪️establezca * después de la palabra para tener en cuenta la ocurrencia\n▪️por ejemplo, si escribe <b>psi*</b>, entonces <u>todos</u> los mensajes, que están <b>contenidos</b> se eliminará esta combinación de letras: <i>anti-<u>psicólogo</u>, <u>Psi</u>coterapeuta..</i>",
    'fr': "\n\n▪️la casse des mots n'est pas importante\n▪️définissez * après le mot pour tenir compte de l'occurrence\n▪️par exemple, si écrivez <b>psy*</b>, alors <u>tous</u> les messages, qui sont <b>contenues</b> cette combinaison de lettres sera supprimée : <i>anti-<u>psychologue</u>, <u>Psy</u>chothérapeute..</i>",
    'zh': "\n\n▪️單詞大小寫不重要\n▪️在單詞之後設置*以說明出現\n▪️例如，如果寫<b>psy*</b>，則<u>所有</u>消息， <b>包含</b>這些字母組合將被刪除：<i>anti-<u>psy</u>chologist, <u>Psy</u>chotherapy..</i>",
    'ar': "\n\n▪️ حالة الكلمة ليست مهمة \n▪️ اضبط * بعد كلمة لحساب الحدوث \n▪️ على سبيل المثال ، إذا كتبت <b>psy*</b> ، ثم <u> كل </u> الرسائل ، التي <b> احتوت </b> ستتم إزالة هذه المجموعة من الأحرف:",
}
l_cstartoperation_answer = {
    'ru': "🚀 <b>Введи</b> <u>старт-слова</u> <b>через</b> пробелы или разделители, чтобы <i>добавить</i> их в базу{0}",
    'en': "🚀 Enter <u>start-words</u> <b>via</b> spaces or separators to <i>add</i> them to Base{0}",
    'es': "🚀 Ingrese <u>palabras de inicio</u> <b>mediante</b> espacios o separadores para <i>agregarlos</i> a la Base{0}",
    'fr': "🚀 Saisissez des <u>start-words</u> <b>via</b> des espaces ou des séparateurs pour les <i>ajouter</i> à Base{0}",
    'zh': "🚀 輸入 <u>start-words</u> <b>via</b> 空格或分隔符以將它們<i>添加</i>到 Base{0}",
    'ar': "✅ أدخل كلمات البداية عبر مسافات أو فواصل من أجل <i> إضافتها </i> إلى القاعدة {0}",
}
l_cstartoperation_noanswer = {
    'ru': "🚫 <b>Введи</b> <u>старт-слова</u> <b>через</b> пробелы или разделители, чтобы их <i>удалить</i> из базы{0}",
    'en': "🚫 Enter <u>start-words</u> <b>via</b> spaces or separators to <i>remove</i> them from Base{0}",
    'es': "🚫 Ingrese <u>palabras de inicio</u> <b>mediante</b> espacios o separadores para <i>eliminarlos</i> de la Base{0}",
    'fr': "🚫 輸入 <u>start-words</u> <b>via</b> 空格或分隔符以將它們從 Base 中<i>刪除</i>{0}",
    'zh': "🚫 輸入 <u>start-words</u> <b>via</b> 空格或分隔符以將它們從 Base 中<i>刪除</i>{0}",
    'ar': "🚫 أدخل كلمات البداية عبر مسافات أو فواصل <i> لإزالتها </i> من Base {0}",
}
l_fsm_start_add_caption = {
    'ru': "🚀 <b>Готово!</b> <b>Текущее</b> количество старт-слов для поста #{0} в <code>{1}</code>-файле: <u>{2}</u>",
    'en': "🚀 Ready! <b>Current</b> number of start-words for post #{0} in <code>{1}</code>-file: <u>{2}</u>",
    'es': "🚀 Listo! Número <b>actual</b> de palabras de inicio para la publicación #{0} en el archivo <code>{1}</code>: <u>{2}</u>",
    'fr': "🚀 Prêt ! <b>Nombre actuel</b> de mots de départ pour le message  #{0} dans le fichier <code>{1}</code> : <u>{2}</u>",
    'zh': "🚀 準備好了！ <code>{1}</code>-文件中帖子 #{0} 的<b>當前</b> 起始字數：<u>{2}</u>",
    'ar': "🚀 جاهز! <b> العدد </b> الحالي لكلمات البداية للمشاركة # {0} في <code>{1}</code> -ملف:<u>{2}</u>",
}
l_fsm_start_add_text = {
    'ru': "🚀 <b>Готово!</b> <b>Текущее</b> количество старт-слов для поста #{0}: <u>{1}</u>",
    'en': "🚀 Ready! <b>Current</b> number of start-words for post #{0} <u>{1}</u>",
    'es': "🚀 Listo! <b>Número actual</b> de palabras de inicio para la publicación #{0} <u>{1}</u>",
    'fr': "🚀 Prêt ! <b>Nombre actuel</b> de mots de départ pour le message  #{0} <u>{1}</u>",
    'zh': "🚀 準備好了！ <b>當前</b>帖子#{0}的起始詞數 <u>{1}</u>",
    'ar': "🚀 جاهز! <b> العدد </b> الحالي لكلمات البداية للمشاركة # {0} <u> {1} </u>",
}
l_need_start_word = {
    'ru': f"🚀 Сначала добавь хотя бы одно старт-слово",
    'en': "🚀 Ready! <b>Current</b> number of start-words for post #{0} <u>{1}</u>",
    'es': "🚀 Listo! <b>Número actual</b> de palabras de inicio para la publicación #{0} <u>{1}</u>",
    'fr': "🚀 Prêt ! <b>Nombre actuel</b> de mots de départ pour le message  #{0} <u>{1}</u>",
    'zh': "🚀 準備好了！ <b>當前</b>帖子#{0}的起始詞數 <u>{1}</u>",
    'ar': "🚀 جاهز! <b> العدد </b> الحالي لكلمات البداية للمشاركة # {0} <u> {1} </u>",
}

# endregion


# region cstop_
l_cstop_text = {
    'ru': "🧾 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-удаление сообщений, содержащие запрещенные стоп-слова\n\n👉🏼 <b>Текущее</b> количество стоп-слов <u>{0}</u>",
    'en': "🧾 Push the ✅/☑️, to <b>On/Off</b> auto-delete of messages, containing prohibited stop-words\n\n👉🏼 Current number of stop-words <u>{0}</u>",
    'es': "🧾 Pulsa ✅/☑️ para <b>activar/desactivar</b> la eliminación automática de mensajes que contengan palabras vacías prohibidas\n\n👉🏼 Número actual de palabras vacías <u>{0}</u>",
    'fr': "🧾 Appuyez sur ✅/☑️, pour <b>Activer/Désactiver</b> la suppression automatique des messages contenant des mots vides interdits\n\n👉🏼 Nombre actuel de mots vides <u>{0}</u>",
    'zh': "🧾 按下 ✅/☑️, 以<b>開/關</b>自動刪除包含禁止停用詞的消息\n\n👉🏼 當前停用詞數量<u>{0}</u>",
    'ar': "🧾 اضغط على ✅ / ☑️ ، من أجل <b> تشغيل / إيقاف </b> للحذف التلقائي للرسائل ، التي تحتوي على كلمات إيقاف محظورة \n\n👉🏼 العدد الحالي لكلمات التوقف <u>{0}</u>",
}
l_cstop_call = {
    'ru': "🔔 Нужно ⚙️Настроить хотя бы одно стоп-слово",
    'en': "🔔 You have to  ⚙️Configure at least one stop-word",
    'es': "🔔 Tienes que ⚙️Configurar al menos una palabra vacía",
    'fr': "🔔 Vous devez ⚙️Configurer au moins un mot vide",
    'zh': "🔔 你必須⚙️至少配置一個停用詞",
    'ar': "🔔 يجب عليك ⚙️ تكوين كلمة توقف واحدة على الأقل",
}
l_cstopchange_caption = {
    'ru': "🧾 Текущее количество стоп-слов в <code>{0}</code>-файле: <u>{1}</u>\n\n<b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> стоп-слова",
    'en': "🧾 Current number of stop-words in <code>{0}</code>-file: <u>{1}</u>\n\nPush the ✅/🚫, to <b>Add/Remove</b> stop-words",
    'es': "🧾 Número actual de palabras vacías en el archivo <code>{0}</code>: <u>{1}</u>\n\nPresione ✅/🚫 para <b>Agregar/Quitar</b> palabras vacías",
    'fr': "🧾 Nombre actuel de mots vides dans le fichier <code>{0}</code> : <u>{1}</u>\n\nAppuyez sur ✅/🚫 pour <b>Ajouter/Supprimer</b> mots vides",
    'zh': "🧾 <code>{0}</code>-文件中當前停用詞的數量：<u>{1}</u>\n\n將 ✅/🚫 推到 <b>添加/刪除</b> 停用詞",
    'ar': "🧾 العدد الحالي لكلمات الإيقاف في <code>{0}</code> -الملف:{1}\n\n اضغط على ✅/🚫 ، من أجل إضافة / إزالة توقف الكلمات",
}
l_cstopchange_text = {
    'ru': "🧾 Текущее количество стоп-слов <u>{0}</u>\n\n<b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> стоп-слова",
    'en': "🧾 Current number of stop-words: <u>{1}</u>\n\nPush the ✅/🚫, to <b>Add/Remove</b> stop-words",
    'es': "🧾 Número actual de palabras vacías: <u>{1}</u>\n\nPresione ✅/🚫 para <b>Agregar/Quitar</b> palabras vacías",
    'fr': "🧾 Nombre actuel de mots vides : <u>{1}</u>\n\nAppuyez sur ✅/🚫 pour <b>ajouter/supprimer</b> des mots vides",
    'zh': "🧾 當前停用詞數量：<u>{1}</u>\n\n按下 ✅/🚫, 以<b>添加/刪除</b>停用詞",
    'ar': "🧾 العدد الحالي لكلمات التوقف: <u>{1}</u>\n\n اضغط على ✅/🚫 ، من أجل <b> إضافة / إزالة <b/> كلمات الإيقاف",
}
l_cstopchange_add = {
    'ru': "\n\n▪️регистр не важен\n▪️поставь звездочку после слова, чтобы учитывать вхождение\n▪️например, если ввести <b>психо*</b>, то будут удаляться <u>все</u> сообщения, которые <b>содержат</b> данное сочетание: <i>анти<u>психо</u>лог, <u>Психо</u>терапевт..</i>",
    'en': "\n\n▪️word case is not important\n▪️set * after word to account for occurrence\n▪️for example, if write <b>psy*</b>, then <u>all</u> messages, which are <b>contained</b> this combination of letters will be removed: <i>anti-<u>psy</u>chologist, <u>Psy</u>chotherapist..</i>",
    'es': "\n\n▪️las mayúsculas y minúsculas no son importantes\n▪️establezca * después de la palabra para tener en cuenta la ocurrencia\n▪️por ejemplo, si escribe <b>psi*</b>, entonces <u>todos</u> los mensajes, que están <b>contenidos</b> se eliminará esta combinación de letras: <i>anti-<u>psicólogo</u>, <u>Psi</u>coterapeuta..</i>",
    'fr': "\n\n▪️la casse des mots n'est pas importante\n▪️définissez * après le mot pour tenir compte de l'occurrence\n▪️par exemple, si écrivez <b>psy*</b>, alors <u>tous</u> les messages, qui sont <b>contenues</b> cette combinaison de lettres sera supprimée : <i>anti-<u>psychologue</u>, <u>Psy</u>chothérapeute..</i>",
    'zh': "\n\n▪️單詞大小寫不重要\n▪️在單詞之後設置*以說明出現\n▪️例如，如果寫<b>psy*</b>，則<u>所有</u>消息， <b>包含</b>這些字母組合將被刪除：<i>anti-<u>psy</u>chologist, <u>Psy</u>chotherapy..</i>",
    'ar': "\n\n▪️ حالة الكلمة ليست مهمة \n▪️ اضبط * بعد كلمة لحساب الحدوث \n▪️ على سبيل المثال ، إذا كتبت <b>psy*</b> ، ثم <u> كل </u> الرسائل ، التي <b> احتوت </b> ستتم إزالة هذه المجموعة من الأحرف:",
}
l_cstopchange_answer = {
    'ru': "✅ <b>Введи</b> <u>стоп-слова</u> <b>через</b> пробелы или разделители, чтобы <i>добавить</i> их в базу{0}",
    'en': "✅ Enter <u>stop-words</u> <b>via</b> spaces or separators to <i>add</i> them to Base{0}",
    'es': "✅ Ingrese <u>palabras vacías</u> <b>a través de</b> espacios o separadores para <i>agregarlos</i> a la Base{0}",
    'fr': "✅ Saisissez des <u>mots vides</u> <b>via</b> des espaces ou des séparateurs pour les <i>ajouter</i> à Base{0}",
    'zh': "✅ 輸入 <u>停用詞</u> <b>通過</b> 空格或分隔符將它們<i>添加</i>到 Base{0}",
    'ar': "✅ أدخل <u> كلمات الإيقاف </u> <b> عبر </b> مسافات أو فواصل من أجل <i> إضافتها </i> إلى القاعدة {0}",
}
l_cstopchange_noanswer = {
    'ru': "🚫 <b>Введи</b> <u>стоп-слова</u> <b>через</b> пробелы или разделители, чтобы их <i>удалить</i> из базы{0}",
    'en': "🚫 Enter <u>stop-words</u> <b>via</b> spaces or separators to <i>removed </i> them from Base{0}",
    'es': "🚫 Ingrese <u>palabras vacías</u> <b>a través de</b> espacios o separadores para <i>eliminarlos </i> de la base {0}",
    'fr': "🚫 Saisissez des <u>mots vides</u> <b>via</b> des espaces ou des séparateurs pour les <i>supprimer </i> de Base {0}",
    'zh': "🚫 輸入 <u>stop-words</u> <b>via</b> 空格或分隔符以將它們從 Base 中<i>刪除 </i>{0}",
    'ar': "🚫 أدخل <u> كلمات الإيقاف </u> <b> عبر </b> مسافات أو فواصل لـ <i> إزالتها </i> من Base {0}",
}
l_fsm_stop_add_caption = {
    'ru': "🧾 <b>Готово!</b> <b>Текущее</b> количество стоп-слов в <code>{0}</code>-файле: <u>{1}</u>",
    'en': "🧾 Ready! <b>Current</b> number of stop-words in <code>{0}</code>-file: <u>{1}</u>",
    'es': "🧾 Listo! Número <b>actual</b> de palabras vacías en el archivo <code>{0}</code>: <u>{1}</u>",
    'fr': "🧾 Prêt ! <b>Nombre actuel</b> de mots vides dans le fichier <code>{0}</code> : <u>{1}</u>",
    'zh': "🧾 準備好了！ <b>當前</b> <code>{0}</code>-文件中的停用詞數：<u>{1}</u>",
    'ar': "🧾 جاهز! <b> العدد </b> الحالي لكلمات التوقف في <code>{0}</code> -الملف: <u>{1}</u>",
}
l_fsm_stop_add_text = {
    'ru': "🧾 <b>Готово!</b> <b>Текущее</b> количество стоп-слов <u>{0}</u>",
    'en': "🧾 Ready! <b>Current</b> number of stop-words <u>{0}</u>",
    'es': "🧾 Listo! <b>Número actual</b> de palabras vacías <u>{0}</u>",
    'fr': "🧾 Prêt ! <b>Nombre actuel</b> de mots vides <u>{0}</u>",
    'zh': "🧾準備好了！ <b>當前</b>停用詞數<u>{0}</u>",
    'ar': "🧾 جاهز! <b> العدد </b> الحالي لكلمات التوقف <u>{0}</u>",
}
# endregion


# region cflood_
l_cflood_text = {
    'ru': "💬 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>проверку</i> на частоту подряд написанных сообщ за один промежуток времени\n\n👉🏼 Например, задай количество сообщ подряд, которое будет считаться флудом командой: <code>/flood 5</code>\n\n👉🏼 Или используй <b>медленный режим</b> в настройках группы для <u>1</u> сообщения",
    'en': "💬 Push the ✅/☑️, to <b>On/Off</b> messages frequency-<i>checking</i> in one period of time\n\n👉🏼 For example, specify the number of consecutive messages that will be considered as flood by the command: <code>/flood 5</code>\n\n👉🏼 Or use <b>Slow Mode</b> in the Settings of group for <u>1</u> message",
    'es': "💬 Presiona ✅/☑️, para <b>Activar/Desactivar</b> la frecuencia de mensajes-<i>comprobar</i> en un período de tiempo\n\n👉🏼 Por ejemplo, especifica la cantidad de mensajes consecutivos que será considerado como inundación por el comando: <code>/flood 5</code>\n\n👉🏼 O use <b>Modo lento</b> en la Configuración del grupo para <u>1</u> mensaje",
    'fr': "💬 Appuyez sur ✅/☑️, pour <b>Activer/Désactiver</b> la fréquence des messages-<i>vérification</i> dans une période de temps\n\n👉🏼 Par exemple, spécifiez le nombre de messages consécutifs qui sera considéré comme une inondation par la commande : <code>/flood 5</code>\n\n👉🏼 Ou utilisez le <b>mode lent</b> dans les paramètres du groupe pour <u>1</u> message",
    'zh': "💬 推 ✅/☑️, 到 <b>On/Off</b> 消息頻率-<i>檢查</i> 在一個時間段內\n\n👉🏼 例如，指定連續消息的數量 將被命令視為洪水： <code>/flood 5</code>\n\n👉🏼 或者在 <u>1</u> 的組的設置中使用 <b>Slow Mode</b> 信息",
    'ar': "💬 ادفع ✅ / ☑️ إلى تردد رسائل <b> تشغيل / إيقاف </b> - <i> التحقق </i> في فترة زمنية واحدة \n\n👉🏼 على سبيل المثال ، حدد عدد الرسائل المتتالية التي سيتم اعتباره فيضانًا بواسطة الأمر: <code> / Flood 5 </code> \n\n👉🏼 أو استخدم <b> الوضع البطيء </b> في إعدادات المجموعة لـ <u> 1 </u> رسالة",
}
l_cflood_count_on = {
    'ru': "✅☑Вкл {0} сообщ",
    'en': "✅☑On {0} msgs",
    'es': "✅☑En {0} mensajes",
    'fr': "✅☑En {0} messages",
    'zh': "✅☑使能夠 {0} 消息",
    'ar': "✅☑يُمكَِن {0} رسائل",
}
l_cflood_count_off = {
    'ru': "☑️☐Выкл {0} сообщ",
    'en': "☑️☐Off {0} msgs",
    'es': "☑️☐De {0} mensajes",
    'fr': "☑️☐De {0} messages",
    'zh': "☑️☐禁用 {0} 消息",
    'ar': "☑️☐ تعطيل {0} رسائل",
}
# endregion


# region cuser_
l_cuser_text = {
    'ru': "👥 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> первичную <i>задержку/свободный вход без входного контроля для premium-аккаунтов/разрешение на инвайт</i> пользователей/ботов в группу или разрешение на <i>редактирование</i> сообщений\n\n👉🏼 Например, <b>задержка</b> (<i>в мин</i>) для <u>новых</u> пользователей (перед написанием их <u>1</u>го сообщ) осуществляется командой: <code>/delay  {0}</code>",
    'en': "👥 Push the ✅/☑️, to <b>On/Off</b> primary <i>delay/free entrance without Enter Control for premium-accounts/permission for inviting</i> users/bots in group or permission to <i>edit</i> messages\n\n👉🏼 For example, <b>delay</b> (<i>in minutes</i>) for <u>new</u> users (before writing their <u>1</u>st message) executed by: <code>/delay  {0}</code>",
    'es': "👥 Presione ✅/☑️, para <b>Encender/Apagar</b> <i>retraso/entrada gratuita principal sin control de entrada para cuentas premium/permiso para invitar</i> usuarios/bots en grupo o permiso para <i>editar</i> mensajes\n\n👉🏼 Por ejemplo, <b>retraso</b> (<i>en minutos</i>) para <u>nuevos</u> usuarios (antes de escribir su <u>1</u>st mensaje) ejecutado por: <code>/delay {0}</code>",
    'fr': "👥 Appuyez sur ✅/☑️, pour <b>On/Off</b> le <i>retard principal/l'entrée gratuite sans Enter Control pour les comptes premium/l'autorisation d'inviter</i> les utilisateurs/bots en groupe ou l'autorisation de <i>modifier</i> les messages\n\n👉🏼 Par exemple, <b>délai</b> (<i>en minutes</i>) pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1</u>er message) exécuté par : <code>/delay {0}</code>",
    'zh': "👥 按下 ✅/☑️，以 <b>開/關</b> 主要 <i>延遲/免費進入，無需進入高級帳戶控制/邀請</i>組中的用戶/機器人或權限<i>編輯</i>消息\n\n👉🏼例如，<u>新</u>用戶的<b>延遲</b>（<i>分鐘</i>）（在編寫他們的 <u>1</u>st message) 執行者：<code>/delay {0}</code>",
    'ar': "👥 اضغط على ✅ / ☑️ ، لـ <b> تشغيل / إيقاف </b> <i> تأخير / دخول مجاني بدون Enter Control للحسابات المميزة / إذن لدعوة </i> المستخدمين / الروبوتات في مجموعة أو إذن لـ <i> تحرير الرسائل </i> \n\n👉🏼 على سبيل المثال ، <b> تأخير </b> (<i> بالدقائق </i>) للمستخدمين <u> الجدد </u> (قبل كتابة <u> 1 </u> st) بواسطة: <code> / delay {0}</code>",
}
l_cuser_call = {
    'ru': "👮🏽 В настройках [Разрешения] включи опцию:\n\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the Settings [Permissions] enable:\n\n[✅ Add members]\n🕚Wait for 1min",
    'es': "👮🏽 En la Configuración [Permisos] habilite:\n\n[✅ Agregar miembros]\n🕚Espere 1 minuto",
    'fr': "👮🏽 Dans les paramètres [Autorisations], activez :\n\n[✅ Ajouter des membres]\n🕚Attendez 1 min",
    'zh': "👮🏽在設置[權限]中啟用：\n\n[✅添加成員]\n🕚等待1分鐘",
    'ar': "👮🏽 في الإعدادات [الأذونات] ، قم بتمكين: \n\n [✅ إضافة أعضاء] \n🕚 انتظر لمدة دقيقة واحدة",
}
l_cuser_delay_on = {
    'ru': "✅☑Вкл задержку {0}min",
    'en': "✅☑On delay {0}min",
    'es': "✅☑En demora {0}min",
    'fr': "✅☑En retard {0}min",
    'zh': "✅☑使能夠 延遲 {0}min",
    'ar': "✅☑يُمكَِن تأخير {0}min",
}
l_cuser_delay_off = {
    'ru': "☑️☐Выкл задержку {0}min",
    'en': "☑️☐Off delay {0}min",
    'es': "☑️☐De demora {0}min",
    'fr': "☑️☐De retard {0}min",
    'zh': "☑️☐禁用 延遲 {0}min",
    'ar': "☑️☐ تعطيل تأخير {0}min",
}
l_cuser_invite_user_on = {
    'ru': "✅☑Вкл инвайт польз.",
    'en': "✅☑On invite users",
    'es': "✅☑En invitar a los usuarios",
    'fr': "✅☑En inviter des utilisateurs",
    'zh': "✅☑使能夠 邀請用戶",
    'ar': "✅☑يُمكَِندعوة المستخدمين",
}
l_cuser_invite_user_off = {
    'ru': "☑️☐Выкл инвайт польз.",
    'en': "☑️☐Off invite users",
    'es': "☑️☐De invitar a los usuarios",
    'fr': "☑️☐De inviter des utilisateurs",
    'zh': "☑️☐禁用 邀請用戶",
    'ar': "☑️☐ تعطيل دعوة المستخدمين",
}

l_cuser_invite_bot_on = {
    'ru': "✅☑Вкл инвайт ботов",
    'en': "✅☑On invite bots",
    'es': "✅☑En invitar robots",
    'fr': "✅☑En inviter des robots",
    'zh': "✅☑使能夠 邀請機器人",
    'ar': "✅☑يُمكَِندعوة دعوة الروبوتات",
}
l_cuser_invite_bot_off = {
    'ru': "☑️☐Выкл инвайт ботов",
    'en': "☑️☐Off invite bots",
    'es': "☑️☐De invitar robots",
    'fr': "☑️☐De inviter des robots",
    'zh': "☑️☐禁用 邀請機器人",
    'ar': "☑️☐ تعطيل دعوة الروبوتات",
}
l_cuser_premium_on = {
    'ru': "✅☑Вкл premium-вход",
    'en': "✅☑On premium-entrance",
    'es': "✅☑En entrada premium",
    'fr': "✅☑En entrée premium",
    'zh': "✅☑使能夠 高級入口",
    'ar': "✅☑ يُمكَِندعوة دخول ممتاز",
}
l_cuser_premium_off = {
    'ru': "☑️☐Выкл premium-вход",
    'en': "☑️☐Off premium-entrance",
    'es': "☑️☐De entrada premium",
    'fr': "☑️☐De entrée premium",
    'zh': "☑️☐禁用 高級入口",
    'ar': "☑️☐ تعطيل دخول ممتاز",
}
l_cuser_edit_on = {
    'ru': "✅☑Вкл редактирование сообщ",
    'en': "✅☑On edit msg",
    'es': "✅☑En editar mensaje",
    'fr': "✅☑En editar mensaje",
    'zh': "✅☑使能夠 編輯消息",
    'ar': "✅☑ يُمكَِندعوة تحرير الرسالة",
}
l_cuser_edit_off = {
    'ru': "☑️☐Выкл редактирование сообщ",
    'en': "☑️☐Off edit msg",
    'es': "☑️☐De editar mensaje",
    'fr': "☑️☐De entrée premium",
    'zh': "☑️☐禁用 編輯消息",
    'ar': "☑️☐ تعطيل تحرير الرسالة",
}
# endregion


# region cadmin_
l_cadmin_text = {
    'ru': "👩🏽‍💻 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <u>admin-доступ</u> (только к /cmd-командам для <i>других</i> администраторов) и <u>god-режим</u> (без ограничений для администраторов)\n\n👉🏼 <b>Текущие администраторы</b>:\n{0}",
    'en': "👩🏽‍💻 Push the ✅/☑️, to <b>On/Off</b> <u>admin-access</u> (to /cmd-commands for <i>other</i> admins) and <u>god-mode</u> (without limits for you and group-creator)\n\n👉🏼 <b>Current administrators</b>:\n{0}",
    'es': "👩🏽‍💻 Presiona ✅/☑️, para <b>Activar/Desactivar</b> <u>acceso de administrador</u> (para /cmd-comandos para <i>otros</i> administradores) y <u>modo dios</u> (sin límites para ti y el creador del grupo)\n\n👉🏼 <b>Administradores actuales</b>:\n{0}",
    'fr': "👩🏽‍💻 Appuyez sur ✅/☑️, pour <b>On/Off</b> <u>admin-access</u> (vers /cmd-commands pour les <i>autres</i> admins) et <u>god-mode</u> (sans limites pour vous et le créateur de groupe)\n\n👉🏼 <b>Administrateurs actuels</b> :\n{0}",
    'zh': "👩🏽‍💻 按下 ✅/☑️，到 <b>On/Off</b> <u>admin-access</u>（到 <i>other</i> 管理員的 /cmd-commands）和 <u>上帝模式</u>（對您和群組創建者沒有限制）\n\n👉🏼 <b>當前管理員</b>：\n{0}",
    'ar': "👩🏽‍💻 اضغط على ✅ / ☑️ ، من أجل <b> تشغيل / إيقاف </b> <u> وصول المشرف </u> (أوامر /cmd لـ <i> مشرفين آخرين </i>) و <u> god-mode </u> (بلا حدود لك ولمنشئ المجموعة) \n \n👉🏼 <b> المسؤولون الحاليون </b>: \n {0}",
}
l_cadmin_admin_on = {
    'ru': "✅☑Вкл admin-доступ",
    'en': "✅☑On admin-access",
    'es': "✅☑En acceso de administrador",
    'fr': "✅☑En accès administrateur",
    'zh': "✅☑啟用管理員訪問",
    'ar': "✅☑ تمكين وصول المسؤول",
}
l_cadmin_admin_off = {
    'ru': "☑️☐Выкл admin-доступ",
    'en': "☑️☐Off admin-access",
    'es': "☑️☐De acceso de administrador",
    'fr': "☑️☐De accès administrateur",
    'zh': "☑️☐禁用管理員訪問",
    'ar': "☑️☐ تعطيل وصول المسؤول",
}
l_cadmin_god_on = {
    'ru': "✅☑Вкл god-режим",
    'en': "✅☑On god-mode",
    'es': "✅☑En modo de Dios",
    'fr': "✅☑En mode divin",
    'zh': "✅☑開啟上帝模式",
    'ar': "✅☑ تمكين وضع الله",
}
l_cadmin_god_off = {
    'ru': "☑️☐Выкл god-режим",
    'en': "☑️☐Off god-mode",
    'es': "☑️☐De modo de Dios",
    'fr': "☑️☐De mode divin",
    'zh': "☑️☐禁用上帝模式",
    'ar': "☑️☐ تعطيل وضع الله",
}
# endregion


# region handlers
l_content_types_invite_user_bot = {
    'ru': "🚶🏽 Инвайт @username/@name_bot не разрешены",
    'en': "🚶🏽 Inviting of @username/@name_bot is not allowed",
    'es': "🚶🏽 No se permite invitar a @username/@name_bot",
    'fr': "🚶🏽 L'invitation de @username/@name_bot n'est pas autorisée",
    'zh': "🚶🏽 不允許邀請 @username/@name_bot",
    'ar': "🚶🏽 دعوة @ username / @ name_bot غير مسموح بها",
}
l_content_types_invite_user = {
    'ru': "🚶🏽 Инвайт @username не разрешен",
    'en': "🚶🏽 Inviting of @username is not allowed",
    'es': "🚶🏽 No se permite invitar a @username",
    'fr': "🚶🏽 L'invitation de @username n'est pas autorisée",
    'zh': "🚶🏽 不允許邀請 @username",
    'ar': "🚶🏽 دعوة @username غير مسموح بها",
}
l_content_types_invite_bot = {
    'ru': "🚶🏽 Инвайт @name_bot не разрешен",
    'en': "🚶🏽 Inviting of @name_bot is not allowed",
    'es': "🚶🏽 No se permite invitar a @name_bot",
    'fr': "🚶🏽 L'invitation de @name_bot n'est pas autorisée",
    'zh': "🚶🏽 不允許邀請 @name_bot",
    'ar': "🚶🏽 دعوة @name_bot غير مسموح بها",
}
l_content_types_button = {
    'ru': "👮🏽 {0}, на<b>Жми</b> на кнопку, чтобы вс︎тупить в группу",
    'en': "👮🏽 {0}, push the button to join the group",
    'es': "👮🏽 {0}, presiona el botón para unirte al grupo",
    'fr': "👮🏽 {0}, appuyez sur le bouton pour rejoindre le groupe",
    'zh': "👮🏽 {0}，按按鈕加入群組",
    'ar': "👮🏽 {0} ، اضغط على الزر للانضمام إلى المجموعة",
}
l_content_types_captcha = {
    'ru': "👮🏽 {0}, выбери <i>правильный вариант</i> ответа, чтобы вс︎тупить в группу:\n\n<code>{1}</code>",
    'en': "👮🏽 {0}, choose <i>correct option</i> to join the group:\n\n<code>{1}</code>",
    'es': "👮🏽 {0}, elige la <i>opción correcta</i> para unirte al grupo:\n\n<code>{1}</code>",
    'fr': "👮🏽 {0}, choisissez la <i>bonne option</i> pour rejoindre le groupe :\n\n<code>{1}</code>",
    'zh': "👮🏽 {0}，選擇<i>正確選項</i>加入群組：\n\n<code>{1}</code>",
    'ar': "👮🏽 {0} اختر <i> الخيار الصحيح </i> للانضمام إلى المجموعة: \n\n <code>{1}</code>",
}
l_hand_msg_FLOOD_USERNAME = {
    'ru': "💬 Пользователь @{0} изменил <b>name/@username</b>! Возможно, шпион!",
    'en': "💬 User @{0} change the <b>name/@username</b>! Possibly a spy!",
    'es': "💬 ¡Usuario @{0} cambia el <b>nombre/@nombre de usuario</b>! ¡Posiblemente un espía!",
    'fr': "💬 L'utilisateur @{0} change le <b>nom/@nom d'utilisateur</b> ! Peut-être un espion !",
    'zh': "💬 用戶@{0} 更改<b>名稱/@用戶名</b>！ 可能是間諜！",
    'ar': "💬 المستخدم @{0} غيّر <b> الاسم / @ اسم المستخدم </b>! ربما جاسوس!",
}
l_hand_msg_flood = {
    'ru': "💬 <i>Flood</i>-сообщения",
    'en': "💬 <i>Flood</i>-messages",
    'es': "💬 <i>Flood</i>-mensajes",
    'fr': "💬 <i>Flood</i>-messages",
    'zh': "💬 <i>Flood</i>-消息",
    'ar': "💬 <i>Flood</i>-رسائل",
}
l_hand_msg_via_bot = {
    'ru': "🗣 Сообщения <i>от имени бота</i> не разрешены",
    'en': "🗣 Messages <i>via bot</i> are not allowed",
    'es': "🗣 Les messages <i>via bot</i> ne sont pas autorisés",
    'fr': "🗣 Les messages <i>via bot</i> ne sont pas autorisés",
    'zh': "🗣 消息<i>通過機器人</i>是不允許的",
    'ar': "🗣 الرسائل <i> عبر البوت </i> غير مسموح بها",
}
l_hand_msg_channel = {
    'ru': "🫥 Сообщения <i>от имени канала</i> не разрешены",
    'en': "🫥 Messages <i>as channel name</i> are not allowed",
    'es': "🫥 No se permiten mensajes <i>como nombre del canal</i>",
    'fr': "🫥 Les messages <i>comme nom de chaîne</i> ne sont pas autorisés",
    'zh': "🫥 消息<i>作為頻道名稱</i>是不允許的",
    'ar': "🫥 الرسائل <i> كاسم قناة </i> غير مسموح بها",
}
l_hand_msg_emoji = {
    'ru': "🗣 Сообщения <i>c emoji</i> не разрешены",
    'en': "🗣 Messages <i>with emoji</i> are not allowed",
    'es': "🗣 No se permiten mensajes <i>con emoji</i>",
    'fr': "🗣 Les messages <i>avec emoji</i> ne sont pas autorisés",
    'zh': "🗣 不允許<i>帶有表情符號</i>的消息",
    'ar': "🗣 غير مسموح بالرسائل <i> ذات الرموز التعبيرية </i>",
}
l_hand_msg_http = {
    'ru': "🔗 Сообщения <i>c внешними ссылками</i> не разрешены",
    'en': "🔗 Messages <i>with external links</i> are not allowed",
    'es': "🔗 No se permiten mensajes <i>con enlaces externos</i>",
    'fr': "🔗 Les messages <i>avec des liens externes</i> ne sont pas autorisés",
    'zh': "🔗 不允許<i>帶有外部鏈接</i>的消息",
    'ar': "🔗 الرسائل <i> ذات الروابط الخارجية </i> غير مسموح بها",
}
l_hand_msg_telegram = {
    'ru': "🔗 Сообщения <i>c telegram-ссылками</i> не разрешены",
    'en': "🔗 Messages <i>with telegram-links</i> are not allowed",
    'es': "🔗 Mensajes <i>con enlaces de Telegram</i> no están permitidos",
    'fr': "🔗 Les messages <i>avec des liens de télégramme</i> ne sont pas autorisés",
    'zh': "🔗 不允許<i>帶有電報鏈接</i>的消息",
    'ar': "🔗 الرسائل <i> التي تحتوي على روابط برقية </i> غير مسموح بها",
}
l_hand_msg_forward = {
    'ru': "🔗 Сообщения <i>c forward-ссылками</i> не разрешены",
    'en': "🔗 Messages <i>with forward-links</i> are not allowed",
    'es': "🔗 No se permiten mensajes <i>con enlaces hacia adelante</i>",
    'fr': "🔗 Les messages <i>avec des liens vers l'avant</i> ne sont pas autorisés",
    'zh': "🔗 不允許<i>帶有轉發鏈接</i>的消息",
    'ar': "🔗 الرسائل <i> ذات الروابط الأمامية </i> غير مسموح بها",
}
l_hand_msg_zalgo = {
    'ru': "文 Сообщения <i>c <a href='https://www.zalgo.org'>zalgo-символами</a></i> не разрешены",
    'en': "文 Messages <i>with <a href='https://www.zalgo.org'>zalgo-symbols</a></i> are not allowed",
    'es': "文 Mensajes <i>con <a href='https://www.zalgo.org'>símbolos-zalgo</a></i> no están permitidos",
    'fr': "文 Les messages <i>avec <a href='https://www.zalgo.org'>symboles zalgo</a></i> ne sont pas autorisés",
    'zh': "<i>帶有<a href='https://www.zalgo.org'>zalgo-symbols</a></i>的消息是不允許的",
    'ar': "文 الرسائل <i> التي تحتوي على <a href='https://www.zalgo.org'> رموز zalgo </a> </i> غير مسموح بها",
}
l_hand_msg_symbols = {
    'ru': "文 Сообщения <i>c 文ب-алфавитами</i> не разрешены",
    'en': "文 Messages <i>with 文ب-alphabet</i> are not allowed",
    'es': "文 Mensajes <i>con 文ب-alfabeto</i> no están permitidos",
    'fr': "文 Les messages <i>avec l'alphabet 文ب</i> ne sont pas autorisés",
    'zh': "不允許<i>帶有文ب-alphabet</i>的文消息",
    'ar': "文 الرسائل <i> التي تحتوي على 文 ب- الأبجدية </i> غير مسموح بها",
}
l_hand_msg_stop = {
    'ru': "🧾 Сообщение содержит <i>стоп-слова</i>",
    'en': "🧾 Message contains <i>stop-words</i>",
    'es': "🧾 El mensaje contiene <i>palabras vacías</i>",
    'fr': "🧾 Le message contient des <i>mots vides</i>",
    'zh': "🧾 消息包含 <i>停用詞</i>",
    'ar': "🧾 تحتوي الرسالة على <i> كلمات التوقف </i>",
}
l_hand_msg_edit = {
    'ru': "👥 <i>Редактирование</i> сообщений не разрешено",
    'en': "👥 Message <i>editing</i> is not allowed",
    'es': "👥 La <i>edición</i> de mensajes no está permitida",
    'fr': "👥 La <i>modification</i> des messages n'est pas autorisée",
    'zh': "👥 消息<i>編輯</i>是不允許的",
    'ar': "👥 رسالة <i> تحرير </i> غير مسموح بها",
}
l_scheduler_autoinvite_is_over = {
    'ru': "🚶🏽 Закончились пользователи для инвайта в группе {0}",
    'en': "🚶🏽 Users for the invite in the {0} group have ended",
    'es': "🚶🏽 Los usuarios de la invitación en el grupo {0} han terminado",
    'fr': "🚶🏽 Les utilisateurs de l'invitation dans le groupe {0} sont terminés",
    'zh': "🚶🏽 {0} 組中邀請的用戶已結束",
    'ar': "🚶🏽 انتهى مستخدمو الدعوة في مجموعة {0}",
}
l_scheduler_autoinvite_success = {
    'ru': "🚶🏽 Успешный инвайт пользователя {0} в группу {1}",
    'en': "🚶🏽 Successful invite of a user {0} to a {1} group",
    'es': "🚶🏽 Invitación exitosa de un usuario {0} a un grupo {1}",
    'fr': "🚶🏽 Invitation réussie d'un utilisateur {0} à un groupe {1}",
    'zh': "🚶🏽 成功邀請用戶 {0} 加入 {1} 組",
    'ar': "دعوة ناجحة من مستخدم {0} إلى مجموعة {1}",
}
l_hand_msg_photo = {
    'ru': "🗣 Сообщения <i>с фото</i> не разрешены",
    'en': "🗣 Messages <i>with photo</i> are not allowed",
    'es': "🗣 No se permiten mensajes <i>con foto</i>",
    'fr': "🗣 Les messages <i>avec photo</i> ne sont pas autorisés",
    'zh': "🗣 不允許<i>帶有照片</i>的消息",
    'ar': "🗣 الرسائل <i> مع الصورة </i> غير مسموح بها",
}
l_hand_msg_video = {
    'ru': "🗣 Сообщения <i>с видео</i> не разрешены",
    'en': "🗣 Messages <i>with video</i> are not allowed",
    'es': "🗣 No se permiten mensajes <i>con video</i>",
    'fr': "🗣 Les messages <i>avec vidéo</i> ne sont pas autorisés",
    'zh': "🗣 不允許<i>帶有視頻</i>的消息",
    'ar': "🗣 الرسائل <i> مع الفيديو </i> غير مسموح بها",
}
l_hand_msg_giff = {
    'ru': "🗣 Сообщения <i>с гиф</i> не разрешены",
    'en': "🗣 Messages <i>with giff</i> are not allowed",
    'es': "🗣 No se permiten mensajes <i>con animación</i>",
    'fr': "🗣 Les messages <i>avec animation</i> ne sont pas autorisés",
    'zh': "🗣 不允許<i>帶有動畫</i>的消息",
    'ar': "🗣 الرسائل <i> ذات الرسوم المتحركة </i> غير مسموح بها",
}
l_hand_msg_audio = {
    'ru': "🗣 Сообщения <i>с аудио</i> не разрешены",
    'en': "🗣 Messages <i>with audio</i> are not allowed",
    'es': "🗣 No se permiten mensajes <i>con audio</i>",
    'fr': "🗣 Les messages <i>avec l'audio</i> ne sont pas autorisés",
    'zh': "🗣 不允許<i>帶有音頻</i>的消息",
    'ar': "🗣 الرسائل <i> مع الصوت </i> غير مسموح بها",
}
l_hand_msg_sticker = {
    'ru': "🗣 Сообщения <i>со стикерами</i> не разрешены",
    'en': "🗣 Messages <i>with sticker</i> are not allowed",
    'es': "🗣 No se permiten mensajes <i>con pegatina</i>",
    'fr': "🗣 Les messages <i>avec autocollant</i> ne sont pas autorisés",
    'zh': "🗣 不允許<i>帶有貼紙</i>的消息",
    'ar': "🗣 الرسائل <i> ذات الملصق </i> غير مسموح بها",
}
l_hand_msg_sticker_ex = {
    'ru': "🗣 Сообщения <i>со стикерами</i> разрешены, но есть исключения",
    'en': "🗣 Messages <i>with sticker</i> are not allowed, but there are exceptions",
    'es': "🗣 No se permiten mensajes <i>con sticker</i>, pero hay excepciones",
    'fr': "🗣 Les messages <i>avec autocollant</i> ne sont pas autorisés, mais il y a des exceptions",
    'zh': "🗣 不允許<i>帶有貼紙</i>的消息，但也有例外",
    'ar': "🗣 الرسائل <i> ذات الملصق </i> غير مسموح بها ، ولكن هناك استثناءات",
}
l_hand_msg_docum = {
    'ru': "🗣 Сообщения <i>с документами</i> не разрешены",
    'en': "🗣 Messages <i>with document</i> are not allowed",
    'es': "🗣 No se permiten mensajes <i>con documento</i>",
    'fr': "🗣 Les messages <i>avec document</i> ne sont pas autorisés",
    'zh': "🗣 不允許<i>帶有文檔</i>的消息",
    'ar': "🗣 الرسائل <i> مع المستند </i> غير مسموح بها",
}
l_hand_msg_poll = {
    'ru': "🗣 Сообщения <i>с опросами</i> не разрешены",
    'en': "🗣 Messages <i>with poll</i> are not allowed",
    'es': "🗣 No se permiten mensajes <i>con prueba</i>",
    'fr': "🗣 Les messages <i>avec questionnaire</i> ne sont pas autorisés",
    'zh': "🗣 不允許<i>帶有測驗</i>的消息",
    'ar': "🗣 الرسائل <i> مع الاستطلاع </i> غير مسموح بها",
}
l_hand_msg_voice = {
    'ru': "🗣 <i>Голосовые-сообщения не разрешены</i>",
    'en': "🗣 <i>Voice-messages are not allowed</i>",
    'es': "🗣 <i>No se permiten mensajes de voz</i>",
    'fr': "🗣 <i>Les messages vocaux ne sont pas autorisés</i>",
    'zh': "🗣 <i>不允許語音留言</i>",
    'ar': "🗣 <i> الرسائل الصوتية غير مسموح بها </i>",
}
l_hand_msg_video_note = {
    'ru': "🗣 Сообщения <i>с видео-заметками</i> не разрешены",
    'en': "🗣 Messages <i>with video-note</i> are not allowed",
    'es': "🗣 No se permiten mensajes <i>con video-nota</i>",
    'fr': "🗣 Les messages <i>avec note vidéo</i> ne sont pas autorisés",
    'zh': "🗣 不允許<i>帶有視頻註釋</i>的消息",
    'ar': "🗣 الرسائل <i> مع ملاحظة الفيديو </i> غير مسموح بها",
}
# endregion

# endregion


# region FereyBotBot
l_bot_btn1 = {
    'ru': '⛰ Боты',
    'en': '⛰ Bots',
    'es': '⛰ Grupos',
    'fr': '⛰ botes',
    'zh': '⛰ 團體',
    'ar': '⛰ مجموعات',
}
l_bot_btn2 = {
    'ru': "🌬 Подписка",
    'en': "🌬 Subscription",
    'es': "🌬 Suscripción",
    'fr': "🌬 Abonnement",
    'zh': "🌬订阅",
    'ar': "🌬 الاشتراك",
}
l_bot_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>автоматизации</code> <b>Telegram</b>-ботов:\n\n▪️авто-постинг и <b>авто-перевод</b>\n▪️<b>авто-ответы</b> и оповещения\n▪️интеграции и платежи\n▪️пользователи и администраторы\n\n❗️также можно заказать разработку чат-бота в нашей <a href='https://t.me/{1}'>ferey</a>-студии",
    'en': "🌱 {0}, welcome to <i>the landing bot</i> of the Ferey project:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ you can also order the development of a chat bot in our Ferey studio",
    'es': "🌱 {0}, bienvenido al <i>bot de aterrizaje</i> del proyecto Ferey:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ también puedes encargar el desarrollo de un chat bot en nuestro estudio Ferey",
    'fr': "🌱 {0}, bienvenue sur <i>le landing bot</i> du projet Ferey :\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ vous pouvez également commander le développement d'un chat bot dans notre studio Ferey",
    'zh': "🌱 {0}，欢迎来到 Ferey 项目的<i>落地机器人</i>：\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️您也可以在我们的Ferey工作室订购聊天机器人的开发",
    'ar': "🌱 {0} ، مرحبًا بك في <i>روبوت الهبوط</i> الخاص بمشروع Ferey:\n\n▪️ <b>openvpn</b>\n▪️ <b>wireguard</b>\n\n❗️ يمكنك أيضًا طلب تطوير روبوت محادثة في استوديو Ferey",
}

l_add_bot_button = {
    'ru': "➕ Добавить бота",
    'en': "➕ Add bot",
    'es': "➕ Agregar grupo",
    'fr': "➕ Ajouter un bote",
    'zh': "➕ 添加組",
    'ar': "➕ إضافة مجموعة",
}
l_add_bot_call = {
    'ru': "➕ Оформи подписку для >1 бота или открепи активного бота, чтобы добавить нового",
    'en': "➕ Add bot",
    'es': "➕ Agregar grupo",
    'fr': "➕ Ajouter un bote",
    'zh': "➕ 添加組",
    'ar': "➕ إضافة مجموعة",
}
l_test_bot_desc = {
    'ru': "🫥 Описание @{0}-бота:\n\n▪️телеграф блог\n▪️авто-перевод\n▪️оповещения и utm-рефералы\n▪️интеграции",
    'en': "🫥 A test bot",
    'es': "🫥 Agregar grupo",
    'fr': "🫥 Ajouter un bote",
    'zh': "🫥 添加組",
    'ar': "🫥إضافة مجموعة",
}
l_clone_bot_button = {
    'ru': "©️ Клонировать бота",
    'en': "©️ Clone bot",
    'es': "©️ Agregar grupo",
    'fr': "©️ Ajouter un bote",
    'zh': "©️ 添加組",
    'ar': "©️ إضافة مجموعة",
}
l_clone_bot_call = {
    'ru': "©️ Оформи подписку для >1 бота или открепи активного бота, чтобы склонировать бота конкурента",
    'en': "➕ Add bot",
    'es': "➕ Agregar grupo",
    'fr': "➕ Ajouter un bote",
    'zh': "➕ 添加組",
    'ar': "➕ إضافة مجموعة",
}
l_clone_bot_text = {
    'ru': "©️ <b>Вставь</b> корректную ссылку на бота, чтобы склонировать его",
    'en': "➕ Add bot",
    'es': "➕ Agregar grupo",
    'fr': "➕ Ajouter un bote",
    'zh': "➕ 添加組",
    'ar': "➕ إضافة مجموعة",
}
l_clone_bot_wait = {
    'ru': "©️ <b>Клонирование</b> бота\n\n#длительность 1мин",
    'en': "➕ Add bot",
    'es': "➕ Agregar grupo",
    'fr': "➕ Ajouter un bote",
    'zh': "➕ 添加組",
    'ar': "➕ إضافة مجموعة",
}
l_addbot_handler = {
    'ru': "➕ Пришли корректный <b>ТОКЕН</b> Telegram-бота, полученный с помощью @botFather-бота\n\n👩🏽‍💻 Например, <code>117783159:BBAD2Kz2h8AQtHYiVtuyyyASdMN</code>",
    'en': "➕ <b>Create</b>/<code>user extra</code> <i>Telegram</i>-bot via <b>mobile</b> app, and then send its phone <u>number</u>℡\n\n👩🏽‍💻 For example, <code>79331114545</code>",
    'es': "➕ Volver..",
    'fr': "➕ Retour..",
    'zh': "➕ 回來..",
    'ar': "🔙 رجوع ..",
}
l_wait_for_translate_bot = {
    'ru': "👩🏽‍💻 <b>Перевод</b> {0}-бота на <i>{1}</i>-язык\n\n#длительность 0мин",
    'en': "👩🏽‍💻 <b>Template</b> for @{0} is ready!",
    'es': "➕ Volver..",
    'fr': "➕ Retour..",
    'zh': "➕ 回來..",
    'ar': "🔙 رجوع ..",
}
l_template_is_ready = {
    'ru': "👩🏽‍💻 <b>Шаблон</b> для @{0} готов!",
    'en': "👩🏽‍💻 <b>Template</b> for @{0} is ready!",
    'es': "➕ Volver..",
    'fr': "➕ Retour..",
    'zh': "➕ 回來..",
    'ar': "🔙 رجوع ..",
}
l_payment_successful = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> {0} 💰Внес оплату в размере {1} {2}",
    'en': "👩🏽‍💻 <b>Template</b> for @{0} is ready!",
    'es': "➕ Volver..",
    'fr': "➕ Retour..",
    'zh': "➕ 回來..",
    'ar': "🔙 رجوع ..",
}
l_promocode_activated = {
    'ru': "👩🏽‍💻 *Промокод*: `{txt}` активирован",
    'en': "👩🏽‍💻 <b>Template</b> for @{0} is ready!",
    'es': "➕ Volver..",
    'fr': "➕ Retour..",
    'zh': "➕ 回來..",
    'ar': "🔙 رجوع ..",
}

# region commands
l_bot_commands_handler = {
    'ru': "⚙️ <b>Команды</b> /cmd для <b>@{0}</b>\n\n/info   <i>информация</i>\n/stat   <i>аналитика</i>\n/status <i>статус</i>\n/on     <i>включение</i>\n<code>/off</code>    <i>выключение</i>\n<code>/restart</code>  <i>перезагрузка</i>\n\n/parse [premium|admin|utm|ban]\n/admin [id]    <i>администраторы</i>\n/promo      <i>промокод</i>\n/ban [id/@username]   <i>список</i>\n/unban     <i>разбан</i>",
    'en': "⚙️ <b>Account commands</b> /cmd for <b>{0}</b> in @{1} works also and in the target bot\n\n/update <i>profile copy</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/status <i>bot status</i>\n/log    <i>recent actions</i>\n/on     <i>enable bot</i>\n<code>/off</code>    <i>disable bot</i>\n<code>/repair</code> <i>accout clear: reading history</i>\n<code>/reset</code>  <i>bot reset: deleting dialogs</i>\n\n/parse      <i>[link/id on chat] [argument]</i>\n/login      <i>login to bot</i>\n/spambot    <i>bot karma</i>\n/autodel+days   <i>auto-deletion 1-365 days</i>\n/delay+sec  <i>auto-delay of auto-answer</i>\n/join+file  <i>join to groups/channels</i>\n/vote       <i>[id of chat] [option]</i>\n<code>/leaveall</code>   <i>leave all groups/channels</i>\n<code>/deleteall</code>  <i>delete all dialogs</i>\n\n# only from bot name\n/screen <i>screenshort-nortification</i>\n/type+msg     <i>typing</i>\n/think          <i>thinking</i>\n<code>* geo-location sending returns @username-list</code>",
    'es': "⚙️ Configuración de <b>Grupo</b> de <b>{0}</b>{1}\n\n<b>⛏ Comandos de administración @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-bots</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from bot for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in bot for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-bots</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for bot</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'fr': "⚙️ Paramètres de <b>bote</b> de <b>{0}</b>{1}\n\n<b>⛏ Commandes d'administration @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-bots</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from bot for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in bot for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-bots</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for bot</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'zh': "⚙️ <b>組</b>設置 <b>{0}</b>{1}\n\n<b>⛏ 管理員命令 @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-bots</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from bot for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in bot for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-bots</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for bot</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
    'ar': "⚙️ إعدادات <b> المجموعة </b> الخاصة بـ <b>{0}</b>{1}\n\n<b>⛏ أوامر المسؤول @{2}</b>\n/update <i>parameters</i>\n/transfer   <i>admin-settings</i>\n/info   <i>information</i>\n/stat   <i>statistics</i>\n/parse  <i>[all|old|premium|active|online]</i>\n<code>/parse old</code> - <i>parsing old id-bots</i>\n\n/channel NAME   <i>add channel for subscribe checking</i>\n/button NAME    <i>add button's name for Enter Control</i>\n/delay MIN      <i>set delay number [min] for 1st message</i>\n/flood NUM      <i>set msg-number for flood</i>\n\n<b>⛏ Commands for other administrations</b>\n/ban 5m|1h|10d <i>delete from bot for time</i>\n/unban\n/mute 5m|1h|10d <i>restriction in bot for time</i>\n/unmute\n/warn+msg <i>warning</i>\n/status\n/karma  [+|-]\n/tag+msg   <i>@tager random-bots</i>\n\n<b>⛏ Commands for users</b>\n/help   <i>show commands</i>\n/rules  <i>for bot</i>\n/report <i>about violation</i>\n/happy  <i>get happyness</i>\n/thanks <i>say to user thank you</i>",
}
l_bot_status_handler = {
    'ru': "👩🏽‍💻 <b>Статус</b> @{0}-бота: {1}",
    'en': "👩🏽‍💻 Account-status: {0}",
    'es': "🎉 Enviar este comando como respuesta al mensaje",
    'fr': "🎉 Envoyez cette commande en réponse au message",
    'zh': "🎉 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_bot_on_handler = {
    'ru': "👩🏽‍💻 <b>Запуск</b> @{0}-бота..\n\n#длительность 1мин",
    'en': "👩🏽‍💻 Begin to start bot..\n\n#duration 1min",
    'es': "🎉 Enviar este comando como respuesta al mensaje",
    'fr': "🎉 Envoyez cette commande en réponse au message",
    'zh': "🎉 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_bot_on_handler_already = {
    'ru': "👩🏽‍💻 <b>@{0}</b>-бот уже запущен",
    'en': "👩🏽‍💻 Account have already started",
    'es': "🎉 Enviar este comando como respuesta al mensaje",
    'fr': "🎉 Envoyez cette commande en réponse au message",
    'zh': "🎉 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_bot_off_handler = {
    'ru': "👩🏽‍💻 <b>Остановка</b> @{0}-бота..\n\n#длительность 1мин",
    'en': "👩🏽‍💻 Finishing bot-session {0}..\n\n#duration 1min",
    'es': "🎉 Enviar este comando como respuesta al mensaje",
    'fr': "🎉 Envoyez cette commande en réponse au message",
    'zh': "🎉 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_bot_off_handler_already = {
    'ru': "👩🏽‍💻 <b>@{0}</b>-бот уже выключен",
    'en': "👩🏽‍💻 Account have already finished",
    'es': "🎉 Enviar este comando como respuesta al mensaje",
    'fr': "🎉 Envoyez cette commande en réponse au message",
    'zh': "🎉 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_bot_off_handler_done = {
    'ru': "👩🏽‍💻 <b>@{0}</b>-бот выключен",
    'en': "👩🏽‍💻 Account is off",
    'es': "🎉 Enviar este comando como respuesta al mensaje",
    'fr': "🎉 Envoyez cette commande en réponse au message",
    'zh': "🎉 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
l_bot_restart_handler = {
    'ru': "👩🏽‍💻 <b>Перезапуск</b> @{0}-бота..\n\n#длительность 1мин",
    'en': "👩🏽‍💻 Restart of bot-session {0}..\n\n#duration 1min",
    'es': "🎉 Enviar este comando como respuesta al mensaje",
    'fr': "🎉 Envoyez cette commande en réponse au message",
    'zh': "🎉 將此命令作為對消息的回復發送",
    'ar': "🎉 أرسل هذا الأمر كرد على الرسالة",
}
# endregion


# region bot
l_bot_config = {
    ("cctor", "👩🏽‍💻", "☑"): {
        'ru': "Конструктор ᴺᴱᵂ",
        'en': "Builder ᴺᴱᵂ",
        'es': "Builder ᴺᴱᵂ",
        'fr': "Builder ᴺᴱᵂ",
        'zh': "Builder ᴺᴱᵂ",
        'ar': "Builder ᴺᴱᵂ",
    },
    ("cban", "🕵🏽", "☑"): {
        'ru': "Авто-бан",
        'en': "Auto-ban",
        'es': "Prohibición automática",
        'fr': "Interdiction automatique",
        'zh': "自動禁止",
        'ar': "حظر تلقائي",
    },
    ("ctranslate", "文", "☐"): {
        'ru': "Авто-перевод",
        'en': "Auto-translate",
        'es': "Saludo automático",
        'fr': "Message d'accueil automatique",
        'zh': "自動問候",
        'ar': "الترحيب التلقائي",
    },
    ("canswer", "👋🏽", "☐"): {
        'ru': "Авто-ответ",
        'en': "Auto-answer",
        'es': "Saludo automático",
        'fr': "Message d'accueil automatique",
        'zh': "自動問候",
        'ar': "الترحيب التلقائي",
    },
    ("cpost", "🔔", "☐"): {
        'ru': "Авто-постинг",
        'en': "Auto-posting",
        'es': "Publicación automática",
        'fr': "Publication automatique",
        'zh': "自動發布",
        'ar': "النشر التلقائي",
    },

    ("cpayment", "💳", "☐"): {
        'ru': "Платежи",
        'en': "Payments",
        'es': "Prohibición automática",
        'fr': "Interdiction automatique",
        'zh': "自動禁止",
        'ar': "حظر تلقائي",
    },
    ("cintegration", "🗝️", "☐"): {
        'ru': "Интеграции",
        'en': "Integrations",
        'es': "Publicación automática",
        'fr': "Publication automatique",
        'zh': "自動發布",
        'ar': "النشر التلقائي",
    },
    ("cnotification", "💬", "☑"): {
        'ru': "Оповещения",
        'en': "Notifications",
        'es': "Mensajes con 文/ب/y",
        'fr': "Messagerie avec 文/ب/y",
        'zh': "與消息 文/ب/y",
        'ar': "文/ب/y الرسائل ذات",
    },
    ("cuser", "👥", "☑"): {
        'ru': "Пользователи",
        'en': "Users",
        'es': "Mensajes con 文/ب/y",
        'fr': "Messagerie avec 文/ب/y",
        'zh': "與消息 文/ب/y",
        'ar': "文/ب/y الرسائل ذات",
    },
    ("cadmin", "👮🏽", "☑"): {
        'ru': "Администраторы",
        'en': "Administrators",
        'es': "Mensajes con 文/ب/y",
        'fr': "Messagerie avec 文/ب/y",
        'zh': "與消息 文/ب/y",
        'ar': "文/ب/y الرسائل ذات",
    },
}
l_remove_bot = {
    'ru': "🚫Убрать бота",
    'en': "🚫Put away bot",
    'es': "🚫Guardar grupo",
    'fr': "🚫bote de rangement",
    'zh': "🚫收起組",
    'ar': "🚫 أبعد المجموعة",
}

l_show_bots = {
    'ru': "👩🏽‍💻 <b>Добавленные боты</b>\n\n[команды /cmd]",
    'en': "🐋 <b>Added bots</b>\n\n[commands /cmd]",
    'es': "🐋 <b>Grupos añadidos</b>\n\n[comandos /cmd]",
    'fr': "🐋 <b>botes ajoutés</b>\n\n[commands /cmd]",
    'zh': "🐋 <b>添加組</b>\n\n[命令 /cmd]",
    'ar': "🐋 <b> المجموعات المضافة </b> \n\n [أوامر /cmd]",
}

l_creturntext = {
    'ru': "✖️ <b>Сбросить</b> настройки по умолчанию (до рекомендуемых) для бота [<b>{0}</b>]?",
    'en': "✖️ Restore settings to default for bot [<b>{0}</b>]?",
    'es': "✖️ ¿Restaurar la configuración predeterminada para el grupo [<b>{0}</b>]?",
    'fr': "✖️ Restaurer les paramètres par défaut pour le bote [<b>{0}</b>] ?",
    'zh': "✖️ 將組 [<b>{0}</b>] 的設置恢復為默認設置？",
    'ar': "✖️ هل تريد استعادة الإعدادات الافتراضية للمجموعة [<b>{0}</b>]؟",
}
l_creturnanswer = {
    'ru': "✖️ Настройки бота [<b>{0}</b>] успешно сброшены!",
    'en': "✖️ Account settings of [<b>{0}</b>] successfully reset!",
    'es': "✖️ ¡La configuración de grupo de [<b>{0}</b>] se restableció correctamente!",
    'fr': "✖️ Les paramètres de bote de [<b>{0}</b>] ont été réinitialisés !",
    'zh': "✖️ [<b>{0}</b>] 的群組設置已成功重置！",
    'ar': "✖️ تمت إعادة تعيين إعدادات المجموعة لـ [<b>{0}</b>] بنجاح!",
}
l_cdeletetext = {
    'ru': "🚫 Убрать привязку бота [<b>{0}</b>]?",
    'en': "🚫 Put away bot-connection with bot [<b>{0}</b>]?",
    'es': "🚫 ¿Eliminar la conexión de bot con el grupo [<b>{0}</b>]?",
    'fr': "🚫 Mettre de côté la connexion au bot avec le bote [<b>{0}</b>] ?",
    'zh': "🚫 放棄與組 [<b>{0}</b>] 的機器人連接？",
    'ar': "🚫 التخلص من اتصال الروبوت بالمجموعة [<b>{0}</b>]؟",
}
l_cdeleteanswer = {
    'ru': "🚫 Бот успешно откреплен [<b>{0}</b>]",
    'en': "🚫 Bot successfully disconnected from bot [<b>{0}</b>] and does not control it!",
    'es': "🚫 ¡El bot se desconectó con éxito del grupo [<b>{0}</b>] y no es miembro en absoluto!",
    'fr': "🚫 Le bot s'est déconnecté avec succès du bote [<b>{0}</b>] et il n'est pas du tout membre !",
    'zh': "🚫 Bot 已成功與群組 [<b>{0}</b>] 斷開連接，並且它根本不是成員！",
    'ar': "🚫 تم قطع اتصال البوت بنجاح بالمجموعة [<b>{0}</b>] وهو ليس عضوًا على الإطلاق!",
}
l_transfer_success = {
    'ru': "👩🏽‍💻 <b>Права</b> владения на @{0}-бота успешно переданы @{1}-аккаунту!\n\n👩🏽‍💻 Теперь для передачи прав/настройки можно использовать @botfather-бота",
    'en': "🚫 Bot successfully disconnected from bot [<b>{0}</b>] and does not control it!",
    'es': "🚫 ¡El bot se desconectó con éxito del grupo [<b>{0}</b>] y no es miembro en absoluto!",
    'fr': "🚫 Le bot s'est déconnecté avec succès du bote [<b>{0}</b>] et il n'est pas du tout membre !",
    'zh': "🚫 Bot 已成功與群組 [<b>{0}</b>] 斷開連接，並且它根本不是成員！",
    'ar': "🚫 تم قطع اتصال البوت بنجاح بالمجموعة [<b>{0}</b>] وهو ليس عضوًا على الإطلاق!",
}
# endregion


# region config
# region ctranslate_
l_ctranslate_text = {
    'ru': "文 <b>Жми</b> на ✅/☑️ чтобы <b>Вкл/Выкл</b> авто-перевод для <i>исходящих</i> сообщений бота на язык пользователя при /start-запуске бота",
    'en': "文 Push the ✅/☑️ to <b>On/Off</b> auto-translate for <i><b>income</b>/<b>outgoing</b> messages</i>",
    'es': "文 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "文 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "文 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
l_ctranslate_in_on = {
    'ru': "✅☑Вкл перевод входящих",
    'en': "✅☑On translate income",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_ctranslate_in_off = {
    'ru': "☑️☐Выкл перевод входящих",
    'en': "☑️☐Off translate income",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}
l_ctranslate_out_on = {
    'ru': "✅☑Вкл перевод исходящих",
    'en': "✅☑On translate outgoing",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_ctranslate_out_off = {
    'ru': "☑️☐Выкл перевод исходящих",
    'en': "☑️☐Off translate outgoing",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}
# endregion


# region canswer_
l_canswer_text = {
    'ru': "👋🏽 <b>Жми</b> на ✅/☑️ чтобы <b>Вкл/Выкл</b> режим авто-ответа на текстовые сообщения с помощью нейросети",
    'en': "👋🏽 Push the ✅/☑️ to <b>On/Off</b> auto-answer on triggers\n\n👩🏽‍💻 Current number of triggers: <u>{0}</u>",
    'es': "👋🏽 Presiona ✅/☑️ para <b>Activar/Desactivar</b> la respuesta automática en mensajes desencadenantes, que contienen palabras de inicio específicas\n\n👩🏽‍💻 Número actual de palabras de inicio <u>{0}</u>",
    'fr': "👋🏽 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> la réponse automatique aux messages déclencheurs, contenant des mots de départ spécifiques\n\n👩🏽‍💻 Nombre actuel de mots de départ <u>{0}</u>",
    'zh': "👋🏽 將 ✅/☑️ 推到 <b>On/Off</b> 觸發消息上的自動應答，包含特定的起始詞\n\n👩🏽‍💻 當前起始詞的數量<u>{0}</u>",
    'ar': "🚀 اضغط على ✅ / ☑️ ، لإجراء تشغيل / إيقاف الرد التلقائي على الرسائل المشغلة ، التي تحتوي على كلمات بداية محددة \n\n👩🏽‍💻 العدد الحالي لكلمات البداية {0} / ش",
}
# endregion


# region cpayment_
l_cpayment_alert = {
    'ru': "💳️ Нужно ⚙️Настроить хотя бы один платежный токен",
    'en': "🗝️ You have to ⚙️Configure post and source for sending",
    'es': "🗝️ Tienes que ⚙️ Configurar al menos una palabra de inicio",
    'fr': "🗝️ Vous devez ⚙️ Configurer au moins un mot de départ",
    'zh': "🗝️ 你必須 ⚙️ 配置至少一個起始詞",
    'ar': "🔔 يجب عليك ⚙️ تكوين كلمة بداية واحدة على الأقل",
}
l_cpayment_text = {
    'ru': "💳️ <b>Жми</b> на ✅/☑️ чтобы <b>Вкл/Выкл</b> платежи в @{0}-боте\n\n👩🏽‍💻 <b>Текущий</b> платежный токен:\n<code>{1}</code>",
    'en': "🗝️ Push the ✅/☑️ to <b>On/Off</b> auto-sending choosen post to many users\n\n👩🏽‍💻 <b>Current</b> settings of auto-sending: {0}",
    'es': "🗝️ Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👩🏽‍💻 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🗝️ Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre bote\n\n👩🏽‍💻 Inviter <u>{0}</u> utilisateurs par jour à partir du bote {1}",
    'zh': "🗝️ 按下 ✅/☑️ 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👩🏽‍💻 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🗝️ ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👩🏽‍💻 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}
l_cpayment_token = {
    'ru': "💳️ <b>Вставь</b> платежный токен, полученный из @BotFather-бота\n\n👩🏽‍💻 <b>Например</b>\n<code>401643678:7049d0b3-f0267096c4a1</code>\n\n👩🏽‍💻 <b>Текущий</b> токен:\n{0}",
    'en': "🗝️ Push the ✅/☑️ to <b>On/Off</b> auto-sending choosen post to many users\n\n👩🏽‍💻 <b>Current</b> settings of auto-sending: {0}",
    'es': "🗝️ Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👩🏽‍💻 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🗝️ Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre bote\n\n👩🏽‍💻 Inviter <u>{0}</u> utilisateurs par jour à partir du bote {1}",
    'zh': "🗝️ 按下 ✅/☑️ 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👩🏽‍💻 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🗝️ ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👩🏽‍💻 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}
l_cpayment_done = {
    'ru': "💳️ <b>Готово!</b>\n\n👩🏽‍💻 <b>Текущий</b> платежный токен для @{0}-бота:\n\n<code>{1}</code>",
    'en': "🗝️ Push the ✅/☑️ to <b>On/Off</b> auto-sending choosen post to many users\n\n👩🏽‍💻 <b>Current</b> settings of auto-sending: {0}",
    'es': "🗝️ Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👩🏽‍💻 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🗝️ Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre bote\n\n👩🏽‍💻 Inviter <u>{0}</u> utilisateurs par jour à partir du bote {1}",
    'zh': "🗝️ 按下 ✅/☑️ 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👩🏽‍💻 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🗝️ ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👩🏽‍💻 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}
# endregion


# region cintegration_
l_cintegration_alert = {
    'ru': "🗝️ Нужно ⚙️Настроить ССЫЛКУ доступа",
    'en': "🗝️ You have to ⚙️Configure post and source for sending",
    'es': "🗝️ Tienes que ⚙️ Configurar al menos una palabra de inicio",
    'fr': "🗝️ Vous devez ⚙️ Configurer au moins un mot de départ",
    'zh': "🗝️ 你必須 ⚙️ 配置至少一個起始詞",
    'ar': "🔔 يجب عليك ⚙️ تكوين كلمة بداية واحدة على الأقل",
}
l_cintegration_text = {
    'ru': "🗝️ <b>Жми</b> на ✅/☑️ чтобы <b>Вкл/Выкл</b> интеграцию базы пользователей с <i><b>google</b>-crm/<b>airtable</b>-crm</i>\n\n👩🏽‍💻 Например, опция [<b>{0}</b>] означает возможность интеграции базы пользователей с <i>google-crm</i>",
    'en': "🗝️ Push the ✅/☑️ to <b>On/Off</b> auto-sending choosen post to many users\n\n👩🏽‍💻 <b>Current</b> settings of auto-sending: {0}",
    'es': "🗝️ Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👩🏽‍💻 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🗝️ Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre bote\n\n👩🏽‍💻 Inviter <u>{0}</u> utilisateurs par jour à partir du bote {1}",
    'zh': "🗝️ 按下 ✅/☑️ 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👩🏽‍💻 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🗝️ ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👩🏽‍💻 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}

l_cintegration_google_on = {
    'ru': "✅☑Вкл google-crm",
    'en': "✅☑On service statuses",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_cintegration_google_off = {
    'ru': "☑️☐Выкл google-crm",
    'en': "☑️☐Off service statuses",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}
l_cintegration_airtable_on = {
    'ru': "✅☑Вкл airtable-crm",
    'en': "✅☑On service statuses",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_cintegration_airtable_off = {
    'ru': "☑️☐Выкл airtable-crm",
    'en': "☑️☐Off service statuses",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}

l_cintegration_google = {
    'ru': "🗝️ <b>Вставь ссылку</b> на пустую google-таблицу (<i>с открытым доступом для редактирования</i>) для интеграции с базой пользователей @{0}-бота\n\n👩🏽‍💻 <b>Например</b>, <code>https://docs.google.com/spreadsheets/d/1aWGYLL0WWZP/edit?usp=sharing</code>\n\n👩🏽‍💻 <b>Текущая</b> ссылка:\n{1}",
    'en': "🗝️ Push the ✅/☑️ to <b>On/Off</b> auto-sending choosen post to many users\n\n👩🏽‍💻 <b>Current</b> settings of auto-sending: {0}",
    'es': "🗝️ Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👩🏽‍💻 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🗝️ Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre bote\n\n👩🏽‍💻 Inviter <u>{0}</u> utilisateurs par jour à partir du bote {1}",
    'zh': "🗝️ 按下 ✅/☑️ 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👩🏽‍💻 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🗝️ ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👩🏽‍💻 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}
l_cintegration_airtable = {
    'ru': "🗝️ <b>Вставь ссылку</b> на пустую airtable-таблицу (<i>с открытым доступом для редактирования и любого e-mail</i>) для интеграции с базой пользователей @{0}-бота\n\n👩🏽‍💻 <b>Например</b>, <code>https://airtable.com/invite/l?inviteId=inv4VGM&inviteToken=f1d31f9aba6b&utm_medium=email</code>\n\n👩🏽‍💻 <b>Текущая</b> ссылка:\n{1}",
    'en': "🗝️ Push the ✅/☑️ to <b>On/Off</b> auto-sending choosen post to many users\n\n👩🏽‍💻 <b>Current</b> settings of auto-sending: {0}",
    'es': "🗝️ Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👩🏽‍💻 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🗝️ Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre bote\n\n👩🏽‍💻 Inviter <u>{0}</u> utilisateurs par jour à partir du bote {1}",
    'zh': "🗝️ 按下 ✅/☑️ 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👩🏽‍💻 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🗝️ ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👩🏽‍💻 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}
l_cintegration_done = {
    'ru': "🗝️ <b>Готово!</b>\n\n👩🏽‍💻 <b>Текущая</b> ссылка:\n{0}",
    'en': "🗝️ Push the ✅/☑️ to <b>On/Off</b> auto-sending choosen post to many users\n\n👩🏽‍💻 <b>Current</b> settings of auto-sending: {0}",
    'es': "🗝️ Presiona ✅/☑️ para <b>activar/desactivar</b> la invitación automática de usuarios a tu grupo\n\n👩🏽‍💻 Invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🗝️ Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> l'invitation automatique d'utilisateurs dans votre bote\n\n👩🏽‍💻 Inviter <u>{0}</u> utilisateurs par jour à partir du bote {1}",
    'zh': "🗝️ 按下 ✅/☑️ 以<b>開/關</b>自動邀請用戶加入您的群組\n\n👩🏽‍💻 每天從群組 {1} 中邀請 <u>{0}</u> 個用戶",
    'ar': "🗝️ ادفع ✅ / ☑️ إلى <b> تشغيل / إيقاف </b> لدعوة المستخدمين تلقائيًا إلى مجموعتك \n\n👩🏽‍💻 دعوة <u>{0}</u> مستخدمين يوميًا من المجموعة {1}",
}
# endregion


# region cnotification_
l_cnotification_text = {
    'ru': "💬 <b>Жми</b> на ✅/☑️ чтобы <b>Вкл/Выкл</b> оповещения о <i><b>/start-stop</b> запуске/блокировке бота пользователем и попадании пользователя в <b>/ban</b>-список/<b>нажатии</b> на кнопки пользователем/<b>диалоге</b> с администраторами/<b>всех</b> действиях пользователя</i>\n\n👩🏽‍💻 Например, опция [<b>{0}</b>] означает <code>показ</code> сообщений от пользователя администраторам бота (/admin) с возможностью реплай-ответа на сообщения",
    'en': "💬 Push the ✅/☑️ to <b>On/Off</b> <i>service <b>statuses</b>/<b>forward</b> income for yourself (including original/<u>deleted</u> messages)/tag about income-<b>reading</b></i>\n\n👩🏽‍💻 For example, [{0}] means <code>show</code> service <b>statuses</b>: <i>typing..search sticker..</i>",
    'es': "💬 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "💬 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "💬 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
l_cnotification_start_on = {
    'ru': "✅☑Вкл /start-stop-/ban",
    'en': "✅☑On service statuses",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_cnotification_start_off = {
    'ru': "☑️☐Выкл /start-stop-/ban",
    'en': "☑️☐Off service statuses",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}
l_cnotification_push_on = {
    'ru': "✅☑Вкл нажатие на кнопки",
    'en': "✅☑On forward to yourself",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_cnotification_push_off = {
    'ru': "☑️☐Выкл нажатие на кнопки",
    'en': "☑️☐Off forward to yourself",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}

l_cnotification_dialog_on = {
    'ru': "✅☑Вкл диалог",
    'en': "✅☑On reading msgs",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_cnotification_dialog_off = {
    'ru': "☑️☐Выкл диалог",
    'en': "☑️☐Off reading msgs",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}
l_cnotification_all_on = {
    'ru': "✅☑Вкл все действия",
    'en': "✅☑On reading msgs",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_cnotification_all_off = {
    'ru': "☑️☐Выкл все действия",
    'en': "☑️☐Off reading msgs",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}

l_cnotification_dialog = {
    'ru': "💬 <b>Пользователь</b>: {0} [<b>id</b>=<code>{1}</code>] написал в @{2}-боте:",
    'en': "👩🏽‍💻 User <b>{0}</b> (<code>{1}</code>) have answered into @{2}-bot:",
    'es': '🌬 Sobre',
    'fr': '🌬 À propos de',
    'zh': '🌬 關於',
    'ar': '🌬 حول',
}
# endregion


# region cuser_
l_cuser_text2 = {
    'ru': "👥 <b>Жми</b> на ✅/☑️ чтобы <b>Вкл/Выкл</b> <i>замену голосовых/телескопов на <b>audio/video</b> (*рекомендуется, если <code>premium</code>-пользователи установили такой запрет)/сервисные <b>статусы</b> бота (печатает..записывает видео..)/ведение списка <b>/utm-рефералов</b></i>\n\n👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/parse - вывести всех пользователей\n/utm - вывести utm-рефералов\n/link - создать реферальную /utm ссылку",
    'en': "👥 Push the ✅/☑️ to <b>On/Off</b> auro-reaction on <i><b>emoji</b> inside message/<b>media</b>-content</i>/<b>reply</b> reaction",
    'es': "👥 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "👥 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "👥 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>"
}
l_cuser_restricted_on = {
    'ru': "✅☑Вкл audio/video замена",
    'en': "✅☑On reaction to emoji",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_cuser_restricted_off = {
    'ru': "☑️☐Выкл audio/video замена",
    'en': "☑️☐Off reaction to emoji",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}
l_cuser_status_on = {
    'ru': "✅☑Вкл сервисные статусы",
    'en': "✅☑On service statuses",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_cuser_status_off = {
    'ru': "☑️☐Выкл сервисные статусы",
    'en': "☑️☐Off service statuses",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}
l_cuser_utm_on = {
    'ru': "✅☑Вкл utm-рефералы",
    'en': "✅☑On reaction to media",
    'es': "✅☑En nueva-id-ban",
    'fr': "✅☑En nouveau-id-ban",
    'zh': "✅☑啟用新身份證",
    'ar': "✅☑ تمكين حظر معرف جديد",
}
l_cuser_utm_off = {
    'ru': "☑️☐Выкл utm-рефералы",
    'en': "☑️☐Off reaction to media",
    'es': "☑️☐De nueva-id-ban",
    'fr': "☑️☐De nouveau-id-ban",
    'zh': "☑️☐關閉新身份證",
    'ar': "☑️☐ تعطيل حظر معرف جديد",
}
l_bot_is_off = {
    'ru': "👩🏽‍💻 <b>@{0}-бот</b> выключен\n\n/on - включить бот",
    'en': "👩🏽‍💻 <b>Account:</b> is off\n\n/on - to on bot",
    'es': "💳 Agregar grupo",
    'fr': "💳 Ajouter un bote",
    'zh': "💳 添加組",
    'ar': "💳 إضافة مجموعة",
}
l_cuser_utm = {
    'ru': "👥 <b>Готово!</b> <b>/utm-список</b> реферальных пользователей @{0}-бота\n\n👩🏽‍💻 <b>Вывести</b> рефералов конкретного пользователя можно командой:\n<code>/utm id</code> или <code>/utm @username</code>\n\n👩🏽‍💻 <b>Текущее</b> число utm-рефералов: <u>{1}</u>",
    'en': "👥 Ready! Gathered members: <u>{0}</u>. You can immediately make an <b>sending</b> or <b>inviting</b> to channel by received members{1}",
    'es': "👥 Listo! Miembros reunidos: <u>{0}</u>. Inmediatamente puede hacer un <b>envío</b> o <b>invitación</b> al grupo por miembros recibidos{1}",
    'fr': "👥 Prêt ! Membres réunis : <u>{0}</u>. Vous pouvez immédiatement faire un <b>envoi</b> ou <b>inviter</b> pour channeler par membres reçus{1}",
    'zh': "👥 準備好了！ 聚集成員：<u>{0}</u>。 您可以立即<b>發送</b>或<b>邀請</b>按收到的成員分組{1}",
    'ar': "🔥 جاهز! الأعضاء الذين تم تجميعهم: <u>{0}</u>. يمكنك على الفور إجراء <b> إرسال </b> أو <b> دعوة </b> للانضمام إلى المجموعة بواسطة الأعضاء المستلمين {1}",
}
l_cuser_link_done = {
    'ru': "👥 <b>Готово!</b> Реферальная /utm ссылка на @{0}-бота (размести ее на любой площадке, чтобы понимать, что пользователи перешли в бота с этой площадки):\n\n<code>{1}</code>",
    'en': "👥 Ready! Gathered members: <u>{0}</u>. You can immediately make an <b>sending</b> or <b>inviting</b> to channel by received members{1}",
    'es': "👥 Listo! Miembros reunidos: <u>{0}</u>. Inmediatamente puede hacer un <b>envío</b> o <b>invitación</b> al grupo por miembros recibidos{1}",
    'fr': "👥 Prêt ! Membres réunis : <u>{0}</u>. Vous pouvez immédiatement faire un <b>envoi</b> ou <b>inviter</b> pour channeler par membres reçus{1}",
    'zh': "👥 準備好了！ 聚集成員：<u>{0}</u>。 您可以立即<b>發送</b>或<b>邀請</b>按收到的成員分組{1}",
    'ar': "🔥 جاهز! الأعضاء الذين تم تجميعهم: <u>{0}</u>. يمكنك على الفور إجراء <b> إرسال </b> أو <b> دعوة </b> للانضمام إلى المجموعة بواسطة الأعضاء المستلمين {1}",
}
l_cuser_link_start = {
    'ru': "👥 <b>Придумай</b> название для /utm ссылки (*после <code>?start=</code> может быть <u>любое</u> имя источника из цифр и/или латинских букв)\n\n👩🏽‍💻 <b>Например</b>, ссылки /utm-рефералов для отслеживания:\nhttps://t.me/{0}?start={1} - <i>реферальных пользователей</i> <code>{1}</code>-<i>пользователя</i>\nhttps://t.me/{0}?start=instagram - <i>пользователей из instagram</i>",
    'en': "👥 Ready! Gathered members: <u>{0}</u>. You can immediately make an <b>sending</b> or <b>inviting</b> to channel by received members{1}",
    'es': "👥 Listo! Miembros reunidos: <u>{0}</u>. Inmediatamente puede hacer un <b>envío</b> o <b>invitación</b> al grupo por miembros recibidos{1}",
    'fr': "👥 Prêt ! Membres réunis : <u>{0}</u>. Vous pouvez immédiatement faire un <b>envoi</b> ou <b>inviter</b> pour channeler par membres reçus{1}",
    'zh': "👥 準備好了！ 聚集成員：<u>{0}</u>。 您可以立即<b>發送</b>或<b>邀請</b>按收到的成員分組{1}",
    'ar': "🔥 جاهز! الأعضاء الذين تم تجميعهم: <u>{0}</u>. يمكنك على الفور إجراء <b> إرسال </b> أو <b> دعوة </b> للانضمام إلى المجموعة بواسطة الأعضاء المستلمين {1}",
}
l_promo_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b>\n\n👩🏽‍💻 <i>Текущий /promo-код</i>:\n<code>{0}</code>\n👩🏽‍💻 <i>Удалить /promo-код</i>:\n<code>/promo 0</code>",
    'en': "👩🏽‍💻 Ready! Gathered members: <u>{0}</u>. You can immediately make an <b>sending</b> or <b>inviting</b> to channel by received members{1}",
    'es': "👩🏽‍💻 Listo! Miembros reunidos: <u>{0}</u>. Inmediatamente puede hacer un <b>envío</b> o <b>invitación</b> al grupo por miembros recibidos{1}",
    'fr': "👩🏽‍💻 Prêt ! Membres réunis : <u>{0}</u>. Vous pouvez immédiatement faire un <b>envoi</b> ou <b>inviter</b> pour channeler par membres reçus{1}",
    'zh': "👩🏽‍💻 準備好了！ 聚集成員：<u>{0}</u>。 您可以立即<b>發送</b>或<b>邀請</b>按收到的成員分組{1}",
    'ar': "🔥 جاهز! الأعضاء الذين تم تجميعهم: <u>{0}</u>. يمكنك على الفور إجراء <b> إرسال </b> أو <b> دعوة </b> للانضمام إلى المجموعة بواسطة الأعضاء المستلمين {1}",
}
l_promo_start = {
    'ru': "👩🏽‍💻 <b>Введи</b> /promo-код для @{0}-бота:\n\n👩🏽‍💻 <i>Текущий /promo-код</i>:\n<code>{1}</code>\n👩🏽‍💻 <i>Удалить /promo-код</i>:\n<code>/promo 0</code>",
    'en': "👩🏽‍💻 Ready! Gathered members: <u>{0}</u>. You can immediately make an <b>sending</b> or <b>inviting</b> to channel by received members{1}",
    'es': "👩🏽‍💻 Listo! Miembros reunidos: <u>{0}</u>. Inmediatamente puede hacer un <b>envío</b> o <b>invitación</b> al grupo por miembros recibidos{1}",
    'fr': "👩🏽‍💻 Prêt ! Membres réunis : <u>{0}</u>. Vous pouvez immédiatement faire un <b>envoi</b> ou <b>inviter</b> pour channeler par membres reçus{1}",
    'zh': "👩🏽‍💻 準備好了！ 聚集成員：<u>{0}</u>。 您可以立即<b>發送</b>或<b>邀請</b>按收到的成員分組{1}",
    'ar': "🔥 جاهز! الأعضاء الذين تم تجميعهم: <u>{0}</u>. يمكنك على الفور إجراء <b> إرسال </b> أو <b> دعوة </b> للانضمام إلى المجموعة بواسطة الأعضاء المستلمين {1}",
}
# endregion


# region cadmin_
l_cadmin_text2 = {
    'ru': "👮🏽 <b>Жми</b> на ✅/☑️ чтобы <b>Вкл/Выкл</b> <i>доступ добавленных администраторов к функционалу <b>[💬 Оповещения]</b></i>\n\n👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/admin - добавить/удалить администратора\n/parse - вывести всех пользователей",
    'en': "👮🏽 Push the ✅/☑️ to <b>On/Off</b> auto-transcribe (speach to text) for <i><b>income</b>/<b>outgoing</b> messages</i>",
    'es': "👮🏽 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "👮🏽 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "👮🏽 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
l_cadmin_done = {
    'ru': "👮🏽 <b>Готово!</b>/admin-список @{0}-бота:\n\n{1}\n\n👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/admin - добавить/удалить администратора\n/parse - вывести всех пользователей\n\n👩🏽‍💻 <b>Текущее</b> число администраторов: <u>{2}/10</u>",
    'en': "🗣 Push the ✅/☑️ to <b>On/Off</b> auto-transcribe (speach to text) for <i><b>income</b>/<b>outgoing</b> messages</i>",
    'es': "🗣 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "🗣 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "🗣 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
l_cadmin_add = {
    'ru': "👮🏽 <b>Введи</b> <code>id</code> пользователей через пробельные символы или разделители, чтобы добавить их в /admin-список\n\n👩🏽‍💻 <b>Текущее</b> число администраторов: <u>{0}</u>",
    'en': "🗣 Push the ✅/☑️ to <b>On/Off</b> auto-transcribe (speach to text) for <i><b>income</b>/<b>outgoing</b> messages</i>",
    'es': "🗣 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "🗣 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "🗣 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
l_cadmin_remove = {
    'ru': "👮🏽 <b>Введи</b> <code>id</code> пользователей через пробельные символы или разделители, чтобы удалить их из /admin-список\n\n👩🏽‍💻 <b>Текущее</b> число администраторов: <u>{0}</u>",
    'en': "🗣 Push the ✅/☑️ to <b>On/Off</b> auto-transcribe (speach to text) for <i><b>income</b>/<b>outgoing</b> messages</i>",
    'es': "🗣 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "🗣 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "🗣 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
l_parse_text = {
    'ru': "👩🏽‍💻 <b>Готово!</b> Парсинг пользователей (<u>{0}</u>) @{1}-бота\n\n👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/parse - вывести всех пользователей\n<code>/parse premium</code> - вывести premium-пользователей\n<code>/parse admin</code> - вывести admin-пользователей\n<code>/parse utm</code> - вывести utm-рефералов\n",
    'en': "🗣 Push the ✅/☑️ to <b>On/Off</b> auto-transcribe (speach to text) for <i><b>income</b>/<b>outgoing</b> messages</i>",
    'es': "🗣 Presiona ✅/☑️ para <b>Encender/Apagar</b> <i>sistema</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <i>Usuario se unió al grupo</i>",
    'fr': "🗣 Appuyez sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a rejoint le bote</i>",
    'zh': "🗣 將 ✅/☑️ 推送到 <b>On/Off</b> <i>system</i> 消息\n\n👩🏽‍💻 例如，<i>用戶加入群組</i>",
    'ar': "👣 اضغط على ✅ / ☑️ ، إلى رسائل <b> تشغيل / إيقاف </b> <i> النظام </i>\n\n👩🏽‍💻 على سبيل المثال ، <i> انضم المستخدم إلى المجموعة </i>",
}
# endregion
# endregion


# region client
l_idea = {
    'ru': "💡 Идея!",
    'en': "💡 Idea!",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
l_have_read = {
    'ru': "👩🏽‍💻 <code>{0}</code> прочитал сообщение",
    'en': "👩🏽‍💻 <code>{0}</code> read message",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
l_telegraph_title = {
    'ru': "📰 Telegraph блог",
    'en': "📰 Telegraph blog",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
l_telegraph_blog = {
    'ru': "<figure><img src='{0}'/><figcaption>Фото профиля: @{1}</figcaption></figure><blockquote>Лэндинг-блог для продвижения в <i>Telegram</i></blockquote>👩🏽‍💻 <b>бот:</b> {2}<br>[<b>id</b>=<code>{3}</code>]<br><b>Био:</b> {4}<br><aside>Описание</aside>{5}",
    'en': "<figure><img src='{0}'/><figcaption>Profile photo: @{1}</figcaption></figure><blockquote>Landing-blog in <i>Telegram</i></blockquote>👩🏽‍💻 <b>Account:</b> {2}<br>[<b>id</b>=<code>{3}</code>]<br><b>Bio:</b> {4}<br><aside>Telegram-channel of expert</aside><aside><a href='https://t.me/{5}'>Subscribe</a></aside>",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
# endregion


# region extra bot
l_show_admin_panel_md = {
    'ru': "*👩🏽‍💻 Создание и редактирование блога*\n\n👩🏽‍💻 Вы зашли как *Администратор* и можете создавать и редактировать блоги, но не удалять их\n\n¹ Авторизация по ссылке в браузере:\n`{0}`\n\n² Перейди (в течение 10сек) по нужной ссылке для редактирования публикации (жми, чтобы скопировать):\n\n",
    'en': "<b>👩🏽‍💻 Blog-publication creating & editing</b>\n\n👩🏽‍💻 You entered as <b>Administrator</b> - you can create and edit blog-publication, but not to delete them\n\n - Push the button [👩🏽‍💻 Authorization] (it has short lifetime)\n2 - Then: click on the nessesary link (for copy) to open it on a browser for editing:\n\n",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
l_show_admin_panel_html = {
    'ru': "<b>👩🏽‍💻 Создание и редактирование блога</b>\n\n👩🏽‍💻 Вы зашли как <b>Администратор</b> и можете создавать и редактировать блоги, но не удалять их\n\n1. Авторизация по ссылке в браузере:\n<code>{0}</code>\n\n2. Перейди (в течение 10сек) по нужной ссылке для редактирования публикации (жми, чтобы скопировать):\n\n",
    'en': "<b>👩🏽‍💻 Blog-publication creating & editing</b>\n\n👩🏽‍💻 You entered as <b>Administrator</b> - you can create and edit blog-publication, but not to delete them\n\n - Push the button [👩🏽‍💻 Authorization] (it has short lifetime)\n2 - Then: click on the nessesary link (for copy) to open it on a browser for editing:\n\n",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
l_show_admin_panel_create = {
    'ru': "🆕 Создать",
    'en': "🆕 Create publication",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
l_show_admin_panel_auth = {
    'ru': "👩🏽‍💻 Авторизация",
    'en': "👩🏽‍💻 Authorization",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
# endregion


# endregion
